@@ -203,6 +203,7 @@ class Subscribe(core.Gs2Model):
     room_name: str = None
     notification_types: List[NotificationType] = None
     created_at: int = None
+    revision: int = None
 
     def with_subscribe_id(self, subscribe_id: str) -> Subscribe:
         self.subscribe_id = subscribe_id
@@ -224,6 +225,10 @@ class Subscribe(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Subscribe:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -313,22 +318,24 @@ class Subscribe(core.Gs2Model):
             .with_subscribe_id(data.get('subscribeId'))\
             .with_user_id(data.get('userId'))\
             .with_room_name(data.get('roomName'))\
-            .with_notification_types([
+            .with_notification_types(None if data.get('notificationTypes') is None else [
                 NotificationType.from_dict(data.get('notificationTypes')[i])
-                for i in range(len(data.get('notificationTypes')) if data.get('notificationTypes') else 0)
+                for i in range(len(data.get('notificationTypes')))
             ])\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "subscribeId": self.subscribe_id,
             "userId": self.user_id,
             "roomName": self.room_name,
-            "notificationTypes": [
+            "notificationTypes": None if self.notification_types is None else [
                 self.notification_types[i].to_dict() if self.notification_types[i] else None
-                for i in range(len(self.notification_types) if self.notification_types else 0)
+                for i in range(len(self.notification_types))
             ],
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -340,6 +347,7 @@ class Message(core.Gs2Model):
     category: int = None
     metadata: str = None
     created_at: int = None
+    revision: int = None
 
     def with_message_id(self, message_id: str) -> Message:
         self.message_id = message_id
@@ -369,6 +377,10 @@ class Message(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Message:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -461,7 +473,8 @@ class Message(core.Gs2Model):
             .with_user_id(data.get('userId'))\
             .with_category(data.get('category'))\
             .with_metadata(data.get('metadata'))\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -472,6 +485,7 @@ class Message(core.Gs2Model):
             "category": self.category,
             "metadata": self.metadata,
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -484,6 +498,7 @@ class Room(core.Gs2Model):
     white_list_user_ids: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_room_id(self, room_id: str) -> Room:
         self.room_id = room_id
@@ -517,6 +532,10 @@ class Room(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Room:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -596,12 +615,13 @@ class Room(core.Gs2Model):
             .with_user_id(data.get('userId'))\
             .with_metadata(data.get('metadata'))\
             .with_password(data.get('password'))\
-            .with_white_list_user_ids([
+            .with_white_list_user_ids(None if data.get('whiteListUserIds') is None else [
                 data.get('whiteListUserIds')[i]
-                for i in range(len(data.get('whiteListUserIds')) if data.get('whiteListUserIds') else 0)
+                for i in range(len(data.get('whiteListUserIds')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -610,12 +630,13 @@ class Room(core.Gs2Model):
             "userId": self.user_id,
             "metadata": self.metadata,
             "password": self.password,
-            "whiteListUserIds": [
+            "whiteListUserIds": None if self.white_list_user_ids is None else [
                 self.white_list_user_ids[i]
-                for i in range(len(self.white_list_user_ids) if self.white_list_user_ids else 0)
+                for i in range(len(self.white_list_user_ids))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -624,6 +645,7 @@ class Namespace(core.Gs2Model):
     name: str = None
     description: str = None
     allow_create_room: bool = None
+    message_life_time_days: int = None
     post_message_script: ScriptSetting = None
     create_room_script: ScriptSetting = None
     delete_room_script: ScriptSetting = None
@@ -633,6 +655,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -650,6 +673,10 @@ class Namespace(core.Gs2Model):
         self.allow_create_room = allow_create_room
         return self
 
+    def with_message_life_time_days(self, message_life_time_days: int) -> Namespace:
+        self.message_life_time_days = message_life_time_days
+        return self
+
     def with_post_message_script(self, post_message_script: ScriptSetting) -> Namespace:
         self.post_message_script = post_message_script
         return self
@@ -686,6 +713,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -752,6 +783,7 @@ class Namespace(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_allow_create_room(data.get('allowCreateRoom'))\
+            .with_message_life_time_days(data.get('messageLifeTimeDays'))\
             .with_post_message_script(ScriptSetting.from_dict(data.get('postMessageScript')))\
             .with_create_room_script(ScriptSetting.from_dict(data.get('createRoomScript')))\
             .with_delete_room_script(ScriptSetting.from_dict(data.get('deleteRoomScript')))\
@@ -760,7 +792,8 @@ class Namespace(core.Gs2Model):
             .with_post_notification(NotificationSetting.from_dict(data.get('postNotification')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -768,6 +801,7 @@ class Namespace(core.Gs2Model):
             "name": self.name,
             "description": self.description,
             "allowCreateRoom": self.allow_create_room,
+            "messageLifeTimeDays": self.message_life_time_days,
             "postMessageScript": self.post_message_script.to_dict() if self.post_message_script else None,
             "createRoomScript": self.create_room_script.to_dict() if self.create_room_script else None,
             "deleteRoomScript": self.delete_room_script.to_dict() if self.delete_room_script else None,
@@ -777,4 +811,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
