@@ -59,6 +59,7 @@ class DataObjectHistory(core.Gs2Model):
     generation: str = None
     content_length: int = None
     created_at: int = None
+    revision: int = None
 
     def with_data_object_history_id(self, data_object_history_id: str) -> DataObjectHistory:
         self.data_object_history_id = data_object_history_id
@@ -80,6 +81,10 @@ class DataObjectHistory(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> DataObjectHistory:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -182,7 +187,8 @@ class DataObjectHistory(core.Gs2Model):
             .with_data_object_name(data.get('dataObjectName'))\
             .with_generation(data.get('generation'))\
             .with_content_length(data.get('contentLength'))\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -191,6 +197,7 @@ class DataObjectHistory(core.Gs2Model):
             "generation": self.generation,
             "contentLength": self.content_length,
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -205,6 +212,7 @@ class DataObject(core.Gs2Model):
     previous_generation: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_data_object_id(self, data_object_id: str) -> DataObject:
         self.data_object_id = data_object_id
@@ -246,6 +254,10 @@ class DataObject(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> DataObject:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -336,15 +348,16 @@ class DataObject(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_user_id(data.get('userId'))\
             .with_scope(data.get('scope'))\
-            .with_allow_user_ids([
+            .with_allow_user_ids(None if data.get('allowUserIds') is None else [
                 data.get('allowUserIds')[i]
-                for i in range(len(data.get('allowUserIds')) if data.get('allowUserIds') else 0)
+                for i in range(len(data.get('allowUserIds')))
             ])\
             .with_status(data.get('status'))\
             .with_generation(data.get('generation'))\
             .with_previous_generation(data.get('previousGeneration'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -352,15 +365,16 @@ class DataObject(core.Gs2Model):
             "name": self.name,
             "userId": self.user_id,
             "scope": self.scope,
-            "allowUserIds": [
+            "allowUserIds": None if self.allow_user_ids is None else [
                 self.allow_user_ids[i]
-                for i in range(len(self.allow_user_ids) if self.allow_user_ids else 0)
+                for i in range(len(self.allow_user_ids))
             ],
             "status": self.status,
             "generation": self.generation,
             "previousGeneration": self.previous_generation,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -427,6 +441,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -456,6 +471,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -524,7 +543,8 @@ class Namespace(core.Gs2Model):
             .with_done_upload_script(ScriptSetting.from_dict(data.get('doneUploadScript')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -535,4 +555,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
