@@ -282,6 +282,350 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class DumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> DumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> DumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckDumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckDumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckDumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckCleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckCleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckCleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class PrepareImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> PrepareImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class ImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> ImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> ImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> ImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
 class DescribeDataObjectsRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -354,6 +698,7 @@ class DescribeDataObjectsByUserIdRequest(core.Gs2Request):
     status: str = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeDataObjectsByUserIdRequest:
         self.namespace_name = namespace_name
@@ -375,6 +720,10 @@ class DescribeDataObjectsByUserIdRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeDataObjectsByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -398,7 +747,8 @@ class DescribeDataObjectsByUserIdRequest(core.Gs2Request):
             .with_user_id(data.get('userId'))\
             .with_status(data.get('status'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -407,6 +757,7 @@ class DescribeDataObjectsByUserIdRequest(core.Gs2Request):
             "status": self.status,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -478,9 +829,9 @@ class PrepareUploadRequest(core.Gs2Request):
             .with_name(data.get('name'))\
             .with_content_type(data.get('contentType'))\
             .with_scope(data.get('scope'))\
-            .with_allow_user_ids([
+            .with_allow_user_ids(None if data.get('allowUserIds') is None else [
                 data.get('allowUserIds')[i]
-                for i in range(len(data.get('allowUserIds')) if data.get('allowUserIds') else 0)
+                for i in range(len(data.get('allowUserIds')))
             ])\
             .with_update_if_exists(data.get('updateIfExists'))
 
@@ -491,9 +842,9 @@ class PrepareUploadRequest(core.Gs2Request):
             "name": self.name,
             "contentType": self.content_type,
             "scope": self.scope,
-            "allowUserIds": [
+            "allowUserIds": None if self.allow_user_ids is None else [
                 self.allow_user_ids[i]
-                for i in range(len(self.allow_user_ids) if self.allow_user_ids else 0)
+                for i in range(len(self.allow_user_ids))
             ],
             "updateIfExists": self.update_if_exists,
         }
@@ -509,6 +860,7 @@ class PrepareUploadByUserIdRequest(core.Gs2Request):
     scope: str = None
     allow_user_ids: List[str] = None
     update_if_exists: bool = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareUploadByUserIdRequest:
@@ -539,6 +891,10 @@ class PrepareUploadByUserIdRequest(core.Gs2Request):
         self.update_if_exists = update_if_exists
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareUploadByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PrepareUploadByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -567,11 +923,12 @@ class PrepareUploadByUserIdRequest(core.Gs2Request):
             .with_name(data.get('name'))\
             .with_content_type(data.get('contentType'))\
             .with_scope(data.get('scope'))\
-            .with_allow_user_ids([
+            .with_allow_user_ids(None if data.get('allowUserIds') is None else [
                 data.get('allowUserIds')[i]
-                for i in range(len(data.get('allowUserIds')) if data.get('allowUserIds') else 0)
+                for i in range(len(data.get('allowUserIds')))
             ])\
-            .with_update_if_exists(data.get('updateIfExists'))
+            .with_update_if_exists(data.get('updateIfExists'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -580,11 +937,12 @@ class PrepareUploadByUserIdRequest(core.Gs2Request):
             "name": self.name,
             "contentType": self.content_type,
             "scope": self.scope,
-            "allowUserIds": [
+            "allowUserIds": None if self.allow_user_ids is None else [
                 self.allow_user_ids[i]
-                for i in range(len(self.allow_user_ids) if self.allow_user_ids else 0)
+                for i in range(len(self.allow_user_ids))
             ],
             "updateIfExists": self.update_if_exists,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -645,9 +1003,9 @@ class UpdateDataObjectRequest(core.Gs2Request):
             .with_data_object_name(data.get('dataObjectName'))\
             .with_access_token(data.get('accessToken'))\
             .with_scope(data.get('scope'))\
-            .with_allow_user_ids([
+            .with_allow_user_ids(None if data.get('allowUserIds') is None else [
                 data.get('allowUserIds')[i]
-                for i in range(len(data.get('allowUserIds')) if data.get('allowUserIds') else 0)
+                for i in range(len(data.get('allowUserIds')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -656,9 +1014,9 @@ class UpdateDataObjectRequest(core.Gs2Request):
             "dataObjectName": self.data_object_name,
             "accessToken": self.access_token,
             "scope": self.scope,
-            "allowUserIds": [
+            "allowUserIds": None if self.allow_user_ids is None else [
                 self.allow_user_ids[i]
-                for i in range(len(self.allow_user_ids) if self.allow_user_ids else 0)
+                for i in range(len(self.allow_user_ids))
             ],
         }
 
@@ -671,6 +1029,7 @@ class UpdateDataObjectByUserIdRequest(core.Gs2Request):
     user_id: str = None
     scope: str = None
     allow_user_ids: List[str] = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateDataObjectByUserIdRequest:
@@ -693,6 +1052,10 @@ class UpdateDataObjectByUserIdRequest(core.Gs2Request):
         self.allow_user_ids = allow_user_ids
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> UpdateDataObjectByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> UpdateDataObjectByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -720,10 +1083,11 @@ class UpdateDataObjectByUserIdRequest(core.Gs2Request):
             .with_data_object_name(data.get('dataObjectName'))\
             .with_user_id(data.get('userId'))\
             .with_scope(data.get('scope'))\
-            .with_allow_user_ids([
+            .with_allow_user_ids(None if data.get('allowUserIds') is None else [
                 data.get('allowUserIds')[i]
-                for i in range(len(data.get('allowUserIds')) if data.get('allowUserIds') else 0)
-            ])
+                for i in range(len(data.get('allowUserIds')))
+            ])\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -731,10 +1095,11 @@ class UpdateDataObjectByUserIdRequest(core.Gs2Request):
             "dataObjectName": self.data_object_name,
             "userId": self.user_id,
             "scope": self.scope,
-            "allowUserIds": [
+            "allowUserIds": None if self.allow_user_ids is None else [
                 self.allow_user_ids[i]
-                for i in range(len(self.allow_user_ids) if self.allow_user_ids else 0)
+                for i in range(len(self.allow_user_ids))
             ],
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -807,6 +1172,7 @@ class PrepareReUploadByUserIdRequest(core.Gs2Request):
     data_object_name: str = None
     user_id: str = None
     content_type: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareReUploadByUserIdRequest:
@@ -825,6 +1191,10 @@ class PrepareReUploadByUserIdRequest(core.Gs2Request):
         self.content_type = content_type
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareReUploadByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PrepareReUploadByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -851,7 +1221,8 @@ class PrepareReUploadByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_data_object_name(data.get('dataObjectName'))\
             .with_user_id(data.get('userId'))\
-            .with_content_type(data.get('contentType'))
+            .with_content_type(data.get('contentType'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -859,6 +1230,7 @@ class PrepareReUploadByUserIdRequest(core.Gs2Request):
             "dataObjectName": self.data_object_name,
             "userId": self.user_id,
             "contentType": self.content_type,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -923,6 +1295,7 @@ class DoneUploadByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     data_object_name: str = None
     user_id: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DoneUploadByUserIdRequest:
@@ -937,6 +1310,10 @@ class DoneUploadByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DoneUploadByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DoneUploadByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -962,13 +1339,15 @@ class DoneUploadByUserIdRequest(core.Gs2Request):
         return DoneUploadByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_data_object_name(data.get('dataObjectName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "dataObjectName": self.data_object_name,
             "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1033,6 +1412,7 @@ class DeleteDataObjectByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     data_object_name: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteDataObjectByUserIdRequest:
@@ -1047,6 +1427,10 @@ class DeleteDataObjectByUserIdRequest(core.Gs2Request):
         self.data_object_name = data_object_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DeleteDataObjectByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DeleteDataObjectByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1072,13 +1456,15 @@ class DeleteDataObjectByUserIdRequest(core.Gs2Request):
         return DeleteDataObjectByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_data_object_name(data.get('dataObjectName'))
+            .with_data_object_name(data.get('dataObjectName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "dataObjectName": self.data_object_name,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1143,6 +1529,7 @@ class PrepareDownloadByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     data_object_id: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadByUserIdRequest:
@@ -1157,6 +1544,10 @@ class PrepareDownloadByUserIdRequest(core.Gs2Request):
         self.data_object_id = data_object_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareDownloadByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1182,13 +1573,15 @@ class PrepareDownloadByUserIdRequest(core.Gs2Request):
         return PrepareDownloadByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_data_object_id(data.get('dataObjectId'))
+            .with_data_object_id(data.get('dataObjectId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "dataObjectId": self.data_object_id,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1261,6 +1654,7 @@ class PrepareDownloadByGenerationAndUserIdRequest(core.Gs2Request):
     user_id: str = None
     data_object_id: str = None
     generation: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadByGenerationAndUserIdRequest:
@@ -1279,6 +1673,10 @@ class PrepareDownloadByGenerationAndUserIdRequest(core.Gs2Request):
         self.generation = generation
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareDownloadByGenerationAndUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadByGenerationAndUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1305,7 +1703,8 @@ class PrepareDownloadByGenerationAndUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
             .with_data_object_id(data.get('dataObjectId'))\
-            .with_generation(data.get('generation'))
+            .with_generation(data.get('generation'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1313,6 +1712,7 @@ class PrepareDownloadByGenerationAndUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "dataObjectId": self.data_object_id,
             "generation": self.generation,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1377,6 +1777,7 @@ class PrepareDownloadByUserIdAndDataObjectNameRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     data_object_name: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadByUserIdAndDataObjectNameRequest:
@@ -1391,6 +1792,10 @@ class PrepareDownloadByUserIdAndDataObjectNameRequest(core.Gs2Request):
         self.data_object_name = data_object_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareDownloadByUserIdAndDataObjectNameRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadByUserIdAndDataObjectNameRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1416,13 +1821,15 @@ class PrepareDownloadByUserIdAndDataObjectNameRequest(core.Gs2Request):
         return PrepareDownloadByUserIdAndDataObjectNameRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_data_object_name(data.get('dataObjectName'))
+            .with_data_object_name(data.get('dataObjectName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "dataObjectName": self.data_object_name,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1495,6 +1902,7 @@ class PrepareDownloadByUserIdAndDataObjectNameAndGenerationRequest(core.Gs2Reque
     user_id: str = None
     data_object_name: str = None
     generation: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadByUserIdAndDataObjectNameAndGenerationRequest:
@@ -1513,6 +1921,10 @@ class PrepareDownloadByUserIdAndDataObjectNameAndGenerationRequest(core.Gs2Reque
         self.generation = generation
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareDownloadByUserIdAndDataObjectNameAndGenerationRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadByUserIdAndDataObjectNameAndGenerationRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1539,7 +1951,8 @@ class PrepareDownloadByUserIdAndDataObjectNameAndGenerationRequest(core.Gs2Reque
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
             .with_data_object_name(data.get('dataObjectName'))\
-            .with_generation(data.get('generation'))
+            .with_generation(data.get('generation'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1547,6 +1960,7 @@ class PrepareDownloadByUserIdAndDataObjectNameAndGenerationRequest(core.Gs2Reque
             "userId": self.user_id,
             "dataObjectName": self.data_object_name,
             "generation": self.generation,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1665,6 +2079,7 @@ class DescribeDataObjectHistoriesByUserIdRequest(core.Gs2Request):
     data_object_name: str = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeDataObjectHistoriesByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1686,6 +2101,10 @@ class DescribeDataObjectHistoriesByUserIdRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeDataObjectHistoriesByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1709,7 +2128,8 @@ class DescribeDataObjectHistoriesByUserIdRequest(core.Gs2Request):
             .with_user_id(data.get('userId'))\
             .with_data_object_name(data.get('dataObjectName'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1718,6 +2138,7 @@ class DescribeDataObjectHistoriesByUserIdRequest(core.Gs2Request):
             "dataObjectName": self.data_object_name,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1785,6 +2206,7 @@ class GetDataObjectHistoryByUserIdRequest(core.Gs2Request):
     user_id: str = None
     data_object_name: str = None
     generation: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetDataObjectHistoryByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1802,6 +2224,10 @@ class GetDataObjectHistoryByUserIdRequest(core.Gs2Request):
         self.generation = generation
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> GetDataObjectHistoryByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1824,7 +2250,8 @@ class GetDataObjectHistoryByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
             .with_data_object_name(data.get('dataObjectName'))\
-            .with_generation(data.get('generation'))
+            .with_generation(data.get('generation'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1832,4 +2259,5 @@ class GetDataObjectHistoryByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "dataObjectName": self.data_object_name,
             "generation": self.generation,
+            "timeOffsetToken": self.time_offset_token,
         }
\ No newline at end of file
