@@ -309,6 +309,121 @@ class CurrentEntryMaster(core.Gs2Model):
         }
 
 
+class Like(core.Gs2Model):
+    like_id: str = None
+    user_id: str = None
+    name: str = None
+
+    def with_like_id(self, like_id: str) -> Like:
+        self.like_id = like_id
+        return self
+
+    def with_user_id(self, user_id: str) -> Like:
+        self.user_id = user_id
+        return self
+
+    def with_name(self, name: str) -> Like:
+        self.name = name
+        return self
+
+    @classmethod
+    def create_grn(
+        cls,
+        region,
+        owner_id,
+        namespace_name,
+        user_id,
+        entry_model_name,
+    ):
+        return 'grn:gs2:{region}:{ownerId}:dictionary:{namespaceName}:user:{userId}:like:{entryModelName}'.format(
+            region=region,
+            ownerId=owner_id,
+            namespaceName=namespace_name,
+            userId=user_id,
+            entryModelName=entry_model_name,
+        )
+
+    @classmethod
+    def get_region_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):user:(?P<userId>.+):like:(?P<entryModelName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('region')
+
+    @classmethod
+    def get_owner_id_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):user:(?P<userId>.+):like:(?P<entryModelName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('owner_id')
+
+    @classmethod
+    def get_namespace_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):user:(?P<userId>.+):like:(?P<entryModelName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('namespace_name')
+
+    @classmethod
+    def get_user_id_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):user:(?P<userId>.+):like:(?P<entryModelName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('user_id')
+
+    @classmethod
+    def get_entry_model_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):user:(?P<userId>.+):like:(?P<entryModelName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('entry_model_name')
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[Like]:
+        if data is None:
+            return None
+        return Like()\
+            .with_like_id(data.get('likeId'))\
+            .with_user_id(data.get('userId'))\
+            .with_name(data.get('name'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "likeId": self.like_id,
+            "userId": self.user_id,
+            "name": self.name,
+        }
+
+
 class Entry(core.Gs2Model):
     entry_id: str = None
     user_id: str = None
@@ -438,6 +553,7 @@ class EntryModelMaster(core.Gs2Model):
     metadata: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_entry_model_id(self, entry_model_id: str) -> EntryModelMaster:
         self.entry_model_id = entry_model_id
@@ -463,19 +579,23 @@ class EntryModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> EntryModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
         region,
         owner_id,
         namespace_name,
-        entry_name,
+        entry_model_name,
     ):
-        return 'grn:gs2:{region}:{ownerId}:dictionary:{namespaceName}:model:{entryName}'.format(
+        return 'grn:gs2:{region}:{ownerId}:dictionary:{namespaceName}:model:{entryModelName}'.format(
             region=region,
             ownerId=owner_id,
             namespaceName=namespace_name,
-            entryName=entry_name,
+            entryModelName=entry_model_name,
         )
 
     @classmethod
@@ -483,7 +603,7 @@ class EntryModelMaster(core.Gs2Model):
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
         return match.group('region')
@@ -493,7 +613,7 @@ class EntryModelMaster(core.Gs2Model):
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
         return match.group('owner_id')
@@ -503,20 +623,20 @@ class EntryModelMaster(core.Gs2Model):
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
         return match.group('namespace_name')
 
     @classmethod
-    def get_entry_name_from_grn(
+    def get_entry_model_name_from_grn(
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
-        return match.group('entry_name')
+        return match.group('entry_model_name')
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -542,7 +662,8 @@ class EntryModelMaster(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -552,6 +673,7 @@ class EntryModelMaster(core.Gs2Model):
             "metadata": self.metadata,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -578,13 +700,13 @@ class EntryModel(core.Gs2Model):
         region,
         owner_id,
         namespace_name,
-        entry_name,
+        entry_model_name,
     ):
-        return 'grn:gs2:{region}:{ownerId}:dictionary:{namespaceName}:model:{entryName}'.format(
+        return 'grn:gs2:{region}:{ownerId}:dictionary:{namespaceName}:model:{entryModelName}'.format(
             region=region,
             ownerId=owner_id,
             namespaceName=namespace_name,
-            entryName=entry_name,
+            entryModelName=entry_model_name,
         )
 
     @classmethod
@@ -592,7 +714,7 @@ class EntryModel(core.Gs2Model):
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
         return match.group('region')
@@ -602,7 +724,7 @@ class EntryModel(core.Gs2Model):
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
         return match.group('owner_id')
@@ -612,20 +734,20 @@ class EntryModel(core.Gs2Model):
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
         return match.group('namespace_name')
 
     @classmethod
-    def get_entry_name_from_grn(
+    def get_entry_model_name_from_grn(
         cls,
         grn: str,
     ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryName>.+)', grn)
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):dictionary:(?P<namespaceName>.+):model:(?P<entryModelName>.+)', grn)
         if match is None:
             return None
-        return match.group('entry_name')
+        return match.group('entry_model_name')
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -663,10 +785,11 @@ class Namespace(core.Gs2Model):
     name: str = None
     description: str = None
     entry_script: ScriptSetting = None
-    duplicate_entry_script: ScriptSetting = None
+    duplicate_entry_script: str = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -684,7 +807,7 @@ class Namespace(core.Gs2Model):
         self.entry_script = entry_script
         return self
 
-    def with_duplicate_entry_script(self, duplicate_entry_script: ScriptSetting) -> Namespace:
+    def with_duplicate_entry_script(self, duplicate_entry_script: str) -> Namespace:
         self.duplicate_entry_script = duplicate_entry_script
         return self
 
@@ -700,6 +823,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -766,10 +893,11 @@ class Namespace(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_entry_script(ScriptSetting.from_dict(data.get('entryScript')))\
-            .with_duplicate_entry_script(ScriptSetting.from_dict(data.get('duplicateEntryScript')))\
+            .with_duplicate_entry_script(data.get('duplicateEntryScript'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -777,8 +905,9 @@ class Namespace(core.Gs2Model):
             "name": self.name,
             "description": self.description,
             "entryScript": self.entry_script.to_dict() if self.entry_script else None,
-            "duplicateEntryScript": self.duplicate_entry_script.to_dict() if self.duplicate_entry_script else None,
+            "duplicateEntryScript": self.duplicate_entry_script,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
