@@ -21,6 +21,9 @@ from gs2 import core
 
 class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
     queue_namespace_id: str = None
@@ -29,6 +32,18 @@ class TransactionSetting(core.Gs2Model):
         self.enable_auto_run = enable_auto_run
         return self
 
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
     def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
         self.distributor_namespace_id = distributor_namespace_id
         return self
@@ -61,6 +76,9 @@ class TransactionSetting(core.Gs2Model):
             return None
         return TransactionSetting()\
             .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))
@@ -68,6 +86,9 @@ class TransactionSetting(core.Gs2Model):
     def to_dict(self) -> Dict[str, Any]:
         return {
             "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
             "queueNamespaceId": self.queue_namespace_id,
@@ -280,6 +301,47 @@ class Config(core.Gs2Model):
         }
 
 
+class UnleashRateEntryModel(core.Gs2Model):
+    grade_value: int = None
+    need_count: int = None
+
+    def with_grade_value(self, grade_value: int) -> UnleashRateEntryModel:
+        self.grade_value = grade_value
+        return self
+
+    def with_need_count(self, need_count: int) -> UnleashRateEntryModel:
+        self.need_count = need_count
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[UnleashRateEntryModel]:
+        if data is None:
+            return None
+        return UnleashRateEntryModel()\
+            .with_grade_value(data.get('gradeValue'))\
+            .with_need_count(data.get('needCount'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "gradeValue": self.grade_value,
+            "needCount": self.need_count,
+        }
+
+
 class Material(core.Gs2Model):
     material_item_set_id: str = None
     count: int = None
@@ -456,6 +518,7 @@ class Progress(core.Gs2Model):
     rate: float = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_progress_id(self, progress_id: str) -> Progress:
         self.progress_id = progress_id
@@ -493,6 +556,10 @@ class Progress(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Progress:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -575,7 +642,8 @@ class Progress(core.Gs2Model):
             .with_experience_value(data.get('experienceValue'))\
             .with_rate(data.get('rate'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -588,6 +656,302 @@ class Progress(core.Gs2Model):
             "rate": self.rate,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
+        }
+
+
+class UnleashRateModelMaster(core.Gs2Model):
+    unleash_rate_model_id: str = None
+    name: str = None
+    description: str = None
+    metadata: str = None
+    target_inventory_model_id: str = None
+    grade_model_id: str = None
+    grade_entries: List[UnleashRateEntryModel] = None
+    created_at: int = None
+    updated_at: int = None
+    revision: int = None
+
+    def with_unleash_rate_model_id(self, unleash_rate_model_id: str) -> UnleashRateModelMaster:
+        self.unleash_rate_model_id = unleash_rate_model_id
+        return self
+
+    def with_name(self, name: str) -> UnleashRateModelMaster:
+        self.name = name
+        return self
+
+    def with_description(self, description: str) -> UnleashRateModelMaster:
+        self.description = description
+        return self
+
+    def with_metadata(self, metadata: str) -> UnleashRateModelMaster:
+        self.metadata = metadata
+        return self
+
+    def with_target_inventory_model_id(self, target_inventory_model_id: str) -> UnleashRateModelMaster:
+        self.target_inventory_model_id = target_inventory_model_id
+        return self
+
+    def with_grade_model_id(self, grade_model_id: str) -> UnleashRateModelMaster:
+        self.grade_model_id = grade_model_id
+        return self
+
+    def with_grade_entries(self, grade_entries: List[UnleashRateEntryModel]) -> UnleashRateModelMaster:
+        self.grade_entries = grade_entries
+        return self
+
+    def with_created_at(self, created_at: int) -> UnleashRateModelMaster:
+        self.created_at = created_at
+        return self
+
+    def with_updated_at(self, updated_at: int) -> UnleashRateModelMaster:
+        self.updated_at = updated_at
+        return self
+
+    def with_revision(self, revision: int) -> UnleashRateModelMaster:
+        self.revision = revision
+        return self
+
+    @classmethod
+    def create_grn(
+        cls,
+        region,
+        owner_id,
+        namespace_name,
+        rate_name,
+    ):
+        return 'grn:gs2:{region}:{ownerId}:enhance:{namespaceName}:unleashRateModelMaster:{rateName}'.format(
+            region=region,
+            ownerId=owner_id,
+            namespaceName=namespace_name,
+            rateName=rate_name,
+        )
+
+    @classmethod
+    def get_region_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModelMaster:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('region')
+
+    @classmethod
+    def get_owner_id_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModelMaster:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('owner_id')
+
+    @classmethod
+    def get_namespace_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModelMaster:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('namespace_name')
+
+    @classmethod
+    def get_rate_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModelMaster:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('rate_name')
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[UnleashRateModelMaster]:
+        if data is None:
+            return None
+        return UnleashRateModelMaster()\
+            .with_unleash_rate_model_id(data.get('unleashRateModelId'))\
+            .with_name(data.get('name'))\
+            .with_description(data.get('description'))\
+            .with_metadata(data.get('metadata'))\
+            .with_target_inventory_model_id(data.get('targetInventoryModelId'))\
+            .with_grade_model_id(data.get('gradeModelId'))\
+            .with_grade_entries(None if data.get('gradeEntries') is None else [
+                UnleashRateEntryModel.from_dict(data.get('gradeEntries')[i])
+                for i in range(len(data.get('gradeEntries')))
+            ])\
+            .with_created_at(data.get('createdAt'))\
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "unleashRateModelId": self.unleash_rate_model_id,
+            "name": self.name,
+            "description": self.description,
+            "metadata": self.metadata,
+            "targetInventoryModelId": self.target_inventory_model_id,
+            "gradeModelId": self.grade_model_id,
+            "gradeEntries": None if self.grade_entries is None else [
+                self.grade_entries[i].to_dict() if self.grade_entries[i] else None
+                for i in range(len(self.grade_entries))
+            ],
+            "createdAt": self.created_at,
+            "updatedAt": self.updated_at,
+            "revision": self.revision,
+        }
+
+
+class UnleashRateModel(core.Gs2Model):
+    unleash_rate_model_id: str = None
+    name: str = None
+    description: str = None
+    metadata: str = None
+    target_inventory_model_id: str = None
+    grade_model_id: str = None
+    grade_entries: List[UnleashRateEntryModel] = None
+
+    def with_unleash_rate_model_id(self, unleash_rate_model_id: str) -> UnleashRateModel:
+        self.unleash_rate_model_id = unleash_rate_model_id
+        return self
+
+    def with_name(self, name: str) -> UnleashRateModel:
+        self.name = name
+        return self
+
+    def with_description(self, description: str) -> UnleashRateModel:
+        self.description = description
+        return self
+
+    def with_metadata(self, metadata: str) -> UnleashRateModel:
+        self.metadata = metadata
+        return self
+
+    def with_target_inventory_model_id(self, target_inventory_model_id: str) -> UnleashRateModel:
+        self.target_inventory_model_id = target_inventory_model_id
+        return self
+
+    def with_grade_model_id(self, grade_model_id: str) -> UnleashRateModel:
+        self.grade_model_id = grade_model_id
+        return self
+
+    def with_grade_entries(self, grade_entries: List[UnleashRateEntryModel]) -> UnleashRateModel:
+        self.grade_entries = grade_entries
+        return self
+
+    @classmethod
+    def create_grn(
+        cls,
+        region,
+        owner_id,
+        namespace_name,
+        rate_name,
+    ):
+        return 'grn:gs2:{region}:{ownerId}:enhance:{namespaceName}:unleashRateModel:{rateName}'.format(
+            region=region,
+            ownerId=owner_id,
+            namespaceName=namespace_name,
+            rateName=rate_name,
+        )
+
+    @classmethod
+    def get_region_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModel:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('region')
+
+    @classmethod
+    def get_owner_id_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModel:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('owner_id')
+
+    @classmethod
+    def get_namespace_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModel:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('namespace_name')
+
+    @classmethod
+    def get_rate_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):enhance:(?P<namespaceName>.+):unleashRateModel:(?P<rateName>.+)', grn)
+        if match is None:
+            return None
+        return match.group('rate_name')
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[UnleashRateModel]:
+        if data is None:
+            return None
+        return UnleashRateModel()\
+            .with_unleash_rate_model_id(data.get('unleashRateModelId'))\
+            .with_name(data.get('name'))\
+            .with_description(data.get('description'))\
+            .with_metadata(data.get('metadata'))\
+            .with_target_inventory_model_id(data.get('targetInventoryModelId'))\
+            .with_grade_model_id(data.get('gradeModelId'))\
+            .with_grade_entries(None if data.get('gradeEntries') is None else [
+                UnleashRateEntryModel.from_dict(data.get('gradeEntries')[i])
+                for i in range(len(data.get('gradeEntries')))
+            ])
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "unleashRateModelId": self.unleash_rate_model_id,
+            "name": self.name,
+            "description": self.description,
+            "metadata": self.metadata,
+            "targetInventoryModelId": self.target_inventory_model_id,
+            "gradeModelId": self.grade_model_id,
+            "gradeEntries": None if self.grade_entries is None else [
+                self.grade_entries[i].to_dict() if self.grade_entries[i] else None
+                for i in range(len(self.grade_entries))
+            ],
         }
 
 
@@ -604,6 +968,7 @@ class RateModelMaster(core.Gs2Model):
     bonus_rates: List[BonusRate] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_rate_model_id(self, rate_model_id: str) -> RateModelMaster:
         self.rate_model_id = rate_model_id
@@ -653,6 +1018,10 @@ class RateModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> RateModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -734,17 +1103,18 @@ class RateModelMaster(core.Gs2Model):
             .with_target_inventory_model_id(data.get('targetInventoryModelId'))\
             .with_acquire_experience_suffix(data.get('acquireExperienceSuffix'))\
             .with_material_inventory_model_id(data.get('materialInventoryModelId'))\
-            .with_acquire_experience_hierarchy([
+            .with_acquire_experience_hierarchy(None if data.get('acquireExperienceHierarchy') is None else [
                 data.get('acquireExperienceHierarchy')[i]
-                for i in range(len(data.get('acquireExperienceHierarchy')) if data.get('acquireExperienceHierarchy') else 0)
+                for i in range(len(data.get('acquireExperienceHierarchy')))
             ])\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_bonus_rates([
+            .with_bonus_rates(None if data.get('bonusRates') is None else [
                 BonusRate.from_dict(data.get('bonusRates')[i])
-                for i in range(len(data.get('bonusRates')) if data.get('bonusRates') else 0)
+                for i in range(len(data.get('bonusRates')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -755,17 +1125,18 @@ class RateModelMaster(core.Gs2Model):
             "targetInventoryModelId": self.target_inventory_model_id,
             "acquireExperienceSuffix": self.acquire_experience_suffix,
             "materialInventoryModelId": self.material_inventory_model_id,
-            "acquireExperienceHierarchy": [
+            "acquireExperienceHierarchy": None if self.acquire_experience_hierarchy is None else [
                 self.acquire_experience_hierarchy[i]
-                for i in range(len(self.acquire_experience_hierarchy) if self.acquire_experience_hierarchy else 0)
+                for i in range(len(self.acquire_experience_hierarchy))
             ],
             "experienceModelId": self.experience_model_id,
-            "bonusRates": [
+            "bonusRates": None if self.bonus_rates is None else [
                 self.bonus_rates[i].to_dict() if self.bonus_rates[i] else None
-                for i in range(len(self.bonus_rates) if self.bonus_rates else 0)
+                for i in range(len(self.bonus_rates))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -902,14 +1273,14 @@ class RateModel(core.Gs2Model):
             .with_target_inventory_model_id(data.get('targetInventoryModelId'))\
             .with_acquire_experience_suffix(data.get('acquireExperienceSuffix'))\
             .with_material_inventory_model_id(data.get('materialInventoryModelId'))\
-            .with_acquire_experience_hierarchy([
+            .with_acquire_experience_hierarchy(None if data.get('acquireExperienceHierarchy') is None else [
                 data.get('acquireExperienceHierarchy')[i]
-                for i in range(len(data.get('acquireExperienceHierarchy')) if data.get('acquireExperienceHierarchy') else 0)
+                for i in range(len(data.get('acquireExperienceHierarchy')))
             ])\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_bonus_rates([
+            .with_bonus_rates(None if data.get('bonusRates') is None else [
                 BonusRate.from_dict(data.get('bonusRates')[i])
-                for i in range(len(data.get('bonusRates')) if data.get('bonusRates') else 0)
+                for i in range(len(data.get('bonusRates')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -921,14 +1292,14 @@ class RateModel(core.Gs2Model):
             "targetInventoryModelId": self.target_inventory_model_id,
             "acquireExperienceSuffix": self.acquire_experience_suffix,
             "materialInventoryModelId": self.material_inventory_model_id,
-            "acquireExperienceHierarchy": [
+            "acquireExperienceHierarchy": None if self.acquire_experience_hierarchy is None else [
                 self.acquire_experience_hierarchy[i]
-                for i in range(len(self.acquire_experience_hierarchy) if self.acquire_experience_hierarchy else 0)
+                for i in range(len(self.acquire_experience_hierarchy))
             ],
             "experienceModelId": self.experience_model_id,
-            "bonusRates": [
+            "bonusRates": None if self.bonus_rates is None else [
                 self.bonus_rates[i].to_dict() if self.bonus_rates[i] else None
-                for i in range(len(self.bonus_rates) if self.bonus_rates else 0)
+                for i in range(len(self.bonus_rates))
             ],
         }
 
@@ -937,14 +1308,15 @@ class Namespace(core.Gs2Model):
     namespace_id: str = None
     name: str = None
     description: str = None
-    enable_direct_enhance: bool = None
     transaction_setting: TransactionSetting = None
     enhance_script: ScriptSetting = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    enable_direct_enhance: bool = None
     queue_namespace_id: str = None
     key_id: str = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -958,10 +1330,6 @@ class Namespace(core.Gs2Model):
         self.description = description
         return self
 
-    def with_enable_direct_enhance(self, enable_direct_enhance: bool) -> Namespace:
-        self.enable_direct_enhance = enable_direct_enhance
-        return self
-
     def with_transaction_setting(self, transaction_setting: TransactionSetting) -> Namespace:
         self.transaction_setting = transaction_setting
         return self
@@ -982,6 +1350,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_enable_direct_enhance(self, enable_direct_enhance: bool) -> Namespace:
+        self.enable_direct_enhance = enable_direct_enhance
+        return self
+
     def with_queue_namespace_id(self, queue_namespace_id: str) -> Namespace:
         self.queue_namespace_id = queue_namespace_id
         return self
@@ -990,6 +1362,10 @@ class Namespace(core.Gs2Model):
         self.key_id = key_id
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1055,26 +1431,28 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
-            .with_enable_direct_enhance(data.get('enableDirectEnhance'))\
             .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_enhance_script(ScriptSetting.from_dict(data.get('enhanceScript')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
+            .with_enable_direct_enhance(data.get('enableDirectEnhance'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
-            .with_key_id(data.get('keyId'))
+            .with_key_id(data.get('keyId'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
-            "enableDirectEnhance": self.enable_direct_enhance,
             "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "enhanceScript": self.enhance_script.to_dict() if self.enhance_script else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "enableDirectEnhance": self.enable_direct_enhance,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
+            "revision": self.revision,
         }
\ No newline at end of file
