@@ -21,6 +21,9 @@ from gs2 import core
 
 class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
     queue_namespace_id: str = None
@@ -29,6 +32,18 @@ class TransactionSetting(core.Gs2Model):
         self.enable_auto_run = enable_auto_run
         return self
 
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
     def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
         self.distributor_namespace_id = distributor_namespace_id
         return self
@@ -61,6 +76,9 @@ class TransactionSetting(core.Gs2Model):
             return None
         return TransactionSetting()\
             .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))
@@ -68,6 +86,9 @@ class TransactionSetting(core.Gs2Model):
     def to_dict(self) -> Dict[str, Any]:
         return {
             "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
             "queueNamespaceId": self.queue_namespace_id,
@@ -280,6 +301,47 @@ class Config(core.Gs2Model):
         }
 
 
+class VerifyAction(core.Gs2Model):
+    action: str = None
+    request: str = None
+
+    def with_action(self, action: str) -> VerifyAction:
+        self.action = action
+        return self
+
+    def with_request(self, request: str) -> VerifyAction:
+        self.request = request
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyAction]:
+        if data is None:
+            return None
+        return VerifyAction()\
+            .with_action(data.get('action'))\
+            .with_request(data.get('request'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "action": self.action,
+            "request": self.request,
+        }
+
+
 class ConsumeAction(core.Gs2Model):
     action: str = None
     request: str = None
@@ -362,13 +424,125 @@ class AcquireAction(core.Gs2Model):
         }
 
 
+class LogRate(core.Gs2Model):
+    base: float = None
+    logs: List[float] = None
+
+    def with_base(self, base: float) -> LogRate:
+        self.base = base
+        return self
+
+    def with_logs(self, logs: List[float]) -> LogRate:
+        self.logs = logs
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[LogRate]:
+        if data is None:
+            return None
+        return LogRate()\
+            .with_base(data.get('base'))\
+            .with_logs(None if data.get('logs') is None else [
+                data.get('logs')[i]
+                for i in range(len(data.get('logs')))
+            ])
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "base": self.base,
+            "logs": None if self.logs is None else [
+                self.logs[i]
+                for i in range(len(self.logs))
+            ],
+        }
+
+
+class LogCost(core.Gs2Model):
+    base: float = None
+    adds: List[float] = None
+    subs: List[float] = None
+
+    def with_base(self, base: float) -> LogCost:
+        self.base = base
+        return self
+
+    def with_adds(self, adds: List[float]) -> LogCost:
+        self.adds = adds
+        return self
+
+    def with_subs(self, subs: List[float]) -> LogCost:
+        self.subs = subs
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[LogCost]:
+        if data is None:
+            return None
+        return LogCost()\
+            .with_base(data.get('base'))\
+            .with_adds(None if data.get('adds') is None else [
+                data.get('adds')[i]
+                for i in range(len(data.get('adds')))
+            ])\
+            .with_subs(None if data.get('subs') is None else [
+                data.get('subs')[i]
+                for i in range(len(data.get('subs')))
+            ])
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "base": self.base,
+            "adds": None if self.adds is None else [
+                self.adds[i]
+                for i in range(len(self.adds))
+            ],
+            "subs": None if self.subs is None else [
+                self.subs[i]
+                for i in range(len(self.subs))
+            ],
+        }
+
+
 class Await(core.Gs2Model):
     await_id: str = None
     user_id: str = None
     rate_name: str = None
     name: str = None
     count: int = None
+    skip_seconds: int = None
+    config: List[Config] = None
+    acquirable_at: int = None
     exchanged_at: int = None
+    created_at: int = None
+    revision: int = None
 
     def with_await_id(self, await_id: str) -> Await:
         self.await_id = await_id
@@ -390,10 +564,30 @@ class Await(core.Gs2Model):
         self.count = count
         return self
 
+    def with_skip_seconds(self, skip_seconds: int) -> Await:
+        self.skip_seconds = skip_seconds
+        return self
+
+    def with_config(self, config: List[Config]) -> Await:
+        self.config = config
+        return self
+
+    def with_acquirable_at(self, acquirable_at: int) -> Await:
+        self.acquirable_at = acquirable_at
+        return self
+
     def with_exchanged_at(self, exchanged_at: int) -> Await:
         self.exchanged_at = exchanged_at
         return self
 
+    def with_created_at(self, created_at: int) -> Await:
+        self.created_at = created_at
+        return self
+
+    def with_revision(self, revision: int) -> Await:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -485,7 +679,15 @@ class Await(core.Gs2Model):
             .with_rate_name(data.get('rateName'))\
             .with_name(data.get('name'))\
             .with_count(data.get('count'))\
-            .with_exchanged_at(data.get('exchangedAt'))
+            .with_skip_seconds(data.get('skipSeconds'))\
+            .with_config(None if data.get('config') is None else [
+                Config.from_dict(data.get('config')[i])
+                for i in range(len(data.get('config')))
+            ])\
+            .with_acquirable_at(data.get('acquirableAt'))\
+            .with_exchanged_at(data.get('exchangedAt'))\
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -494,7 +696,15 @@ class Await(core.Gs2Model):
             "rateName": self.rate_name,
             "name": self.name,
             "count": self.count,
+            "skipSeconds": self.skip_seconds,
+            "config": None if self.config is None else [
+                self.config[i].to_dict() if self.config[i] else None
+                for i in range(len(self.config))
+            ],
+            "acquirableAt": self.acquirable_at,
             "exchangedAt": self.exchanged_at,
+            "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -593,9 +803,11 @@ class IncrementalRateModelMaster(core.Gs2Model):
     coefficient_value: int = None
     calculate_script_id: str = None
     exchange_count_id: str = None
+    maximum_exchange_count: int = None
     acquire_actions: List[AcquireAction] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_incremental_rate_model_id(self, incremental_rate_model_id: str) -> IncrementalRateModelMaster:
         self.incremental_rate_model_id = incremental_rate_model_id
@@ -637,6 +849,10 @@ class IncrementalRateModelMaster(core.Gs2Model):
         self.exchange_count_id = exchange_count_id
         return self
 
+    def with_maximum_exchange_count(self, maximum_exchange_count: int) -> IncrementalRateModelMaster:
+        self.maximum_exchange_count = maximum_exchange_count
+        return self
+
     def with_acquire_actions(self, acquire_actions: List[AcquireAction]) -> IncrementalRateModelMaster:
         self.acquire_actions = acquire_actions
         return self
@@ -649,6 +865,10 @@ class IncrementalRateModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> IncrementalRateModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -733,12 +953,14 @@ class IncrementalRateModelMaster(core.Gs2Model):
             .with_coefficient_value(data.get('coefficientValue'))\
             .with_calculate_script_id(data.get('calculateScriptId'))\
             .with_exchange_count_id(data.get('exchangeCountId'))\
-            .with_acquire_actions([
+            .with_maximum_exchange_count(data.get('maximumExchangeCount'))\
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -752,12 +974,14 @@ class IncrementalRateModelMaster(core.Gs2Model):
             "coefficientValue": self.coefficient_value,
             "calculateScriptId": self.calculate_script_id,
             "exchangeCountId": self.exchange_count_id,
-            "acquireActions": [
+            "maximumExchangeCount": self.maximum_exchange_count,
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -771,6 +995,7 @@ class IncrementalRateModel(core.Gs2Model):
     coefficient_value: int = None
     calculate_script_id: str = None
     exchange_count_id: str = None
+    maximum_exchange_count: int = None
     acquire_actions: List[AcquireAction] = None
 
     def with_incremental_rate_model_id(self, incremental_rate_model_id: str) -> IncrementalRateModel:
@@ -809,6 +1034,10 @@ class IncrementalRateModel(core.Gs2Model):
         self.exchange_count_id = exchange_count_id
         return self
 
+    def with_maximum_exchange_count(self, maximum_exchange_count: int) -> IncrementalRateModel:
+        self.maximum_exchange_count = maximum_exchange_count
+        return self
+
     def with_acquire_actions(self, acquire_actions: List[AcquireAction]) -> IncrementalRateModel:
         self.acquire_actions = acquire_actions
         return self
@@ -896,9 +1125,10 @@ class IncrementalRateModel(core.Gs2Model):
             .with_coefficient_value(data.get('coefficientValue'))\
             .with_calculate_script_id(data.get('calculateScriptId'))\
             .with_exchange_count_id(data.get('exchangeCountId'))\
-            .with_acquire_actions([
+            .with_maximum_exchange_count(data.get('maximumExchangeCount'))\
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -912,9 +1142,10 @@ class IncrementalRateModel(core.Gs2Model):
             "coefficientValue": self.coefficient_value,
             "calculateScriptId": self.calculate_script_id,
             "exchangeCountId": self.exchange_count_id,
-            "acquireActions": [
+            "maximumExchangeCount": self.maximum_exchange_count,
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
         }
 
@@ -924,14 +1155,14 @@ class RateModelMaster(core.Gs2Model):
     name: str = None
     description: str = None
     metadata: str = None
+    verify_actions: List[VerifyAction] = None
     consume_actions: List[ConsumeAction] = None
     timing_type: str = None
     lock_time: int = None
-    enable_skip: bool = None
-    skip_consume_actions: List[ConsumeAction] = None
     acquire_actions: List[AcquireAction] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_rate_model_id(self, rate_model_id: str) -> RateModelMaster:
         self.rate_model_id = rate_model_id
@@ -949,6 +1180,10 @@ class RateModelMaster(core.Gs2Model):
         self.metadata = metadata
         return self
 
+    def with_verify_actions(self, verify_actions: List[VerifyAction]) -> RateModelMaster:
+        self.verify_actions = verify_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> RateModelMaster:
         self.consume_actions = consume_actions
         return self
@@ -961,14 +1196,6 @@ class RateModelMaster(core.Gs2Model):
         self.lock_time = lock_time
         return self
 
-    def with_enable_skip(self, enable_skip: bool) -> RateModelMaster:
-        self.enable_skip = enable_skip
-        return self
-
-    def with_skip_consume_actions(self, skip_consume_actions: List[ConsumeAction]) -> RateModelMaster:
-        self.skip_consume_actions = skip_consume_actions
-        return self
-
     def with_acquire_actions(self, acquire_actions: List[AcquireAction]) -> RateModelMaster:
         self.acquire_actions = acquire_actions
         return self
@@ -981,6 +1208,10 @@ class RateModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> RateModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1059,23 +1290,23 @@ class RateModelMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
-            .with_consume_actions([
+            .with_verify_actions(None if data.get('verifyActions') is None else [
+                VerifyAction.from_dict(data.get('verifyActions')[i])
+                for i in range(len(data.get('verifyActions')))
+            ])\
+            .with_consume_actions(None if data.get('consumeActions') is None else [
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
-                for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
+                for i in range(len(data.get('consumeActions')))
             ])\
             .with_timing_type(data.get('timingType'))\
             .with_lock_time(data.get('lockTime'))\
-            .with_enable_skip(data.get('enableSkip'))\
-            .with_skip_consume_actions([
-                ConsumeAction.from_dict(data.get('skipConsumeActions')[i])
-                for i in range(len(data.get('skipConsumeActions')) if data.get('skipConsumeActions') else 0)
-            ])\
-            .with_acquire_actions([
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1083,23 +1314,23 @@ class RateModelMaster(core.Gs2Model):
             "name": self.name,
             "description": self.description,
             "metadata": self.metadata,
-            "consumeActions": [
+            "verifyActions": None if self.verify_actions is None else [
+                self.verify_actions[i].to_dict() if self.verify_actions[i] else None
+                for i in range(len(self.verify_actions))
+            ],
+            "consumeActions": None if self.consume_actions is None else [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
-                for i in range(len(self.consume_actions) if self.consume_actions else 0)
+                for i in range(len(self.consume_actions))
             ],
             "timingType": self.timing_type,
             "lockTime": self.lock_time,
-            "enableSkip": self.enable_skip,
-            "skipConsumeActions": [
-                self.skip_consume_actions[i].to_dict() if self.skip_consume_actions[i] else None
-                for i in range(len(self.skip_consume_actions) if self.skip_consume_actions else 0)
-            ],
-            "acquireActions": [
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1107,11 +1338,10 @@ class RateModel(core.Gs2Model):
     rate_model_id: str = None
     name: str = None
     metadata: str = None
+    verify_actions: List[VerifyAction] = None
     consume_actions: List[ConsumeAction] = None
     timing_type: str = None
     lock_time: int = None
-    enable_skip: bool = None
-    skip_consume_actions: List[ConsumeAction] = None
     acquire_actions: List[AcquireAction] = None
 
     def with_rate_model_id(self, rate_model_id: str) -> RateModel:
@@ -1126,6 +1356,10 @@ class RateModel(core.Gs2Model):
         self.metadata = metadata
         return self
 
+    def with_verify_actions(self, verify_actions: List[VerifyAction]) -> RateModel:
+        self.verify_actions = verify_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> RateModel:
         self.consume_actions = consume_actions
         return self
@@ -1138,14 +1372,6 @@ class RateModel(core.Gs2Model):
         self.lock_time = lock_time
         return self
 
-    def with_enable_skip(self, enable_skip: bool) -> RateModel:
-        self.enable_skip = enable_skip
-        return self
-
-    def with_skip_consume_actions(self, skip_consume_actions: List[ConsumeAction]) -> RateModel:
-        self.skip_consume_actions = skip_consume_actions
-        return self
-
     def with_acquire_actions(self, acquire_actions: List[AcquireAction]) -> RateModel:
         self.acquire_actions = acquire_actions
         return self
@@ -1227,20 +1453,19 @@ class RateModel(core.Gs2Model):
             .with_rate_model_id(data.get('rateModelId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_consume_actions([
+            .with_verify_actions(None if data.get('verifyActions') is None else [
+                VerifyAction.from_dict(data.get('verifyActions')[i])
+                for i in range(len(data.get('verifyActions')))
+            ])\
+            .with_consume_actions(None if data.get('consumeActions') is None else [
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
-                for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
+                for i in range(len(data.get('consumeActions')))
             ])\
             .with_timing_type(data.get('timingType'))\
             .with_lock_time(data.get('lockTime'))\
-            .with_enable_skip(data.get('enableSkip'))\
-            .with_skip_consume_actions([
-                ConsumeAction.from_dict(data.get('skipConsumeActions')[i])
-                for i in range(len(data.get('skipConsumeActions')) if data.get('skipConsumeActions') else 0)
-            ])\
-            .with_acquire_actions([
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -1248,20 +1473,19 @@ class RateModel(core.Gs2Model):
             "rateModelId": self.rate_model_id,
             "name": self.name,
             "metadata": self.metadata,
-            "consumeActions": [
+            "verifyActions": None if self.verify_actions is None else [
+                self.verify_actions[i].to_dict() if self.verify_actions[i] else None
+                for i in range(len(self.verify_actions))
+            ],
+            "consumeActions": None if self.consume_actions is None else [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
-                for i in range(len(self.consume_actions) if self.consume_actions else 0)
+                for i in range(len(self.consume_actions))
             ],
             "timingType": self.timing_type,
             "lockTime": self.lock_time,
-            "enableSkip": self.enable_skip,
-            "skipConsumeActions": [
-                self.skip_consume_actions[i].to_dict() if self.skip_consume_actions[i] else None
-                for i in range(len(self.skip_consume_actions) if self.skip_consume_actions else 0)
-            ],
-            "acquireActions": [
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
         }
 
@@ -1274,11 +1498,14 @@ class Namespace(core.Gs2Model):
     enable_await_exchange: bool = None
     transaction_setting: TransactionSetting = None
     exchange_script: ScriptSetting = None
+    incremental_exchange_script: ScriptSetting = None
+    acquire_await_script: ScriptSetting = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
     queue_namespace_id: str = None
     key_id: str = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1308,6 +1535,14 @@ class Namespace(core.Gs2Model):
         self.exchange_script = exchange_script
         return self
 
+    def with_incremental_exchange_script(self, incremental_exchange_script: ScriptSetting) -> Namespace:
+        self.incremental_exchange_script = incremental_exchange_script
+        return self
+
+    def with_acquire_await_script(self, acquire_await_script: ScriptSetting) -> Namespace:
+        self.acquire_await_script = acquire_await_script
+        return self
+
     def with_log_setting(self, log_setting: LogSetting) -> Namespace:
         self.log_setting = log_setting
         return self
@@ -1328,6 +1563,10 @@ class Namespace(core.Gs2Model):
         self.key_id = key_id
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1397,11 +1636,14 @@ class Namespace(core.Gs2Model):
             .with_enable_await_exchange(data.get('enableAwaitExchange'))\
             .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_exchange_script(ScriptSetting.from_dict(data.get('exchangeScript')))\
+            .with_incremental_exchange_script(ScriptSetting.from_dict(data.get('incrementalExchangeScript')))\
+            .with_acquire_await_script(ScriptSetting.from_dict(data.get('acquireAwaitScript')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
-            .with_key_id(data.get('keyId'))
+            .with_key_id(data.get('keyId'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1412,9 +1654,12 @@ class Namespace(core.Gs2Model):
             "enableAwaitExchange": self.enable_await_exchange,
             "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "exchangeScript": self.exchange_script.to_dict() if self.exchange_script else None,
+            "incrementalExchangeScript": self.incremental_exchange_script.to_dict() if self.incremental_exchange_script else None,
+            "acquireAwaitScript": self.acquire_await_script.to_dict() if self.acquire_await_script else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
+            "revision": self.revision,
         }
\ No newline at end of file
