@@ -19,6 +19,82 @@ from typing import *
 from gs2 import core
 
 
+class TransactionSetting(core.Gs2Model):
+    enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
+    distributor_namespace_id: str = None
+    key_id: str = None
+    queue_namespace_id: str = None
+
+    def with_enable_auto_run(self, enable_auto_run: bool) -> TransactionSetting:
+        self.enable_auto_run = enable_auto_run
+        return self
+
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
+    def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
+        self.distributor_namespace_id = distributor_namespace_id
+        return self
+
+    def with_key_id(self, key_id: str) -> TransactionSetting:
+        self.key_id = key_id
+        return self
+
+    def with_queue_namespace_id(self, queue_namespace_id: str) -> TransactionSetting:
+        self.queue_namespace_id = queue_namespace_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[TransactionSetting]:
+        if data is None:
+            return None
+        return TransactionSetting()\
+            .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
+            .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
+            .with_key_id(data.get('keyId'))\
+            .with_queue_namespace_id(data.get('queueNamespaceId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
+            "distributorNamespaceId": self.distributor_namespace_id,
+            "keyId": self.key_id,
+            "queueNamespaceId": self.queue_namespace_id,
+        }
+
+
 class LogSetting(core.Gs2Model):
     logging_namespace_id: str = None
 
@@ -184,6 +260,47 @@ class GitHubCheckoutSetting(core.Gs2Model):
         }
 
 
+class AcquireAction(core.Gs2Model):
+    action: str = None
+    request: str = None
+
+    def with_action(self, action: str) -> AcquireAction:
+        self.action = action
+        return self
+
+    def with_request(self, request: str) -> AcquireAction:
+        self.request = request
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[AcquireAction]:
+        if data is None:
+            return None
+        return AcquireAction()\
+            .with_action(data.get('action'))\
+            .with_request(data.get('request'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "action": self.action,
+            "request": self.request,
+        }
+
+
 class Status(core.Gs2Model):
     status_id: str = None
     experience_name: str = None
@@ -195,6 +312,7 @@ class Status(core.Gs2Model):
     next_rank_up_experience_value: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_status_id(self, status_id: str) -> Status:
         self.status_id = status_id
@@ -236,6 +354,10 @@ class Status(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Status:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -343,7 +465,8 @@ class Status(core.Gs2Model):
             .with_rank_cap_value(data.get('rankCapValue'))\
             .with_next_rank_up_experience_value(data.get('nextRankUpExperienceValue'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -357,6 +480,7 @@ class Status(core.Gs2Model):
             "nextRankUpExperienceValue": self.next_rank_up_experience_value,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -444,6 +568,73 @@ class CurrentExperienceMaster(core.Gs2Model):
         }
 
 
+class AcquireActionRate(core.Gs2Model):
+    name: str = None
+    mode: str = None
+    rates: List[float] = None
+    big_rates: List[str] = None
+
+    def with_name(self, name: str) -> AcquireActionRate:
+        self.name = name
+        return self
+
+    def with_mode(self, mode: str) -> AcquireActionRate:
+        self.mode = mode
+        return self
+
+    def with_rates(self, rates: List[float]) -> AcquireActionRate:
+        self.rates = rates
+        return self
+
+    def with_big_rates(self, big_rates: List[str]) -> AcquireActionRate:
+        self.big_rates = big_rates
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[AcquireActionRate]:
+        if data is None:
+            return None
+        return AcquireActionRate()\
+            .with_name(data.get('name'))\
+            .with_mode(data.get('mode'))\
+            .with_rates(None if data.get('rates') is None else [
+                data.get('rates')[i]
+                for i in range(len(data.get('rates')))
+            ])\
+            .with_big_rates(None if data.get('bigRates') is None else [
+                data.get('bigRates')[i]
+                for i in range(len(data.get('bigRates')))
+            ])
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "name": self.name,
+            "mode": self.mode,
+            "rates": None if self.rates is None else [
+                self.rates[i]
+                for i in range(len(self.rates))
+            ],
+            "bigRates": None if self.big_rates is None else [
+                self.big_rates[i]
+                for i in range(len(self.big_rates))
+            ],
+        }
+
+
 class Threshold(core.Gs2Model):
     metadata: str = None
     values: List[int] = None
@@ -476,17 +667,17 @@ class Threshold(core.Gs2Model):
             return None
         return Threshold()\
             .with_metadata(data.get('metadata'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "metadata": self.metadata,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
         }
 
@@ -499,6 +690,7 @@ class ThresholdMaster(core.Gs2Model):
     values: List[int] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_threshold_id(self, threshold_id: str) -> ThresholdMaster:
         self.threshold_id = threshold_id
@@ -528,6 +720,10 @@ class ThresholdMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> ThresholdMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -606,12 +802,13 @@ class ThresholdMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -619,12 +816,13 @@ class ThresholdMaster(core.Gs2Model):
             "name": self.name,
             "description": self.description,
             "metadata": self.metadata,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -636,6 +834,7 @@ class ExperienceModel(core.Gs2Model):
     default_rank_cap: int = None
     max_rank_cap: int = None
     rank_threshold: Threshold = None
+    acquire_action_rates: List[AcquireActionRate] = None
 
     def with_experience_model_id(self, experience_model_id: str) -> ExperienceModel:
         self.experience_model_id = experience_model_id
@@ -665,6 +864,10 @@ class ExperienceModel(core.Gs2Model):
         self.rank_threshold = rank_threshold
         return self
 
+    def with_acquire_action_rates(self, acquire_action_rates: List[AcquireActionRate]) -> ExperienceModel:
+        self.acquire_action_rates = acquire_action_rates
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -745,7 +948,11 @@ class ExperienceModel(core.Gs2Model):
             .with_default_experience(data.get('defaultExperience'))\
             .with_default_rank_cap(data.get('defaultRankCap'))\
             .with_max_rank_cap(data.get('maxRankCap'))\
-            .with_rank_threshold(Threshold.from_dict(data.get('rankThreshold')))
+            .with_rank_threshold(Threshold.from_dict(data.get('rankThreshold')))\
+            .with_acquire_action_rates(None if data.get('acquireActionRates') is None else [
+                AcquireActionRate.from_dict(data.get('acquireActionRates')[i])
+                for i in range(len(data.get('acquireActionRates')))
+            ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -756,6 +963,10 @@ class ExperienceModel(core.Gs2Model):
             "defaultRankCap": self.default_rank_cap,
             "maxRankCap": self.max_rank_cap,
             "rankThreshold": self.rank_threshold.to_dict() if self.rank_threshold else None,
+            "acquireActionRates": None if self.acquire_action_rates is None else [
+                self.acquire_action_rates[i].to_dict() if self.acquire_action_rates[i] else None
+                for i in range(len(self.acquire_action_rates))
+            ],
         }
 
 
@@ -768,8 +979,10 @@ class ExperienceModelMaster(core.Gs2Model):
     default_rank_cap: int = None
     max_rank_cap: int = None
     rank_threshold_name: str = None
+    acquire_action_rates: List[AcquireActionRate] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_experience_model_id(self, experience_model_id: str) -> ExperienceModelMaster:
         self.experience_model_id = experience_model_id
@@ -803,6 +1016,10 @@ class ExperienceModelMaster(core.Gs2Model):
         self.rank_threshold_name = rank_threshold_name
         return self
 
+    def with_acquire_action_rates(self, acquire_action_rates: List[AcquireActionRate]) -> ExperienceModelMaster:
+        self.acquire_action_rates = acquire_action_rates
+        return self
+
     def with_created_at(self, created_at: int) -> ExperienceModelMaster:
         self.created_at = created_at
         return self
@@ -811,6 +1028,10 @@ class ExperienceModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> ExperienceModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -893,8 +1114,13 @@ class ExperienceModelMaster(core.Gs2Model):
             .with_default_rank_cap(data.get('defaultRankCap'))\
             .with_max_rank_cap(data.get('maxRankCap'))\
             .with_rank_threshold_name(data.get('rankThresholdName'))\
+            .with_acquire_action_rates(None if data.get('acquireActionRates') is None else [
+                AcquireActionRate.from_dict(data.get('acquireActionRates')[i])
+                for i in range(len(data.get('acquireActionRates')))
+            ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -906,8 +1132,13 @@ class ExperienceModelMaster(core.Gs2Model):
             "defaultRankCap": self.default_rank_cap,
             "maxRankCap": self.max_rank_cap,
             "rankThresholdName": self.rank_threshold_name,
+            "acquireActionRates": None if self.acquire_action_rates is None else [
+                self.acquire_action_rates[i].to_dict() if self.acquire_action_rates[i] else None
+                for i in range(len(self.acquire_action_rates))
+            ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -915,14 +1146,16 @@ class Namespace(core.Gs2Model):
     namespace_id: str = None
     name: str = None
     description: str = None
-    experience_cap_script_id: str = None
+    transaction_setting: TransactionSetting = None
+    rank_cap_script_id: str = None
     change_experience_script: ScriptSetting = None
     change_rank_script: ScriptSetting = None
     change_rank_cap_script: ScriptSetting = None
-    overflow_experience_script: ScriptSetting = None
+    overflow_experience_script: str = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -936,8 +1169,12 @@ class Namespace(core.Gs2Model):
         self.description = description
         return self
 
-    def with_experience_cap_script_id(self, experience_cap_script_id: str) -> Namespace:
-        self.experience_cap_script_id = experience_cap_script_id
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> Namespace:
+        self.transaction_setting = transaction_setting
+        return self
+
+    def with_rank_cap_script_id(self, rank_cap_script_id: str) -> Namespace:
+        self.rank_cap_script_id = rank_cap_script_id
         return self
 
     def with_change_experience_script(self, change_experience_script: ScriptSetting) -> Namespace:
@@ -952,7 +1189,7 @@ class Namespace(core.Gs2Model):
         self.change_rank_cap_script = change_rank_cap_script
         return self
 
-    def with_overflow_experience_script(self, overflow_experience_script: ScriptSetting) -> Namespace:
+    def with_overflow_experience_script(self, overflow_experience_script: str) -> Namespace:
         self.overflow_experience_script = overflow_experience_script
         return self
 
@@ -968,6 +1205,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1033,26 +1274,30 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
-            .with_experience_cap_script_id(data.get('experienceCapScriptId'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
+            .with_rank_cap_script_id(data.get('rankCapScriptId'))\
             .with_change_experience_script(ScriptSetting.from_dict(data.get('changeExperienceScript')))\
             .with_change_rank_script(ScriptSetting.from_dict(data.get('changeRankScript')))\
             .with_change_rank_cap_script(ScriptSetting.from_dict(data.get('changeRankCapScript')))\
-            .with_overflow_experience_script(ScriptSetting.from_dict(data.get('overflowExperienceScript')))\
+            .with_overflow_experience_script(data.get('overflowExperienceScript'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
-            "experienceCapScriptId": self.experience_cap_script_id,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
+            "rankCapScriptId": self.rank_cap_script_id,
             "changeExperienceScript": self.change_experience_script.to_dict() if self.change_experience_script else None,
             "changeRankScript": self.change_rank_script.to_dict() if self.change_rank_script else None,
             "changeRankCapScript": self.change_rank_cap_script.to_dict() if self.change_rank_cap_script else None,
-            "overflowExperienceScript": self.overflow_experience_script.to_dict() if self.overflow_experience_script else None,
+            "overflowExperienceScript": self.overflow_experience_script,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
