@@ -464,6 +464,7 @@ class BlackList(core.Gs2Model):
     target_user_ids: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_black_list_id(self, black_list_id: str) -> BlackList:
         self.black_list_id = black_list_id
@@ -485,6 +486,10 @@ class BlackList(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> BlackList:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -561,23 +566,25 @@ class BlackList(core.Gs2Model):
         return BlackList()\
             .with_black_list_id(data.get('blackListId'))\
             .with_user_id(data.get('userId'))\
-            .with_target_user_ids([
+            .with_target_user_ids(None if data.get('targetUserIds') is None else [
                 data.get('targetUserIds')[i]
-                for i in range(len(data.get('targetUserIds')) if data.get('targetUserIds') else 0)
+                for i in range(len(data.get('targetUserIds')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "blackListId": self.black_list_id,
             "userId": self.user_id,
-            "targetUserIds": [
+            "targetUserIds": None if self.target_user_ids is None else [
                 self.target_user_ids[i]
-                for i in range(len(self.target_user_ids) if self.target_user_ids else 0)
+                for i in range(len(self.target_user_ids))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -587,6 +594,7 @@ class Inbox(core.Gs2Model):
     from_user_ids: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_inbox_id(self, inbox_id: str) -> Inbox:
         self.inbox_id = inbox_id
@@ -608,6 +616,10 @@ class Inbox(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Inbox:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -684,23 +696,25 @@ class Inbox(core.Gs2Model):
         return Inbox()\
             .with_inbox_id(data.get('inboxId'))\
             .with_user_id(data.get('userId'))\
-            .with_from_user_ids([
+            .with_from_user_ids(None if data.get('fromUserIds') is None else [
                 data.get('fromUserIds')[i]
-                for i in range(len(data.get('fromUserIds')) if data.get('fromUserIds') else 0)
+                for i in range(len(data.get('fromUserIds')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "inboxId": self.inbox_id,
             "userId": self.user_id,
-            "fromUserIds": [
+            "fromUserIds": None if self.from_user_ids is None else [
                 self.from_user_ids[i]
-                for i in range(len(self.from_user_ids) if self.from_user_ids else 0)
+                for i in range(len(self.from_user_ids))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -710,6 +724,7 @@ class SendBox(core.Gs2Model):
     target_user_ids: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_send_box_id(self, send_box_id: str) -> SendBox:
         self.send_box_id = send_box_id
@@ -731,6 +746,10 @@ class SendBox(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> SendBox:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -807,23 +826,25 @@ class SendBox(core.Gs2Model):
         return SendBox()\
             .with_send_box_id(data.get('sendBoxId'))\
             .with_user_id(data.get('userId'))\
-            .with_target_user_ids([
+            .with_target_user_ids(None if data.get('targetUserIds') is None else [
                 data.get('targetUserIds')[i]
-                for i in range(len(data.get('targetUserIds')) if data.get('targetUserIds') else 0)
+                for i in range(len(data.get('targetUserIds')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "sendBoxId": self.send_box_id,
             "userId": self.user_id,
-            "targetUserIds": [
+            "targetUserIds": None if self.target_user_ids is None else [
                 self.target_user_ids[i]
-                for i in range(len(self.target_user_ids) if self.target_user_ids else 0)
+                for i in range(len(self.target_user_ids))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -833,6 +854,7 @@ class Friend(core.Gs2Model):
     target_user_ids: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_friend_id(self, friend_id: str) -> Friend:
         self.friend_id = friend_id
@@ -854,6 +876,10 @@ class Friend(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Friend:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -930,23 +956,25 @@ class Friend(core.Gs2Model):
         return Friend()\
             .with_friend_id(data.get('friendId'))\
             .with_user_id(data.get('userId'))\
-            .with_target_user_ids([
+            .with_target_user_ids(None if data.get('targetUserIds') is None else [
                 data.get('targetUserIds')[i]
-                for i in range(len(data.get('targetUserIds')) if data.get('targetUserIds') else 0)
+                for i in range(len(data.get('targetUserIds')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "friendId": self.friend_id,
             "userId": self.user_id,
-            "targetUserIds": [
+            "targetUserIds": None if self.target_user_ids is None else [
                 self.target_user_ids[i]
-                for i in range(len(self.target_user_ids) if self.target_user_ids else 0)
+                for i in range(len(self.target_user_ids))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -956,6 +984,7 @@ class Follow(core.Gs2Model):
     target_user_ids: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_follow_id(self, follow_id: str) -> Follow:
         self.follow_id = follow_id
@@ -977,6 +1006,10 @@ class Follow(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Follow:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1053,23 +1086,25 @@ class Follow(core.Gs2Model):
         return Follow()\
             .with_follow_id(data.get('followId'))\
             .with_user_id(data.get('userId'))\
-            .with_target_user_ids([
+            .with_target_user_ids(None if data.get('targetUserIds') is None else [
                 data.get('targetUserIds')[i]
-                for i in range(len(data.get('targetUserIds')) if data.get('targetUserIds') else 0)
+                for i in range(len(data.get('targetUserIds')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "followId": self.follow_id,
             "userId": self.user_id,
-            "targetUserIds": [
+            "targetUserIds": None if self.target_user_ids is None else [
                 self.target_user_ids[i]
-                for i in range(len(self.target_user_ids) if self.target_user_ids else 0)
+                for i in range(len(self.target_user_ids))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1081,6 +1116,7 @@ class Profile(core.Gs2Model):
     friend_profile: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_profile_id(self, profile_id: str) -> Profile:
         self.profile_id = profile_id
@@ -1110,6 +1146,10 @@ class Profile(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Profile:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1190,7 +1230,8 @@ class Profile(core.Gs2Model):
             .with_follower_profile(data.get('followerProfile'))\
             .with_friend_profile(data.get('friendProfile'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1201,6 +1242,7 @@ class Profile(core.Gs2Model):
             "friendProfile": self.friend_profile,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1218,10 +1260,14 @@ class Namespace(core.Gs2Model):
     update_profile_script: ScriptSetting = None
     follow_notification: NotificationSetting = None
     receive_request_notification: NotificationSetting = None
+    cancel_request_notification: NotificationSetting = None
     accept_request_notification: NotificationSetting = None
+    reject_request_notification: NotificationSetting = None
+    delete_friend_notification: NotificationSetting = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1275,10 +1321,22 @@ class Namespace(core.Gs2Model):
         self.receive_request_notification = receive_request_notification
         return self
 
+    def with_cancel_request_notification(self, cancel_request_notification: NotificationSetting) -> Namespace:
+        self.cancel_request_notification = cancel_request_notification
+        return self
+
     def with_accept_request_notification(self, accept_request_notification: NotificationSetting) -> Namespace:
         self.accept_request_notification = accept_request_notification
         return self
 
+    def with_reject_request_notification(self, reject_request_notification: NotificationSetting) -> Namespace:
+        self.reject_request_notification = reject_request_notification
+        return self
+
+    def with_delete_friend_notification(self, delete_friend_notification: NotificationSetting) -> Namespace:
+        self.delete_friend_notification = delete_friend_notification
+        return self
+
     def with_log_setting(self, log_setting: LogSetting) -> Namespace:
         self.log_setting = log_setting
         return self
@@ -1291,6 +1349,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1366,10 +1428,14 @@ class Namespace(core.Gs2Model):
             .with_update_profile_script(ScriptSetting.from_dict(data.get('updateProfileScript')))\
             .with_follow_notification(NotificationSetting.from_dict(data.get('followNotification')))\
             .with_receive_request_notification(NotificationSetting.from_dict(data.get('receiveRequestNotification')))\
+            .with_cancel_request_notification(NotificationSetting.from_dict(data.get('cancelRequestNotification')))\
             .with_accept_request_notification(NotificationSetting.from_dict(data.get('acceptRequestNotification')))\
+            .with_reject_request_notification(NotificationSetting.from_dict(data.get('rejectRequestNotification')))\
+            .with_delete_friend_notification(NotificationSetting.from_dict(data.get('deleteFriendNotification')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1386,8 +1452,12 @@ class Namespace(core.Gs2Model):
             "updateProfileScript": self.update_profile_script.to_dict() if self.update_profile_script else None,
             "followNotification": self.follow_notification.to_dict() if self.follow_notification else None,
             "receiveRequestNotification": self.receive_request_notification.to_dict() if self.receive_request_notification else None,
+            "cancelRequestNotification": self.cancel_request_notification.to_dict() if self.cancel_request_notification else None,
             "acceptRequestNotification": self.accept_request_notification.to_dict() if self.accept_request_notification else None,
+            "rejectRequestNotification": self.reject_request_notification.to_dict() if self.reject_request_notification else None,
+            "deleteFriendNotification": self.delete_friend_notification.to_dict() if self.delete_friend_notification else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
