@@ -19,6 +19,40 @@ from typing import *
 from gs2 import core
 
 
+class TwoFactorAuthenticationSetting(core.Gs2Model):
+    status: str = None
+
+    def with_status(self, status: str) -> TwoFactorAuthenticationSetting:
+        self.status = status
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[TwoFactorAuthenticationSetting]:
+        if data is None:
+            return None
+        return TwoFactorAuthenticationSetting()\
+            .with_status(data.get('status'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "status": self.status,
+        }
+
+
 class ProjectToken(core.Gs2Model):
     token: str = None
 
@@ -57,6 +91,7 @@ class AttachSecurityPolicy(core.Gs2Model):
     user_id: str = None
     security_policy_ids: List[str] = None
     attached_at: int = None
+    revision: int = None
 
     def with_user_id(self, user_id: str) -> AttachSecurityPolicy:
         self.user_id = user_id
@@ -70,6 +105,10 @@ class AttachSecurityPolicy(core.Gs2Model):
         self.attached_at = attached_at
         return self
 
+    def with_revision(self, revision: int) -> AttachSecurityPolicy:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -121,20 +160,22 @@ class AttachSecurityPolicy(core.Gs2Model):
             return None
         return AttachSecurityPolicy()\
             .with_user_id(data.get('userId'))\
-            .with_security_policy_ids([
+            .with_security_policy_ids(None if data.get('securityPolicyIds') is None else [
                 data.get('securityPolicyIds')[i]
-                for i in range(len(data.get('securityPolicyIds')) if data.get('securityPolicyIds') else 0)
+                for i in range(len(data.get('securityPolicyIds')))
             ])\
-            .with_attached_at(data.get('attachedAt'))
+            .with_attached_at(data.get('attachedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userId": self.user_id,
-            "securityPolicyIds": [
+            "securityPolicyIds": None if self.security_policy_ids is None else [
                 self.security_policy_ids[i]
-                for i in range(len(self.security_policy_ids) if self.security_policy_ids else 0)
+                for i in range(len(self.security_policy_ids))
             ],
             "attachedAt": self.attached_at,
+            "revision": self.revision,
         }
 
 
@@ -142,7 +183,10 @@ class Password(core.Gs2Model):
     password_id: str = None
     user_id: str = None
     user_name: str = None
+    enable_two_factor_authentication: str = None
+    two_factor_authentication_setting: TwoFactorAuthenticationSetting = None
     created_at: int = None
+    revision: int = None
 
     def with_password_id(self, password_id: str) -> Password:
         self.password_id = password_id
@@ -156,10 +200,22 @@ class Password(core.Gs2Model):
         self.user_name = user_name
         return self
 
+    def with_enable_two_factor_authentication(self, enable_two_factor_authentication: str) -> Password:
+        self.enable_two_factor_authentication = enable_two_factor_authentication
+        return self
+
+    def with_two_factor_authentication_setting(self, two_factor_authentication_setting: TwoFactorAuthenticationSetting) -> Password:
+        self.two_factor_authentication_setting = two_factor_authentication_setting
+        return self
+
     def with_created_at(self, created_at: int) -> Password:
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Password:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -213,14 +269,20 @@ class Password(core.Gs2Model):
             .with_password_id(data.get('passwordId'))\
             .with_user_id(data.get('userId'))\
             .with_user_name(data.get('userName'))\
-            .with_created_at(data.get('createdAt'))
+            .with_enable_two_factor_authentication(data.get('enableTwoFactorAuthentication'))\
+            .with_two_factor_authentication_setting(TwoFactorAuthenticationSetting.from_dict(data.get('twoFactorAuthenticationSetting')))\
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "passwordId": self.password_id,
             "userId": self.user_id,
             "userName": self.user_name,
+            "enableTwoFactorAuthentication": self.enable_two_factor_authentication,
+            "twoFactorAuthenticationSetting": self.two_factor_authentication_setting.to_dict() if self.two_factor_authentication_setting else None,
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -229,6 +291,7 @@ class Identifier(core.Gs2Model):
     user_name: str = None
     client_secret: str = None
     created_at: int = None
+    revision: int = None
 
     def with_client_id(self, client_id: str) -> Identifier:
         self.client_id = client_id
@@ -246,6 +309,10 @@ class Identifier(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Identifier:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -275,7 +342,8 @@ class Identifier(core.Gs2Model):
             .with_client_id(data.get('clientId'))\
             .with_user_name(data.get('userName'))\
             .with_client_secret(data.get('clientSecret'))\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -283,6 +351,7 @@ class Identifier(core.Gs2Model):
             "userName": self.user_name,
             "clientSecret": self.client_secret,
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -392,6 +461,7 @@ class User(core.Gs2Model):
     description: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_user_id(self, user_id: str) -> User:
         self.user_id = user_id
@@ -413,6 +483,10 @@ class User(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> User:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -467,7 +541,8 @@ class User(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -476,4 +551,5 @@ class User(core.Gs2Model):
             "description": self.description,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
