@@ -648,25 +648,20 @@ class DeleteIdentifierRequest(core.Gs2Request):
         }
 
 
-class DescribePasswordsRequest(core.Gs2Request):
+class DescribeAttachedGuardsRequest(core.Gs2Request):
 
     context_stack: str = None
+    client_id: str = None
     user_name: str = None
-    page_token: str = None
-    limit: int = None
 
-    def with_user_name(self, user_name: str) -> DescribePasswordsRequest:
+    def with_client_id(self, client_id: str) -> DescribeAttachedGuardsRequest:
+        self.client_id = client_id
+        return self
+
+    def with_user_name(self, user_name: str) -> DescribeAttachedGuardsRequest:
         self.user_name = user_name
         return self
 
-    def with_page_token(self, page_token: str) -> DescribePasswordsRequest:
-        self.page_token = page_token
-        return self
-
-    def with_limit(self, limit: int) -> DescribePasswordsRequest:
-        self.limit = limit
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -682,19 +677,146 @@ class DescribePasswordsRequest(core.Gs2Request):
     @staticmethod
     def from_dict(
         data: Dict[str, Any],
-    ) -> Optional[DescribePasswordsRequest]:
+    ) -> Optional[DescribeAttachedGuardsRequest]:
         if data is None:
             return None
-        return DescribePasswordsRequest()\
+        return DescribeAttachedGuardsRequest()\
+            .with_client_id(data.get('clientId'))\
+            .with_user_name(data.get('userName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "clientId": self.client_id,
+            "userName": self.user_name,
+        }
+
+
+class AttachGuardRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_name: str = None
+    client_id: str = None
+    guard_namespace_id: str = None
+
+    def with_user_name(self, user_name: str) -> AttachGuardRequest:
+        self.user_name = user_name
+        return self
+
+    def with_client_id(self, client_id: str) -> AttachGuardRequest:
+        self.client_id = client_id
+        return self
+
+    def with_guard_namespace_id(self, guard_namespace_id: str) -> AttachGuardRequest:
+        self.guard_namespace_id = guard_namespace_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[AttachGuardRequest]:
+        if data is None:
+            return None
+        return AttachGuardRequest()\
             .with_user_name(data.get('userName'))\
-            .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_client_id(data.get('clientId'))\
+            .with_guard_namespace_id(data.get('guardNamespaceId'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userName": self.user_name,
-            "pageToken": self.page_token,
-            "limit": self.limit,
+            "clientId": self.client_id,
+            "guardNamespaceId": self.guard_namespace_id,
+        }
+
+
+class DetachGuardRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_name: str = None
+    client_id: str = None
+    guard_namespace_id: str = None
+
+    def with_user_name(self, user_name: str) -> DetachGuardRequest:
+        self.user_name = user_name
+        return self
+
+    def with_client_id(self, client_id: str) -> DetachGuardRequest:
+        self.client_id = client_id
+        return self
+
+    def with_guard_namespace_id(self, guard_namespace_id: str) -> DetachGuardRequest:
+        self.guard_namespace_id = guard_namespace_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DetachGuardRequest]:
+        if data is None:
+            return None
+        return DetachGuardRequest()\
+            .with_user_name(data.get('userName'))\
+            .with_client_id(data.get('clientId'))\
+            .with_guard_namespace_id(data.get('guardNamespaceId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userName": self.user_name,
+            "clientId": self.client_id,
+            "guardNamespaceId": self.guard_namespace_id,
+        }
+
+
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
         }
 
 
@@ -777,6 +899,121 @@ class GetPasswordRequest(core.Gs2Request):
         }
 
 
+class EnableMfaRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_name: str = None
+
+    def with_user_name(self, user_name: str) -> EnableMfaRequest:
+        self.user_name = user_name
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[EnableMfaRequest]:
+        if data is None:
+            return None
+        return EnableMfaRequest()\
+            .with_user_name(data.get('userName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userName": self.user_name,
+        }
+
+
+class ChallengeMfaRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_name: str = None
+    passcode: str = None
+
+    def with_user_name(self, user_name: str) -> ChallengeMfaRequest:
+        self.user_name = user_name
+        return self
+
+    def with_passcode(self, passcode: str) -> ChallengeMfaRequest:
+        self.passcode = passcode
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ChallengeMfaRequest]:
+        if data is None:
+            return None
+        return ChallengeMfaRequest()\
+            .with_user_name(data.get('userName'))\
+            .with_passcode(data.get('passcode'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userName": self.user_name,
+            "passcode": self.passcode,
+        }
+
+
+class DisableMfaRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_name: str = None
+
+    def with_user_name(self, user_name: str) -> DisableMfaRequest:
+        self.user_name = user_name
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DisableMfaRequest]:
+        if data is None:
+            return None
+        return DisableMfaRequest()\
+            .with_user_name(data.get('userName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userName": self.user_name,
+        }
+
+
 class DeletePasswordRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -968,8 +1205,8 @@ class LoginRequest(core.Gs2Request):
         if data is None:
             return None
         return LoginRequest()\
-            .with_client_id(data.get('clientId'))\
-            .with_client_secret(data.get('clientSecret'))
+            .with_client_id(data.get('client_id'))\
+            .with_client_secret(data.get('client_secret'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -983,6 +1220,7 @@ class LoginByUserRequest(core.Gs2Request):
     context_stack: str = None
     user_name: str = None
     password: str = None
+    otp: str = None
 
     def with_user_name(self, user_name: str) -> LoginByUserRequest:
         self.user_name = user_name
@@ -992,6 +1230,10 @@ class LoginByUserRequest(core.Gs2Request):
         self.password = password
         return self
 
+    def with_otp(self, otp: str) -> LoginByUserRequest:
+        self.otp = otp
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1012,10 +1254,12 @@ class LoginByUserRequest(core.Gs2Request):
             return None
         return LoginByUserRequest()\
             .with_user_name(data.get('userName'))\
-            .with_password(data.get('password'))
+            .with_password(data.get('password'))\
+            .with_otp(data.get('otp'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "userName": self.user_name,
             "password": self.password,
+            "otp": self.otp,
         }
\ No newline at end of file
