@@ -29,6 +29,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeUsersResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -102,6 +103,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateUserResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -175,6 +177,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateUserResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -248,6 +251,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetUserResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -319,6 +323,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteUserResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -390,6 +395,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeSecurityPoliciesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -463,6 +469,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeCommonSecurityPoliciesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -536,6 +543,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateSecurityPolicyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -611,6 +619,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateSecurityPolicyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -686,6 +695,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetSecurityPolicyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -757,6 +767,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteSecurityPolicyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -828,6 +839,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeIdentifiersResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -903,6 +915,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateIdentifierResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -974,6 +987,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetIdentifierResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1046,6 +1060,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteIdentifierResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1112,16 +1127,18 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _describe_passwords(
+    def _describe_attached_guards(
         self,
-        request: DescribePasswordsRequest,
-        callback: Callable[[AsyncResult[DescribePasswordsResult]], None],
+        request: DescribeAttachedGuardsRequest,
+        callback: Callable[[AsyncResult[DescribeAttachedGuardsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
-        ) + "/user/{userName}/password".format(
+        ) + "/user/{userName}/identifier/{clientId}/guard".format(
+            clientId=request.client_id if request.client_id is not None and request.client_id != '' else 'null',
             userName=request.user_name if request.user_name is not None and request.user_name != '' else 'null',
         )
 
@@ -1129,17 +1146,13 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         query_strings = {
             'contextStack': request.context_stack,
         }
-        if request.page_token is not None:
-            query_strings["pageToken"] = request.page_token
-        if request.limit is not None:
-            query_strings["limit"] = request.limit
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
         _job = rest.NetworkJob(
             url=url,
             method='GET',
-            result_type=DescribePasswordsResult,
+            result_type=DescribeAttachedGuardsResult,
             callback=callback,
             headers=headers,
             query_strings=query_strings,
@@ -1150,13 +1163,13 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
             is_blocking=is_blocking,
         )
 
-    def describe_passwords(
+    def describe_attached_guards(
         self,
-        request: DescribePasswordsRequest,
-    ) -> DescribePasswordsResult:
+        request: DescribeAttachedGuardsRequest,
+    ) -> DescribeAttachedGuardsResult:
         async_result = []
         with timeout(30):
-            self._describe_passwords(
+            self._describe_attached_guards(
                 request,
                 lambda result: async_result.append(result),
                 is_blocking=True,
@@ -1167,12 +1180,231 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         return async_result[0].result
 
 
-    async def describe_passwords_async(
+    async def describe_attached_guards_async(
         self,
-        request: DescribePasswordsRequest,
-    ) -> DescribePasswordsResult:
+        request: DescribeAttachedGuardsRequest,
+    ) -> DescribeAttachedGuardsResult:
         async_result = []
-        self._describe_passwords(
+        self._describe_attached_guards(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _attach_guard(
+        self,
+        request: AttachGuardRequest,
+        callback: Callable[[AsyncResult[AttachGuardResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='identifier',
+            region=self.session.region,
+        ) + "/user/{userName}/identifier/{clientId}/guard".format(
+            userName=request.user_name if request.user_name is not None and request.user_name != '' else 'null',
+            clientId=request.client_id if request.client_id is not None and request.client_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.guard_namespace_id is not None:
+            body["guardNamespaceId"] = request.guard_namespace_id
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=AttachGuardResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def attach_guard(
+        self,
+        request: AttachGuardRequest,
+    ) -> AttachGuardResult:
+        async_result = []
+        with timeout(30):
+            self._attach_guard(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def attach_guard_async(
+        self,
+        request: AttachGuardRequest,
+    ) -> AttachGuardResult:
+        async_result = []
+        self._attach_guard(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _detach_guard(
+        self,
+        request: DetachGuardRequest,
+        callback: Callable[[AsyncResult[DetachGuardResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='identifier',
+            region=self.session.region,
+        ) + "/user/{userName}/identifier/{clientId}/guard/{guardNamespaceId}".format(
+            userName=request.user_name if request.user_name is not None and request.user_name != '' else 'null',
+            clientId=request.client_id if request.client_id is not None and request.client_id != '' else 'null',
+            guardNamespaceId=request.guard_namespace_id if request.guard_namespace_id is not None and request.guard_namespace_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='DELETE',
+            result_type=DetachGuardResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def detach_guard(
+        self,
+        request: DetachGuardRequest,
+    ) -> DetachGuardResult:
+        async_result = []
+        with timeout(30):
+            self._detach_guard(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def detach_guard_async(
+        self,
+        request: DetachGuardRequest,
+    ) -> DetachGuardResult:
+        async_result = []
+        self._detach_guard(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='identifier',
+            region=self.session.region,
+        ) + "/system/version"
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetServiceVersionResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
             request,
             lambda result: async_result.append(result),
             is_blocking=False,
@@ -1193,6 +1425,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreatePasswordResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1266,6 +1499,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetPasswordResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1331,12 +1565,231 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _enable_mfa(
+        self,
+        request: EnableMfaRequest,
+        callback: Callable[[AsyncResult[EnableMfaResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='identifier',
+            region=self.session.region,
+        ) + "/user/{userName}/mfa".format(
+            userName=request.user_name if request.user_name is not None and request.user_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=EnableMfaResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def enable_mfa(
+        self,
+        request: EnableMfaRequest,
+    ) -> EnableMfaResult:
+        async_result = []
+        with timeout(30):
+            self._enable_mfa(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def enable_mfa_async(
+        self,
+        request: EnableMfaRequest,
+    ) -> EnableMfaResult:
+        async_result = []
+        self._enable_mfa(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _challenge_mfa(
+        self,
+        request: ChallengeMfaRequest,
+        callback: Callable[[AsyncResult[ChallengeMfaResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='identifier',
+            region=self.session.region,
+        ) + "/user/{userName}/mfa/challenge".format(
+            userName=request.user_name if request.user_name is not None and request.user_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.passcode is not None:
+            body["passcode"] = request.passcode
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=ChallengeMfaResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def challenge_mfa(
+        self,
+        request: ChallengeMfaRequest,
+    ) -> ChallengeMfaResult:
+        async_result = []
+        with timeout(30):
+            self._challenge_mfa(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def challenge_mfa_async(
+        self,
+        request: ChallengeMfaRequest,
+    ) -> ChallengeMfaResult:
+        async_result = []
+        self._challenge_mfa(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _disable_mfa(
+        self,
+        request: DisableMfaRequest,
+        callback: Callable[[AsyncResult[DisableMfaResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='identifier',
+            region=self.session.region,
+        ) + "/user/{userName}/mfa".format(
+            userName=request.user_name if request.user_name is not None and request.user_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='DELETE',
+            result_type=DisableMfaResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def disable_mfa(
+        self,
+        request: DisableMfaRequest,
+    ) -> DisableMfaResult:
+        async_result = []
+        with timeout(30):
+            self._disable_mfa(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def disable_mfa_async(
+        self,
+        request: DisableMfaRequest,
+    ) -> DisableMfaResult:
+        async_result = []
+        self._disable_mfa(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _delete_password(
         self,
         request: DeletePasswordRequest,
         callback: Callable[[AsyncResult[DeletePasswordResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1408,6 +1861,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetHasSecurityPolicyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1479,6 +1933,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[AttachSecurityPolicyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1552,6 +2007,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DetachSecurityPolicyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1624,6 +2080,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[LoginResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1697,6 +2154,7 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[LoginByUserResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='identifier',
             region=self.session.region,
@@ -1710,6 +2168,8 @@ class Gs2IdentifierRestClient(rest.AbstractGs2RestClient):
             body["userName"] = request.user_name
         if request.password is not None:
             body["password"] = request.password
+        if request.otp is not None:
+            body["otp"] = request.otp
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
