@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2IdentifierWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -1112,29 +1113,27 @@ class Gs2IdentifierWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _describe_passwords(
+    def _describe_attached_guards(
         self,
-        request: DescribePasswordsRequest,
-        callback: Callable[[AsyncResult[DescribePasswordsResult]], None],
+        request: DescribeAttachedGuardsRequest,
+        callback: Callable[[AsyncResult[DescribeAttachedGuardsResult]], None],
     ):
         import uuid
 
         request_id = str(uuid.uuid4())
         body = self._create_metadata(
             service="identifier",
-            component='password',
-            function='describePasswords',
+            component='identifier',
+            function='describeAttachedGuards',
             request_id=request_id,
         )
 
         if request.context_stack:
             body['contextStack'] = str(request.context_stack)
+        if request.client_id is not None:
+            body["clientId"] = request.client_id
         if request.user_name is not None:
             body["userName"] = request.user_name
-        if request.page_token is not None:
-            body["pageToken"] = request.page_token
-        if request.limit is not None:
-            body["limit"] = request.limit
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1142,19 +1141,19 @@ class Gs2IdentifierWebSocketClient(web_socket.AbstractGs2WebSocketClient):
         self.session.send(
             web_socket.NetworkJob(
                 request_id=request_id,
-                result_type=DescribePasswordsResult,
+                result_type=DescribeAttachedGuardsResult,
                 callback=callback,
                 body=body,
             )
         )
 
-    def describe_passwords(
+    def describe_attached_guards(
         self,
-        request: DescribePasswordsRequest,
-    ) -> DescribePasswordsResult:
+        request: DescribeAttachedGuardsRequest,
+    ) -> DescribeAttachedGuardsResult:
         async_result = []
         with timeout(30):
-            self._describe_passwords(
+            self._describe_attached_guards(
                 request,
                 lambda result: async_result.append(result),
             )
@@ -1168,12 +1167,231 @@ class Gs2IdentifierWebSocketClient(web_socket.AbstractGs2WebSocketClient):
         return async_result[0].result
 
 
-    async def describe_passwords_async(
+    async def describe_attached_guards_async(
         self,
-        request: DescribePasswordsRequest,
-    ) -> DescribePasswordsResult:
+        request: DescribeAttachedGuardsRequest,
+    ) -> DescribeAttachedGuardsResult:
         async_result = []
-        self._describe_passwords(
+        self._describe_attached_guards(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _attach_guard(
+        self,
+        request: AttachGuardRequest,
+        callback: Callable[[AsyncResult[AttachGuardResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="identifier",
+            component='identifier',
+            function='attachGuard',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_name is not None:
+            body["userName"] = request.user_name
+        if request.client_id is not None:
+            body["clientId"] = request.client_id
+        if request.guard_namespace_id is not None:
+            body["guardNamespaceId"] = request.guard_namespace_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=AttachGuardResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def attach_guard(
+        self,
+        request: AttachGuardRequest,
+    ) -> AttachGuardResult:
+        async_result = []
+        with timeout(30):
+            self._attach_guard(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def attach_guard_async(
+        self,
+        request: AttachGuardRequest,
+    ) -> AttachGuardResult:
+        async_result = []
+        self._attach_guard(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _detach_guard(
+        self,
+        request: DetachGuardRequest,
+        callback: Callable[[AsyncResult[DetachGuardResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="identifier",
+            component='identifier',
+            function='detachGuard',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_name is not None:
+            body["userName"] = request.user_name
+        if request.client_id is not None:
+            body["clientId"] = request.client_id
+        if request.guard_namespace_id is not None:
+            body["guardNamespaceId"] = request.guard_namespace_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=DetachGuardResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def detach_guard(
+        self,
+        request: DetachGuardRequest,
+    ) -> DetachGuardResult:
+        async_result = []
+        with timeout(30):
+            self._detach_guard(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def detach_guard_async(
+        self,
+        request: DetachGuardRequest,
+    ) -> DetachGuardResult:
+        async_result = []
+        self._detach_guard(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="identifier",
+            component='identifier',
+            function='getServiceVersion',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=GetServiceVersionResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
             request,
             lambda result: async_result.append(result),
         )
@@ -1331,6 +1549,221 @@ class Gs2IdentifierWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _enable_mfa(
+        self,
+        request: EnableMfaRequest,
+        callback: Callable[[AsyncResult[EnableMfaResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="identifier",
+            component='password',
+            function='enableMfa',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_name is not None:
+            body["userName"] = request.user_name
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=EnableMfaResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def enable_mfa(
+        self,
+        request: EnableMfaRequest,
+    ) -> EnableMfaResult:
+        async_result = []
+        with timeout(30):
+            self._enable_mfa(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def enable_mfa_async(
+        self,
+        request: EnableMfaRequest,
+    ) -> EnableMfaResult:
+        async_result = []
+        self._enable_mfa(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _challenge_mfa(
+        self,
+        request: ChallengeMfaRequest,
+        callback: Callable[[AsyncResult[ChallengeMfaResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="identifier",
+            component='password',
+            function='challengeMfa',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_name is not None:
+            body["userName"] = request.user_name
+        if request.passcode is not None:
+            body["passcode"] = request.passcode
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=ChallengeMfaResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def challenge_mfa(
+        self,
+        request: ChallengeMfaRequest,
+    ) -> ChallengeMfaResult:
+        async_result = []
+        with timeout(30):
+            self._challenge_mfa(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def challenge_mfa_async(
+        self,
+        request: ChallengeMfaRequest,
+    ) -> ChallengeMfaResult:
+        async_result = []
+        self._challenge_mfa(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _disable_mfa(
+        self,
+        request: DisableMfaRequest,
+        callback: Callable[[AsyncResult[DisableMfaResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="identifier",
+            component='password',
+            function='disableMfa',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_name is not None:
+            body["userName"] = request.user_name
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=DisableMfaResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def disable_mfa(
+        self,
+        request: DisableMfaRequest,
+    ) -> DisableMfaResult:
+        async_result = []
+        with timeout(30):
+            self._disable_mfa(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def disable_mfa_async(
+        self,
+        request: DisableMfaRequest,
+    ) -> DisableMfaResult:
+        async_result = []
+        self._disable_mfa(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _delete_password(
         self,
         request: DeletePasswordRequest,
@@ -1713,6 +2146,8 @@ class Gs2IdentifierWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userName"] = request.user_name
         if request.password is not None:
             body["password"] = request.password
+        if request.otp is not None:
+            body["otp"] = request.otp
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
