@@ -186,6 +186,9 @@ class ScriptSetting(core.Gs2Model):
 
 class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
     queue_namespace_id: str = None
@@ -194,6 +197,18 @@ class TransactionSetting(core.Gs2Model):
         self.enable_auto_run = enable_auto_run
         return self
 
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
     def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
         self.distributor_namespace_id = distributor_namespace_id
         return self
@@ -226,6 +241,9 @@ class TransactionSetting(core.Gs2Model):
             return None
         return TransactionSetting()\
             .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))
@@ -233,6 +251,9 @@ class TransactionSetting(core.Gs2Model):
     def to_dict(self) -> Dict[str, Any]:
         return {
             "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
             "queueNamespaceId": self.queue_namespace_id,
@@ -265,16 +286,16 @@ class AcquireActionList(core.Gs2Model):
         if data is None:
             return None
         return AcquireActionList()\
-            .with_acquire_actions([
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "acquireActions": [
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
         }
 
@@ -451,9 +472,11 @@ class Status(core.Gs2Model):
     user_id: str = None
     random_seed: int = None
     idle_minutes: int = None
+    next_rewards_at: int = None
     maximum_idle_minutes: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_status_id(self, status_id: str) -> Status:
         self.status_id = status_id
@@ -475,6 +498,10 @@ class Status(core.Gs2Model):
         self.idle_minutes = idle_minutes
         return self
 
+    def with_next_rewards_at(self, next_rewards_at: int) -> Status:
+        self.next_rewards_at = next_rewards_at
+        return self
+
     def with_maximum_idle_minutes(self, maximum_idle_minutes: int) -> Status:
         self.maximum_idle_minutes = maximum_idle_minutes
         return self
@@ -487,6 +514,10 @@ class Status(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Status:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -578,9 +609,11 @@ class Status(core.Gs2Model):
             .with_user_id(data.get('userId'))\
             .with_random_seed(data.get('randomSeed'))\
             .with_idle_minutes(data.get('idleMinutes'))\
+            .with_next_rewards_at(data.get('nextRewardsAt'))\
             .with_maximum_idle_minutes(data.get('maximumIdleMinutes'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -589,9 +622,11 @@ class Status(core.Gs2Model):
             "userId": self.user_id,
             "randomSeed": self.random_seed,
             "idleMinutes": self.idle_minutes,
+            "nextRewardsAt": self.next_rewards_at,
             "maximumIdleMinutes": self.maximum_idle_minutes,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -601,6 +636,7 @@ class CategoryModel(core.Gs2Model):
     metadata: str = None
     reward_interval_minutes: int = None
     default_maximum_idle_minutes: int = None
+    reward_reset_mode: str = None
     acquire_actions: List[AcquireActionList] = None
     idle_period_schedule_id: str = None
     receive_period_schedule_id: str = None
@@ -625,6 +661,10 @@ class CategoryModel(core.Gs2Model):
         self.default_maximum_idle_minutes = default_maximum_idle_minutes
         return self
 
+    def with_reward_reset_mode(self, reward_reset_mode: str) -> CategoryModel:
+        self.reward_reset_mode = reward_reset_mode
+        return self
+
     def with_acquire_actions(self, acquire_actions: List[AcquireActionList]) -> CategoryModel:
         self.acquire_actions = acquire_actions
         return self
@@ -716,9 +756,10 @@ class CategoryModel(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_reward_interval_minutes(data.get('rewardIntervalMinutes'))\
             .with_default_maximum_idle_minutes(data.get('defaultMaximumIdleMinutes'))\
-            .with_acquire_actions([
+            .with_reward_reset_mode(data.get('rewardResetMode'))\
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireActionList.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])\
             .with_idle_period_schedule_id(data.get('idlePeriodScheduleId'))\
             .with_receive_period_schedule_id(data.get('receivePeriodScheduleId'))
@@ -730,9 +771,10 @@ class CategoryModel(core.Gs2Model):
             "metadata": self.metadata,
             "rewardIntervalMinutes": self.reward_interval_minutes,
             "defaultMaximumIdleMinutes": self.default_maximum_idle_minutes,
-            "acquireActions": [
+            "rewardResetMode": self.reward_reset_mode,
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
             "idlePeriodScheduleId": self.idle_period_schedule_id,
             "receivePeriodScheduleId": self.receive_period_schedule_id,
@@ -746,11 +788,13 @@ class CategoryModelMaster(core.Gs2Model):
     metadata: str = None
     reward_interval_minutes: int = None
     default_maximum_idle_minutes: int = None
+    reward_reset_mode: str = None
     acquire_actions: List[AcquireActionList] = None
     idle_period_schedule_id: str = None
     receive_period_schedule_id: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_category_model_id(self, category_model_id: str) -> CategoryModelMaster:
         self.category_model_id = category_model_id
@@ -776,6 +820,10 @@ class CategoryModelMaster(core.Gs2Model):
         self.default_maximum_idle_minutes = default_maximum_idle_minutes
         return self
 
+    def with_reward_reset_mode(self, reward_reset_mode: str) -> CategoryModelMaster:
+        self.reward_reset_mode = reward_reset_mode
+        return self
+
     def with_acquire_actions(self, acquire_actions: List[AcquireActionList]) -> CategoryModelMaster:
         self.acquire_actions = acquire_actions
         return self
@@ -796,6 +844,10 @@ class CategoryModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> CategoryModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -876,14 +928,16 @@ class CategoryModelMaster(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_reward_interval_minutes(data.get('rewardIntervalMinutes'))\
             .with_default_maximum_idle_minutes(data.get('defaultMaximumIdleMinutes'))\
-            .with_acquire_actions([
+            .with_reward_reset_mode(data.get('rewardResetMode'))\
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireActionList.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])\
             .with_idle_period_schedule_id(data.get('idlePeriodScheduleId'))\
             .with_receive_period_schedule_id(data.get('receivePeriodScheduleId'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -893,14 +947,16 @@ class CategoryModelMaster(core.Gs2Model):
             "metadata": self.metadata,
             "rewardIntervalMinutes": self.reward_interval_minutes,
             "defaultMaximumIdleMinutes": self.default_maximum_idle_minutes,
-            "acquireActions": [
+            "rewardResetMode": self.reward_reset_mode,
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
             "idlePeriodScheduleId": self.idle_period_schedule_id,
             "receivePeriodScheduleId": self.receive_period_schedule_id,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -910,9 +966,11 @@ class Namespace(core.Gs2Model):
     description: str = None
     transaction_setting: TransactionSetting = None
     receive_script: ScriptSetting = None
+    override_acquire_actions_script_id: str = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -934,6 +992,10 @@ class Namespace(core.Gs2Model):
         self.receive_script = receive_script
         return self
 
+    def with_override_acquire_actions_script_id(self, override_acquire_actions_script_id: str) -> Namespace:
+        self.override_acquire_actions_script_id = override_acquire_actions_script_id
+        return self
+
     def with_log_setting(self, log_setting: LogSetting) -> Namespace:
         self.log_setting = log_setting
         return self
@@ -946,6 +1008,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1013,9 +1079,11 @@ class Namespace(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_receive_script(ScriptSetting.from_dict(data.get('receiveScript')))\
+            .with_override_acquire_actions_script_id(data.get('overrideAcquireActionsScriptId'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1024,7 +1092,9 @@ class Namespace(core.Gs2Model):
             "description": self.description,
             "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "receiveScript": self.receive_script.to_dict() if self.receive_script else None,
+            "overrideAcquireActionsScriptId": self.override_acquire_actions_script_id,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
