@@ -21,6 +21,9 @@ from gs2 import core
 
 class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
     queue_namespace_id: str = None
@@ -29,6 +32,18 @@ class TransactionSetting(core.Gs2Model):
         self.enable_auto_run = enable_auto_run
         return self
 
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
     def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
         self.distributor_namespace_id = distributor_namespace_id
         return self
@@ -61,6 +76,9 @@ class TransactionSetting(core.Gs2Model):
             return None
         return TransactionSetting()\
             .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))
@@ -68,6 +86,9 @@ class TransactionSetting(core.Gs2Model):
     def to_dict(self) -> Dict[str, Any]:
         return {
             "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
             "queueNamespaceId": self.queue_namespace_id,
@@ -423,6 +444,7 @@ class Received(core.Gs2Model):
     received_global_message_names: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_received_id(self, received_id: str) -> Received:
         self.received_id = received_id
@@ -444,6 +466,10 @@ class Received(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Received:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -520,23 +546,25 @@ class Received(core.Gs2Model):
         return Received()\
             .with_received_id(data.get('receivedId'))\
             .with_user_id(data.get('userId'))\
-            .with_received_global_message_names([
+            .with_received_global_message_names(None if data.get('receivedGlobalMessageNames') is None else [
                 data.get('receivedGlobalMessageNames')[i]
-                for i in range(len(data.get('receivedGlobalMessageNames')) if data.get('receivedGlobalMessageNames') else 0)
+                for i in range(len(data.get('receivedGlobalMessageNames')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "receivedId": self.received_id,
             "userId": self.user_id,
-            "receivedGlobalMessageNames": [
+            "receivedGlobalMessageNames": None if self.received_global_message_names is None else [
                 self.received_global_message_names[i]
-                for i in range(len(self.received_global_message_names) if self.received_global_message_names else 0)
+                for i in range(len(self.received_global_message_names))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -547,6 +575,7 @@ class GlobalMessage(core.Gs2Model):
     read_acquire_actions: List[AcquireAction] = None
     expires_time_span: TimeSpan = None
     expires_at: int = None
+    message_reception_period_event_id: str = None
 
     def with_global_message_id(self, global_message_id: str) -> GlobalMessage:
         self.global_message_id = global_message_id
@@ -572,6 +601,10 @@ class GlobalMessage(core.Gs2Model):
         self.expires_at = expires_at
         return self
 
+    def with_message_reception_period_event_id(self, message_reception_period_event_id: str) -> GlobalMessage:
+        self.message_reception_period_event_id = message_reception_period_event_id
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -649,24 +682,26 @@ class GlobalMessage(core.Gs2Model):
             .with_global_message_id(data.get('globalMessageId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_read_acquire_actions([
+            .with_read_acquire_actions(None if data.get('readAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('readAcquireActions')[i])
-                for i in range(len(data.get('readAcquireActions')) if data.get('readAcquireActions') else 0)
+                for i in range(len(data.get('readAcquireActions')))
             ])\
             .with_expires_time_span(TimeSpan.from_dict(data.get('expiresTimeSpan')))\
-            .with_expires_at(data.get('expiresAt'))
+            .with_expires_at(data.get('expiresAt'))\
+            .with_message_reception_period_event_id(data.get('messageReceptionPeriodEventId'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "globalMessageId": self.global_message_id,
             "name": self.name,
             "metadata": self.metadata,
-            "readAcquireActions": [
+            "readAcquireActions": None if self.read_acquire_actions is None else [
                 self.read_acquire_actions[i].to_dict() if self.read_acquire_actions[i] else None
-                for i in range(len(self.read_acquire_actions) if self.read_acquire_actions else 0)
+                for i in range(len(self.read_acquire_actions))
             ],
             "expiresTimeSpan": self.expires_time_span.to_dict() if self.expires_time_span else None,
             "expiresAt": self.expires_at,
+            "messageReceptionPeriodEventId": self.message_reception_period_event_id,
         }
 
 
@@ -676,8 +711,10 @@ class GlobalMessageMaster(core.Gs2Model):
     metadata: str = None
     read_acquire_actions: List[AcquireAction] = None
     expires_time_span: TimeSpan = None
-    created_at: int = None
     expires_at: int = None
+    message_reception_period_event_id: str = None
+    created_at: int = None
+    revision: int = None
 
     def with_global_message_id(self, global_message_id: str) -> GlobalMessageMaster:
         self.global_message_id = global_message_id
@@ -699,12 +736,20 @@ class GlobalMessageMaster(core.Gs2Model):
         self.expires_time_span = expires_time_span
         return self
 
+    def with_expires_at(self, expires_at: int) -> GlobalMessageMaster:
+        self.expires_at = expires_at
+        return self
+
+    def with_message_reception_period_event_id(self, message_reception_period_event_id: str) -> GlobalMessageMaster:
+        self.message_reception_period_event_id = message_reception_period_event_id
+        return self
+
     def with_created_at(self, created_at: int) -> GlobalMessageMaster:
         self.created_at = created_at
         return self
 
-    def with_expires_at(self, expires_at: int) -> GlobalMessageMaster:
-        self.expires_at = expires_at
+    def with_revision(self, revision: int) -> GlobalMessageMaster:
+        self.revision = revision
         return self
 
     @classmethod
@@ -784,26 +829,30 @@ class GlobalMessageMaster(core.Gs2Model):
             .with_global_message_id(data.get('globalMessageId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_read_acquire_actions([
+            .with_read_acquire_actions(None if data.get('readAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('readAcquireActions')[i])
-                for i in range(len(data.get('readAcquireActions')) if data.get('readAcquireActions') else 0)
+                for i in range(len(data.get('readAcquireActions')))
             ])\
             .with_expires_time_span(TimeSpan.from_dict(data.get('expiresTimeSpan')))\
+            .with_expires_at(data.get('expiresAt'))\
+            .with_message_reception_period_event_id(data.get('messageReceptionPeriodEventId'))\
             .with_created_at(data.get('createdAt'))\
-            .with_expires_at(data.get('expiresAt'))
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "globalMessageId": self.global_message_id,
             "name": self.name,
             "metadata": self.metadata,
-            "readAcquireActions": [
+            "readAcquireActions": None if self.read_acquire_actions is None else [
                 self.read_acquire_actions[i].to_dict() if self.read_acquire_actions[i] else None
-                for i in range(len(self.read_acquire_actions) if self.read_acquire_actions else 0)
+                for i in range(len(self.read_acquire_actions))
             ],
             "expiresTimeSpan": self.expires_time_span.to_dict() if self.expires_time_span else None,
-            "createdAt": self.created_at,
             "expiresAt": self.expires_at,
+            "messageReceptionPeriodEventId": self.message_reception_period_event_id,
+            "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -901,6 +950,7 @@ class Message(core.Gs2Model):
     received_at: int = None
     read_at: int = None
     expires_at: int = None
+    revision: int = None
 
     def with_message_id(self, message_id: str) -> Message:
         self.message_id = message_id
@@ -938,6 +988,10 @@ class Message(core.Gs2Model):
         self.expires_at = expires_at
         return self
 
+    def with_revision(self, revision: int) -> Message:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1029,13 +1083,14 @@ class Message(core.Gs2Model):
             .with_user_id(data.get('userId'))\
             .with_metadata(data.get('metadata'))\
             .with_is_read(data.get('isRead'))\
-            .with_read_acquire_actions([
+            .with_read_acquire_actions(None if data.get('readAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('readAcquireActions')[i])
-                for i in range(len(data.get('readAcquireActions')) if data.get('readAcquireActions') else 0)
+                for i in range(len(data.get('readAcquireActions')))
             ])\
             .with_received_at(data.get('receivedAt'))\
             .with_read_at(data.get('readAt'))\
-            .with_expires_at(data.get('expiresAt'))
+            .with_expires_at(data.get('expiresAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1044,13 +1099,14 @@ class Message(core.Gs2Model):
             "userId": self.user_id,
             "metadata": self.metadata,
             "isRead": self.is_read,
-            "readAcquireActions": [
+            "readAcquireActions": None if self.read_acquire_actions is None else [
                 self.read_acquire_actions[i].to_dict() if self.read_acquire_actions[i] else None
-                for i in range(len(self.read_acquire_actions) if self.read_acquire_actions else 0)
+                for i in range(len(self.read_acquire_actions))
             ],
             "receivedAt": self.received_at,
             "readAt": self.read_at,
             "expiresAt": self.expires_at,
+            "revision": self.revision,
         }
 
 
@@ -1069,6 +1125,7 @@ class Namespace(core.Gs2Model):
     updated_at: int = None
     queue_namespace_id: str = None
     key_id: str = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1126,6 +1183,10 @@ class Namespace(core.Gs2Model):
         self.key_id = key_id
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1201,7 +1262,8 @@ class Namespace(core.Gs2Model):
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
-            .with_key_id(data.get('keyId'))
+            .with_key_id(data.get('keyId'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1219,4 +1281,5 @@ class Namespace(core.Gs2Model):
             "updatedAt": self.updated_at,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
+            "revision": self.revision,
         }
\ No newline at end of file
