@@ -204,162 +204,6 @@ class NotificationSetting(core.Gs2Model):
         }
 
 
-class DeadLetterJob(core.Gs2Model):
-    dead_letter_job_id: str = None
-    name: str = None
-    user_id: str = None
-    script_id: str = None
-    args: str = None
-    result: List[JobResultBody] = None
-    created_at: int = None
-    updated_at: int = None
-
-    def with_dead_letter_job_id(self, dead_letter_job_id: str) -> DeadLetterJob:
-        self.dead_letter_job_id = dead_letter_job_id
-        return self
-
-    def with_name(self, name: str) -> DeadLetterJob:
-        self.name = name
-        return self
-
-    def with_user_id(self, user_id: str) -> DeadLetterJob:
-        self.user_id = user_id
-        return self
-
-    def with_script_id(self, script_id: str) -> DeadLetterJob:
-        self.script_id = script_id
-        return self
-
-    def with_args(self, args: str) -> DeadLetterJob:
-        self.args = args
-        return self
-
-    def with_result(self, result: List[JobResultBody]) -> DeadLetterJob:
-        self.result = result
-        return self
-
-    def with_created_at(self, created_at: int) -> DeadLetterJob:
-        self.created_at = created_at
-        return self
-
-    def with_updated_at(self, updated_at: int) -> DeadLetterJob:
-        self.updated_at = updated_at
-        return self
-
-    @classmethod
-    def create_grn(
-        cls,
-        region,
-        owner_id,
-        namespace_name,
-        user_id,
-        dead_letter_job_name,
-    ):
-        return 'grn:gs2:{region}:{ownerId}:queue:{namespaceName}:user:{userId}:dead:{deadLetterJobName}'.format(
-            region=region,
-            ownerId=owner_id,
-            namespaceName=namespace_name,
-            userId=user_id,
-            deadLetterJobName=dead_letter_job_name,
-        )
-
-    @classmethod
-    def get_region_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):queue:(?P<namespaceName>.+):user:(?P<userId>.+):dead:(?P<deadLetterJobName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('region')
-
-    @classmethod
-    def get_owner_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):queue:(?P<namespaceName>.+):user:(?P<userId>.+):dead:(?P<deadLetterJobName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('owner_id')
-
-    @classmethod
-    def get_namespace_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):queue:(?P<namespaceName>.+):user:(?P<userId>.+):dead:(?P<deadLetterJobName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('namespace_name')
-
-    @classmethod
-    def get_user_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):queue:(?P<namespaceName>.+):user:(?P<userId>.+):dead:(?P<deadLetterJobName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('user_id')
-
-    @classmethod
-    def get_dead_letter_job_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):queue:(?P<namespaceName>.+):user:(?P<userId>.+):dead:(?P<deadLetterJobName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('dead_letter_job_name')
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[DeadLetterJob]:
-        if data is None:
-            return None
-        return DeadLetterJob()\
-            .with_dead_letter_job_id(data.get('deadLetterJobId'))\
-            .with_name(data.get('name'))\
-            .with_user_id(data.get('userId'))\
-            .with_script_id(data.get('scriptId'))\
-            .with_args(data.get('args'))\
-            .with_result([
-                JobResultBody.from_dict(data.get('result')[i])
-                for i in range(len(data.get('result')) if data.get('result') else 0)
-            ])\
-            .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "deadLetterJobId": self.dead_letter_job_id,
-            "name": self.name,
-            "userId": self.user_id,
-            "scriptId": self.script_id,
-            "args": self.args,
-            "result": [
-                self.result[i].to_dict() if self.result[i] else None
-                for i in range(len(self.result) if self.result else 0)
-            ],
-            "createdAt": self.created_at,
-            "updatedAt": self.updated_at,
-        }
-
-
 class JobResult(core.Gs2Model):
     job_result_id: str = None
     job_id: str = None
@@ -689,6 +533,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -726,6 +571,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -796,7 +645,8 @@ class Namespace(core.Gs2Model):
             .with_push_notification(NotificationSetting.from_dict(data.get('pushNotification')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -809,4 +659,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
