@@ -310,6 +310,350 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class DumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> DumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> DumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckDumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckDumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckDumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckCleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckCleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckCleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class PrepareImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> PrepareImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class ImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> ImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> ImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> ImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
 class DescribeJobsByUserIdRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -317,6 +661,7 @@ class DescribeJobsByUserIdRequest(core.Gs2Request):
     user_id: str = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeJobsByUserIdRequest:
         self.namespace_name = namespace_name
@@ -334,6 +679,10 @@ class DescribeJobsByUserIdRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeJobsByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -356,7 +705,8 @@ class DescribeJobsByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -364,6 +714,7 @@ class DescribeJobsByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -373,6 +724,7 @@ class GetJobByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     job_name: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetJobByUserIdRequest:
         self.namespace_name = namespace_name
@@ -386,6 +738,10 @@ class GetJobByUserIdRequest(core.Gs2Request):
         self.job_name = job_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> GetJobByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -407,13 +763,15 @@ class GetJobByUserIdRequest(core.Gs2Request):
         return GetJobByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_job_name(data.get('jobName'))
+            .with_job_name(data.get('jobName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "jobName": self.job_name,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -423,6 +781,7 @@ class PushByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     jobs: List[JobEntry] = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PushByUserIdRequest:
@@ -437,6 +796,10 @@ class PushByUserIdRequest(core.Gs2Request):
         self.jobs = jobs
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PushByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PushByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -462,19 +825,21 @@ class PushByUserIdRequest(core.Gs2Request):
         return PushByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_jobs([
+            .with_jobs(None if data.get('jobs') is None else [
                 JobEntry.from_dict(data.get('jobs')[i])
-                for i in range(len(data.get('jobs')) if data.get('jobs') else 0)
-            ])
+                for i in range(len(data.get('jobs')))
+            ])\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
-            "jobs": [
+            "jobs": None if self.jobs is None else [
                 self.jobs[i].to_dict() if self.jobs[i] else None
-                for i in range(len(self.jobs) if self.jobs else 0)
+                for i in range(len(self.jobs))
             ],
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -531,6 +896,7 @@ class RunByUserIdRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     user_id: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> RunByUserIdRequest:
@@ -541,6 +907,10 @@ class RunByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> RunByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> RunByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -565,12 +935,69 @@ class RunByUserIdRequest(core.Gs2Request):
             return None
         return RunByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class DeleteJobRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    access_token: str = None
+    job_name: str = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> DeleteJobRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_access_token(self, access_token: str) -> DeleteJobRequest:
+        self.access_token = access_token
+        return self
+
+    def with_job_name(self, job_name: str) -> DeleteJobRequest:
+        self.job_name = job_name
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteJobRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DeleteJobRequest]:
+        if data is None:
+            return None
+        return DeleteJobRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_access_token(data.get('accessToken'))\
+            .with_job_name(data.get('jobName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "accessToken": self.access_token,
+            "jobName": self.job_name,
         }
 
 
@@ -580,6 +1007,7 @@ class DeleteJobByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     job_name: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteJobByUserIdRequest:
@@ -594,6 +1022,10 @@ class DeleteJobByUserIdRequest(core.Gs2Request):
         self.job_name = job_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DeleteJobByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DeleteJobByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -619,13 +1051,15 @@ class DeleteJobByUserIdRequest(core.Gs2Request):
         return DeleteJobByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_job_name(data.get('jobName'))
+            .with_job_name(data.get('jobName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "jobName": self.job_name,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -672,12 +1106,56 @@ class PushByStampSheetRequest(core.Gs2Request):
         }
 
 
+class DeleteByStampTaskRequest(core.Gs2Request):
+
+    context_stack: str = None
+    stamp_task: str = None
+    key_id: str = None
+
+    def with_stamp_task(self, stamp_task: str) -> DeleteByStampTaskRequest:
+        self.stamp_task = stamp_task
+        return self
+
+    def with_key_id(self, key_id: str) -> DeleteByStampTaskRequest:
+        self.key_id = key_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DeleteByStampTaskRequest]:
+        if data is None:
+            return None
+        return DeleteByStampTaskRequest()\
+            .with_stamp_task(data.get('stampTask'))\
+            .with_key_id(data.get('keyId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "stampTask": self.stamp_task,
+            "keyId": self.key_id,
+        }
+
+
 class GetJobResultRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
     access_token: str = None
     job_name: str = None
+    try_number: int = None
 
     def with_namespace_name(self, namespace_name: str) -> GetJobResultRequest:
         self.namespace_name = namespace_name
@@ -691,6 +1169,10 @@ class GetJobResultRequest(core.Gs2Request):
         self.job_name = job_name
         return self
 
+    def with_try_number(self, try_number: int) -> GetJobResultRequest:
+        self.try_number = try_number
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -712,13 +1194,15 @@ class GetJobResultRequest(core.Gs2Request):
         return GetJobResultRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_access_token(data.get('accessToken'))\
-            .with_job_name(data.get('jobName'))
+            .with_job_name(data.get('jobName'))\
+            .with_try_number(data.get('tryNumber'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "accessToken": self.access_token,
             "jobName": self.job_name,
+            "tryNumber": self.try_number,
         }
 
 
@@ -728,6 +1212,8 @@ class GetJobResultByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     job_name: str = None
+    try_number: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetJobResultByUserIdRequest:
         self.namespace_name = namespace_name
@@ -741,6 +1227,14 @@ class GetJobResultByUserIdRequest(core.Gs2Request):
         self.job_name = job_name
         return self
 
+    def with_try_number(self, try_number: int) -> GetJobResultByUserIdRequest:
+        self.try_number = try_number
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> GetJobResultByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -762,173 +1256,15 @@ class GetJobResultByUserIdRequest(core.Gs2Request):
         return GetJobResultByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_job_name(data.get('jobName'))
+            .with_job_name(data.get('jobName'))\
+            .with_try_number(data.get('tryNumber'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "jobName": self.job_name,
-        }
-
-
-class DescribeDeadLetterJobsByUserIdRequest(core.Gs2Request):
-
-    context_stack: str = None
-    namespace_name: str = None
-    user_id: str = None
-    page_token: str = None
-    limit: int = None
-
-    def with_namespace_name(self, namespace_name: str) -> DescribeDeadLetterJobsByUserIdRequest:
-        self.namespace_name = namespace_name
-        return self
-
-    def with_user_id(self, user_id: str) -> DescribeDeadLetterJobsByUserIdRequest:
-        self.user_id = user_id
-        return self
-
-    def with_page_token(self, page_token: str) -> DescribeDeadLetterJobsByUserIdRequest:
-        self.page_token = page_token
-        return self
-
-    def with_limit(self, limit: int) -> DescribeDeadLetterJobsByUserIdRequest:
-        self.limit = limit
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[DescribeDeadLetterJobsByUserIdRequest]:
-        if data is None:
-            return None
-        return DescribeDeadLetterJobsByUserIdRequest()\
-            .with_namespace_name(data.get('namespaceName'))\
-            .with_user_id(data.get('userId'))\
-            .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "namespaceName": self.namespace_name,
-            "userId": self.user_id,
-            "pageToken": self.page_token,
-            "limit": self.limit,
-        }
-
-
-class GetDeadLetterJobByUserIdRequest(core.Gs2Request):
-
-    context_stack: str = None
-    namespace_name: str = None
-    user_id: str = None
-    dead_letter_job_name: str = None
-
-    def with_namespace_name(self, namespace_name: str) -> GetDeadLetterJobByUserIdRequest:
-        self.namespace_name = namespace_name
-        return self
-
-    def with_user_id(self, user_id: str) -> GetDeadLetterJobByUserIdRequest:
-        self.user_id = user_id
-        return self
-
-    def with_dead_letter_job_name(self, dead_letter_job_name: str) -> GetDeadLetterJobByUserIdRequest:
-        self.dead_letter_job_name = dead_letter_job_name
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[GetDeadLetterJobByUserIdRequest]:
-        if data is None:
-            return None
-        return GetDeadLetterJobByUserIdRequest()\
-            .with_namespace_name(data.get('namespaceName'))\
-            .with_user_id(data.get('userId'))\
-            .with_dead_letter_job_name(data.get('deadLetterJobName'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "namespaceName": self.namespace_name,
-            "userId": self.user_id,
-            "deadLetterJobName": self.dead_letter_job_name,
-        }
-
-
-class DeleteDeadLetterJobByUserIdRequest(core.Gs2Request):
-
-    context_stack: str = None
-    namespace_name: str = None
-    user_id: str = None
-    dead_letter_job_name: str = None
-    duplication_avoider: str = None
-
-    def with_namespace_name(self, namespace_name: str) -> DeleteDeadLetterJobByUserIdRequest:
-        self.namespace_name = namespace_name
-        return self
-
-    def with_user_id(self, user_id: str) -> DeleteDeadLetterJobByUserIdRequest:
-        self.user_id = user_id
-        return self
-
-    def with_dead_letter_job_name(self, dead_letter_job_name: str) -> DeleteDeadLetterJobByUserIdRequest:
-        self.dead_letter_job_name = dead_letter_job_name
-        return self
-
-    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteDeadLetterJobByUserIdRequest:
-        self.duplication_avoider = duplication_avoider
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[DeleteDeadLetterJobByUserIdRequest]:
-        if data is None:
-            return None
-        return DeleteDeadLetterJobByUserIdRequest()\
-            .with_namespace_name(data.get('namespaceName'))\
-            .with_user_id(data.get('userId'))\
-            .with_dead_letter_job_name(data.get('deadLetterJobName'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "namespaceName": self.namespace_name,
-            "userId": self.user_id,
-            "deadLetterJobName": self.dead_letter_job_name,
+            "tryNumber": self.try_number,
+            "timeOffsetToken": self.time_offset_token,
         }
\ No newline at end of file
