@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -469,6 +470,590 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='getServiceVersion',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=GetServiceVersionResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _dump_user_data_by_user_id(
+        self,
+        request: DumpUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[DumpUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='dumpUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=DumpUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def dump_user_data_by_user_id(
+        self,
+        request: DumpUserDataByUserIdRequest,
+    ) -> DumpUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._dump_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def dump_user_data_by_user_id_async(
+        self,
+        request: DumpUserDataByUserIdRequest,
+    ) -> DumpUserDataByUserIdResult:
+        async_result = []
+        self._dump_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_dump_user_data_by_user_id(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckDumpUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='checkDumpUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckDumpUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_dump_user_data_by_user_id(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+    ) -> CheckDumpUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_dump_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_dump_user_data_by_user_id_async(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+    ) -> CheckDumpUserDataByUserIdResult:
+        async_result = []
+        self._check_dump_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _clean_user_data_by_user_id(
+        self,
+        request: CleanUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CleanUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='cleanUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CleanUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def clean_user_data_by_user_id(
+        self,
+        request: CleanUserDataByUserIdRequest,
+    ) -> CleanUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._clean_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def clean_user_data_by_user_id_async(
+        self,
+        request: CleanUserDataByUserIdRequest,
+    ) -> CleanUserDataByUserIdResult:
+        async_result = []
+        self._clean_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_clean_user_data_by_user_id(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckCleanUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='checkCleanUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckCleanUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_clean_user_data_by_user_id(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+    ) -> CheckCleanUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_clean_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_clean_user_data_by_user_id_async(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+    ) -> CheckCleanUserDataByUserIdResult:
+        async_result = []
+        self._check_clean_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _prepare_import_user_data_by_user_id(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[PrepareImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='prepareImportUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=PrepareImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def prepare_import_user_data_by_user_id(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+    ) -> PrepareImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._prepare_import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def prepare_import_user_data_by_user_id_async(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+    ) -> PrepareImportUserDataByUserIdResult:
+        async_result = []
+        self._prepare_import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _import_user_data_by_user_id(
+        self,
+        request: ImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[ImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='importUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=ImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def import_user_data_by_user_id(
+        self,
+        request: ImportUserDataByUserIdRequest,
+    ) -> ImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def import_user_data_by_user_id_async(
+        self,
+        request: ImportUserDataByUserIdRequest,
+    ) -> ImportUserDataByUserIdResult:
+        async_result = []
+        self._import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_import_user_data_by_user_id(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='namespace',
+            function='checkImportUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_import_user_data_by_user_id(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+    ) -> CheckImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_import_user_data_by_user_id_async(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+    ) -> CheckImportUserDataByUserIdResult:
+        async_result = []
+        self._check_import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_jobs_by_user_id(
         self,
         request: DescribeJobsByUserIdRequest,
@@ -494,6 +1079,8 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -569,6 +1156,8 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.job_name is not None:
             body["jobName"] = request.job_name
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -647,6 +1236,8 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
                 item.to_dict()
                 for item in request.jobs
             ]
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -799,6 +1390,8 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["namespaceName"] = request.namespace_name
         if request.user_id is not None:
             body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -853,6 +1446,85 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _delete_job(
+        self,
+        request: DeleteJobRequest,
+        callback: Callable[[AsyncResult[DeleteJobResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='job',
+            function='deleteJob',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.access_token is not None:
+            body["accessToken"] = request.access_token
+        if request.job_name is not None:
+            body["jobName"] = request.job_name
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.access_token:
+            body["xGs2AccessToken"] = request.access_token
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=DeleteJobResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def delete_job(
+        self,
+        request: DeleteJobRequest,
+    ) -> DeleteJobResult:
+        async_result = []
+        with timeout(30):
+            self._delete_job(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def delete_job_async(
+        self,
+        request: DeleteJobRequest,
+    ) -> DeleteJobResult:
+        async_result = []
+        self._delete_job(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _delete_job_by_user_id(
         self,
         request: DeleteJobByUserIdRequest,
@@ -876,6 +1548,8 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.job_name is not None:
             body["jobName"] = request.job_name
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1003,6 +1677,79 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _delete_by_stamp_task(
+        self,
+        request: DeleteByStampTaskRequest,
+        callback: Callable[[AsyncResult[DeleteByStampTaskResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="jobQueue",
+            component='job',
+            function='deleteByStampTask',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.stamp_task is not None:
+            body["stampTask"] = request.stamp_task
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=DeleteByStampTaskResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def delete_by_stamp_task(
+        self,
+        request: DeleteByStampTaskRequest,
+    ) -> DeleteByStampTaskResult:
+        async_result = []
+        with timeout(30):
+            self._delete_by_stamp_task(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def delete_by_stamp_task_async(
+        self,
+        request: DeleteByStampTaskRequest,
+    ) -> DeleteByStampTaskResult:
+        async_result = []
+        self._delete_by_stamp_task(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _get_job_result(
         self,
         request: GetJobResultRequest,
@@ -1026,6 +1773,8 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["accessToken"] = request.access_token
         if request.job_name is not None:
             body["jobName"] = request.job_name
+        if request.try_number is not None:
+            body["tryNumber"] = request.try_number
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1103,6 +1852,10 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.job_name is not None:
             body["jobName"] = request.job_name
+        if request.try_number is not None:
+            body["tryNumber"] = request.try_number
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1146,235 +1899,6 @@ class Gs2JobQueueWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             lambda result: async_result.append(result),
         )
 
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _describe_dead_letter_jobs_by_user_id(
-        self,
-        request: DescribeDeadLetterJobsByUserIdRequest,
-        callback: Callable[[AsyncResult[DescribeDeadLetterJobsByUserIdResult]], None],
-    ):
-        import uuid
-
-        request_id = str(uuid.uuid4())
-        body = self._create_metadata(
-            service="jobQueue",
-            component='deadLetterJob',
-            function='describeDeadLetterJobsByUserId',
-            request_id=request_id,
-        )
-
-        if request.context_stack:
-            body['contextStack'] = str(request.context_stack)
-        if request.namespace_name is not None:
-            body["namespaceName"] = request.namespace_name
-        if request.user_id is not None:
-            body["userId"] = request.user_id
-        if request.page_token is not None:
-            body["pageToken"] = request.page_token
-        if request.limit is not None:
-            body["limit"] = request.limit
-
-        if request.request_id:
-            body["xGs2RequestId"] = request.request_id
-
-        self.session.send(
-            web_socket.NetworkJob(
-                request_id=request_id,
-                result_type=DescribeDeadLetterJobsByUserIdResult,
-                callback=callback,
-                body=body,
-            )
-        )
-
-    def describe_dead_letter_jobs_by_user_id(
-        self,
-        request: DescribeDeadLetterJobsByUserIdRequest,
-    ) -> DescribeDeadLetterJobsByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._describe_dead_letter_jobs_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-            )
-
-        with timeout(30):
-            while not async_result:
-                time.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def describe_dead_letter_jobs_by_user_id_async(
-        self,
-        request: DescribeDeadLetterJobsByUserIdRequest,
-    ) -> DescribeDeadLetterJobsByUserIdResult:
-        async_result = []
-        self._describe_dead_letter_jobs_by_user_id(
-            request,
-            lambda result: async_result.append(result),
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _get_dead_letter_job_by_user_id(
-        self,
-        request: GetDeadLetterJobByUserIdRequest,
-        callback: Callable[[AsyncResult[GetDeadLetterJobByUserIdResult]], None],
-    ):
-        import uuid
-
-        request_id = str(uuid.uuid4())
-        body = self._create_metadata(
-            service="jobQueue",
-            component='deadLetterJob',
-            function='getDeadLetterJobByUserId',
-            request_id=request_id,
-        )
-
-        if request.context_stack:
-            body['contextStack'] = str(request.context_stack)
-        if request.namespace_name is not None:
-            body["namespaceName"] = request.namespace_name
-        if request.user_id is not None:
-            body["userId"] = request.user_id
-        if request.dead_letter_job_name is not None:
-            body["deadLetterJobName"] = request.dead_letter_job_name
-
-        if request.request_id:
-            body["xGs2RequestId"] = request.request_id
-
-        self.session.send(
-            web_socket.NetworkJob(
-                request_id=request_id,
-                result_type=GetDeadLetterJobByUserIdResult,
-                callback=callback,
-                body=body,
-            )
-        )
-
-    def get_dead_letter_job_by_user_id(
-        self,
-        request: GetDeadLetterJobByUserIdRequest,
-    ) -> GetDeadLetterJobByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._get_dead_letter_job_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-            )
-
-        with timeout(30):
-            while not async_result:
-                time.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def get_dead_letter_job_by_user_id_async(
-        self,
-        request: GetDeadLetterJobByUserIdRequest,
-    ) -> GetDeadLetterJobByUserIdResult:
-        async_result = []
-        self._get_dead_letter_job_by_user_id(
-            request,
-            lambda result: async_result.append(result),
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _delete_dead_letter_job_by_user_id(
-        self,
-        request: DeleteDeadLetterJobByUserIdRequest,
-        callback: Callable[[AsyncResult[DeleteDeadLetterJobByUserIdResult]], None],
-    ):
-        import uuid
-
-        request_id = str(uuid.uuid4())
-        body = self._create_metadata(
-            service="jobQueue",
-            component='deadLetterJob',
-            function='deleteDeadLetterJobByUserId',
-            request_id=request_id,
-        )
-
-        if request.context_stack:
-            body['contextStack'] = str(request.context_stack)
-        if request.namespace_name is not None:
-            body["namespaceName"] = request.namespace_name
-        if request.user_id is not None:
-            body["userId"] = request.user_id
-        if request.dead_letter_job_name is not None:
-            body["deadLetterJobName"] = request.dead_letter_job_name
-
-        if request.request_id:
-            body["xGs2RequestId"] = request.request_id
-        if request.duplication_avoider:
-            body["xGs2DuplicationAvoider"] = request.duplication_avoider
-
-        self.session.send(
-            web_socket.NetworkJob(
-                request_id=request_id,
-                result_type=DeleteDeadLetterJobByUserIdResult,
-                callback=callback,
-                body=body,
-            )
-        )
-
-    def delete_dead_letter_job_by_user_id(
-        self,
-        request: DeleteDeadLetterJobByUserIdRequest,
-    ) -> DeleteDeadLetterJobByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._delete_dead_letter_job_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-            )
-
-        with timeout(30):
-            while not async_result:
-                time.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def delete_dead_letter_job_by_user_id_async(
-        self,
-        request: DeleteDeadLetterJobByUserIdRequest,
-    ) -> DeleteDeadLetterJobByUserIdResult:
-        async_result = []
-        self._delete_dead_letter_job_by_user_id(
-            request,
-            lambda result: async_result.append(result),
-        )
-
         import asyncio
         with timeout(30):
             while not async_result:
