@@ -27,6 +27,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNamespacesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -100,6 +101,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -175,6 +177,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceStatusResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -246,6 +249,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -317,6 +321,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -392,6 +397,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -457,12 +463,83 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='key',
+            region=self.session.region,
+        ) + "/system/version"
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetServiceVersionResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_keys(
         self,
         request: DescribeKeysRequest,
         callback: Callable[[AsyncResult[DescribeKeysResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -538,6 +615,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -613,6 +691,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -687,6 +766,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -759,6 +839,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -831,6 +912,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[EncryptResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -905,6 +987,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DecryptResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -979,6 +1062,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeGitHubApiKeysResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -1054,6 +1138,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateGitHubApiKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -1133,6 +1218,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateGitHubApiKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -1211,6 +1297,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetGitHubApiKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
@@ -1283,6 +1370,7 @@ class Gs2KeyRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteGitHubApiKeyResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='key',
             region=self.session.region,
