@@ -27,6 +27,8 @@ class LimitModel(core.Gs2Model):
     reset_day_of_month: int = None
     reset_day_of_week: str = None
     reset_hour: int = None
+    anchor_timestamp: int = None
+    days: int = None
 
     def with_limit_model_id(self, limit_model_id: str) -> LimitModel:
         self.limit_model_id = limit_model_id
@@ -56,6 +58,14 @@ class LimitModel(core.Gs2Model):
         self.reset_hour = reset_hour
         return self
 
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> LimitModel:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_days(self, days: int) -> LimitModel:
+        self.days = days
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -136,7 +146,9 @@ class LimitModel(core.Gs2Model):
             .with_reset_type(data.get('resetType'))\
             .with_reset_day_of_month(data.get('resetDayOfMonth'))\
             .with_reset_day_of_week(data.get('resetDayOfWeek'))\
-            .with_reset_hour(data.get('resetHour'))
+            .with_reset_hour(data.get('resetHour'))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_days(data.get('days'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -147,6 +159,8 @@ class LimitModel(core.Gs2Model):
             "resetDayOfMonth": self.reset_day_of_month,
             "resetDayOfWeek": self.reset_day_of_week,
             "resetHour": self.reset_hour,
+            "anchorTimestamp": self.anchor_timestamp,
+            "days": self.days,
         }
 
 
@@ -353,8 +367,11 @@ class LimitModelMaster(core.Gs2Model):
     reset_day_of_month: int = None
     reset_day_of_week: str = None
     reset_hour: int = None
+    anchor_timestamp: int = None
+    days: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_limit_model_id(self, limit_model_id: str) -> LimitModelMaster:
         self.limit_model_id = limit_model_id
@@ -388,6 +405,14 @@ class LimitModelMaster(core.Gs2Model):
         self.reset_hour = reset_hour
         return self
 
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> LimitModelMaster:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_days(self, days: int) -> LimitModelMaster:
+        self.days = days
+        return self
+
     def with_created_at(self, created_at: int) -> LimitModelMaster:
         self.created_at = created_at
         return self
@@ -396,6 +421,10 @@ class LimitModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> LimitModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -478,8 +507,11 @@ class LimitModelMaster(core.Gs2Model):
             .with_reset_day_of_month(data.get('resetDayOfMonth'))\
             .with_reset_day_of_week(data.get('resetDayOfWeek'))\
             .with_reset_hour(data.get('resetHour'))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_days(data.get('days'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -491,8 +523,11 @@ class LimitModelMaster(core.Gs2Model):
             "resetDayOfMonth": self.reset_day_of_month,
             "resetDayOfWeek": self.reset_day_of_week,
             "resetHour": self.reset_hour,
+            "anchorTimestamp": self.anchor_timestamp,
+            "days": self.days,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -505,6 +540,7 @@ class Counter(core.Gs2Model):
     next_reset_at: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_counter_id(self, counter_id: str) -> Counter:
         self.counter_id = counter_id
@@ -538,6 +574,10 @@ class Counter(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Counter:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -643,7 +683,8 @@ class Counter(core.Gs2Model):
             .with_count(data.get('count'))\
             .with_next_reset_at(data.get('nextResetAt'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -655,6 +696,7 @@ class Counter(core.Gs2Model):
             "nextResetAt": self.next_reset_at,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -665,6 +707,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -690,6 +733,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -757,7 +804,8 @@ class Namespace(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -767,4 +815,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
