@@ -268,6 +268,350 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class DumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> DumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> DumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckDumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckDumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckDumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckCleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckCleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckCleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class PrepareImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> PrepareImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class ImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> ImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> ImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> ImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
 class DescribeCountersRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -340,6 +684,7 @@ class DescribeCountersByUserIdRequest(core.Gs2Request):
     limit_name: str = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeCountersByUserIdRequest:
         self.namespace_name = namespace_name
@@ -361,6 +706,10 @@ class DescribeCountersByUserIdRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeCountersByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -384,7 +733,8 @@ class DescribeCountersByUserIdRequest(core.Gs2Request):
             .with_user_id(data.get('userId'))\
             .with_limit_name(data.get('limitName'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -393,6 +743,7 @@ class DescribeCountersByUserIdRequest(core.Gs2Request):
             "limitName": self.limit_name,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -460,6 +811,7 @@ class GetCounterByUserIdRequest(core.Gs2Request):
     limit_name: str = None
     user_id: str = None
     counter_name: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetCounterByUserIdRequest:
         self.namespace_name = namespace_name
@@ -477,6 +829,10 @@ class GetCounterByUserIdRequest(core.Gs2Request):
         self.counter_name = counter_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> GetCounterByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -499,7 +855,8 @@ class GetCounterByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_limit_name(data.get('limitName'))\
             .with_user_id(data.get('userId'))\
-            .with_counter_name(data.get('counterName'))
+            .with_counter_name(data.get('counterName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -507,6 +864,7 @@ class GetCounterByUserIdRequest(core.Gs2Request):
             "limitName": self.limit_name,
             "userId": self.user_id,
             "counterName": self.counter_name,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -595,6 +953,7 @@ class CountUpByUserIdRequest(core.Gs2Request):
     user_id: str = None
     count_up_value: int = None
     max_value: int = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CountUpByUserIdRequest:
@@ -621,6 +980,10 @@ class CountUpByUserIdRequest(core.Gs2Request):
         self.max_value = max_value
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> CountUpByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> CountUpByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -649,7 +1012,8 @@ class CountUpByUserIdRequest(core.Gs2Request):
             .with_counter_name(data.get('counterName'))\
             .with_user_id(data.get('userId'))\
             .with_count_up_value(data.get('countUpValue'))\
-            .with_max_value(data.get('maxValue'))
+            .with_max_value(data.get('maxValue'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -659,6 +1023,83 @@ class CountUpByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "countUpValue": self.count_up_value,
             "maxValue": self.max_value,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CountDownByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    limit_name: str = None
+    counter_name: str = None
+    user_id: str = None
+    count_down_value: int = None
+    time_offset_token: str = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> CountDownByUserIdRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_limit_name(self, limit_name: str) -> CountDownByUserIdRequest:
+        self.limit_name = limit_name
+        return self
+
+    def with_counter_name(self, counter_name: str) -> CountDownByUserIdRequest:
+        self.counter_name = counter_name
+        return self
+
+    def with_user_id(self, user_id: str) -> CountDownByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_count_down_value(self, count_down_value: int) -> CountDownByUserIdRequest:
+        self.count_down_value = count_down_value
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CountDownByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> CountDownByUserIdRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CountDownByUserIdRequest]:
+        if data is None:
+            return None
+        return CountDownByUserIdRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_limit_name(data.get('limitName'))\
+            .with_counter_name(data.get('counterName'))\
+            .with_user_id(data.get('userId'))\
+            .with_count_down_value(data.get('countDownValue'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "limitName": self.limit_name,
+            "counterName": self.counter_name,
+            "userId": self.user_id,
+            "countDownValue": self.count_down_value,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -669,6 +1110,7 @@ class DeleteCounterByUserIdRequest(core.Gs2Request):
     limit_name: str = None
     user_id: str = None
     counter_name: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteCounterByUserIdRequest:
@@ -687,6 +1129,10 @@ class DeleteCounterByUserIdRequest(core.Gs2Request):
         self.counter_name = counter_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DeleteCounterByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DeleteCounterByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -713,7 +1159,8 @@ class DeleteCounterByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_limit_name(data.get('limitName'))\
             .with_user_id(data.get('userId'))\
-            .with_counter_name(data.get('counterName'))
+            .with_counter_name(data.get('counterName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -721,6 +1168,180 @@ class DeleteCounterByUserIdRequest(core.Gs2Request):
             "limitName": self.limit_name,
             "userId": self.user_id,
             "counterName": self.counter_name,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class VerifyCounterRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    access_token: str = None
+    limit_name: str = None
+    counter_name: str = None
+    verify_type: str = None
+    count: int = None
+    multiply_value_specifying_quantity: bool = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> VerifyCounterRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_access_token(self, access_token: str) -> VerifyCounterRequest:
+        self.access_token = access_token
+        return self
+
+    def with_limit_name(self, limit_name: str) -> VerifyCounterRequest:
+        self.limit_name = limit_name
+        return self
+
+    def with_counter_name(self, counter_name: str) -> VerifyCounterRequest:
+        self.counter_name = counter_name
+        return self
+
+    def with_verify_type(self, verify_type: str) -> VerifyCounterRequest:
+        self.verify_type = verify_type
+        return self
+
+    def with_count(self, count: int) -> VerifyCounterRequest:
+        self.count = count
+        return self
+
+    def with_multiply_value_specifying_quantity(self, multiply_value_specifying_quantity: bool) -> VerifyCounterRequest:
+        self.multiply_value_specifying_quantity = multiply_value_specifying_quantity
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> VerifyCounterRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyCounterRequest]:
+        if data is None:
+            return None
+        return VerifyCounterRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_access_token(data.get('accessToken'))\
+            .with_limit_name(data.get('limitName'))\
+            .with_counter_name(data.get('counterName'))\
+            .with_verify_type(data.get('verifyType'))\
+            .with_count(data.get('count'))\
+            .with_multiply_value_specifying_quantity(data.get('multiplyValueSpecifyingQuantity'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "accessToken": self.access_token,
+            "limitName": self.limit_name,
+            "counterName": self.counter_name,
+            "verifyType": self.verify_type,
+            "count": self.count,
+            "multiplyValueSpecifyingQuantity": self.multiply_value_specifying_quantity,
+        }
+
+
+class VerifyCounterByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    user_id: str = None
+    limit_name: str = None
+    counter_name: str = None
+    verify_type: str = None
+    count: int = None
+    multiply_value_specifying_quantity: bool = None
+    time_offset_token: str = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> VerifyCounterByUserIdRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_user_id(self, user_id: str) -> VerifyCounterByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_limit_name(self, limit_name: str) -> VerifyCounterByUserIdRequest:
+        self.limit_name = limit_name
+        return self
+
+    def with_counter_name(self, counter_name: str) -> VerifyCounterByUserIdRequest:
+        self.counter_name = counter_name
+        return self
+
+    def with_verify_type(self, verify_type: str) -> VerifyCounterByUserIdRequest:
+        self.verify_type = verify_type
+        return self
+
+    def with_count(self, count: int) -> VerifyCounterByUserIdRequest:
+        self.count = count
+        return self
+
+    def with_multiply_value_specifying_quantity(self, multiply_value_specifying_quantity: bool) -> VerifyCounterByUserIdRequest:
+        self.multiply_value_specifying_quantity = multiply_value_specifying_quantity
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> VerifyCounterByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> VerifyCounterByUserIdRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyCounterByUserIdRequest]:
+        if data is None:
+            return None
+        return VerifyCounterByUserIdRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_user_id(data.get('userId'))\
+            .with_limit_name(data.get('limitName'))\
+            .with_counter_name(data.get('counterName'))\
+            .with_verify_type(data.get('verifyType'))\
+            .with_count(data.get('count'))\
+            .with_multiply_value_specifying_quantity(data.get('multiplyValueSpecifyingQuantity'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "userId": self.user_id,
+            "limitName": self.limit_name,
+            "counterName": self.counter_name,
+            "verifyType": self.verify_type,
+            "count": self.count,
+            "multiplyValueSpecifyingQuantity": self.multiply_value_specifying_quantity,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -767,6 +1388,49 @@ class CountUpByStampTaskRequest(core.Gs2Request):
         }
 
 
+class CountDownByStampSheetRequest(core.Gs2Request):
+
+    context_stack: str = None
+    stamp_sheet: str = None
+    key_id: str = None
+
+    def with_stamp_sheet(self, stamp_sheet: str) -> CountDownByStampSheetRequest:
+        self.stamp_sheet = stamp_sheet
+        return self
+
+    def with_key_id(self, key_id: str) -> CountDownByStampSheetRequest:
+        self.key_id = key_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CountDownByStampSheetRequest]:
+        if data is None:
+            return None
+        return CountDownByStampSheetRequest()\
+            .with_stamp_sheet(data.get('stampSheet'))\
+            .with_key_id(data.get('keyId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "stampSheet": self.stamp_sheet,
+            "keyId": self.key_id,
+        }
+
+
 class DeleteByStampSheetRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -810,6 +1474,49 @@ class DeleteByStampSheetRequest(core.Gs2Request):
         }
 
 
+class VerifyCounterByStampTaskRequest(core.Gs2Request):
+
+    context_stack: str = None
+    stamp_task: str = None
+    key_id: str = None
+
+    def with_stamp_task(self, stamp_task: str) -> VerifyCounterByStampTaskRequest:
+        self.stamp_task = stamp_task
+        return self
+
+    def with_key_id(self, key_id: str) -> VerifyCounterByStampTaskRequest:
+        self.key_id = key_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyCounterByStampTaskRequest]:
+        if data is None:
+            return None
+        return VerifyCounterByStampTaskRequest()\
+            .with_stamp_task(data.get('stampTask'))\
+            .with_key_id(data.get('keyId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "stampTask": self.stamp_task,
+            "keyId": self.key_id,
+        }
+
+
 class DescribeLimitModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -871,6 +1578,8 @@ class CreateLimitModelMasterRequest(core.Gs2Request):
     reset_day_of_month: int = None
     reset_day_of_week: str = None
     reset_hour: int = None
+    anchor_timestamp: int = None
+    days: int = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateLimitModelMasterRequest:
         self.namespace_name = namespace_name
@@ -904,6 +1613,14 @@ class CreateLimitModelMasterRequest(core.Gs2Request):
         self.reset_hour = reset_hour
         return self
 
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> CreateLimitModelMasterRequest:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_days(self, days: int) -> CreateLimitModelMasterRequest:
+        self.days = days
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -930,7 +1647,9 @@ class CreateLimitModelMasterRequest(core.Gs2Request):
             .with_reset_type(data.get('resetType'))\
             .with_reset_day_of_month(data.get('resetDayOfMonth'))\
             .with_reset_day_of_week(data.get('resetDayOfWeek'))\
-            .with_reset_hour(data.get('resetHour'))
+            .with_reset_hour(data.get('resetHour'))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_days(data.get('days'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -942,6 +1661,8 @@ class CreateLimitModelMasterRequest(core.Gs2Request):
             "resetDayOfMonth": self.reset_day_of_month,
             "resetDayOfWeek": self.reset_day_of_week,
             "resetHour": self.reset_hour,
+            "anchorTimestamp": self.anchor_timestamp,
+            "days": self.days,
         }
 
 
@@ -999,6 +1720,8 @@ class UpdateLimitModelMasterRequest(core.Gs2Request):
     reset_day_of_month: int = None
     reset_day_of_week: str = None
     reset_hour: int = None
+    anchor_timestamp: int = None
+    days: int = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateLimitModelMasterRequest:
         self.namespace_name = namespace_name
@@ -1032,6 +1755,14 @@ class UpdateLimitModelMasterRequest(core.Gs2Request):
         self.reset_hour = reset_hour
         return self
 
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> UpdateLimitModelMasterRequest:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_days(self, days: int) -> UpdateLimitModelMasterRequest:
+        self.days = days
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1058,7 +1789,9 @@ class UpdateLimitModelMasterRequest(core.Gs2Request):
             .with_reset_type(data.get('resetType'))\
             .with_reset_day_of_month(data.get('resetDayOfMonth'))\
             .with_reset_day_of_week(data.get('resetDayOfWeek'))\
-            .with_reset_hour(data.get('resetHour'))
+            .with_reset_hour(data.get('resetHour'))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_days(data.get('days'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1070,6 +1803,8 @@ class UpdateLimitModelMasterRequest(core.Gs2Request):
             "resetDayOfMonth": self.reset_day_of_month,
             "resetDayOfWeek": self.reset_day_of_week,
             "resetHour": self.reset_hour,
+            "anchorTimestamp": self.anchor_timestamp,
+            "days": self.days,
         }
 
 
@@ -1188,20 +1923,66 @@ class GetCurrentLimitMasterRequest(core.Gs2Request):
         }
 
 
+class PreUpdateCurrentLimitMasterRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> PreUpdateCurrentLimitMasterRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PreUpdateCurrentLimitMasterRequest]:
+        if data is None:
+            return None
+        return PreUpdateCurrentLimitMasterRequest()\
+            .with_namespace_name(data.get('namespaceName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+        }
+
+
 class UpdateCurrentLimitMasterRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    mode: str = None
     settings: str = None
+    upload_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateCurrentLimitMasterRequest:
         self.namespace_name = namespace_name
         return self
 
+    def with_mode(self, mode: str) -> UpdateCurrentLimitMasterRequest:
+        self.mode = mode
+        return self
+
     def with_settings(self, settings: str) -> UpdateCurrentLimitMasterRequest:
         self.settings = settings
         return self
 
+    def with_upload_token(self, upload_token: str) -> UpdateCurrentLimitMasterRequest:
+        self.upload_token = upload_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1222,12 +2003,16 @@ class UpdateCurrentLimitMasterRequest(core.Gs2Request):
             return None
         return UpdateCurrentLimitMasterRequest()\
             .with_namespace_name(data.get('namespaceName'))\
-            .with_settings(data.get('settings'))
+            .with_mode(data.get('mode'))\
+            .with_settings(data.get('settings'))\
+            .with_upload_token(data.get('uploadToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "mode": self.mode,
             "settings": self.settings,
+            "uploadToken": self.upload_token,
         }
 
 
