@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -457,6 +458,590 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='getServiceVersion',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=GetServiceVersionResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _dump_user_data_by_user_id(
+        self,
+        request: DumpUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[DumpUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='dumpUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=DumpUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def dump_user_data_by_user_id(
+        self,
+        request: DumpUserDataByUserIdRequest,
+    ) -> DumpUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._dump_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def dump_user_data_by_user_id_async(
+        self,
+        request: DumpUserDataByUserIdRequest,
+    ) -> DumpUserDataByUserIdResult:
+        async_result = []
+        self._dump_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_dump_user_data_by_user_id(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckDumpUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='checkDumpUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckDumpUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_dump_user_data_by_user_id(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+    ) -> CheckDumpUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_dump_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_dump_user_data_by_user_id_async(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+    ) -> CheckDumpUserDataByUserIdResult:
+        async_result = []
+        self._check_dump_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _clean_user_data_by_user_id(
+        self,
+        request: CleanUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CleanUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='cleanUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CleanUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def clean_user_data_by_user_id(
+        self,
+        request: CleanUserDataByUserIdRequest,
+    ) -> CleanUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._clean_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def clean_user_data_by_user_id_async(
+        self,
+        request: CleanUserDataByUserIdRequest,
+    ) -> CleanUserDataByUserIdResult:
+        async_result = []
+        self._clean_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_clean_user_data_by_user_id(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckCleanUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='checkCleanUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckCleanUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_clean_user_data_by_user_id(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+    ) -> CheckCleanUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_clean_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_clean_user_data_by_user_id_async(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+    ) -> CheckCleanUserDataByUserIdResult:
+        async_result = []
+        self._check_clean_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _prepare_import_user_data_by_user_id(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[PrepareImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='prepareImportUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=PrepareImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def prepare_import_user_data_by_user_id(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+    ) -> PrepareImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._prepare_import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def prepare_import_user_data_by_user_id_async(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+    ) -> PrepareImportUserDataByUserIdResult:
+        async_result = []
+        self._prepare_import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _import_user_data_by_user_id(
+        self,
+        request: ImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[ImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='importUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=ImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def import_user_data_by_user_id(
+        self,
+        request: ImportUserDataByUserIdRequest,
+    ) -> ImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def import_user_data_by_user_id_async(
+        self,
+        request: ImportUserDataByUserIdRequest,
+    ) -> ImportUserDataByUserIdResult:
+        async_result = []
+        self._import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_import_user_data_by_user_id(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='namespace',
+            function='checkImportUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_import_user_data_by_user_id(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+    ) -> CheckImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_import_user_data_by_user_id_async(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+    ) -> CheckImportUserDataByUserIdResult:
+        async_result = []
+        self._check_import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_counters(
         self,
         request: DescribeCountersRequest,
@@ -565,6 +1150,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -721,6 +1308,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.counter_name is not None:
             body["counterName"] = request.counter_name
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -887,6 +1476,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["countUpValue"] = request.count_up_value
         if request.max_value is not None:
             body["maxValue"] = request.max_value
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -941,6 +1532,89 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _count_down_by_user_id(
+        self,
+        request: CountDownByUserIdRequest,
+        callback: Callable[[AsyncResult[CountDownByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='counter',
+            function='countDownByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.limit_name is not None:
+            body["limitName"] = request.limit_name
+        if request.counter_name is not None:
+            body["counterName"] = request.counter_name
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.count_down_value is not None:
+            body["countDownValue"] = request.count_down_value
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CountDownByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def count_down_by_user_id(
+        self,
+        request: CountDownByUserIdRequest,
+    ) -> CountDownByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._count_down_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def count_down_by_user_id_async(
+        self,
+        request: CountDownByUserIdRequest,
+    ) -> CountDownByUserIdResult:
+        async_result = []
+        self._count_down_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _delete_counter_by_user_id(
         self,
         request: DeleteCounterByUserIdRequest,
@@ -966,6 +1640,8 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.counter_name is not None:
             body["counterName"] = request.counter_name
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1020,6 +1696,180 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _verify_counter(
+        self,
+        request: VerifyCounterRequest,
+        callback: Callable[[AsyncResult[VerifyCounterResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='counter',
+            function='verifyCounter',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.access_token is not None:
+            body["accessToken"] = request.access_token
+        if request.limit_name is not None:
+            body["limitName"] = request.limit_name
+        if request.counter_name is not None:
+            body["counterName"] = request.counter_name
+        if request.verify_type is not None:
+            body["verifyType"] = request.verify_type
+        if request.count is not None:
+            body["count"] = request.count
+        if request.multiply_value_specifying_quantity is not None:
+            body["multiplyValueSpecifyingQuantity"] = request.multiply_value_specifying_quantity
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.access_token:
+            body["xGs2AccessToken"] = request.access_token
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=VerifyCounterResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def verify_counter(
+        self,
+        request: VerifyCounterRequest,
+    ) -> VerifyCounterResult:
+        async_result = []
+        with timeout(30):
+            self._verify_counter(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def verify_counter_async(
+        self,
+        request: VerifyCounterRequest,
+    ) -> VerifyCounterResult:
+        async_result = []
+        self._verify_counter(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _verify_counter_by_user_id(
+        self,
+        request: VerifyCounterByUserIdRequest,
+        callback: Callable[[AsyncResult[VerifyCounterByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='counter',
+            function='verifyCounterByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.limit_name is not None:
+            body["limitName"] = request.limit_name
+        if request.counter_name is not None:
+            body["counterName"] = request.counter_name
+        if request.verify_type is not None:
+            body["verifyType"] = request.verify_type
+        if request.count is not None:
+            body["count"] = request.count
+        if request.multiply_value_specifying_quantity is not None:
+            body["multiplyValueSpecifyingQuantity"] = request.multiply_value_specifying_quantity
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=VerifyCounterByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def verify_counter_by_user_id(
+        self,
+        request: VerifyCounterByUserIdRequest,
+    ) -> VerifyCounterByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._verify_counter_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def verify_counter_by_user_id_async(
+        self,
+        request: VerifyCounterByUserIdRequest,
+    ) -> VerifyCounterByUserIdResult:
+        async_result = []
+        self._verify_counter_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _count_up_by_stamp_task(
         self,
         request: CountUpByStampTaskRequest,
@@ -1093,6 +1943,79 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _count_down_by_stamp_sheet(
+        self,
+        request: CountDownByStampSheetRequest,
+        callback: Callable[[AsyncResult[CountDownByStampSheetResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='counter',
+            function='countDownByStampSheet',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.stamp_sheet is not None:
+            body["stampSheet"] = request.stamp_sheet
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CountDownByStampSheetResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def count_down_by_stamp_sheet(
+        self,
+        request: CountDownByStampSheetRequest,
+    ) -> CountDownByStampSheetResult:
+        async_result = []
+        with timeout(30):
+            self._count_down_by_stamp_sheet(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def count_down_by_stamp_sheet_async(
+        self,
+        request: CountDownByStampSheetRequest,
+    ) -> CountDownByStampSheetResult:
+        async_result = []
+        self._count_down_by_stamp_sheet(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _delete_by_stamp_sheet(
         self,
         request: DeleteByStampSheetRequest,
@@ -1166,6 +2089,79 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _verify_counter_by_stamp_task(
+        self,
+        request: VerifyCounterByStampTaskRequest,
+        callback: Callable[[AsyncResult[VerifyCounterByStampTaskResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='counter',
+            function='verifyCounterByStampTask',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.stamp_task is not None:
+            body["stampTask"] = request.stamp_task
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=VerifyCounterByStampTaskResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def verify_counter_by_stamp_task(
+        self,
+        request: VerifyCounterByStampTaskRequest,
+    ) -> VerifyCounterByStampTaskResult:
+        async_result = []
+        with timeout(30):
+            self._verify_counter_by_stamp_task(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def verify_counter_by_stamp_task_async(
+        self,
+        request: VerifyCounterByStampTaskRequest,
+    ) -> VerifyCounterByStampTaskResult:
+        async_result = []
+        self._verify_counter_by_stamp_task(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_limit_model_masters(
         self,
         request: DescribeLimitModelMastersRequest,
@@ -1274,6 +2270,10 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["resetDayOfWeek"] = request.reset_day_of_week
         if request.reset_hour is not None:
             body["resetHour"] = request.reset_hour
+        if request.anchor_timestamp is not None:
+            body["anchorTimestamp"] = request.anchor_timestamp
+        if request.days is not None:
+            body["days"] = request.days
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1432,6 +2432,10 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["resetDayOfWeek"] = request.reset_day_of_week
         if request.reset_hour is not None:
             body["resetHour"] = request.reset_hour
+        if request.anchor_timestamp is not None:
+            body["anchorTimestamp"] = request.anchor_timestamp
+        if request.days is not None:
+            body["days"] = request.days
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1699,6 +2703,77 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _pre_update_current_limit_master(
+        self,
+        request: PreUpdateCurrentLimitMasterRequest,
+        callback: Callable[[AsyncResult[PreUpdateCurrentLimitMasterResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="limit",
+            component='currentLimitMaster',
+            function='preUpdateCurrentLimitMaster',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=PreUpdateCurrentLimitMasterResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def pre_update_current_limit_master(
+        self,
+        request: PreUpdateCurrentLimitMasterRequest,
+    ) -> PreUpdateCurrentLimitMasterResult:
+        async_result = []
+        with timeout(30):
+            self._pre_update_current_limit_master(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def pre_update_current_limit_master_async(
+        self,
+        request: PreUpdateCurrentLimitMasterRequest,
+    ) -> PreUpdateCurrentLimitMasterResult:
+        async_result = []
+        self._pre_update_current_limit_master(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _update_current_limit_master(
         self,
         request: UpdateCurrentLimitMasterRequest,
@@ -1718,8 +2793,12 @@ class Gs2LimitWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body['contextStack'] = str(request.context_stack)
         if request.namespace_name is not None:
             body["namespaceName"] = request.namespace_name
+        if request.mode is not None:
+            body["mode"] = request.mode
         if request.settings is not None:
             body["settings"] = request.settings
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
