@@ -268,29 +268,9 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
-class DescribeMutexesRequest(core.Gs2Request):
+class GetServiceVersionRequest(core.Gs2Request):
 
     context_stack: str = None
-    namespace_name: str = None
-    access_token: str = None
-    page_token: str = None
-    limit: int = None
-
-    def with_namespace_name(self, namespace_name: str) -> DescribeMutexesRequest:
-        self.namespace_name = namespace_name
-        return self
-
-    def with_access_token(self, access_token: str) -> DescribeMutexesRequest:
-        self.access_token = access_token
-        return self
-
-    def with_page_token(self, page_token: str) -> DescribeMutexesRequest:
-        self.page_token = page_token
-        return self
-
-    def with_limit(self, limit: int) -> DescribeMutexesRequest:
-        self.limit = limit
-        return self
 
     def get(self, key, default=None):
         items = self.to_dict()
@@ -307,78 +287,13 @@ class DescribeMutexesRequest(core.Gs2Request):
     @staticmethod
     def from_dict(
         data: Dict[str, Any],
-    ) -> Optional[DescribeMutexesRequest]:
+    ) -> Optional[GetServiceVersionRequest]:
         if data is None:
             return None
-        return DescribeMutexesRequest()\
-            .with_namespace_name(data.get('namespaceName'))\
-            .with_access_token(data.get('accessToken'))\
-            .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+        return GetServiceVersionRequest()\
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "namespaceName": self.namespace_name,
-            "accessToken": self.access_token,
-            "pageToken": self.page_token,
-            "limit": self.limit,
-        }
-
-
-class DescribeMutexesByUserIdRequest(core.Gs2Request):
-
-    context_stack: str = None
-    namespace_name: str = None
-    user_id: str = None
-    page_token: str = None
-    limit: int = None
-
-    def with_namespace_name(self, namespace_name: str) -> DescribeMutexesByUserIdRequest:
-        self.namespace_name = namespace_name
-        return self
-
-    def with_user_id(self, user_id: str) -> DescribeMutexesByUserIdRequest:
-        self.user_id = user_id
-        return self
-
-    def with_page_token(self, page_token: str) -> DescribeMutexesByUserIdRequest:
-        self.page_token = page_token
-        return self
-
-    def with_limit(self, limit: int) -> DescribeMutexesByUserIdRequest:
-        self.limit = limit
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[DescribeMutexesByUserIdRequest]:
-        if data is None:
-            return None
-        return DescribeMutexesByUserIdRequest()\
-            .with_namespace_name(data.get('namespaceName'))\
-            .with_user_id(data.get('userId'))\
-            .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "namespaceName": self.namespace_name,
-            "userId": self.user_id,
-            "pageToken": self.page_token,
-            "limit": self.limit,
         }
 
 
@@ -459,6 +374,7 @@ class LockByUserIdRequest(core.Gs2Request):
     user_id: str = None
     transaction_id: str = None
     ttl: int = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> LockByUserIdRequest:
@@ -481,6 +397,10 @@ class LockByUserIdRequest(core.Gs2Request):
         self.ttl = ttl
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> LockByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> LockByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -508,7 +428,8 @@ class LockByUserIdRequest(core.Gs2Request):
             .with_property_id(data.get('propertyId'))\
             .with_user_id(data.get('userId'))\
             .with_transaction_id(data.get('transactionId'))\
-            .with_ttl(data.get('ttl'))
+            .with_ttl(data.get('ttl'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -517,6 +438,7 @@ class LockByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "transactionId": self.transaction_id,
             "ttl": self.ttl,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -589,6 +511,7 @@ class UnlockByUserIdRequest(core.Gs2Request):
     property_id: str = None
     user_id: str = None
     transaction_id: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UnlockByUserIdRequest:
@@ -607,6 +530,10 @@ class UnlockByUserIdRequest(core.Gs2Request):
         self.transaction_id = transaction_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> UnlockByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> UnlockByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -633,7 +560,8 @@ class UnlockByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_property_id(data.get('propertyId'))\
             .with_user_id(data.get('userId'))\
-            .with_transaction_id(data.get('transactionId'))
+            .with_transaction_id(data.get('transactionId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -641,6 +569,7 @@ class UnlockByUserIdRequest(core.Gs2Request):
             "propertyId": self.property_id,
             "userId": self.user_id,
             "transactionId": self.transaction_id,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -700,6 +629,7 @@ class GetMutexByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     property_id: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetMutexByUserIdRequest:
         self.namespace_name = namespace_name
@@ -713,6 +643,10 @@ class GetMutexByUserIdRequest(core.Gs2Request):
         self.property_id = property_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> GetMutexByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -734,13 +668,15 @@ class GetMutexByUserIdRequest(core.Gs2Request):
         return GetMutexByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_property_id(data.get('propertyId'))
+            .with_property_id(data.get('propertyId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "propertyId": self.property_id,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -750,6 +686,7 @@ class DeleteMutexByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     property_id: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteMutexByUserIdRequest:
@@ -764,6 +701,10 @@ class DeleteMutexByUserIdRequest(core.Gs2Request):
         self.property_id = property_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DeleteMutexByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DeleteMutexByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -789,11 +730,13 @@ class DeleteMutexByUserIdRequest(core.Gs2Request):
         return DeleteMutexByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_property_id(data.get('propertyId'))
+            .with_property_id(data.get('propertyId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "propertyId": self.property_id,
+            "timeOffsetToken": self.time_offset_token,
         }
\ No newline at end of file
