@@ -27,6 +27,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNamespacesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -100,6 +101,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -175,6 +177,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceStatusResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -246,6 +249,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -317,6 +321,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -392,6 +397,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -457,36 +463,29 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _describe_mutexes(
+    def _get_service_version(
         self,
-        request: DescribeMutexesRequest,
-        callback: Callable[[AsyncResult[DescribeMutexesResult]], None],
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
-        ) + "/{namespaceName}/user/me/mutex".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-        )
+        ) + "/system/version"
 
         headers = self._create_authorized_headers()
         query_strings = {
             'contextStack': request.context_stack,
         }
-        if request.page_token is not None:
-            query_strings["pageToken"] = request.page_token
-        if request.limit is not None:
-            query_strings["limit"] = request.limit
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.access_token:
-            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
-            result_type=DescribeMutexesResult,
+            result_type=GetServiceVersionResult,
             callback=callback,
             headers=headers,
             query_strings=query_strings,
@@ -497,13 +496,13 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
             is_blocking=is_blocking,
         )
 
-    def describe_mutexes(
+    def get_service_version(
         self,
-        request: DescribeMutexesRequest,
-    ) -> DescribeMutexesResult:
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
         async_result = []
         with timeout(30):
-            self._describe_mutexes(
+            self._get_service_version(
                 request,
                 lambda result: async_result.append(result),
                 is_blocking=True,
@@ -514,88 +513,12 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         return async_result[0].result
 
 
-    async def describe_mutexes_async(
+    async def get_service_version_async(
         self,
-        request: DescribeMutexesRequest,
-    ) -> DescribeMutexesResult:
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
         async_result = []
-        self._describe_mutexes(
-            request,
-            lambda result: async_result.append(result),
-            is_blocking=False,
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _describe_mutexes_by_user_id(
-        self,
-        request: DescribeMutexesByUserIdRequest,
-        callback: Callable[[AsyncResult[DescribeMutexesByUserIdResult]], None],
-        is_blocking: bool,
-    ):
-        url = Gs2Constant.ENDPOINT_HOST.format(
-            service='lock',
-            region=self.session.region,
-        ) + "/{namespaceName}/user/{userId}/mutex".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
-        )
-
-        headers = self._create_authorized_headers()
-        query_strings = {
-            'contextStack': request.context_stack,
-        }
-        if request.page_token is not None:
-            query_strings["pageToken"] = request.page_token
-        if request.limit is not None:
-            query_strings["limit"] = request.limit
-
-        if request.request_id:
-            headers["X-GS2-REQUEST-ID"] = request.request_id
-        _job = rest.NetworkJob(
-            url=url,
-            method='GET',
-            result_type=DescribeMutexesByUserIdResult,
-            callback=callback,
-            headers=headers,
-            query_strings=query_strings,
-        )
-
-        self.session.send(
-            job=_job,
-            is_blocking=is_blocking,
-        )
-
-    def describe_mutexes_by_user_id(
-        self,
-        request: DescribeMutexesByUserIdRequest,
-    ) -> DescribeMutexesByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._describe_mutexes_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-                is_blocking=True,
-            )
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def describe_mutexes_by_user_id_async(
-        self,
-        request: DescribeMutexesByUserIdRequest,
-    ) -> DescribeMutexesByUserIdResult:
-        async_result = []
-        self._describe_mutexes_by_user_id(
+        self._get_service_version(
             request,
             lambda result: async_result.append(result),
             is_blocking=False,
@@ -616,6 +539,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[LockResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -696,6 +620,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[LockByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -718,6 +643,8 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
             headers["X-GS2-REQUEST-ID"] = request.request_id
         if request.duplication_avoider:
             headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='POST',
@@ -775,6 +702,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UnlockResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -853,6 +781,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UnlockByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -873,6 +802,8 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
             headers["X-GS2-REQUEST-ID"] = request.request_id
         if request.duplication_avoider:
             headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='POST',
@@ -930,6 +861,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetMutexResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -1004,6 +936,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetMutexByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -1020,6 +953,8 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -1077,6 +1012,7 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteMutexByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='lock',
             region=self.session.region,
@@ -1095,6 +1031,8 @@ class Gs2LockRestClient(rest.AbstractGs2RestClient):
             headers["X-GS2-REQUEST-ID"] = request.request_id
         if request.duplication_avoider:
             headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='DELETE',
