@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -457,53 +458,43 @@ class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _describe_mutexes(
+    def _get_service_version(
         self,
-        request: DescribeMutexesRequest,
-        callback: Callable[[AsyncResult[DescribeMutexesResult]], None],
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
     ):
         import uuid
 
         request_id = str(uuid.uuid4())
         body = self._create_metadata(
             service="lock",
-            component='mutex',
-            function='describeMutexes',
+            component='namespace',
+            function='getServiceVersion',
             request_id=request_id,
         )
 
         if request.context_stack:
             body['contextStack'] = str(request.context_stack)
-        if request.namespace_name is not None:
-            body["namespaceName"] = request.namespace_name
-        if request.access_token is not None:
-            body["accessToken"] = request.access_token
-        if request.page_token is not None:
-            body["pageToken"] = request.page_token
-        if request.limit is not None:
-            body["limit"] = request.limit
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
-        if request.access_token:
-            body["xGs2AccessToken"] = request.access_token
 
         self.session.send(
             web_socket.NetworkJob(
                 request_id=request_id,
-                result_type=DescribeMutexesResult,
+                result_type=GetServiceVersionResult,
                 callback=callback,
                 body=body,
             )
         )
 
-    def describe_mutexes(
+    def get_service_version(
         self,
-        request: DescribeMutexesRequest,
-    ) -> DescribeMutexesResult:
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
         async_result = []
         with timeout(30):
-            self._describe_mutexes(
+            self._get_service_version(
                 request,
                 lambda result: async_result.append(result),
             )
@@ -517,89 +508,12 @@ class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
         return async_result[0].result
 
 
-    async def describe_mutexes_async(
+    async def get_service_version_async(
         self,
-        request: DescribeMutexesRequest,
-    ) -> DescribeMutexesResult:
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
         async_result = []
-        self._describe_mutexes(
-            request,
-            lambda result: async_result.append(result),
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _describe_mutexes_by_user_id(
-        self,
-        request: DescribeMutexesByUserIdRequest,
-        callback: Callable[[AsyncResult[DescribeMutexesByUserIdResult]], None],
-    ):
-        import uuid
-
-        request_id = str(uuid.uuid4())
-        body = self._create_metadata(
-            service="lock",
-            component='mutex',
-            function='describeMutexesByUserId',
-            request_id=request_id,
-        )
-
-        if request.context_stack:
-            body['contextStack'] = str(request.context_stack)
-        if request.namespace_name is not None:
-            body["namespaceName"] = request.namespace_name
-        if request.user_id is not None:
-            body["userId"] = request.user_id
-        if request.page_token is not None:
-            body["pageToken"] = request.page_token
-        if request.limit is not None:
-            body["limit"] = request.limit
-
-        if request.request_id:
-            body["xGs2RequestId"] = request.request_id
-
-        self.session.send(
-            web_socket.NetworkJob(
-                request_id=request_id,
-                result_type=DescribeMutexesByUserIdResult,
-                callback=callback,
-                body=body,
-            )
-        )
-
-    def describe_mutexes_by_user_id(
-        self,
-        request: DescribeMutexesByUserIdRequest,
-    ) -> DescribeMutexesByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._describe_mutexes_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-            )
-
-        with timeout(30):
-            while not async_result:
-                time.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def describe_mutexes_by_user_id_async(
-        self,
-        request: DescribeMutexesByUserIdRequest,
-    ) -> DescribeMutexesByUserIdResult:
-        async_result = []
-        self._describe_mutexes_by_user_id(
+        self._get_service_version(
             request,
             lambda result: async_result.append(result),
         )
@@ -723,6 +637,8 @@ class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["transactionId"] = request.transaction_id
         if request.ttl is not None:
             body["ttl"] = request.ttl
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -883,6 +799,8 @@ class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.transaction_id is not None:
             body["transactionId"] = request.transaction_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1037,6 +955,8 @@ class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.property_id is not None:
             body["propertyId"] = request.property_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1112,6 +1032,8 @@ class Gs2LockWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.property_id is not None:
             body["propertyId"] = request.property_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
