@@ -73,6 +73,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     aws_access_key_id: str = None
     aws_secret_access_key: str = None
     firehose_stream_name: str = None
+    firehose_compress_data: str = None
 
     def with_name(self, name: str) -> CreateNamespaceRequest:
         self.name = name
@@ -114,6 +115,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.firehose_stream_name = firehose_stream_name
         return self
 
+    def with_firehose_compress_data(self, firehose_compress_data: str) -> CreateNamespaceRequest:
+        self.firehose_compress_data = firehose_compress_data
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -142,7 +147,8 @@ class CreateNamespaceRequest(core.Gs2Request):
             .with_aws_region(data.get('awsRegion'))\
             .with_aws_access_key_id(data.get('awsAccessKeyId'))\
             .with_aws_secret_access_key(data.get('awsSecretAccessKey'))\
-            .with_firehose_stream_name(data.get('firehoseStreamName'))
+            .with_firehose_stream_name(data.get('firehoseStreamName'))\
+            .with_firehose_compress_data(data.get('firehoseCompressData'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -156,6 +162,7 @@ class CreateNamespaceRequest(core.Gs2Request):
             "awsAccessKeyId": self.aws_access_key_id,
             "awsSecretAccessKey": self.aws_secret_access_key,
             "firehoseStreamName": self.firehose_stream_name,
+            "firehoseCompressData": self.firehose_compress_data,
         }
 
 
@@ -244,6 +251,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     aws_access_key_id: str = None
     aws_secret_access_key: str = None
     firehose_stream_name: str = None
+    firehose_compress_data: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateNamespaceRequest:
         self.namespace_name = namespace_name
@@ -285,6 +293,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.firehose_stream_name = firehose_stream_name
         return self
 
+    def with_firehose_compress_data(self, firehose_compress_data: str) -> UpdateNamespaceRequest:
+        self.firehose_compress_data = firehose_compress_data
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -313,7 +325,8 @@ class UpdateNamespaceRequest(core.Gs2Request):
             .with_aws_region(data.get('awsRegion'))\
             .with_aws_access_key_id(data.get('awsAccessKeyId'))\
             .with_aws_secret_access_key(data.get('awsSecretAccessKey'))\
-            .with_firehose_stream_name(data.get('firehoseStreamName'))
+            .with_firehose_stream_name(data.get('firehoseStreamName'))\
+            .with_firehose_compress_data(data.get('firehoseCompressData'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -327,6 +340,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
             "awsAccessKeyId": self.aws_access_key_id,
             "awsSecretAccessKey": self.aws_secret_access_key,
             "firehoseStreamName": self.firehose_stream_name,
+            "firehoseCompressData": self.firehose_compress_data,
         }
 
 
@@ -366,6 +380,35 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
 class QueryAccessLogRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -378,7 +421,7 @@ class QueryAccessLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
-    duplication_avoider: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryAccessLogRequest:
         self.namespace_name = namespace_name
@@ -416,8 +459,8 @@ class QueryAccessLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> QueryAccessLogRequest:
-        self.duplication_avoider = duplication_avoider
+    def with_time_offset_token(self, time_offset_token: str) -> QueryAccessLogRequest:
+        self.time_offset_token = time_offset_token
         return self
 
     def get(self, key, default=None):
@@ -447,7 +490,8 @@ class QueryAccessLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -460,6 +504,7 @@ class QueryAccessLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -475,6 +520,7 @@ class CountAccessLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CountAccessLogRequest:
         self.namespace_name = namespace_name
@@ -512,6 +558,10 @@ class CountAccessLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> CountAccessLogRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -539,7 +589,8 @@ class CountAccessLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -552,6 +603,7 @@ class CountAccessLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -568,7 +620,7 @@ class QueryIssueStampSheetLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
-    duplication_avoider: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryIssueStampSheetLogRequest:
         self.namespace_name = namespace_name
@@ -610,8 +662,8 @@ class QueryIssueStampSheetLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> QueryIssueStampSheetLogRequest:
-        self.duplication_avoider = duplication_avoider
+    def with_time_offset_token(self, time_offset_token: str) -> QueryIssueStampSheetLogRequest:
+        self.time_offset_token = time_offset_token
         return self
 
     def get(self, key, default=None):
@@ -642,7 +694,8 @@ class QueryIssueStampSheetLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -656,6 +709,7 @@ class QueryIssueStampSheetLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -672,6 +726,7 @@ class CountIssueStampSheetLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CountIssueStampSheetLogRequest:
         self.namespace_name = namespace_name
@@ -713,6 +768,10 @@ class CountIssueStampSheetLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> CountIssueStampSheetLogRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -741,7 +800,8 @@ class CountIssueStampSheetLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -755,6 +815,7 @@ class CountIssueStampSheetLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -771,7 +832,7 @@ class QueryExecuteStampSheetLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
-    duplication_avoider: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryExecuteStampSheetLogRequest:
         self.namespace_name = namespace_name
@@ -813,8 +874,8 @@ class QueryExecuteStampSheetLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> QueryExecuteStampSheetLogRequest:
-        self.duplication_avoider = duplication_avoider
+    def with_time_offset_token(self, time_offset_token: str) -> QueryExecuteStampSheetLogRequest:
+        self.time_offset_token = time_offset_token
         return self
 
     def get(self, key, default=None):
@@ -845,7 +906,8 @@ class QueryExecuteStampSheetLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -859,6 +921,7 @@ class QueryExecuteStampSheetLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -875,6 +938,7 @@ class CountExecuteStampSheetLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CountExecuteStampSheetLogRequest:
         self.namespace_name = namespace_name
@@ -916,6 +980,10 @@ class CountExecuteStampSheetLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> CountExecuteStampSheetLogRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -944,7 +1012,8 @@ class CountExecuteStampSheetLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -958,6 +1027,7 @@ class CountExecuteStampSheetLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -974,7 +1044,7 @@ class QueryExecuteStampTaskLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
-    duplication_avoider: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryExecuteStampTaskLogRequest:
         self.namespace_name = namespace_name
@@ -1016,8 +1086,8 @@ class QueryExecuteStampTaskLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
-    def with_duplication_avoider(self, duplication_avoider: str) -> QueryExecuteStampTaskLogRequest:
-        self.duplication_avoider = duplication_avoider
+    def with_time_offset_token(self, time_offset_token: str) -> QueryExecuteStampTaskLogRequest:
+        self.time_offset_token = time_offset_token
         return self
 
     def get(self, key, default=None):
@@ -1048,7 +1118,8 @@ class QueryExecuteStampTaskLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1062,6 +1133,7 @@ class QueryExecuteStampTaskLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1078,6 +1150,7 @@ class CountExecuteStampTaskLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CountExecuteStampTaskLogRequest:
         self.namespace_name = namespace_name
@@ -1119,6 +1192,10 @@ class CountExecuteStampTaskLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> CountExecuteStampTaskLogRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1147,7 +1224,8 @@ class CountExecuteStampTaskLogRequest(core.Gs2Request):
             .with_end(data.get('end'))\
             .with_long_term(data.get('longTerm'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1161,26 +1239,62 @@ class CountExecuteStampTaskLogRequest(core.Gs2Request):
             "longTerm": self.long_term,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
-class PutLogRequest(core.Gs2Request):
+class QueryInGameLogRequest(core.Gs2Request):
 
     context_stack: str = None
-    logging_namespace_id: str = None
-    log_category: str = None
-    payload: str = None
+    namespace_name: str = None
+    user_id: str = None
+    tags: List[InGameLogTag] = None
+    begin: int = None
+    end: int = None
+    long_term: bool = None
+    page_token: str = None
+    limit: int = None
+    time_offset_token: str = None
+    duplication_avoider: str = None
 
-    def with_logging_namespace_id(self, logging_namespace_id: str) -> PutLogRequest:
-        self.logging_namespace_id = logging_namespace_id
+    def with_namespace_name(self, namespace_name: str) -> QueryInGameLogRequest:
+        self.namespace_name = namespace_name
         return self
 
-    def with_log_category(self, log_category: str) -> PutLogRequest:
-        self.log_category = log_category
+    def with_user_id(self, user_id: str) -> QueryInGameLogRequest:
+        self.user_id = user_id
         return self
 
-    def with_payload(self, payload: str) -> PutLogRequest:
-        self.payload = payload
+    def with_tags(self, tags: List[InGameLogTag]) -> QueryInGameLogRequest:
+        self.tags = tags
+        return self
+
+    def with_begin(self, begin: int) -> QueryInGameLogRequest:
+        self.begin = begin
+        return self
+
+    def with_end(self, end: int) -> QueryInGameLogRequest:
+        self.end = end
+        return self
+
+    def with_long_term(self, long_term: bool) -> QueryInGameLogRequest:
+        self.long_term = long_term
+        return self
+
+    def with_page_token(self, page_token: str) -> QueryInGameLogRequest:
+        self.page_token = page_token
+        return self
+
+    def with_limit(self, limit: int) -> QueryInGameLogRequest:
+        self.limit = limit
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> QueryInGameLogRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> QueryInGameLogRequest:
+        self.duplication_avoider = duplication_avoider
         return self
 
     def get(self, key, default=None):
@@ -1198,22 +1312,268 @@ class PutLogRequest(core.Gs2Request):
     @staticmethod
     def from_dict(
         data: Dict[str, Any],
-    ) -> Optional[PutLogRequest]:
+    ) -> Optional[QueryInGameLogRequest]:
         if data is None:
             return None
-        return PutLogRequest()\
-            .with_logging_namespace_id(data.get('loggingNamespaceId'))\
-            .with_log_category(data.get('logCategory'))\
+        return QueryInGameLogRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_user_id(data.get('userId'))\
+            .with_tags(None if data.get('tags') is None else [
+                InGameLogTag.from_dict(data.get('tags')[i])
+                for i in range(len(data.get('tags')))
+            ])\
+            .with_begin(data.get('begin'))\
+            .with_end(data.get('end'))\
+            .with_long_term(data.get('longTerm'))\
+            .with_page_token(data.get('pageToken'))\
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "userId": self.user_id,
+            "tags": None if self.tags is None else [
+                self.tags[i].to_dict() if self.tags[i] else None
+                for i in range(len(self.tags))
+            ],
+            "begin": self.begin,
+            "end": self.end,
+            "longTerm": self.long_term,
+            "pageToken": self.page_token,
+            "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class SendInGameLogRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    access_token: str = None
+    tags: List[InGameLogTag] = None
+    payload: str = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> SendInGameLogRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_access_token(self, access_token: str) -> SendInGameLogRequest:
+        self.access_token = access_token
+        return self
+
+    def with_tags(self, tags: List[InGameLogTag]) -> SendInGameLogRequest:
+        self.tags = tags
+        return self
+
+    def with_payload(self, payload: str) -> SendInGameLogRequest:
+        self.payload = payload
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> SendInGameLogRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[SendInGameLogRequest]:
+        if data is None:
+            return None
+        return SendInGameLogRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_access_token(data.get('accessToken'))\
+            .with_tags(None if data.get('tags') is None else [
+                InGameLogTag.from_dict(data.get('tags')[i])
+                for i in range(len(data.get('tags')))
+            ])\
             .with_payload(data.get('payload'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "loggingNamespaceId": self.logging_namespace_id,
-            "logCategory": self.log_category,
+            "namespaceName": self.namespace_name,
+            "accessToken": self.access_token,
+            "tags": None if self.tags is None else [
+                self.tags[i].to_dict() if self.tags[i] else None
+                for i in range(len(self.tags))
+            ],
             "payload": self.payload,
         }
 
 
+class SendInGameLogByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    user_id: str = None
+    tags: List[InGameLogTag] = None
+    payload: str = None
+    time_offset_token: str = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> SendInGameLogByUserIdRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_user_id(self, user_id: str) -> SendInGameLogByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_tags(self, tags: List[InGameLogTag]) -> SendInGameLogByUserIdRequest:
+        self.tags = tags
+        return self
+
+    def with_payload(self, payload: str) -> SendInGameLogByUserIdRequest:
+        self.payload = payload
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> SendInGameLogByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> SendInGameLogByUserIdRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[SendInGameLogByUserIdRequest]:
+        if data is None:
+            return None
+        return SendInGameLogByUserIdRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_user_id(data.get('userId'))\
+            .with_tags(None if data.get('tags') is None else [
+                InGameLogTag.from_dict(data.get('tags')[i])
+                for i in range(len(data.get('tags')))
+            ])\
+            .with_payload(data.get('payload'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "userId": self.user_id,
+            "tags": None if self.tags is None else [
+                self.tags[i].to_dict() if self.tags[i] else None
+                for i in range(len(self.tags))
+            ],
+            "payload": self.payload,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class QueryAccessLogWithTelemetryRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    user_id: str = None
+    begin: int = None
+    end: int = None
+    long_term: bool = None
+    page_token: str = None
+    limit: int = None
+    time_offset_token: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> QueryAccessLogWithTelemetryRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_user_id(self, user_id: str) -> QueryAccessLogWithTelemetryRequest:
+        self.user_id = user_id
+        return self
+
+    def with_begin(self, begin: int) -> QueryAccessLogWithTelemetryRequest:
+        self.begin = begin
+        return self
+
+    def with_end(self, end: int) -> QueryAccessLogWithTelemetryRequest:
+        self.end = end
+        return self
+
+    def with_long_term(self, long_term: bool) -> QueryAccessLogWithTelemetryRequest:
+        self.long_term = long_term
+        return self
+
+    def with_page_token(self, page_token: str) -> QueryAccessLogWithTelemetryRequest:
+        self.page_token = page_token
+        return self
+
+    def with_limit(self, limit: int) -> QueryAccessLogWithTelemetryRequest:
+        self.limit = limit
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> QueryAccessLogWithTelemetryRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[QueryAccessLogWithTelemetryRequest]:
+        if data is None:
+            return None
+        return QueryAccessLogWithTelemetryRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_user_id(data.get('userId'))\
+            .with_begin(data.get('begin'))\
+            .with_end(data.get('end'))\
+            .with_long_term(data.get('longTerm'))\
+            .with_page_token(data.get('pageToken'))\
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "userId": self.user_id,
+            "begin": self.begin,
+            "end": self.end,
+            "longTerm": self.long_term,
+            "pageToken": self.page_token,
+            "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
 class DescribeInsightsRequest(core.Gs2Request):
 
     context_stack: str = None
