@@ -27,6 +27,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNamespacesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -100,6 +101,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -129,6 +131,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
             body["awsSecretAccessKey"] = request.aws_secret_access_key
         if request.firehose_stream_name is not None:
             body["firehoseStreamName"] = request.firehose_stream_name
+        if request.firehose_compress_data is not None:
+            body["firehoseCompressData"] = request.firehose_compress_data
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -189,6 +193,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceStatusResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -260,6 +265,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -331,6 +337,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -360,6 +367,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
             body["awsSecretAccessKey"] = request.aws_secret_access_key
         if request.firehose_stream_name is not None:
             body["firehoseStreamName"] = request.firehose_stream_name
+        if request.firehose_compress_data is not None:
+            body["firehoseCompressData"] = request.firehose_compress_data
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -420,6 +429,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -485,12 +495,83 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='log',
+            region=self.session.region,
+        ) + "/system/version"
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetServiceVersionResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _query_access_log(
         self,
         request: QueryAccessLogRequest,
         callback: Callable[[AsyncResult[QueryAccessLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -521,8 +602,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -580,6 +661,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CountAccessLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -610,6 +692,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -667,6 +751,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[QueryIssueStampSheetLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -699,8 +784,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -758,6 +843,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CountIssueStampSheetLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -790,6 +876,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -847,6 +935,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[QueryExecuteStampSheetLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -879,8 +968,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -938,6 +1027,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CountExecuteStampSheetLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -970,6 +1060,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -1027,6 +1119,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[QueryExecuteStampTaskLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -1059,8 +1152,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -1118,6 +1211,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CountExecuteStampTaskLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -1150,6 +1244,8 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -1201,34 +1297,52 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _put_log(
+    def _query_in_game_log(
         self,
-        request: PutLogRequest,
-        callback: Callable[[AsyncResult[PutLogResult]], None],
+        request: QueryInGameLogRequest,
+        callback: Callable[[AsyncResult[QueryInGameLogResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
-        ) + "/log/put"
+        ) + "/{namespaceName}/ingame/log".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+        )
 
         headers = self._create_authorized_headers()
         body = {
             'contextStack': request.context_stack,
         }
-        if request.logging_namespace_id is not None:
-            body["loggingNamespaceId"] = request.logging_namespace_id
-        if request.log_category is not None:
-            body["logCategory"] = request.log_category
-        if request.payload is not None:
-            body["payload"] = request.payload
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.tags is not None:
+            body["tags"] = [
+                item.to_dict()
+                for item in request.tags
+            ]
+        if request.begin is not None:
+            body["begin"] = request.begin
+        if request.end is not None:
+            body["end"] = request.end
+        if request.long_term is not None:
+            body["longTerm"] = request.long_term
+        if request.page_token is not None:
+            body["pageToken"] = request.page_token
+        if request.limit is not None:
+            body["limit"] = request.limit
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='POST',
-            result_type=PutLogResult,
+            result_type=QueryInGameLogResult,
             callback=callback,
             headers=headers,
             body=body,
@@ -1239,13 +1353,13 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
             is_blocking=is_blocking,
         )
 
-    def put_log(
+    def query_in_game_log(
         self,
-        request: PutLogRequest,
-    ) -> PutLogResult:
+        request: QueryInGameLogRequest,
+    ) -> QueryInGameLogResult:
         async_result = []
         with timeout(30):
-            self._put_log(
+            self._query_in_game_log(
                 request,
                 lambda result: async_result.append(result),
                 is_blocking=True,
@@ -1256,12 +1370,265 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         return async_result[0].result
 
 
-    async def put_log_async(
+    async def query_in_game_log_async(
         self,
-        request: PutLogRequest,
-    ) -> PutLogResult:
+        request: QueryInGameLogRequest,
+    ) -> QueryInGameLogResult:
         async_result = []
-        self._put_log(
+        self._query_in_game_log(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _send_in_game_log(
+        self,
+        request: SendInGameLogRequest,
+        callback: Callable[[AsyncResult[SendInGameLogResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='log',
+            region=self.session.region,
+        ) + "/{namespaceName}/ingame/log/user/me/send".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.tags is not None:
+            body["tags"] = [
+                item.to_dict()
+                for item in request.tags
+            ]
+        if request.payload is not None:
+            body["payload"] = request.payload
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.access_token:
+            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=SendInGameLogResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def send_in_game_log(
+        self,
+        request: SendInGameLogRequest,
+    ) -> SendInGameLogResult:
+        async_result = []
+        with timeout(30):
+            self._send_in_game_log(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def send_in_game_log_async(
+        self,
+        request: SendInGameLogRequest,
+    ) -> SendInGameLogResult:
+        async_result = []
+        self._send_in_game_log(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _send_in_game_log_by_user_id(
+        self,
+        request: SendInGameLogByUserIdRequest,
+        callback: Callable[[AsyncResult[SendInGameLogByUserIdResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='log',
+            region=self.session.region,
+        ) + "/{namespaceName}/ingame/log/user/{userId}/send".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.tags is not None:
+            body["tags"] = [
+                item.to_dict()
+                for item in request.tags
+            ]
+        if request.payload is not None:
+            body["payload"] = request.payload
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=SendInGameLogByUserIdResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def send_in_game_log_by_user_id(
+        self,
+        request: SendInGameLogByUserIdRequest,
+    ) -> SendInGameLogByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._send_in_game_log_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def send_in_game_log_by_user_id_async(
+        self,
+        request: SendInGameLogByUserIdRequest,
+    ) -> SendInGameLogByUserIdResult:
+        async_result = []
+        self._send_in_game_log_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _query_access_log_with_telemetry(
+        self,
+        request: QueryAccessLogWithTelemetryRequest,
+        callback: Callable[[AsyncResult[QueryAccessLogWithTelemetryResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='log',
+            region=self.session.region,
+        ) + "/{namespaceName}/log/access/telemetry".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+        if request.user_id is not None:
+            query_strings["userId"] = request.user_id
+        if request.begin is not None:
+            query_strings["begin"] = request.begin
+        if request.end is not None:
+            query_strings["end"] = request.end
+        if request.long_term is not None:
+            query_strings["longTerm"] = request.long_term
+        if request.page_token is not None:
+            query_strings["pageToken"] = request.page_token
+        if request.limit is not None:
+            query_strings["limit"] = request.limit
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=QueryAccessLogWithTelemetryResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def query_access_log_with_telemetry(
+        self,
+        request: QueryAccessLogWithTelemetryRequest,
+    ) -> QueryAccessLogWithTelemetryResult:
+        async_result = []
+        with timeout(30):
+            self._query_access_log_with_telemetry(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def query_access_log_with_telemetry_async(
+        self,
+        request: QueryAccessLogWithTelemetryRequest,
+    ) -> QueryAccessLogWithTelemetryResult:
+        async_result = []
+        self._query_access_log_with_telemetry(
             request,
             lambda result: async_result.append(result),
             is_blocking=False,
@@ -1282,6 +1649,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeInsightsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -1357,6 +1725,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateInsightResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -1428,6 +1797,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetInsightResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
@@ -1500,6 +1870,7 @@ class Gs2LogRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteInsightResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='log',
             region=self.session.region,
