@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -131,6 +132,8 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["awsSecretAccessKey"] = request.aws_secret_access_key
         if request.firehose_stream_name is not None:
             body["firehoseStreamName"] = request.firehose_stream_name
+        if request.firehose_compress_data is not None:
+            body["firehoseCompressData"] = request.firehose_compress_data
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -362,6 +365,8 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["awsSecretAccessKey"] = request.aws_secret_access_key
         if request.firehose_stream_name is not None:
             body["firehoseStreamName"] = request.firehose_stream_name
+        if request.firehose_compress_data is not None:
+            body["firehoseCompressData"] = request.firehose_compress_data
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -485,6 +490,75 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="log",
+            component='namespace',
+            function='getServiceVersion',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=GetServiceVersionResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _query_access_log(
         self,
         request: QueryAccessLogRequest,
@@ -520,11 +594,11 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
-        if request.duplication_avoider:
-            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
@@ -609,6 +683,8 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -698,11 +774,11 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
-        if request.duplication_avoider:
-            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
@@ -789,6 +865,8 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -878,11 +956,11 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
-        if request.duplication_avoider:
-            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
@@ -969,6 +1047,8 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1058,11 +1138,11 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
-        if request.duplication_avoider:
-            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
@@ -1149,6 +1229,8 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["pageToken"] = request.page_token
         if request.limit is not None:
             body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1201,49 +1283,66 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _put_log(
+    def _query_in_game_log(
         self,
-        request: PutLogRequest,
-        callback: Callable[[AsyncResult[PutLogResult]], None],
+        request: QueryInGameLogRequest,
+        callback: Callable[[AsyncResult[QueryInGameLogResult]], None],
     ):
         import uuid
 
         request_id = str(uuid.uuid4())
         body = self._create_metadata(
             service="log",
-            component='log',
-            function='putLog',
+            component='inGameLog',
+            function='queryInGameLog',
             request_id=request_id,
         )
 
         if request.context_stack:
             body['contextStack'] = str(request.context_stack)
-        if request.logging_namespace_id is not None:
-            body["loggingNamespaceId"] = request.logging_namespace_id
-        if request.log_category is not None:
-            body["logCategory"] = request.log_category
-        if request.payload is not None:
-            body["payload"] = request.payload
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.tags is not None:
+            body["tags"] = [
+                item.to_dict()
+                for item in request.tags
+            ]
+        if request.begin is not None:
+            body["begin"] = request.begin
+        if request.end is not None:
+            body["end"] = request.end
+        if request.long_term is not None:
+            body["longTerm"] = request.long_term
+        if request.page_token is not None:
+            body["pageToken"] = request.page_token
+        if request.limit is not None:
+            body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
                 request_id=request_id,
-                result_type=PutLogResult,
+                result_type=QueryInGameLogResult,
                 callback=callback,
                 body=body,
             )
         )
 
-    def put_log(
+    def query_in_game_log(
         self,
-        request: PutLogRequest,
-    ) -> PutLogResult:
+        request: QueryInGameLogRequest,
+    ) -> QueryInGameLogResult:
         async_result = []
         with timeout(30):
-            self._put_log(
+            self._query_in_game_log(
                 request,
                 lambda result: async_result.append(result),
             )
@@ -1257,12 +1356,265 @@ class Gs2LogWebSocketClient(web_socket.AbstractGs2WebSocketClient):
         return async_result[0].result
 
 
-    async def put_log_async(
+    async def query_in_game_log_async(
         self,
-        request: PutLogRequest,
-    ) -> PutLogResult:
+        request: QueryInGameLogRequest,
+    ) -> QueryInGameLogResult:
         async_result = []
-        self._put_log(
+        self._query_in_game_log(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _send_in_game_log(
+        self,
+        request: SendInGameLogRequest,
+        callback: Callable[[AsyncResult[SendInGameLogResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="log",
+            component='inGameLog',
+            function='sendInGameLog',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.access_token is not None:
+            body["accessToken"] = request.access_token
+        if request.tags is not None:
+            body["tags"] = [
+                item.to_dict()
+                for item in request.tags
+            ]
+        if request.payload is not None:
+            body["payload"] = request.payload
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.access_token:
+            body["xGs2AccessToken"] = request.access_token
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=SendInGameLogResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def send_in_game_log(
+        self,
+        request: SendInGameLogRequest,
+    ) -> SendInGameLogResult:
+        async_result = []
+        with timeout(30):
+            self._send_in_game_log(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def send_in_game_log_async(
+        self,
+        request: SendInGameLogRequest,
+    ) -> SendInGameLogResult:
+        async_result = []
+        self._send_in_game_log(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _send_in_game_log_by_user_id(
+        self,
+        request: SendInGameLogByUserIdRequest,
+        callback: Callable[[AsyncResult[SendInGameLogByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="log",
+            component='inGameLog',
+            function='sendInGameLogByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.tags is not None:
+            body["tags"] = [
+                item.to_dict()
+                for item in request.tags
+            ]
+        if request.payload is not None:
+            body["payload"] = request.payload
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=SendInGameLogByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def send_in_game_log_by_user_id(
+        self,
+        request: SendInGameLogByUserIdRequest,
+    ) -> SendInGameLogByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._send_in_game_log_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def send_in_game_log_by_user_id_async(
+        self,
+        request: SendInGameLogByUserIdRequest,
+    ) -> SendInGameLogByUserIdResult:
+        async_result = []
+        self._send_in_game_log_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _query_access_log_with_telemetry(
+        self,
+        request: QueryAccessLogWithTelemetryRequest,
+        callback: Callable[[AsyncResult[QueryAccessLogWithTelemetryResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="log",
+            component='accessLogWithTelemetry',
+            function='queryAccessLogWithTelemetry',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.begin is not None:
+            body["begin"] = request.begin
+        if request.end is not None:
+            body["end"] = request.end
+        if request.long_term is not None:
+            body["longTerm"] = request.long_term
+        if request.page_token is not None:
+            body["pageToken"] = request.page_token
+        if request.limit is not None:
+            body["limit"] = request.limit
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=QueryAccessLogWithTelemetryResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def query_access_log_with_telemetry(
+        self,
+        request: QueryAccessLogWithTelemetryRequest,
+    ) -> QueryAccessLogWithTelemetryResult:
+        async_result = []
+        with timeout(30):
+            self._query_access_log_with_telemetry(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def query_access_log_with_telemetry_async(
+        self,
+        request: QueryAccessLogWithTelemetryRequest,
+    ) -> QueryAccessLogWithTelemetryResult:
+        async_result = []
+        self._query_access_log_with_telemetry(
             request,
             lambda result: async_result.append(result),
         )
