@@ -21,6 +21,9 @@ from gs2 import core
 
 class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
     queue_namespace_id: str = None
@@ -29,6 +32,18 @@ class TransactionSetting(core.Gs2Model):
         self.enable_auto_run = enable_auto_run
         return self
 
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
     def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
         self.distributor_namespace_id = distributor_namespace_id
         return self
@@ -61,6 +76,9 @@ class TransactionSetting(core.Gs2Model):
             return None
         return TransactionSetting()\
             .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))
@@ -68,6 +86,9 @@ class TransactionSetting(core.Gs2Model):
     def to_dict(self) -> Dict[str, Any]:
         return {
             "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
             "queueNamespaceId": self.queue_namespace_id,
@@ -377,9 +398,9 @@ class BoxItems(core.Gs2Model):
             .with_box_id(data.get('boxId'))\
             .with_prize_table_name(data.get('prizeTableName'))\
             .with_user_id(data.get('userId'))\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 BoxItem.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -387,18 +408,23 @@ class BoxItems(core.Gs2Model):
             "boxId": self.box_id,
             "prizeTableName": self.prize_table_name,
             "userId": self.user_id,
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
 
 class BoxItem(core.Gs2Model):
+    prize_id: str = None
     acquire_actions: List[AcquireAction] = None
     remaining: int = None
     initial: int = None
 
+    def with_prize_id(self, prize_id: str) -> BoxItem:
+        self.prize_id = prize_id
+        return self
+
     def with_acquire_actions(self, acquire_actions: List[AcquireAction]) -> BoxItem:
         self.acquire_actions = acquire_actions
         return self
@@ -430,18 +456,20 @@ class BoxItem(core.Gs2Model):
         if data is None:
             return None
         return BoxItem()\
-            .with_acquire_actions([
+            .with_prize_id(data.get('prizeId'))\
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])\
             .with_remaining(data.get('remaining'))\
             .with_initial(data.get('initial'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "acquireActions": [
+            "prizeId": self.prize_id,
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
             "remaining": self.remaining,
             "initial": self.initial,
@@ -480,17 +508,17 @@ class DrawnPrize(core.Gs2Model):
             return None
         return DrawnPrize()\
             .with_prize_id(data.get('prizeId'))\
-            .with_acquire_actions([
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "prizeId": self.prize_id,
-            "acquireActions": [
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
         }
 
@@ -501,6 +529,7 @@ class PrizeLimit(core.Gs2Model):
     drawn_count: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_prize_limit_id(self, prize_limit_id: str) -> PrizeLimit:
         self.prize_limit_id = prize_limit_id
@@ -522,6 +551,10 @@ class PrizeLimit(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> PrizeLimit:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -612,7 +645,8 @@ class PrizeLimit(core.Gs2Model):
             .with_prize_id(data.get('prizeId'))\
             .with_drawn_count(data.get('drawnCount'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -621,6 +655,7 @@ class PrizeLimit(core.Gs2Model):
             "drawnCount": self.drawn_count,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -682,9 +717,9 @@ class Prize(core.Gs2Model):
         return Prize()\
             .with_prize_id(data.get('prizeId'))\
             .with_type(data.get('type'))\
-            .with_acquire_actions([
+            .with_acquire_actions(None if data.get('acquireActions') is None else [
                 AcquireAction.from_dict(data.get('acquireActions')[i])
-                for i in range(len(data.get('acquireActions')) if data.get('acquireActions') else 0)
+                for i in range(len(data.get('acquireActions')))
             ])\
             .with_drawn_limit(data.get('drawnLimit'))\
             .with_limit_fail_over_prize_id(data.get('limitFailOverPrizeId'))\
@@ -695,9 +730,9 @@ class Prize(core.Gs2Model):
         return {
             "prizeId": self.prize_id,
             "type": self.type,
-            "acquireActions": [
+            "acquireActions": None if self.acquire_actions is None else [
                 self.acquire_actions[i].to_dict() if self.acquire_actions[i] else None
-                for i in range(len(self.acquire_actions) if self.acquire_actions else 0)
+                for i in range(len(self.acquire_actions))
             ],
             "drawnLimit": self.drawn_limit,
             "limitFailOverPrizeId": self.limit_fail_over_prize_id,
@@ -930,9 +965,9 @@ class PrizeTable(core.Gs2Model):
             .with_prize_table_id(data.get('prizeTableId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_prizes([
+            .with_prizes(None if data.get('prizes') is None else [
                 Prize.from_dict(data.get('prizes')[i])
-                for i in range(len(data.get('prizes')) if data.get('prizes') else 0)
+                for i in range(len(data.get('prizes')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -940,9 +975,9 @@ class PrizeTable(core.Gs2Model):
             "prizeTableId": self.prize_table_id,
             "name": self.name,
             "metadata": self.metadata,
-            "prizes": [
+            "prizes": None if self.prizes is None else [
                 self.prizes[i].to_dict() if self.prizes[i] else None
-                for i in range(len(self.prizes) if self.prizes else 0)
+                for i in range(len(self.prizes))
             ],
         }
 
@@ -1086,6 +1121,7 @@ class PrizeTableMaster(core.Gs2Model):
     prizes: List[Prize] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_prize_table_id(self, prize_table_id: str) -> PrizeTableMaster:
         self.prize_table_id = prize_table_id
@@ -1115,6 +1151,10 @@ class PrizeTableMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> PrizeTableMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1193,12 +1233,13 @@ class PrizeTableMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_description(data.get('description'))\
-            .with_prizes([
+            .with_prizes(None if data.get('prizes') is None else [
                 Prize.from_dict(data.get('prizes')[i])
-                for i in range(len(data.get('prizes')) if data.get('prizes') else 0)
+                for i in range(len(data.get('prizes')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1206,12 +1247,13 @@ class PrizeTableMaster(core.Gs2Model):
             "name": self.name,
             "metadata": self.metadata,
             "description": self.description,
-            "prizes": [
+            "prizes": None if self.prizes is None else [
                 self.prizes[i].to_dict() if self.prizes[i] else None
-                for i in range(len(self.prizes) if self.prizes else 0)
+                for i in range(len(self.prizes))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1226,6 +1268,7 @@ class LotteryModelMaster(core.Gs2Model):
     choice_prize_table_script_id: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_lottery_model_id(self, lottery_model_id: str) -> LotteryModelMaster:
         self.lottery_model_id = lottery_model_id
@@ -1267,6 +1310,10 @@ class LotteryModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> LotteryModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1350,7 +1397,8 @@ class LotteryModelMaster(core.Gs2Model):
             .with_prize_table_name(data.get('prizeTableName'))\
             .with_choice_prize_table_script_id(data.get('choicePrizeTableScriptId'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1364,6 +1412,7 @@ class LotteryModelMaster(core.Gs2Model):
             "choicePrizeTableScriptId": self.choice_prize_table_script_id,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1379,6 +1428,7 @@ class Namespace(core.Gs2Model):
     updated_at: int = None
     queue_namespace_id: str = None
     key_id: str = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1424,6 +1474,10 @@ class Namespace(core.Gs2Model):
         self.key_id = key_id
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1496,7 +1550,8 @@ class Namespace(core.Gs2Model):
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
-            .with_key_id(data.get('keyId'))
+            .with_key_id(data.get('keyId'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1511,4 +1566,5 @@ class Namespace(core.Gs2Model):
             "updatedAt": self.updated_at,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
+            "revision": self.revision,
         }
\ No newline at end of file
