@@ -338,6 +338,350 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class DumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> DumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> DumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckDumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckDumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckDumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckCleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckCleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckCleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class PrepareImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> PrepareImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class ImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> ImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> ImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> ImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
 class DescribeLotteryModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -746,9 +1090,9 @@ class CreatePrizeTableMasterRequest(core.Gs2Request):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
-            .with_prizes([
+            .with_prizes(None if data.get('prizes') is None else [
                 Prize.from_dict(data.get('prizes')[i])
-                for i in range(len(data.get('prizes')) if data.get('prizes') else 0)
+                for i in range(len(data.get('prizes')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -757,9 +1101,9 @@ class CreatePrizeTableMasterRequest(core.Gs2Request):
             "name": self.name,
             "description": self.description,
             "metadata": self.metadata,
-            "prizes": [
+            "prizes": None if self.prizes is None else [
                 self.prizes[i].to_dict() if self.prizes[i] else None
-                for i in range(len(self.prizes) if self.prizes else 0)
+                for i in range(len(self.prizes))
             ],
         }
 
@@ -859,9 +1203,9 @@ class UpdatePrizeTableMasterRequest(core.Gs2Request):
             .with_prize_table_name(data.get('prizeTableName'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
-            .with_prizes([
+            .with_prizes(None if data.get('prizes') is None else [
                 Prize.from_dict(data.get('prizes')[i])
-                for i in range(len(data.get('prizes')) if data.get('prizes') else 0)
+                for i in range(len(data.get('prizes')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -870,9 +1214,9 @@ class UpdatePrizeTableMasterRequest(core.Gs2Request):
             "prizeTableName": self.prize_table_name,
             "description": self.description,
             "metadata": self.metadata,
-            "prizes": [
+            "prizes": None if self.prizes is None else [
                 self.prizes[i].to_dict() if self.prizes[i] else None
-                for i in range(len(self.prizes) if self.prizes else 0)
+                for i in range(len(self.prizes))
             ],
         }
 
@@ -1086,6 +1430,7 @@ class DrawByUserIdRequest(core.Gs2Request):
     user_id: str = None
     count: int = None
     config: List[Config] = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DrawByUserIdRequest:
@@ -1108,6 +1453,10 @@ class DrawByUserIdRequest(core.Gs2Request):
         self.config = config
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DrawByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DrawByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1135,10 +1484,11 @@ class DrawByUserIdRequest(core.Gs2Request):
             .with_lottery_name(data.get('lotteryName'))\
             .with_user_id(data.get('userId'))\
             .with_count(data.get('count'))\
-            .with_config([
+            .with_config(None if data.get('config') is None else [
                 Config.from_dict(data.get('config')[i])
-                for i in range(len(data.get('config')) if data.get('config') else 0)
-            ])
+                for i in range(len(data.get('config')))
+            ])\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1146,10 +1496,11 @@ class DrawByUserIdRequest(core.Gs2Request):
             "lotteryName": self.lottery_name,
             "userId": self.user_id,
             "count": self.count,
-            "config": [
+            "config": None if self.config is None else [
                 self.config[i].to_dict() if self.config[i] else None
-                for i in range(len(self.config) if self.config else 0)
+                for i in range(len(self.config))
             ],
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1230,6 +1581,7 @@ class PredictionByUserIdRequest(core.Gs2Request):
     user_id: str = None
     random_seed: int = None
     count: int = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PredictionByUserIdRequest:
@@ -1252,6 +1604,10 @@ class PredictionByUserIdRequest(core.Gs2Request):
         self.count = count
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PredictionByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PredictionByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1279,7 +1635,8 @@ class PredictionByUserIdRequest(core.Gs2Request):
             .with_lottery_name(data.get('lotteryName'))\
             .with_user_id(data.get('userId'))\
             .with_random_seed(data.get('randomSeed'))\
-            .with_count(data.get('count'))
+            .with_count(data.get('count'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1288,6 +1645,7 @@ class PredictionByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "randomSeed": self.random_seed,
             "count": self.count,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1300,6 +1658,7 @@ class DrawWithRandomSeedByUserIdRequest(core.Gs2Request):
     random_seed: int = None
     count: int = None
     config: List[Config] = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DrawWithRandomSeedByUserIdRequest:
@@ -1326,6 +1685,10 @@ class DrawWithRandomSeedByUserIdRequest(core.Gs2Request):
         self.config = config
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DrawWithRandomSeedByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DrawWithRandomSeedByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1354,10 +1717,11 @@ class DrawWithRandomSeedByUserIdRequest(core.Gs2Request):
             .with_user_id(data.get('userId'))\
             .with_random_seed(data.get('randomSeed'))\
             .with_count(data.get('count'))\
-            .with_config([
+            .with_config(None if data.get('config') is None else [
                 Config.from_dict(data.get('config')[i])
-                for i in range(len(data.get('config')) if data.get('config') else 0)
-            ])
+                for i in range(len(data.get('config')))
+            ])\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1366,10 +1730,11 @@ class DrawWithRandomSeedByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "randomSeed": self.random_seed,
             "count": self.count,
-            "config": [
+            "config": None if self.config is None else [
                 self.config[i].to_dict() if self.config[i] else None
-                for i in range(len(self.config) if self.config else 0)
+                for i in range(len(self.config))
             ],
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1472,6 +1837,7 @@ class DescribeProbabilitiesByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     lottery_name: str = None
     user_id: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeProbabilitiesByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1485,6 +1851,10 @@ class DescribeProbabilitiesByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeProbabilitiesByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1506,13 +1876,15 @@ class DescribeProbabilitiesByUserIdRequest(core.Gs2Request):
         return DescribeProbabilitiesByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_lottery_name(data.get('lotteryName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "lotteryName": self.lottery_name,
             "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1588,20 +1960,66 @@ class GetCurrentLotteryMasterRequest(core.Gs2Request):
         }
 
 
+class PreUpdateCurrentLotteryMasterRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> PreUpdateCurrentLotteryMasterRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PreUpdateCurrentLotteryMasterRequest]:
+        if data is None:
+            return None
+        return PreUpdateCurrentLotteryMasterRequest()\
+            .with_namespace_name(data.get('namespaceName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+        }
+
+
 class UpdateCurrentLotteryMasterRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    mode: str = None
     settings: str = None
+    upload_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateCurrentLotteryMasterRequest:
         self.namespace_name = namespace_name
         return self
 
+    def with_mode(self, mode: str) -> UpdateCurrentLotteryMasterRequest:
+        self.mode = mode
+        return self
+
     def with_settings(self, settings: str) -> UpdateCurrentLotteryMasterRequest:
         self.settings = settings
         return self
 
+    def with_upload_token(self, upload_token: str) -> UpdateCurrentLotteryMasterRequest:
+        self.upload_token = upload_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1622,12 +2040,16 @@ class UpdateCurrentLotteryMasterRequest(core.Gs2Request):
             return None
         return UpdateCurrentLotteryMasterRequest()\
             .with_namespace_name(data.get('namespaceName'))\
-            .with_settings(data.get('settings'))
+            .with_mode(data.get('mode'))\
+            .with_settings(data.get('settings'))\
+            .with_upload_token(data.get('uploadToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "mode": self.mode,
             "settings": self.settings,
+            "uploadToken": self.upload_token,
         }
 
 
@@ -1895,6 +2317,7 @@ class DescribeBoxesByUserIdRequest(core.Gs2Request):
     user_id: str = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeBoxesByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1912,6 +2335,10 @@ class DescribeBoxesByUserIdRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeBoxesByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1934,7 +2361,8 @@ class DescribeBoxesByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1942,6 +2370,7 @@ class DescribeBoxesByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -2001,6 +2430,7 @@ class GetBoxByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     prize_table_name: str = None
     user_id: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetBoxByUserIdRequest:
         self.namespace_name = namespace_name
@@ -2014,6 +2444,10 @@ class GetBoxByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> GetBoxByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -2035,13 +2469,15 @@ class GetBoxByUserIdRequest(core.Gs2Request):
         return GetBoxByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_prize_table_name(data.get('prizeTableName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "prizeTableName": self.prize_table_name,
             "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -2106,6 +2542,7 @@ class ResetBoxByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     prize_table_name: str = None
     user_id: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> ResetBoxByUserIdRequest:
@@ -2120,6 +2557,10 @@ class ResetBoxByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> ResetBoxByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> ResetBoxByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -2145,11 +2586,56 @@ class ResetBoxByUserIdRequest(core.Gs2Request):
         return ResetBoxByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_prize_table_name(data.get('prizeTableName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "prizeTableName": self.prize_table_name,
             "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class ResetByStampSheetRequest(core.Gs2Request):
+
+    context_stack: str = None
+    stamp_sheet: str = None
+    key_id: str = None
+
+    def with_stamp_sheet(self, stamp_sheet: str) -> ResetByStampSheetRequest:
+        self.stamp_sheet = stamp_sheet
+        return self
+
+    def with_key_id(self, key_id: str) -> ResetByStampSheetRequest:
+        self.key_id = key_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ResetByStampSheetRequest]:
+        if data is None:
+            return None
+        return ResetByStampSheetRequest()\
+            .with_stamp_sheet(data.get('stampSheet'))\
+            .with_key_id(data.get('keyId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "stampSheet": self.stamp_sheet,
+            "keyId": self.key_id,
         }
\ No newline at end of file
