@@ -268,6 +268,35 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
 class DescribeAreaModelsRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -1047,20 +1076,66 @@ class GetCurrentFieldMasterRequest(core.Gs2Request):
         }
 
 
+class PreUpdateCurrentFieldMasterRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> PreUpdateCurrentFieldMasterRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PreUpdateCurrentFieldMasterRequest]:
+        if data is None:
+            return None
+        return PreUpdateCurrentFieldMasterRequest()\
+            .with_namespace_name(data.get('namespaceName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+        }
+
+
 class UpdateCurrentFieldMasterRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    mode: str = None
     settings: str = None
+    upload_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateCurrentFieldMasterRequest:
         self.namespace_name = namespace_name
         return self
 
+    def with_mode(self, mode: str) -> UpdateCurrentFieldMasterRequest:
+        self.mode = mode
+        return self
+
     def with_settings(self, settings: str) -> UpdateCurrentFieldMasterRequest:
         self.settings = settings
         return self
 
+    def with_upload_token(self, upload_token: str) -> UpdateCurrentFieldMasterRequest:
+        self.upload_token = upload_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1081,12 +1156,16 @@ class UpdateCurrentFieldMasterRequest(core.Gs2Request):
             return None
         return UpdateCurrentFieldMasterRequest()\
             .with_namespace_name(data.get('namespaceName'))\
-            .with_settings(data.get('settings'))
+            .with_mode(data.get('mode'))\
+            .with_settings(data.get('settings'))\
+            .with_upload_token(data.get('uploadToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "mode": self.mode,
             "settings": self.settings,
+            "uploadToken": self.upload_token,
         }
 
 
@@ -1226,6 +1305,7 @@ class PutPositionByUserIdRequest(core.Gs2Request):
     position: Position = None
     vector: Vector = None
     r: float = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PutPositionByUserIdRequest:
@@ -1256,6 +1336,10 @@ class PutPositionByUserIdRequest(core.Gs2Request):
         self.r = r
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> PutPositionByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> PutPositionByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1285,7 +1369,8 @@ class PutPositionByUserIdRequest(core.Gs2Request):
             .with_layer_model_name(data.get('layerModelName'))\
             .with_position(Position.from_dict(data.get('position')))\
             .with_vector(Vector.from_dict(data.get('vector')))\
-            .with_r(data.get('r'))
+            .with_r(data.get('r'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1296,6 +1381,7 @@ class PutPositionByUserIdRequest(core.Gs2Request):
             "position": self.position.to_dict() if self.position else None,
             "vector": self.vector.to_dict() if self.vector else None,
             "r": self.r,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1356,9 +1442,9 @@ class FetchPositionRequest(core.Gs2Request):
             .with_access_token(data.get('accessToken'))\
             .with_area_model_name(data.get('areaModelName'))\
             .with_layer_model_name(data.get('layerModelName'))\
-            .with_user_ids([
+            .with_user_ids(None if data.get('userIds') is None else [
                 data.get('userIds')[i]
-                for i in range(len(data.get('userIds')) if data.get('userIds') else 0)
+                for i in range(len(data.get('userIds')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -1367,9 +1453,9 @@ class FetchPositionRequest(core.Gs2Request):
             "accessToken": self.access_token,
             "areaModelName": self.area_model_name,
             "layerModelName": self.layer_model_name,
-            "userIds": [
+            "userIds": None if self.user_ids is None else [
                 self.user_ids[i]
-                for i in range(len(self.user_ids) if self.user_ids else 0)
+                for i in range(len(self.user_ids))
             ],
         }
 
@@ -1425,9 +1511,9 @@ class FetchPositionFromSystemRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_area_model_name(data.get('areaModelName'))\
             .with_layer_model_name(data.get('layerModelName'))\
-            .with_user_ids([
+            .with_user_ids(None if data.get('userIds') is None else [
                 data.get('userIds')[i]
-                for i in range(len(data.get('userIds')) if data.get('userIds') else 0)
+                for i in range(len(data.get('userIds')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -1435,9 +1521,9 @@ class FetchPositionFromSystemRequest(core.Gs2Request):
             "namespaceName": self.namespace_name,
             "areaModelName": self.area_model_name,
             "layerModelName": self.layer_model_name,
-            "userIds": [
+            "userIds": None if self.user_ids is None else [
                 self.user_ids[i]
-                for i in range(len(self.user_ids) if self.user_ids else 0)
+                for i in range(len(self.user_ids))
             ],
         }
 
@@ -1664,9 +1750,9 @@ class ActionRequest(core.Gs2Request):
             .with_area_model_name(data.get('areaModelName'))\
             .with_layer_model_name(data.get('layerModelName'))\
             .with_position(MyPosition.from_dict(data.get('position')))\
-            .with_scopes([
+            .with_scopes(None if data.get('scopes') is None else [
                 Scope.from_dict(data.get('scopes')[i])
-                for i in range(len(data.get('scopes')) if data.get('scopes') else 0)
+                for i in range(len(data.get('scopes')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -1676,9 +1762,9 @@ class ActionRequest(core.Gs2Request):
             "areaModelName": self.area_model_name,
             "layerModelName": self.layer_model_name,
             "position": self.position.to_dict() if self.position else None,
-            "scopes": [
+            "scopes": None if self.scopes is None else [
                 self.scopes[i].to_dict() if self.scopes[i] else None
-                for i in range(len(self.scopes) if self.scopes else 0)
+                for i in range(len(self.scopes))
             ],
         }
 
@@ -1692,6 +1778,7 @@ class ActionByUserIdRequest(core.Gs2Request):
     layer_model_name: str = None
     position: MyPosition = None
     scopes: List[Scope] = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> ActionByUserIdRequest:
@@ -1718,6 +1805,10 @@ class ActionByUserIdRequest(core.Gs2Request):
         self.scopes = scopes
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> ActionByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> ActionByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1746,10 +1837,11 @@ class ActionByUserIdRequest(core.Gs2Request):
             .with_area_model_name(data.get('areaModelName'))\
             .with_layer_model_name(data.get('layerModelName'))\
             .with_position(MyPosition.from_dict(data.get('position')))\
-            .with_scopes([
+            .with_scopes(None if data.get('scopes') is None else [
                 Scope.from_dict(data.get('scopes')[i])
-                for i in range(len(data.get('scopes')) if data.get('scopes') else 0)
-            ])
+                for i in range(len(data.get('scopes')))
+            ])\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1758,8 +1850,9 @@ class ActionByUserIdRequest(core.Gs2Request):
             "areaModelName": self.area_model_name,
             "layerModelName": self.layer_model_name,
             "position": self.position.to_dict() if self.position else None,
-            "scopes": [
+            "scopes": None if self.scopes is None else [
                 self.scopes[i].to_dict() if self.scopes[i] else None
-                for i in range(len(self.scopes) if self.scopes else 0)
+                for i in range(len(self.scopes))
             ],
+            "timeOffsetToken": self.time_offset_token,
         }
\ No newline at end of file
