@@ -27,6 +27,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNamespacesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -100,6 +101,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -175,6 +177,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceStatusResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -246,6 +249,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -317,6 +321,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -392,6 +397,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -457,12 +463,83 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='mega-field',
+            region=self.session.region,
+        ) + "/system/version"
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetServiceVersionResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_area_models(
         self,
         request: DescribeAreaModelsRequest,
         callback: Callable[[AsyncResult[DescribeAreaModelsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -534,6 +611,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetAreaModelResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -606,6 +684,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeAreaModelMastersResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -681,6 +760,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateAreaModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -758,6 +838,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetAreaModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -830,6 +911,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateAreaModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -906,6 +988,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteAreaModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -978,6 +1061,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeLayerModelsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1050,6 +1134,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetLayerModelResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1123,6 +1208,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeLayerModelMastersResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1199,6 +1285,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateLayerModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1277,6 +1364,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetLayerModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1350,6 +1438,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateLayerModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1427,6 +1516,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteLayerModelMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1500,6 +1590,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[ExportMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1571,6 +1662,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetCurrentFieldMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1636,12 +1728,13 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _update_current_field_master(
+    def _pre_update_current_field_master(
         self,
-        request: UpdateCurrentFieldMasterRequest,
-        callback: Callable[[AsyncResult[UpdateCurrentFieldMasterResult]], None],
+        request: PreUpdateCurrentFieldMasterRequest,
+        callback: Callable[[AsyncResult[PreUpdateCurrentFieldMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1653,8 +1746,97 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         body = {
             'contextStack': request.context_stack,
         }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=PreUpdateCurrentFieldMasterResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def pre_update_current_field_master(
+        self,
+        request: PreUpdateCurrentFieldMasterRequest,
+    ) -> PreUpdateCurrentFieldMasterResult:
+        async_result = []
+        with timeout(30):
+            self._pre_update_current_field_master(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def pre_update_current_field_master_async(
+        self,
+        request: PreUpdateCurrentFieldMasterRequest,
+    ) -> PreUpdateCurrentFieldMasterResult:
+        async_result = []
+        self._pre_update_current_field_master(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _update_current_field_master(
+        self,
+        request: UpdateCurrentFieldMasterRequest,
+        callback: Callable[[AsyncResult[UpdateCurrentFieldMasterResult]], None],
+        is_blocking: bool,
+    ):
+        if request.settings is not None:
+            res = self.pre_update_current_field_master(
+                PreUpdateCurrentFieldMasterRequest() \
+                    .with_context_stack(request.context_stack) \
+                    .with_namespace_name(request.namespace_name)
+            )
+            import requests
+            requests.put(res.upload_url, data=request.settings, headers={
+                'Content-Type': 'application/json',
+            })
+            request.mode = "preUpload"
+            request.upload_token = res.upload_token
+            request.settings = None
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='mega-field',
+            region=self.session.region,
+        ) + "/{namespaceName}/master".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.mode is not None:
+            body["mode"] = request.mode
         if request.settings is not None:
             body["settings"] = request.settings
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -1715,6 +1897,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateCurrentFieldMasterFromGitHubResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1788,6 +1971,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[PutPositionResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1871,6 +2055,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[PutPositionByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -1896,6 +2081,8 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
             headers["X-GS2-REQUEST-ID"] = request.request_id
         if request.duplication_avoider:
             headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='POST',
@@ -1953,6 +2140,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[FetchPositionResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -2035,6 +2223,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[FetchPositionFromSystemResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -2115,6 +2304,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[NearUserIdsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -2198,6 +2388,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[NearUserIdsFromSystemResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -2279,6 +2470,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[ActionResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -2363,6 +2555,7 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[ActionByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='mega-field',
             region=self.session.region,
@@ -2389,6 +2582,8 @@ class Gs2MegaFieldRestClient(rest.AbstractGs2RestClient):
             headers["X-GS2-REQUEST-ID"] = request.request_id
         if request.duplication_avoider:
             headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='POST',
