@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2MegaFieldWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -457,6 +458,75 @@ class Gs2MegaFieldWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="megaField",
+            component='namespace',
+            function='getServiceVersion',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=GetServiceVersionResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_area_models(
         self,
         request: DescribeAreaModelsRequest,
@@ -1651,6 +1721,77 @@ class Gs2MegaFieldWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _pre_update_current_field_master(
+        self,
+        request: PreUpdateCurrentFieldMasterRequest,
+        callback: Callable[[AsyncResult[PreUpdateCurrentFieldMasterResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="megaField",
+            component='currentFieldMaster',
+            function='preUpdateCurrentFieldMaster',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=PreUpdateCurrentFieldMasterResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def pre_update_current_field_master(
+        self,
+        request: PreUpdateCurrentFieldMasterRequest,
+    ) -> PreUpdateCurrentFieldMasterResult:
+        async_result = []
+        with timeout(30):
+            self._pre_update_current_field_master(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def pre_update_current_field_master_async(
+        self,
+        request: PreUpdateCurrentFieldMasterRequest,
+    ) -> PreUpdateCurrentFieldMasterResult:
+        async_result = []
+        self._pre_update_current_field_master(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _update_current_field_master(
         self,
         request: UpdateCurrentFieldMasterRequest,
@@ -1670,8 +1811,12 @@ class Gs2MegaFieldWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body['contextStack'] = str(request.context_stack)
         if request.namespace_name is not None:
             body["namespaceName"] = request.namespace_name
+        if request.mode is not None:
+            body["mode"] = request.mode
         if request.settings is not None:
             body["settings"] = request.settings
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1915,6 +2060,8 @@ class Gs2MegaFieldWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["vector"] = request.vector.to_dict()
         if request.r is not None:
             body["r"] = request.r
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -2427,6 +2574,8 @@ class Gs2MegaFieldWebSocketClient(web_socket.AbstractGs2WebSocketClient):
                 item.to_dict()
                 for item in request.scopes
             ]
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
