@@ -21,6 +21,9 @@ from gs2 import core
 
 class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
     queue_namespace_id: str = None
@@ -29,6 +32,18 @@ class TransactionSetting(core.Gs2Model):
         self.enable_auto_run = enable_auto_run
         return self
 
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
     def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
         self.distributor_namespace_id = distributor_namespace_id
         return self
@@ -61,6 +76,9 @@ class TransactionSetting(core.Gs2Model):
             return None
         return TransactionSetting()\
             .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))
@@ -68,6 +86,9 @@ class TransactionSetting(core.Gs2Model):
     def to_dict(self) -> Dict[str, Any]:
         return {
             "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
             "queueNamespaceId": self.queue_namespace_id,
@@ -280,6 +301,88 @@ class Config(core.Gs2Model):
         }
 
 
+class VerifyAction(core.Gs2Model):
+    action: str = None
+    request: str = None
+
+    def with_action(self, action: str) -> VerifyAction:
+        self.action = action
+        return self
+
+    def with_request(self, request: str) -> VerifyAction:
+        self.request = request
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyAction]:
+        if data is None:
+            return None
+        return VerifyAction()\
+            .with_action(data.get('action'))\
+            .with_request(data.get('request'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "action": self.action,
+            "request": self.request,
+        }
+
+
+class ConsumeAction(core.Gs2Model):
+    action: str = None
+    request: str = None
+
+    def with_action(self, action: str) -> ConsumeAction:
+        self.action = action
+        return self
+
+    def with_request(self, request: str) -> ConsumeAction:
+        self.request = request
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ConsumeAction]:
+        if data is None:
+            return None
+        return ConsumeAction()\
+            .with_action(data.get('action'))\
+            .with_request(data.get('request'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "action": self.action,
+            "request": self.request,
+        }
+
+
 class AcquireAction(core.Gs2Model):
     action: str = None
     request: str = None
@@ -321,18 +424,154 @@ class AcquireAction(core.Gs2Model):
         }
 
 
+class TargetCounterModel(core.Gs2Model):
+    counter_name: str = None
+    scope_type: str = None
+    reset_type: str = None
+    condition_name: str = None
+    value: int = None
+
+    def with_counter_name(self, counter_name: str) -> TargetCounterModel:
+        self.counter_name = counter_name
+        return self
+
+    def with_scope_type(self, scope_type: str) -> TargetCounterModel:
+        self.scope_type = scope_type
+        return self
+
+    def with_reset_type(self, reset_type: str) -> TargetCounterModel:
+        self.reset_type = reset_type
+        return self
+
+    def with_condition_name(self, condition_name: str) -> TargetCounterModel:
+        self.condition_name = condition_name
+        return self
+
+    def with_value(self, value: int) -> TargetCounterModel:
+        self.value = value
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[TargetCounterModel]:
+        if data is None:
+            return None
+        return TargetCounterModel()\
+            .with_counter_name(data.get('counterName'))\
+            .with_scope_type(data.get('scopeType'))\
+            .with_reset_type(data.get('resetType'))\
+            .with_condition_name(data.get('conditionName'))\
+            .with_value(data.get('value'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "counterName": self.counter_name,
+            "scopeType": self.scope_type,
+            "resetType": self.reset_type,
+            "conditionName": self.condition_name,
+            "value": self.value,
+        }
+
+
+class ScopedValue(core.Gs2Model):
+    scope_type: str = None
+    reset_type: str = None
+    condition_name: str = None
+    value: int = None
+    next_reset_at: int = None
+    updated_at: int = None
+
+    def with_scope_type(self, scope_type: str) -> ScopedValue:
+        self.scope_type = scope_type
+        return self
+
+    def with_reset_type(self, reset_type: str) -> ScopedValue:
+        self.reset_type = reset_type
+        return self
+
+    def with_condition_name(self, condition_name: str) -> ScopedValue:
+        self.condition_name = condition_name
+        return self
+
+    def with_value(self, value: int) -> ScopedValue:
+        self.value = value
+        return self
+
+    def with_next_reset_at(self, next_reset_at: int) -> ScopedValue:
+        self.next_reset_at = next_reset_at
+        return self
+
+    def with_updated_at(self, updated_at: int) -> ScopedValue:
+        self.updated_at = updated_at
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ScopedValue]:
+        if data is None:
+            return None
+        return ScopedValue()\
+            .with_scope_type(data.get('scopeType'))\
+            .with_reset_type(data.get('resetType'))\
+            .with_condition_name(data.get('conditionName'))\
+            .with_value(data.get('value'))\
+            .with_next_reset_at(data.get('nextResetAt'))\
+            .with_updated_at(data.get('updatedAt'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "scopeType": self.scope_type,
+            "resetType": self.reset_type,
+            "conditionName": self.condition_name,
+            "value": self.value,
+            "nextResetAt": self.next_reset_at,
+            "updatedAt": self.updated_at,
+        }
+
+
 class MissionTaskModelMaster(core.Gs2Model):
     mission_task_id: str = None
     name: str = None
     metadata: str = None
     description: str = None
-    counter_name: str = None
-    target_value: int = None
+    verify_complete_type: str = None
+    target_counter: TargetCounterModel = None
+    verify_complete_consume_actions: List[VerifyAction] = None
     complete_acquire_actions: List[AcquireAction] = None
     challenge_period_event_id: str = None
     premise_mission_task_name: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
+    counter_name: str = None
+    target_reset_type: str = None
+    target_value: int = None
 
     def with_mission_task_id(self, mission_task_id: str) -> MissionTaskModelMaster:
         self.mission_task_id = mission_task_id
@@ -350,12 +589,16 @@ class MissionTaskModelMaster(core.Gs2Model):
         self.description = description
         return self
 
-    def with_counter_name(self, counter_name: str) -> MissionTaskModelMaster:
-        self.counter_name = counter_name
+    def with_verify_complete_type(self, verify_complete_type: str) -> MissionTaskModelMaster:
+        self.verify_complete_type = verify_complete_type
         return self
 
-    def with_target_value(self, target_value: int) -> MissionTaskModelMaster:
-        self.target_value = target_value
+    def with_target_counter(self, target_counter: TargetCounterModel) -> MissionTaskModelMaster:
+        self.target_counter = target_counter
+        return self
+
+    def with_verify_complete_consume_actions(self, verify_complete_consume_actions: List[VerifyAction]) -> MissionTaskModelMaster:
+        self.verify_complete_consume_actions = verify_complete_consume_actions
         return self
 
     def with_complete_acquire_actions(self, complete_acquire_actions: List[AcquireAction]) -> MissionTaskModelMaster:
@@ -378,6 +621,22 @@ class MissionTaskModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> MissionTaskModelMaster:
+        self.revision = revision
+        return self
+
+    def with_counter_name(self, counter_name: str) -> MissionTaskModelMaster:
+        self.counter_name = counter_name
+        return self
+
+    def with_target_reset_type(self, target_reset_type: str) -> MissionTaskModelMaster:
+        self.target_reset_type = target_reset_type
+        return self
+
+    def with_target_value(self, target_value: int) -> MissionTaskModelMaster:
+        self.target_value = target_value
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -468,16 +727,24 @@ class MissionTaskModelMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_description(data.get('description'))\
-            .with_counter_name(data.get('counterName'))\
-            .with_target_value(data.get('targetValue'))\
-            .with_complete_acquire_actions([
+            .with_verify_complete_type(data.get('verifyCompleteType'))\
+            .with_target_counter(TargetCounterModel.from_dict(data.get('targetCounter')))\
+            .with_verify_complete_consume_actions(None if data.get('verifyCompleteConsumeActions') is None else [
+                VerifyAction.from_dict(data.get('verifyCompleteConsumeActions')[i])
+                for i in range(len(data.get('verifyCompleteConsumeActions')))
+            ])\
+            .with_complete_acquire_actions(None if data.get('completeAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('completeAcquireActions')[i])
-                for i in range(len(data.get('completeAcquireActions')) if data.get('completeAcquireActions') else 0)
+                for i in range(len(data.get('completeAcquireActions')))
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
             .with_premise_mission_task_name(data.get('premiseMissionTaskName'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))\
+            .with_counter_name(data.get('counterName'))\
+            .with_target_reset_type(data.get('targetResetType'))\
+            .with_target_value(data.get('targetValue'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -485,71 +752,24 @@ class MissionTaskModelMaster(core.Gs2Model):
             "name": self.name,
             "metadata": self.metadata,
             "description": self.description,
-            "counterName": self.counter_name,
-            "targetValue": self.target_value,
-            "completeAcquireActions": [
+            "verifyCompleteType": self.verify_complete_type,
+            "targetCounter": self.target_counter.to_dict() if self.target_counter else None,
+            "verifyCompleteConsumeActions": None if self.verify_complete_consume_actions is None else [
+                self.verify_complete_consume_actions[i].to_dict() if self.verify_complete_consume_actions[i] else None
+                for i in range(len(self.verify_complete_consume_actions))
+            ],
+            "completeAcquireActions": None if self.complete_acquire_actions is None else [
                 self.complete_acquire_actions[i].to_dict() if self.complete_acquire_actions[i] else None
-                for i in range(len(self.complete_acquire_actions) if self.complete_acquire_actions else 0)
+                for i in range(len(self.complete_acquire_actions))
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
             "premiseMissionTaskName": self.premise_mission_task_name,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
-        }
-
-
-class ScopedValue(core.Gs2Model):
-    reset_type: str = None
-    value: int = None
-    next_reset_at: int = None
-    updated_at: int = None
-
-    def with_reset_type(self, reset_type: str) -> ScopedValue:
-        self.reset_type = reset_type
-        return self
-
-    def with_value(self, value: int) -> ScopedValue:
-        self.value = value
-        return self
-
-    def with_next_reset_at(self, next_reset_at: int) -> ScopedValue:
-        self.next_reset_at = next_reset_at
-        return self
-
-    def with_updated_at(self, updated_at: int) -> ScopedValue:
-        self.updated_at = updated_at
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[ScopedValue]:
-        if data is None:
-            return None
-        return ScopedValue()\
-            .with_reset_type(data.get('resetType'))\
-            .with_value(data.get('value'))\
-            .with_next_reset_at(data.get('nextResetAt'))\
-            .with_updated_at(data.get('updatedAt'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "resetType": self.reset_type,
-            "value": self.value,
-            "nextResetAt": self.next_reset_at,
-            "updatedAt": self.updated_at,
+            "revision": self.revision,
+            "counterName": self.counter_name,
+            "targetResetType": self.target_reset_type,
+            "targetValue": self.target_value,
         }
 
 
@@ -557,11 +777,15 @@ class MissionTaskModel(core.Gs2Model):
     mission_task_id: str = None
     name: str = None
     metadata: str = None
-    counter_name: str = None
-    target_value: int = None
+    verify_complete_type: str = None
+    target_counter: TargetCounterModel = None
+    verify_complete_consume_actions: List[VerifyAction] = None
     complete_acquire_actions: List[AcquireAction] = None
     challenge_period_event_id: str = None
     premise_mission_task_name: str = None
+    counter_name: str = None
+    target_reset_type: str = None
+    target_value: int = None
 
     def with_mission_task_id(self, mission_task_id: str) -> MissionTaskModel:
         self.mission_task_id = mission_task_id
@@ -575,12 +799,16 @@ class MissionTaskModel(core.Gs2Model):
         self.metadata = metadata
         return self
 
-    def with_counter_name(self, counter_name: str) -> MissionTaskModel:
-        self.counter_name = counter_name
+    def with_verify_complete_type(self, verify_complete_type: str) -> MissionTaskModel:
+        self.verify_complete_type = verify_complete_type
         return self
 
-    def with_target_value(self, target_value: int) -> MissionTaskModel:
-        self.target_value = target_value
+    def with_target_counter(self, target_counter: TargetCounterModel) -> MissionTaskModel:
+        self.target_counter = target_counter
+        return self
+
+    def with_verify_complete_consume_actions(self, verify_complete_consume_actions: List[VerifyAction]) -> MissionTaskModel:
+        self.verify_complete_consume_actions = verify_complete_consume_actions
         return self
 
     def with_complete_acquire_actions(self, complete_acquire_actions: List[AcquireAction]) -> MissionTaskModel:
@@ -595,6 +823,18 @@ class MissionTaskModel(core.Gs2Model):
         self.premise_mission_task_name = premise_mission_task_name
         return self
 
+    def with_counter_name(self, counter_name: str) -> MissionTaskModel:
+        self.counter_name = counter_name
+        return self
+
+    def with_target_reset_type(self, target_reset_type: str) -> MissionTaskModel:
+        self.target_reset_type = target_reset_type
+        return self
+
+    def with_target_value(self, target_value: int) -> MissionTaskModel:
+        self.target_value = target_value
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -684,28 +924,42 @@ class MissionTaskModel(core.Gs2Model):
             .with_mission_task_id(data.get('missionTaskId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_counter_name(data.get('counterName'))\
-            .with_target_value(data.get('targetValue'))\
-            .with_complete_acquire_actions([
+            .with_verify_complete_type(data.get('verifyCompleteType'))\
+            .with_target_counter(TargetCounterModel.from_dict(data.get('targetCounter')))\
+            .with_verify_complete_consume_actions(None if data.get('verifyCompleteConsumeActions') is None else [
+                VerifyAction.from_dict(data.get('verifyCompleteConsumeActions')[i])
+                for i in range(len(data.get('verifyCompleteConsumeActions')))
+            ])\
+            .with_complete_acquire_actions(None if data.get('completeAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('completeAcquireActions')[i])
-                for i in range(len(data.get('completeAcquireActions')) if data.get('completeAcquireActions') else 0)
+                for i in range(len(data.get('completeAcquireActions')))
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
-            .with_premise_mission_task_name(data.get('premiseMissionTaskName'))
+            .with_premise_mission_task_name(data.get('premiseMissionTaskName'))\
+            .with_counter_name(data.get('counterName'))\
+            .with_target_reset_type(data.get('targetResetType'))\
+            .with_target_value(data.get('targetValue'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "missionTaskId": self.mission_task_id,
             "name": self.name,
             "metadata": self.metadata,
-            "counterName": self.counter_name,
-            "targetValue": self.target_value,
-            "completeAcquireActions": [
+            "verifyCompleteType": self.verify_complete_type,
+            "targetCounter": self.target_counter.to_dict() if self.target_counter else None,
+            "verifyCompleteConsumeActions": None if self.verify_complete_consume_actions is None else [
+                self.verify_complete_consume_actions[i].to_dict() if self.verify_complete_consume_actions[i] else None
+                for i in range(len(self.verify_complete_consume_actions))
+            ],
+            "completeAcquireActions": None if self.complete_acquire_actions is None else [
                 self.complete_acquire_actions[i].to_dict() if self.complete_acquire_actions[i] else None
-                for i in range(len(self.complete_acquire_actions) if self.complete_acquire_actions else 0)
+                for i in range(len(self.complete_acquire_actions))
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
             "premiseMissionTaskName": self.premise_mission_task_name,
+            "counterName": self.counter_name,
+            "targetResetType": self.target_reset_type,
+            "targetValue": self.target_value,
         }
 
 
@@ -719,6 +973,8 @@ class MissionGroupModel(core.Gs2Model):
     reset_day_of_week: str = None
     reset_hour: int = None
     complete_notification_namespace_id: str = None
+    anchor_timestamp: int = None
+    days: int = None
 
     def with_mission_group_id(self, mission_group_id: str) -> MissionGroupModel:
         self.mission_group_id = mission_group_id
@@ -756,6 +1012,14 @@ class MissionGroupModel(core.Gs2Model):
         self.complete_notification_namespace_id = complete_notification_namespace_id
         return self
 
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> MissionGroupModel:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_days(self, days: int) -> MissionGroupModel:
+        self.days = days
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -833,30 +1097,34 @@ class MissionGroupModel(core.Gs2Model):
             .with_mission_group_id(data.get('missionGroupId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_tasks([
+            .with_tasks(None if data.get('tasks') is None else [
                 MissionTaskModel.from_dict(data.get('tasks')[i])
-                for i in range(len(data.get('tasks')) if data.get('tasks') else 0)
+                for i in range(len(data.get('tasks')))
             ])\
             .with_reset_type(data.get('resetType'))\
             .with_reset_day_of_month(data.get('resetDayOfMonth'))\
             .with_reset_day_of_week(data.get('resetDayOfWeek'))\
             .with_reset_hour(data.get('resetHour'))\
-            .with_complete_notification_namespace_id(data.get('completeNotificationNamespaceId'))
+            .with_complete_notification_namespace_id(data.get('completeNotificationNamespaceId'))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_days(data.get('days'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "missionGroupId": self.mission_group_id,
             "name": self.name,
             "metadata": self.metadata,
-            "tasks": [
+            "tasks": None if self.tasks is None else [
                 self.tasks[i].to_dict() if self.tasks[i] else None
-                for i in range(len(self.tasks) if self.tasks else 0)
+                for i in range(len(self.tasks))
             ],
             "resetType": self.reset_type,
             "resetDayOfMonth": self.reset_day_of_month,
             "resetDayOfWeek": self.reset_day_of_week,
             "resetHour": self.reset_hour,
             "completeNotificationNamespaceId": self.complete_notification_namespace_id,
+            "anchorTimestamp": self.anchor_timestamp,
+            "days": self.days,
         }
 
 
@@ -964,9 +1232,9 @@ class CounterModel(core.Gs2Model):
             .with_counter_id(data.get('counterId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_scopes([
+            .with_scopes(None if data.get('scopes') is None else [
                 CounterScopeModel.from_dict(data.get('scopes')[i])
-                for i in range(len(data.get('scopes')) if data.get('scopes') else 0)
+                for i in range(len(data.get('scopes')))
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))
 
@@ -975,9 +1243,9 @@ class CounterModel(core.Gs2Model):
             "counterId": self.counter_id,
             "name": self.name,
             "metadata": self.metadata,
-            "scopes": [
+            "scopes": None if self.scopes is None else [
                 self.scopes[i].to_dict() if self.scopes[i] else None
-                for i in range(len(self.scopes) if self.scopes else 0)
+                for i in range(len(self.scopes))
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
         }
@@ -1074,6 +1342,7 @@ class Counter(core.Gs2Model):
     values: List[ScopedValue] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_counter_id(self, counter_id: str) -> Counter:
         self.counter_id = counter_id
@@ -1099,6 +1368,10 @@ class Counter(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Counter:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1188,24 +1461,26 @@ class Counter(core.Gs2Model):
             .with_counter_id(data.get('counterId'))\
             .with_user_id(data.get('userId'))\
             .with_name(data.get('name'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 ScopedValue.from_dict(data.get('values')[i])
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "counterId": self.counter_id,
             "userId": self.user_id,
             "name": self.name,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i].to_dict() if self.values[i] else None
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1223,6 +1498,7 @@ class Namespace(core.Gs2Model):
     updated_at: int = None
     queue_namespace_id: str = None
     key_id: str = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1276,6 +1552,10 @@ class Namespace(core.Gs2Model):
         self.key_id = key_id
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1350,7 +1630,8 @@ class Namespace(core.Gs2Model):
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
-            .with_key_id(data.get('keyId'))
+            .with_key_id(data.get('keyId'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1367,6 +1648,7 @@ class Namespace(core.Gs2Model):
             "updatedAt": self.updated_at,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
+            "revision": self.revision,
         }
 
 
@@ -1379,9 +1661,12 @@ class MissionGroupModelMaster(core.Gs2Model):
     reset_day_of_month: int = None
     reset_day_of_week: str = None
     reset_hour: int = None
+    anchor_timestamp: int = None
+    days: int = None
     complete_notification_namespace_id: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_mission_group_id(self, mission_group_id: str) -> MissionGroupModelMaster:
         self.mission_group_id = mission_group_id
@@ -1415,6 +1700,14 @@ class MissionGroupModelMaster(core.Gs2Model):
         self.reset_hour = reset_hour
         return self
 
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> MissionGroupModelMaster:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_days(self, days: int) -> MissionGroupModelMaster:
+        self.days = days
+        return self
+
     def with_complete_notification_namespace_id(self, complete_notification_namespace_id: str) -> MissionGroupModelMaster:
         self.complete_notification_namespace_id = complete_notification_namespace_id
         return self
@@ -1427,6 +1720,10 @@ class MissionGroupModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> MissionGroupModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1509,9 +1806,12 @@ class MissionGroupModelMaster(core.Gs2Model):
             .with_reset_day_of_month(data.get('resetDayOfMonth'))\
             .with_reset_day_of_week(data.get('resetDayOfWeek'))\
             .with_reset_hour(data.get('resetHour'))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_days(data.get('days'))\
             .with_complete_notification_namespace_id(data.get('completeNotificationNamespaceId'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1523,17 +1823,29 @@ class MissionGroupModelMaster(core.Gs2Model):
             "resetDayOfMonth": self.reset_day_of_month,
             "resetDayOfWeek": self.reset_day_of_week,
             "resetHour": self.reset_hour,
+            "anchorTimestamp": self.anchor_timestamp,
+            "days": self.days,
             "completeNotificationNamespaceId": self.complete_notification_namespace_id,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
 class CounterScopeModel(core.Gs2Model):
+    scope_type: str = None
     reset_type: str = None
     reset_day_of_month: int = None
     reset_day_of_week: str = None
     reset_hour: int = None
+    condition_name: str = None
+    condition: VerifyAction = None
+    anchor_timestamp: int = None
+    days: int = None
+
+    def with_scope_type(self, scope_type: str) -> CounterScopeModel:
+        self.scope_type = scope_type
+        return self
 
     def with_reset_type(self, reset_type: str) -> CounterScopeModel:
         self.reset_type = reset_type
@@ -1551,6 +1863,22 @@ class CounterScopeModel(core.Gs2Model):
         self.reset_hour = reset_hour
         return self
 
+    def with_condition_name(self, condition_name: str) -> CounterScopeModel:
+        self.condition_name = condition_name
+        return self
+
+    def with_condition(self, condition: VerifyAction) -> CounterScopeModel:
+        self.condition = condition
+        return self
+
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> CounterScopeModel:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_days(self, days: int) -> CounterScopeModel:
+        self.days = days
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1570,17 +1898,27 @@ class CounterScopeModel(core.Gs2Model):
         if data is None:
             return None
         return CounterScopeModel()\
+            .with_scope_type(data.get('scopeType'))\
             .with_reset_type(data.get('resetType'))\
             .with_reset_day_of_month(data.get('resetDayOfMonth'))\
             .with_reset_day_of_week(data.get('resetDayOfWeek'))\
-            .with_reset_hour(data.get('resetHour'))
+            .with_reset_hour(data.get('resetHour'))\
+            .with_condition_name(data.get('conditionName'))\
+            .with_condition(VerifyAction.from_dict(data.get('condition')))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_days(data.get('days'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "scopeType": self.scope_type,
             "resetType": self.reset_type,
             "resetDayOfMonth": self.reset_day_of_month,
             "resetDayOfWeek": self.reset_day_of_week,
             "resetHour": self.reset_hour,
+            "conditionName": self.condition_name,
+            "condition": self.condition.to_dict() if self.condition else None,
+            "anchorTimestamp": self.anchor_timestamp,
+            "days": self.days,
         }
 
 
@@ -1593,6 +1931,7 @@ class CounterModelMaster(core.Gs2Model):
     challenge_period_event_id: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_counter_id(self, counter_id: str) -> CounterModelMaster:
         self.counter_id = counter_id
@@ -1626,6 +1965,10 @@ class CounterModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> CounterModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1704,13 +2047,14 @@ class CounterModelMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_description(data.get('description'))\
-            .with_scopes([
+            .with_scopes(None if data.get('scopes') is None else [
                 CounterScopeModel.from_dict(data.get('scopes')[i])
-                for i in range(len(data.get('scopes')) if data.get('scopes') else 0)
+                for i in range(len(data.get('scopes')))
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1718,13 +2062,14 @@ class CounterModelMaster(core.Gs2Model):
             "name": self.name,
             "metadata": self.metadata,
             "description": self.description,
-            "scopes": [
+            "scopes": None if self.scopes is None else [
                 self.scopes[i].to_dict() if self.scopes[i] else None
-                for i in range(len(self.scopes) if self.scopes else 0)
+                for i in range(len(self.scopes))
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1785,6 +2130,7 @@ class Complete(core.Gs2Model):
     next_reset_at: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_complete_id(self, complete_id: str) -> Complete:
         self.complete_id = complete_id
@@ -1818,6 +2164,10 @@ class Complete(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Complete:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1907,32 +2257,34 @@ class Complete(core.Gs2Model):
             .with_complete_id(data.get('completeId'))\
             .with_user_id(data.get('userId'))\
             .with_mission_group_name(data.get('missionGroupName'))\
-            .with_completed_mission_task_names([
+            .with_completed_mission_task_names(None if data.get('completedMissionTaskNames') is None else [
                 data.get('completedMissionTaskNames')[i]
-                for i in range(len(data.get('completedMissionTaskNames')) if data.get('completedMissionTaskNames') else 0)
+                for i in range(len(data.get('completedMissionTaskNames')))
             ])\
-            .with_received_mission_task_names([
+            .with_received_mission_task_names(None if data.get('receivedMissionTaskNames') is None else [
                 data.get('receivedMissionTaskNames')[i]
-                for i in range(len(data.get('receivedMissionTaskNames')) if data.get('receivedMissionTaskNames') else 0)
+                for i in range(len(data.get('receivedMissionTaskNames')))
             ])\
             .with_next_reset_at(data.get('nextResetAt'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "completeId": self.complete_id,
             "userId": self.user_id,
             "missionGroupName": self.mission_group_name,
-            "completedMissionTaskNames": [
+            "completedMissionTaskNames": None if self.completed_mission_task_names is None else [
                 self.completed_mission_task_names[i]
-                for i in range(len(self.completed_mission_task_names) if self.completed_mission_task_names else 0)
+                for i in range(len(self.completed_mission_task_names))
             ],
-            "receivedMissionTaskNames": [
+            "receivedMissionTaskNames": None if self.received_mission_task_names is None else [
                 self.received_mission_task_names[i]
-                for i in range(len(self.received_mission_task_names) if self.received_mission_task_names else 0)
+                for i in range(len(self.received_mission_task_names))
             ],
             "nextResetAt": self.next_reset_at,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
