@@ -162,6 +162,7 @@ class Receipt(core.Gs2Model):
     total: int = None
     contents_id: str = None
     created_at: int = None
+    revision: int = None
 
     def with_receipt_id(self, receipt_id: str) -> Receipt:
         self.receipt_id = receipt_id
@@ -211,6 +212,10 @@ class Receipt(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Receipt:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -308,7 +313,8 @@ class Receipt(core.Gs2Model):
             .with_free(data.get('free'))\
             .with_total(data.get('total'))\
             .with_contents_id(data.get('contentsId'))\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -324,6 +330,7 @@ class Receipt(core.Gs2Model):
             "total": self.total,
             "contentsId": self.contents_id,
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -334,8 +341,10 @@ class Wallet(core.Gs2Model):
     paid: int = None
     free: int = None
     detail: List[WalletDetail] = None
+    share_free: bool = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_wallet_id(self, wallet_id: str) -> Wallet:
         self.wallet_id = wallet_id
@@ -361,6 +370,10 @@ class Wallet(core.Gs2Model):
         self.detail = detail
         return self
 
+    def with_share_free(self, share_free: bool) -> Wallet:
+        self.share_free = share_free
+        return self
+
     def with_created_at(self, created_at: int) -> Wallet:
         self.created_at = created_at
         return self
@@ -369,6 +382,10 @@ class Wallet(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Wallet:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -460,12 +477,14 @@ class Wallet(core.Gs2Model):
             .with_slot(data.get('slot'))\
             .with_paid(data.get('paid'))\
             .with_free(data.get('free'))\
-            .with_detail([
+            .with_detail(None if data.get('detail') is None else [
                 WalletDetail.from_dict(data.get('detail')[i])
-                for i in range(len(data.get('detail')) if data.get('detail') else 0)
+                for i in range(len(data.get('detail')))
             ])\
+            .with_share_free(data.get('shareFree'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -474,12 +493,14 @@ class Wallet(core.Gs2Model):
             "slot": self.slot,
             "paid": self.paid,
             "free": self.free,
-            "detail": [
+            "detail": None if self.detail is None else [
                 self.detail[i].to_dict() if self.detail[i] else None
-                for i in range(len(self.detail) if self.detail else 0)
+                for i in range(len(self.detail))
             ],
+            "shareFree": self.share_free,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -500,6 +521,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -565,6 +587,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -642,7 +668,8 @@ class Namespace(core.Gs2Model):
             .with_balance(data.get('balance'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -662,4 +689,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
