@@ -141,6 +141,13 @@ class SetCookieRequestEntry(core.Gs2Model):
         self.value = value
         return self
 
+    @classmethod
+    def create_grn(
+        cls,
+    ):
+        return ''.format(
+        )
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -318,24 +325,24 @@ class View(core.Gs2Model):
         if data is None:
             return None
         return View()\
-            .with_contents([
+            .with_contents(None if data.get('contents') is None else [
                 Content.from_dict(data.get('contents')[i])
-                for i in range(len(data.get('contents')) if data.get('contents') else 0)
+                for i in range(len(data.get('contents')))
             ])\
-            .with_remove_contents([
+            .with_remove_contents(None if data.get('removeContents') is None else [
                 Content.from_dict(data.get('removeContents')[i])
-                for i in range(len(data.get('removeContents')) if data.get('removeContents') else 0)
+                for i in range(len(data.get('removeContents')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "contents": [
+            "contents": None if self.contents is None else [
                 self.contents[i].to_dict() if self.contents[i] else None
-                for i in range(len(self.contents) if self.contents else 0)
+                for i in range(len(self.contents))
             ],
-            "removeContents": [
+            "removeContents": None if self.remove_contents is None else [
                 self.remove_contents[i].to_dict() if self.remove_contents[i] else None
-                for i in range(len(self.remove_contents) if self.remove_contents else 0)
+                for i in range(len(self.remove_contents))
             ],
         }
 
@@ -345,6 +352,7 @@ class Output(core.Gs2Model):
     name: str = None
     text: str = None
     created_at: int = None
+    revision: int = None
 
     def with_output_id(self, output_id: str) -> Output:
         self.output_id = output_id
@@ -362,6 +370,10 @@ class Output(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Output:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -451,7 +463,8 @@ class Output(core.Gs2Model):
             .with_output_id(data.get('outputId'))\
             .with_name(data.get('name'))\
             .with_text(data.get('text'))\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -459,6 +472,7 @@ class Output(core.Gs2Model):
             "name": self.name,
             "text": self.text,
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -469,6 +483,7 @@ class Progress(core.Gs2Model):
     pattern_count: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_progress_id(self, progress_id: str) -> Progress:
         self.progress_id = progress_id
@@ -494,6 +509,10 @@ class Progress(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Progress:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -573,7 +592,8 @@ class Progress(core.Gs2Model):
             .with_generated(data.get('generated'))\
             .with_pattern_count(data.get('patternCount'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -583,6 +603,7 @@ class Progress(core.Gs2Model):
             "patternCount": self.pattern_count,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -594,6 +615,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -623,6 +645,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -691,7 +717,8 @@ class Namespace(core.Gs2Model):
             .with_version(data.get('version'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -702,4 +729,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
