@@ -268,6 +268,35 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
 class DescribeProgressesRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -638,6 +667,7 @@ class DescribeNewsByUserIdRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     user_id: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeNewsByUserIdRequest:
         self.namespace_name = namespace_name
@@ -647,6 +677,10 @@ class DescribeNewsByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeNewsByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -667,12 +701,14 @@ class DescribeNewsByUserIdRequest(core.Gs2Request):
             return None
         return DescribeNewsByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -724,6 +760,7 @@ class WantGrantByUserIdRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     user_id: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> WantGrantByUserIdRequest:
         self.namespace_name = namespace_name
@@ -733,6 +770,10 @@ class WantGrantByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> WantGrantByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -753,10 +794,12 @@ class WantGrantByUserIdRequest(core.Gs2Request):
             return None
         return WantGrantByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
         }
\ No newline at end of file
