@@ -27,6 +27,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNamespacesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -100,6 +101,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -175,6 +177,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceStatusResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -246,6 +249,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -317,6 +321,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -392,6 +397,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -457,12 +463,83 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='news',
+            region=self.session.region,
+        ) + "/system/version"
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetServiceVersionResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_progresses(
         self,
         request: DescribeProgressesRequest,
         callback: Callable[[AsyncResult[DescribeProgressesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -538,6 +615,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetProgressResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -610,6 +688,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeOutputsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -686,6 +765,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetOutputResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -759,6 +839,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[PrepareUpdateCurrentNewsMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -830,6 +911,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateCurrentNewsMasterResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -903,6 +985,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[PrepareUpdateCurrentNewsMasterFromGitHubResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -976,6 +1059,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNewsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -1049,6 +1133,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNewsByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -1064,6 +1149,8 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
@@ -1121,6 +1208,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[WantGrantResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -1194,6 +1282,7 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[WantGrantByUserIdResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='news',
             region=self.session.region,
@@ -1209,6 +1298,8 @@ class Gs2NewsRestClient(rest.AbstractGs2RestClient):
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='GET',
