@@ -14,6 +14,7 @@
 
 from __future__ import annotations
 
+from ..core.model import *
 from .model import *
 
 
@@ -48,17 +49,17 @@ class DescribeNamespacesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNamespacesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Namespace.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -234,6 +235,40 @@ class DeleteNamespaceResult(core.Gs2Result):
         }
 
 
+class GetServiceVersionResult(core.Gs2Result):
+    item: str = None
+
+    def with_item(self, item: str) -> GetServiceVersionResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionResult]:
+        if data is None:
+            return None
+        return GetServiceVersionResult()\
+            .with_item(data.get('item'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item,
+        }
+
+
 class DescribeProgressesResult(core.Gs2Result):
     items: List[Progress] = None
     next_page_token: str = None
@@ -265,17 +300,17 @@ class DescribeProgressesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeProgressesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Progress.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -346,17 +381,17 @@ class DescribeOutputsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeOutputsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Output.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -534,18 +569,18 @@ class DescribeNewsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNewsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 News.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_content_hash(data.get('contentHash'))\
             .with_template_hash(data.get('templateHash'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "contentHash": self.content_hash,
             "templateHash": self.template_hash,
@@ -588,18 +623,18 @@ class DescribeNewsByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNewsByUserIdResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 News.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_content_hash(data.get('contentHash'))\
             .with_template_hash(data.get('templateHash'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "contentHash": self.content_hash,
             "templateHash": self.template_hash,
@@ -642,18 +677,18 @@ class WantGrantResult(core.Gs2Result):
         if data is None:
             return None
         return WantGrantResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SetCookieRequestEntry.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_browser_url(data.get('browserUrl'))\
             .with_zip_url(data.get('zipUrl'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "browserUrl": self.browser_url,
             "zipUrl": self.zip_url,
@@ -696,18 +731,18 @@ class WantGrantByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return WantGrantByUserIdResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SetCookieRequestEntry.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_browser_url(data.get('browserUrl'))\
             .with_zip_url(data.get('zipUrl'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "browserUrl": self.browser_url,
             "zipUrl": self.zip_url,
