@@ -21,6 +21,9 @@ from gs2 import core
 
 class TransactionSetting(core.Gs2Model):
     enable_auto_run: bool = None
+    enable_atomic_commit: bool = None
+    transaction_use_distributor: bool = None
+    acquire_action_use_job_queue: bool = None
     distributor_namespace_id: str = None
     key_id: str = None
     queue_namespace_id: str = None
@@ -29,6 +32,18 @@ class TransactionSetting(core.Gs2Model):
         self.enable_auto_run = enable_auto_run
         return self
 
+    def with_enable_atomic_commit(self, enable_atomic_commit: bool) -> TransactionSetting:
+        self.enable_atomic_commit = enable_atomic_commit
+        return self
+
+    def with_transaction_use_distributor(self, transaction_use_distributor: bool) -> TransactionSetting:
+        self.transaction_use_distributor = transaction_use_distributor
+        return self
+
+    def with_acquire_action_use_job_queue(self, acquire_action_use_job_queue: bool) -> TransactionSetting:
+        self.acquire_action_use_job_queue = acquire_action_use_job_queue
+        return self
+
     def with_distributor_namespace_id(self, distributor_namespace_id: str) -> TransactionSetting:
         self.distributor_namespace_id = distributor_namespace_id
         return self
@@ -61,6 +76,9 @@ class TransactionSetting(core.Gs2Model):
             return None
         return TransactionSetting()\
             .with_enable_auto_run(data.get('enableAutoRun'))\
+            .with_enable_atomic_commit(data.get('enableAtomicCommit'))\
+            .with_transaction_use_distributor(data.get('transactionUseDistributor'))\
+            .with_acquire_action_use_job_queue(data.get('acquireActionUseJobQueue'))\
             .with_distributor_namespace_id(data.get('distributorNamespaceId'))\
             .with_key_id(data.get('keyId'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))
@@ -68,6 +86,9 @@ class TransactionSetting(core.Gs2Model):
     def to_dict(self) -> Dict[str, Any]:
         return {
             "enableAutoRun": self.enable_auto_run,
+            "enableAtomicCommit": self.enable_atomic_commit,
+            "transactionUseDistributor": self.transaction_use_distributor,
+            "acquireActionUseJobQueue": self.acquire_action_use_job_queue,
             "distributorNamespaceId": self.distributor_namespace_id,
             "keyId": self.key_id,
             "queueNamespaceId": self.queue_namespace_id,
@@ -280,6 +301,47 @@ class Config(core.Gs2Model):
         }
 
 
+class VerifyAction(core.Gs2Model):
+    action: str = None
+    request: str = None
+
+    def with_action(self, action: str) -> VerifyAction:
+        self.action = action
+        return self
+
+    def with_request(self, request: str) -> VerifyAction:
+        self.request = request
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyAction]:
+        if data is None:
+            return None
+        return VerifyAction()\
+            .with_action(data.get('action'))\
+            .with_request(data.get('request'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "action": self.action,
+            "request": self.request,
+        }
+
+
 class ConsumeAction(core.Gs2Model):
     action: str = None
     request: str = None
@@ -369,6 +431,7 @@ class QuestModel(core.Gs2Model):
     contents: List[Contents] = None
     challenge_period_event_id: str = None
     first_complete_acquire_actions: List[AcquireAction] = None
+    verify_actions: List[VerifyAction] = None
     consume_actions: List[ConsumeAction] = None
     failed_acquire_actions: List[AcquireAction] = None
     premise_quest_names: List[str] = None
@@ -397,6 +460,10 @@ class QuestModel(core.Gs2Model):
         self.first_complete_acquire_actions = first_complete_acquire_actions
         return self
 
+    def with_verify_actions(self, verify_actions: List[VerifyAction]) -> QuestModel:
+        self.verify_actions = verify_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> QuestModel:
         self.consume_actions = consume_actions
         return self
@@ -498,26 +565,30 @@ class QuestModel(core.Gs2Model):
             .with_quest_model_id(data.get('questModelId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_contents([
+            .with_contents(None if data.get('contents') is None else [
                 Contents.from_dict(data.get('contents')[i])
-                for i in range(len(data.get('contents')) if data.get('contents') else 0)
+                for i in range(len(data.get('contents')))
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
-            .with_first_complete_acquire_actions([
+            .with_first_complete_acquire_actions(None if data.get('firstCompleteAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('firstCompleteAcquireActions')[i])
-                for i in range(len(data.get('firstCompleteAcquireActions')) if data.get('firstCompleteAcquireActions') else 0)
+                for i in range(len(data.get('firstCompleteAcquireActions')))
             ])\
-            .with_consume_actions([
+            .with_verify_actions(None if data.get('verifyActions') is None else [
+                VerifyAction.from_dict(data.get('verifyActions')[i])
+                for i in range(len(data.get('verifyActions')))
+            ])\
+            .with_consume_actions(None if data.get('consumeActions') is None else [
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
-                for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
+                for i in range(len(data.get('consumeActions')))
             ])\
-            .with_failed_acquire_actions([
+            .with_failed_acquire_actions(None if data.get('failedAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('failedAcquireActions')[i])
-                for i in range(len(data.get('failedAcquireActions')) if data.get('failedAcquireActions') else 0)
+                for i in range(len(data.get('failedAcquireActions')))
             ])\
-            .with_premise_quest_names([
+            .with_premise_quest_names(None if data.get('premiseQuestNames') is None else [
                 data.get('premiseQuestNames')[i]
-                for i in range(len(data.get('premiseQuestNames')) if data.get('premiseQuestNames') else 0)
+                for i in range(len(data.get('premiseQuestNames')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
@@ -525,26 +596,30 @@ class QuestModel(core.Gs2Model):
             "questModelId": self.quest_model_id,
             "name": self.name,
             "metadata": self.metadata,
-            "contents": [
+            "contents": None if self.contents is None else [
                 self.contents[i].to_dict() if self.contents[i] else None
-                for i in range(len(self.contents) if self.contents else 0)
+                for i in range(len(self.contents))
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
-            "firstCompleteAcquireActions": [
+            "firstCompleteAcquireActions": None if self.first_complete_acquire_actions is None else [
                 self.first_complete_acquire_actions[i].to_dict() if self.first_complete_acquire_actions[i] else None
-                for i in range(len(self.first_complete_acquire_actions) if self.first_complete_acquire_actions else 0)
+                for i in range(len(self.first_complete_acquire_actions))
             ],
-            "consumeActions": [
+            "verifyActions": None if self.verify_actions is None else [
+                self.verify_actions[i].to_dict() if self.verify_actions[i] else None
+                for i in range(len(self.verify_actions))
+            ],
+            "consumeActions": None if self.consume_actions is None else [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
-                for i in range(len(self.consume_actions) if self.consume_actions else 0)
+                for i in range(len(self.consume_actions))
             ],
-            "failedAcquireActions": [
+            "failedAcquireActions": None if self.failed_acquire_actions is None else [
                 self.failed_acquire_actions[i].to_dict() if self.failed_acquire_actions[i] else None
-                for i in range(len(self.failed_acquire_actions) if self.failed_acquire_actions else 0)
+                for i in range(len(self.failed_acquire_actions))
             ],
-            "premiseQuestNames": [
+            "premiseQuestNames": None if self.premise_quest_names is None else [
                 self.premise_quest_names[i]
-                for i in range(len(self.premise_quest_names) if self.premise_quest_names else 0)
+                for i in range(len(self.premise_quest_names))
             ],
         }
 
@@ -653,9 +728,9 @@ class QuestGroupModel(core.Gs2Model):
             .with_quest_group_model_id(data.get('questGroupModelId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
-            .with_quests([
+            .with_quests(None if data.get('quests') is None else [
                 QuestModel.from_dict(data.get('quests')[i])
-                for i in range(len(data.get('quests')) if data.get('quests') else 0)
+                for i in range(len(data.get('quests')))
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))
 
@@ -664,9 +739,9 @@ class QuestGroupModel(core.Gs2Model):
             "questGroupModelId": self.quest_group_model_id,
             "name": self.name,
             "metadata": self.metadata,
-            "quests": [
+            "quests": None if self.quests is None else [
                 self.quests[i].to_dict() if self.quests[i] else None
-                for i in range(len(self.quests) if self.quests else 0)
+                for i in range(len(self.quests))
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
         }
@@ -679,6 +754,7 @@ class CompletedQuestList(core.Gs2Model):
     complete_quest_names: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_completed_quest_list_id(self, completed_quest_list_id: str) -> CompletedQuestList:
         self.completed_quest_list_id = completed_quest_list_id
@@ -704,6 +780,10 @@ class CompletedQuestList(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> CompletedQuestList:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -793,24 +873,26 @@ class CompletedQuestList(core.Gs2Model):
             .with_completed_quest_list_id(data.get('completedQuestListId'))\
             .with_user_id(data.get('userId'))\
             .with_quest_group_name(data.get('questGroupName'))\
-            .with_complete_quest_names([
+            .with_complete_quest_names(None if data.get('completeQuestNames') is None else [
                 data.get('completeQuestNames')[i]
-                for i in range(len(data.get('completeQuestNames')) if data.get('completeQuestNames') else 0)
+                for i in range(len(data.get('completeQuestNames')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "completedQuestListId": self.completed_quest_list_id,
             "userId": self.user_id,
             "questGroupName": self.quest_group_name,
-            "completeQuestNames": [
+            "completeQuestNames": None if self.complete_quest_names is None else [
                 self.complete_quest_names[i]
-                for i in range(len(self.complete_quest_names) if self.complete_quest_names else 0)
+                for i in range(len(self.complete_quest_names))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -821,9 +903,11 @@ class Progress(core.Gs2Model):
     quest_model_id: str = None
     random_seed: int = None
     rewards: List[Reward] = None
+    failed_rewards: List[Reward] = None
     metadata: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_progress_id(self, progress_id: str) -> Progress:
         self.progress_id = progress_id
@@ -849,6 +933,10 @@ class Progress(core.Gs2Model):
         self.rewards = rewards
         return self
 
+    def with_failed_rewards(self, failed_rewards: List[Reward]) -> Progress:
+        self.failed_rewards = failed_rewards
+        return self
+
     def with_metadata(self, metadata: str) -> Progress:
         self.metadata = metadata
         return self
@@ -861,6 +949,10 @@ class Progress(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Progress:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -940,13 +1032,18 @@ class Progress(core.Gs2Model):
             .with_transaction_id(data.get('transactionId'))\
             .with_quest_model_id(data.get('questModelId'))\
             .with_random_seed(data.get('randomSeed'))\
-            .with_rewards([
+            .with_rewards(None if data.get('rewards') is None else [
                 Reward.from_dict(data.get('rewards')[i])
-                for i in range(len(data.get('rewards')) if data.get('rewards') else 0)
+                for i in range(len(data.get('rewards')))
+            ])\
+            .with_failed_rewards(None if data.get('failedRewards') is None else [
+                Reward.from_dict(data.get('failedRewards')[i])
+                for i in range(len(data.get('failedRewards')))
             ])\
             .with_metadata(data.get('metadata'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -955,13 +1052,18 @@ class Progress(core.Gs2Model):
             "transactionId": self.transaction_id,
             "questModelId": self.quest_model_id,
             "randomSeed": self.random_seed,
-            "rewards": [
+            "rewards": None if self.rewards is None else [
                 self.rewards[i].to_dict() if self.rewards[i] else None
-                for i in range(len(self.rewards) if self.rewards else 0)
+                for i in range(len(self.rewards))
+            ],
+            "failedRewards": None if self.failed_rewards is None else [
+                self.failed_rewards[i].to_dict() if self.failed_rewards[i] else None
+                for i in range(len(self.failed_rewards))
             ],
             "metadata": self.metadata,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1057,18 +1159,18 @@ class Contents(core.Gs2Model):
             return None
         return Contents()\
             .with_metadata(data.get('metadata'))\
-            .with_complete_acquire_actions([
+            .with_complete_acquire_actions(None if data.get('completeAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('completeAcquireActions')[i])
-                for i in range(len(data.get('completeAcquireActions')) if data.get('completeAcquireActions') else 0)
+                for i in range(len(data.get('completeAcquireActions')))
             ])\
             .with_weight(data.get('weight'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "metadata": self.metadata,
-            "completeAcquireActions": [
+            "completeAcquireActions": None if self.complete_acquire_actions is None else [
                 self.complete_acquire_actions[i].to_dict() if self.complete_acquire_actions[i] else None
-                for i in range(len(self.complete_acquire_actions) if self.complete_acquire_actions else 0)
+                for i in range(len(self.complete_acquire_actions))
             ],
             "weight": self.weight,
         }
@@ -1167,11 +1269,13 @@ class QuestModelMaster(core.Gs2Model):
     contents: List[Contents] = None
     challenge_period_event_id: str = None
     first_complete_acquire_actions: List[AcquireAction] = None
+    verify_actions: List[VerifyAction] = None
     consume_actions: List[ConsumeAction] = None
     failed_acquire_actions: List[AcquireAction] = None
     premise_quest_names: List[str] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_quest_model_id(self, quest_model_id: str) -> QuestModelMaster:
         self.quest_model_id = quest_model_id
@@ -1205,6 +1309,10 @@ class QuestModelMaster(core.Gs2Model):
         self.first_complete_acquire_actions = first_complete_acquire_actions
         return self
 
+    def with_verify_actions(self, verify_actions: List[VerifyAction]) -> QuestModelMaster:
+        self.verify_actions = verify_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> QuestModelMaster:
         self.consume_actions = consume_actions
         return self
@@ -1225,6 +1333,10 @@ class QuestModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> QuestModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1316,29 +1428,34 @@ class QuestModelMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
-            .with_contents([
+            .with_contents(None if data.get('contents') is None else [
                 Contents.from_dict(data.get('contents')[i])
-                for i in range(len(data.get('contents')) if data.get('contents') else 0)
+                for i in range(len(data.get('contents')))
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
-            .with_first_complete_acquire_actions([
+            .with_first_complete_acquire_actions(None if data.get('firstCompleteAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('firstCompleteAcquireActions')[i])
-                for i in range(len(data.get('firstCompleteAcquireActions')) if data.get('firstCompleteAcquireActions') else 0)
+                for i in range(len(data.get('firstCompleteAcquireActions')))
             ])\
-            .with_consume_actions([
+            .with_verify_actions(None if data.get('verifyActions') is None else [
+                VerifyAction.from_dict(data.get('verifyActions')[i])
+                for i in range(len(data.get('verifyActions')))
+            ])\
+            .with_consume_actions(None if data.get('consumeActions') is None else [
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
-                for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
+                for i in range(len(data.get('consumeActions')))
             ])\
-            .with_failed_acquire_actions([
+            .with_failed_acquire_actions(None if data.get('failedAcquireActions') is None else [
                 AcquireAction.from_dict(data.get('failedAcquireActions')[i])
-                for i in range(len(data.get('failedAcquireActions')) if data.get('failedAcquireActions') else 0)
+                for i in range(len(data.get('failedAcquireActions')))
             ])\
-            .with_premise_quest_names([
+            .with_premise_quest_names(None if data.get('premiseQuestNames') is None else [
                 data.get('premiseQuestNames')[i]
-                for i in range(len(data.get('premiseQuestNames')) if data.get('premiseQuestNames') else 0)
+                for i in range(len(data.get('premiseQuestNames')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1347,29 +1464,34 @@ class QuestModelMaster(core.Gs2Model):
             "name": self.name,
             "description": self.description,
             "metadata": self.metadata,
-            "contents": [
+            "contents": None if self.contents is None else [
                 self.contents[i].to_dict() if self.contents[i] else None
-                for i in range(len(self.contents) if self.contents else 0)
+                for i in range(len(self.contents))
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
-            "firstCompleteAcquireActions": [
+            "firstCompleteAcquireActions": None if self.first_complete_acquire_actions is None else [
                 self.first_complete_acquire_actions[i].to_dict() if self.first_complete_acquire_actions[i] else None
-                for i in range(len(self.first_complete_acquire_actions) if self.first_complete_acquire_actions else 0)
+                for i in range(len(self.first_complete_acquire_actions))
             ],
-            "consumeActions": [
+            "verifyActions": None if self.verify_actions is None else [
+                self.verify_actions[i].to_dict() if self.verify_actions[i] else None
+                for i in range(len(self.verify_actions))
+            ],
+            "consumeActions": None if self.consume_actions is None else [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
-                for i in range(len(self.consume_actions) if self.consume_actions else 0)
+                for i in range(len(self.consume_actions))
             ],
-            "failedAcquireActions": [
+            "failedAcquireActions": None if self.failed_acquire_actions is None else [
                 self.failed_acquire_actions[i].to_dict() if self.failed_acquire_actions[i] else None
-                for i in range(len(self.failed_acquire_actions) if self.failed_acquire_actions else 0)
+                for i in range(len(self.failed_acquire_actions))
             ],
-            "premiseQuestNames": [
+            "premiseQuestNames": None if self.premise_quest_names is None else [
                 self.premise_quest_names[i]
-                for i in range(len(self.premise_quest_names) if self.premise_quest_names else 0)
+                for i in range(len(self.premise_quest_names))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1381,6 +1503,7 @@ class QuestGroupModelMaster(core.Gs2Model):
     challenge_period_event_id: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_quest_group_model_id(self, quest_group_model_id: str) -> QuestGroupModelMaster:
         self.quest_group_model_id = quest_group_model_id
@@ -1410,6 +1533,10 @@ class QuestGroupModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> QuestGroupModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1490,7 +1617,8 @@ class QuestGroupModelMaster(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1501,6 +1629,7 @@ class QuestGroupModelMaster(core.Gs2Model):
             "challengePeriodEventId": self.challenge_period_event_id,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1517,6 +1646,7 @@ class Namespace(core.Gs2Model):
     updated_at: int = None
     queue_namespace_id: str = None
     key_id: str = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1566,6 +1696,10 @@ class Namespace(core.Gs2Model):
         self.key_id = key_id
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1639,7 +1773,8 @@ class Namespace(core.Gs2Model):
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))\
             .with_queue_namespace_id(data.get('queueNamespaceId'))\
-            .with_key_id(data.get('keyId'))
+            .with_key_id(data.get('keyId'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1655,4 +1790,5 @@ class Namespace(core.Gs2Model):
             "updatedAt": self.updated_at,
             "queueNamespaceId": self.queue_namespace_id,
             "keyId": self.key_id,
+            "revision": self.revision,
         }
\ No newline at end of file
