@@ -304,6 +304,169 @@ class CalculatedAt(core.Gs2Model):
         }
 
 
+class FixedTiming(core.Gs2Model):
+    hour: int = None
+    minute: int = None
+
+    def with_hour(self, hour: int) -> FixedTiming:
+        self.hour = hour
+        return self
+
+    def with_minute(self, minute: int) -> FixedTiming:
+        self.minute = minute
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[FixedTiming]:
+        if data is None:
+            return None
+        return FixedTiming()\
+            .with_hour(data.get('hour'))\
+            .with_minute(data.get('minute'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "hour": self.hour,
+            "minute": self.minute,
+        }
+
+
+class GlobalRankingSetting(core.Gs2Model):
+    unique_by_user_id: bool = None
+    calculate_interval_minutes: int = None
+    calculate_fixed_timing: FixedTiming = None
+    additional_scopes: List[Scope] = None
+    ignore_user_ids: List[str] = None
+    generation: str = None
+
+    def with_unique_by_user_id(self, unique_by_user_id: bool) -> GlobalRankingSetting:
+        self.unique_by_user_id = unique_by_user_id
+        return self
+
+    def with_calculate_interval_minutes(self, calculate_interval_minutes: int) -> GlobalRankingSetting:
+        self.calculate_interval_minutes = calculate_interval_minutes
+        return self
+
+    def with_calculate_fixed_timing(self, calculate_fixed_timing: FixedTiming) -> GlobalRankingSetting:
+        self.calculate_fixed_timing = calculate_fixed_timing
+        return self
+
+    def with_additional_scopes(self, additional_scopes: List[Scope]) -> GlobalRankingSetting:
+        self.additional_scopes = additional_scopes
+        return self
+
+    def with_ignore_user_ids(self, ignore_user_ids: List[str]) -> GlobalRankingSetting:
+        self.ignore_user_ids = ignore_user_ids
+        return self
+
+    def with_generation(self, generation: str) -> GlobalRankingSetting:
+        self.generation = generation
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GlobalRankingSetting]:
+        if data is None:
+            return None
+        return GlobalRankingSetting()\
+            .with_unique_by_user_id(data.get('uniqueByUserId'))\
+            .with_calculate_interval_minutes(data.get('calculateIntervalMinutes'))\
+            .with_calculate_fixed_timing(FixedTiming.from_dict(data.get('calculateFixedTiming')))\
+            .with_additional_scopes(None if data.get('additionalScopes') is None else [
+                Scope.from_dict(data.get('additionalScopes')[i])
+                for i in range(len(data.get('additionalScopes')))
+            ])\
+            .with_ignore_user_ids(None if data.get('ignoreUserIds') is None else [
+                data.get('ignoreUserIds')[i]
+                for i in range(len(data.get('ignoreUserIds')))
+            ])\
+            .with_generation(data.get('generation'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "uniqueByUserId": self.unique_by_user_id,
+            "calculateIntervalMinutes": self.calculate_interval_minutes,
+            "calculateFixedTiming": self.calculate_fixed_timing.to_dict() if self.calculate_fixed_timing else None,
+            "additionalScopes": None if self.additional_scopes is None else [
+                self.additional_scopes[i].to_dict() if self.additional_scopes[i] else None
+                for i in range(len(self.additional_scopes))
+            ],
+            "ignoreUserIds": None if self.ignore_user_ids is None else [
+                self.ignore_user_ids[i]
+                for i in range(len(self.ignore_user_ids))
+            ],
+            "generation": self.generation,
+        }
+
+
+class Scope(core.Gs2Model):
+    name: str = None
+    target_days: int = None
+
+    def with_name(self, name: str) -> Scope:
+        self.name = name
+        return self
+
+    def with_target_days(self, target_days: int) -> Scope:
+        self.target_days = target_days
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[Scope]:
+        if data is None:
+            return None
+        return Scope()\
+            .with_name(data.get('name'))\
+            .with_target_days(data.get('targetDays'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "name": self.name,
+            "targetDays": self.target_days,
+        }
+
+
 class CurrentRankingMaster(core.Gs2Model):
     namespace_id: str = None
     settings: str = None
@@ -473,6 +636,7 @@ class Score(core.Gs2Model):
     score: int = None
     metadata: str = None
     created_at: int = None
+    revision: int = None
 
     def with_score_id(self, score_id: str) -> Score:
         self.score_id = score_id
@@ -506,6 +670,10 @@ class Score(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Score:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -623,7 +791,8 @@ class Score(core.Gs2Model):
             .with_scorer_user_id(data.get('scorerUserId'))\
             .with_score(data.get('score'))\
             .with_metadata(data.get('metadata'))\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -635,6 +804,7 @@ class Score(core.Gs2Model):
             "score": self.score,
             "metadata": self.metadata,
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -645,6 +815,7 @@ class Subscribe(core.Gs2Model):
     target_user_ids: List[str] = None
     subscribed_user_ids: List[str] = None
     created_at: int = None
+    revision: int = None
 
     def with_subscribe_id(self, subscribe_id: str) -> Subscribe:
         self.subscribe_id = subscribe_id
@@ -670,6 +841,10 @@ class Subscribe(core.Gs2Model):
         self.created_at = created_at
         return self
 
+    def with_revision(self, revision: int) -> Subscribe:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -759,30 +934,32 @@ class Subscribe(core.Gs2Model):
             .with_subscribe_id(data.get('subscribeId'))\
             .with_category_name(data.get('categoryName'))\
             .with_user_id(data.get('userId'))\
-            .with_target_user_ids([
+            .with_target_user_ids(None if data.get('targetUserIds') is None else [
                 data.get('targetUserIds')[i]
-                for i in range(len(data.get('targetUserIds')) if data.get('targetUserIds') else 0)
+                for i in range(len(data.get('targetUserIds')))
             ])\
-            .with_subscribed_user_ids([
+            .with_subscribed_user_ids(None if data.get('subscribedUserIds') is None else [
                 data.get('subscribedUserIds')[i]
-                for i in range(len(data.get('subscribedUserIds')) if data.get('subscribedUserIds') else 0)
+                for i in range(len(data.get('subscribedUserIds')))
             ])\
-            .with_created_at(data.get('createdAt'))
+            .with_created_at(data.get('createdAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "subscribeId": self.subscribe_id,
             "categoryName": self.category_name,
             "userId": self.user_id,
-            "targetUserIds": [
+            "targetUserIds": None if self.target_user_ids is None else [
                 self.target_user_ids[i]
-                for i in range(len(self.target_user_ids) if self.target_user_ids else 0)
+                for i in range(len(self.target_user_ids))
             ],
-            "subscribedUserIds": [
+            "subscribedUserIds": None if self.subscribed_user_ids is None else [
                 self.subscribed_user_ids[i]
-                for i in range(len(self.subscribed_user_ids) if self.subscribed_user_ids else 0)
+                for i in range(len(self.subscribed_user_ids))
             ],
             "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -793,19 +970,22 @@ class CategoryModelMaster(core.Gs2Model):
     metadata: str = None
     minimum_value: int = None
     maximum_value: int = None
+    sum: bool = None
     order_direction: str = None
     scope: str = None
+    global_ranking_setting: GlobalRankingSetting = None
+    entry_period_event_id: str = None
+    access_period_event_id: str = None
     unique_by_user_id: bool = None
-    sum: bool = None
     calculate_fixed_timing_hour: int = None
     calculate_fixed_timing_minute: int = None
     calculate_interval_minutes: int = None
-    entry_period_event_id: str = None
-    access_period_event_id: str = None
+    additional_scopes: List[Scope] = None
     ignore_user_ids: List[str] = None
     generation: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_category_model_id(self, category_model_id: str) -> CategoryModelMaster:
         self.category_model_id = category_model_id
@@ -831,6 +1011,10 @@ class CategoryModelMaster(core.Gs2Model):
         self.maximum_value = maximum_value
         return self
 
+    def with_sum(self, sum: bool) -> CategoryModelMaster:
+        self.sum = sum
+        return self
+
     def with_order_direction(self, order_direction: str) -> CategoryModelMaster:
         self.order_direction = order_direction
         return self
@@ -839,12 +1023,20 @@ class CategoryModelMaster(core.Gs2Model):
         self.scope = scope
         return self
 
-    def with_unique_by_user_id(self, unique_by_user_id: bool) -> CategoryModelMaster:
-        self.unique_by_user_id = unique_by_user_id
+    def with_global_ranking_setting(self, global_ranking_setting: GlobalRankingSetting) -> CategoryModelMaster:
+        self.global_ranking_setting = global_ranking_setting
         return self
 
-    def with_sum(self, sum: bool) -> CategoryModelMaster:
-        self.sum = sum
+    def with_entry_period_event_id(self, entry_period_event_id: str) -> CategoryModelMaster:
+        self.entry_period_event_id = entry_period_event_id
+        return self
+
+    def with_access_period_event_id(self, access_period_event_id: str) -> CategoryModelMaster:
+        self.access_period_event_id = access_period_event_id
+        return self
+
+    def with_unique_by_user_id(self, unique_by_user_id: bool) -> CategoryModelMaster:
+        self.unique_by_user_id = unique_by_user_id
         return self
 
     def with_calculate_fixed_timing_hour(self, calculate_fixed_timing_hour: int) -> CategoryModelMaster:
@@ -859,12 +1051,8 @@ class CategoryModelMaster(core.Gs2Model):
         self.calculate_interval_minutes = calculate_interval_minutes
         return self
 
-    def with_entry_period_event_id(self, entry_period_event_id: str) -> CategoryModelMaster:
-        self.entry_period_event_id = entry_period_event_id
-        return self
-
-    def with_access_period_event_id(self, access_period_event_id: str) -> CategoryModelMaster:
-        self.access_period_event_id = access_period_event_id
+    def with_additional_scopes(self, additional_scopes: List[Scope]) -> CategoryModelMaster:
+        self.additional_scopes = additional_scopes
         return self
 
     def with_ignore_user_ids(self, ignore_user_ids: List[str]) -> CategoryModelMaster:
@@ -883,6 +1071,10 @@ class CategoryModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> CategoryModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -963,22 +1155,28 @@ class CategoryModelMaster(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_minimum_value(data.get('minimumValue'))\
             .with_maximum_value(data.get('maximumValue'))\
+            .with_sum(data.get('sum'))\
             .with_order_direction(data.get('orderDirection'))\
             .with_scope(data.get('scope'))\
+            .with_global_ranking_setting(GlobalRankingSetting.from_dict(data.get('globalRankingSetting')))\
+            .with_entry_period_event_id(data.get('entryPeriodEventId'))\
+            .with_access_period_event_id(data.get('accessPeriodEventId'))\
             .with_unique_by_user_id(data.get('uniqueByUserId'))\
-            .with_sum(data.get('sum'))\
             .with_calculate_fixed_timing_hour(data.get('calculateFixedTimingHour'))\
             .with_calculate_fixed_timing_minute(data.get('calculateFixedTimingMinute'))\
             .with_calculate_interval_minutes(data.get('calculateIntervalMinutes'))\
-            .with_entry_period_event_id(data.get('entryPeriodEventId'))\
-            .with_access_period_event_id(data.get('accessPeriodEventId'))\
-            .with_ignore_user_ids([
+            .with_additional_scopes(None if data.get('additionalScopes') is None else [
+                Scope.from_dict(data.get('additionalScopes')[i])
+                for i in range(len(data.get('additionalScopes')))
+            ])\
+            .with_ignore_user_ids(None if data.get('ignoreUserIds') is None else [
                 data.get('ignoreUserIds')[i]
-                for i in range(len(data.get('ignoreUserIds')) if data.get('ignoreUserIds') else 0)
+                for i in range(len(data.get('ignoreUserIds')))
             ])\
             .with_generation(data.get('generation'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -988,22 +1186,28 @@ class CategoryModelMaster(core.Gs2Model):
             "metadata": self.metadata,
             "minimumValue": self.minimum_value,
             "maximumValue": self.maximum_value,
+            "sum": self.sum,
             "orderDirection": self.order_direction,
             "scope": self.scope,
+            "globalRankingSetting": self.global_ranking_setting.to_dict() if self.global_ranking_setting else None,
+            "entryPeriodEventId": self.entry_period_event_id,
+            "accessPeriodEventId": self.access_period_event_id,
             "uniqueByUserId": self.unique_by_user_id,
-            "sum": self.sum,
             "calculateFixedTimingHour": self.calculate_fixed_timing_hour,
             "calculateFixedTimingMinute": self.calculate_fixed_timing_minute,
             "calculateIntervalMinutes": self.calculate_interval_minutes,
-            "entryPeriodEventId": self.entry_period_event_id,
-            "accessPeriodEventId": self.access_period_event_id,
-            "ignoreUserIds": [
+            "additionalScopes": None if self.additional_scopes is None else [
+                self.additional_scopes[i].to_dict() if self.additional_scopes[i] else None
+                for i in range(len(self.additional_scopes))
+            ],
+            "ignoreUserIds": None if self.ignore_user_ids is None else [
                 self.ignore_user_ids[i]
-                for i in range(len(self.ignore_user_ids) if self.ignore_user_ids else 0)
+                for i in range(len(self.ignore_user_ids))
             ],
             "generation": self.generation,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1013,15 +1217,17 @@ class CategoryModel(core.Gs2Model):
     metadata: str = None
     minimum_value: int = None
     maximum_value: int = None
+    sum: bool = None
     order_direction: str = None
     scope: str = None
+    global_ranking_setting: GlobalRankingSetting = None
+    entry_period_event_id: str = None
+    access_period_event_id: str = None
     unique_by_user_id: bool = None
-    sum: bool = None
     calculate_fixed_timing_hour: int = None
     calculate_fixed_timing_minute: int = None
     calculate_interval_minutes: int = None
-    entry_period_event_id: str = None
-    access_period_event_id: str = None
+    additional_scopes: List[Scope] = None
     ignore_user_ids: List[str] = None
     generation: str = None
 
@@ -1045,6 +1251,10 @@ class CategoryModel(core.Gs2Model):
         self.maximum_value = maximum_value
         return self
 
+    def with_sum(self, sum: bool) -> CategoryModel:
+        self.sum = sum
+        return self
+
     def with_order_direction(self, order_direction: str) -> CategoryModel:
         self.order_direction = order_direction
         return self
@@ -1053,12 +1263,20 @@ class CategoryModel(core.Gs2Model):
         self.scope = scope
         return self
 
-    def with_unique_by_user_id(self, unique_by_user_id: bool) -> CategoryModel:
-        self.unique_by_user_id = unique_by_user_id
+    def with_global_ranking_setting(self, global_ranking_setting: GlobalRankingSetting) -> CategoryModel:
+        self.global_ranking_setting = global_ranking_setting
         return self
 
-    def with_sum(self, sum: bool) -> CategoryModel:
-        self.sum = sum
+    def with_entry_period_event_id(self, entry_period_event_id: str) -> CategoryModel:
+        self.entry_period_event_id = entry_period_event_id
+        return self
+
+    def with_access_period_event_id(self, access_period_event_id: str) -> CategoryModel:
+        self.access_period_event_id = access_period_event_id
+        return self
+
+    def with_unique_by_user_id(self, unique_by_user_id: bool) -> CategoryModel:
+        self.unique_by_user_id = unique_by_user_id
         return self
 
     def with_calculate_fixed_timing_hour(self, calculate_fixed_timing_hour: int) -> CategoryModel:
@@ -1073,12 +1291,8 @@ class CategoryModel(core.Gs2Model):
         self.calculate_interval_minutes = calculate_interval_minutes
         return self
 
-    def with_entry_period_event_id(self, entry_period_event_id: str) -> CategoryModel:
-        self.entry_period_event_id = entry_period_event_id
-        return self
-
-    def with_access_period_event_id(self, access_period_event_id: str) -> CategoryModel:
-        self.access_period_event_id = access_period_event_id
+    def with_additional_scopes(self, additional_scopes: List[Scope]) -> CategoryModel:
+        self.additional_scopes = additional_scopes
         return self
 
     def with_ignore_user_ids(self, ignore_user_ids: List[str]) -> CategoryModel:
@@ -1168,18 +1382,23 @@ class CategoryModel(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_minimum_value(data.get('minimumValue'))\
             .with_maximum_value(data.get('maximumValue'))\
+            .with_sum(data.get('sum'))\
             .with_order_direction(data.get('orderDirection'))\
             .with_scope(data.get('scope'))\
+            .with_global_ranking_setting(GlobalRankingSetting.from_dict(data.get('globalRankingSetting')))\
+            .with_entry_period_event_id(data.get('entryPeriodEventId'))\
+            .with_access_period_event_id(data.get('accessPeriodEventId'))\
             .with_unique_by_user_id(data.get('uniqueByUserId'))\
-            .with_sum(data.get('sum'))\
             .with_calculate_fixed_timing_hour(data.get('calculateFixedTimingHour'))\
             .with_calculate_fixed_timing_minute(data.get('calculateFixedTimingMinute'))\
             .with_calculate_interval_minutes(data.get('calculateIntervalMinutes'))\
-            .with_entry_period_event_id(data.get('entryPeriodEventId'))\
-            .with_access_period_event_id(data.get('accessPeriodEventId'))\
-            .with_ignore_user_ids([
+            .with_additional_scopes(None if data.get('additionalScopes') is None else [
+                Scope.from_dict(data.get('additionalScopes')[i])
+                for i in range(len(data.get('additionalScopes')))
+            ])\
+            .with_ignore_user_ids(None if data.get('ignoreUserIds') is None else [
                 data.get('ignoreUserIds')[i]
-                for i in range(len(data.get('ignoreUserIds')) if data.get('ignoreUserIds') else 0)
+                for i in range(len(data.get('ignoreUserIds')))
             ])\
             .with_generation(data.get('generation'))
 
@@ -1190,18 +1409,23 @@ class CategoryModel(core.Gs2Model):
             "metadata": self.metadata,
             "minimumValue": self.minimum_value,
             "maximumValue": self.maximum_value,
+            "sum": self.sum,
             "orderDirection": self.order_direction,
             "scope": self.scope,
+            "globalRankingSetting": self.global_ranking_setting.to_dict() if self.global_ranking_setting else None,
+            "entryPeriodEventId": self.entry_period_event_id,
+            "accessPeriodEventId": self.access_period_event_id,
             "uniqueByUserId": self.unique_by_user_id,
-            "sum": self.sum,
             "calculateFixedTimingHour": self.calculate_fixed_timing_hour,
             "calculateFixedTimingMinute": self.calculate_fixed_timing_minute,
             "calculateIntervalMinutes": self.calculate_interval_minutes,
-            "entryPeriodEventId": self.entry_period_event_id,
-            "accessPeriodEventId": self.access_period_event_id,
-            "ignoreUserIds": [
+            "additionalScopes": None if self.additional_scopes is None else [
+                self.additional_scopes[i].to_dict() if self.additional_scopes[i] else None
+                for i in range(len(self.additional_scopes))
+            ],
+            "ignoreUserIds": None if self.ignore_user_ids is None else [
                 self.ignore_user_ids[i]
-                for i in range(len(self.ignore_user_ids) if self.ignore_user_ids else 0)
+                for i in range(len(self.ignore_user_ids))
             ],
             "generation": self.generation,
         }
@@ -1215,6 +1439,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1244,6 +1469,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1309,24 +1538,26 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
-            .with_last_calculated_ats([
+            .with_last_calculated_ats(None if data.get('lastCalculatedAts') is None else [
                 CalculatedAt.from_dict(data.get('lastCalculatedAts')[i])
-                for i in range(len(data.get('lastCalculatedAts')) if data.get('lastCalculatedAts') else 0)
+                for i in range(len(data.get('lastCalculatedAts')))
             ])\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
-            "lastCalculatedAts": [
+            "lastCalculatedAts": None if self.last_calculated_ats is None else [
                 self.last_calculated_ats[i].to_dict() if self.last_calculated_ats[i] else None
-                for i in range(len(self.last_calculated_ats) if self.last_calculated_ats else 0)
+                for i in range(len(self.last_calculated_ats))
             ],
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
