@@ -346,6 +346,35 @@ class NowRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
 class DescribeRoomsRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -436,18 +465,18 @@ class WantRoomRequest(core.Gs2Request):
         return WantRoomRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_name(data.get('name'))\
-            .with_notification_user_ids([
+            .with_notification_user_ids(None if data.get('notificationUserIds') is None else [
                 data.get('notificationUserIds')[i]
-                for i in range(len(data.get('notificationUserIds')) if data.get('notificationUserIds') else 0)
+                for i in range(len(data.get('notificationUserIds')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "name": self.name,
-            "notificationUserIds": [
+            "notificationUserIds": None if self.notification_user_ids is None else [
                 self.notification_user_ids[i]
-                for i in range(len(self.notification_user_ids) if self.notification_user_ids else 0)
+                for i in range(len(self.notification_user_ids))
             ],
         }
 
