@@ -19,68 +19,6 @@ from typing import *
 from gs2 import core
 
 
-class RepeatSchedule(core.Gs2Model):
-    repeat_count: int = None
-    current_repeat_start_at: int = None
-    current_repeat_end_at: int = None
-    last_repeat_end_at: int = None
-    next_repeat_start_at: int = None
-
-    def with_repeat_count(self, repeat_count: int) -> RepeatSchedule:
-        self.repeat_count = repeat_count
-        return self
-
-    def with_current_repeat_start_at(self, current_repeat_start_at: int) -> RepeatSchedule:
-        self.current_repeat_start_at = current_repeat_start_at
-        return self
-
-    def with_current_repeat_end_at(self, current_repeat_end_at: int) -> RepeatSchedule:
-        self.current_repeat_end_at = current_repeat_end_at
-        return self
-
-    def with_last_repeat_end_at(self, last_repeat_end_at: int) -> RepeatSchedule:
-        self.last_repeat_end_at = last_repeat_end_at
-        return self
-
-    def with_next_repeat_start_at(self, next_repeat_start_at: int) -> RepeatSchedule:
-        self.next_repeat_start_at = next_repeat_start_at
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[RepeatSchedule]:
-        if data is None:
-            return None
-        return RepeatSchedule()\
-            .with_repeat_count(data.get('repeatCount'))\
-            .with_current_repeat_start_at(data.get('currentRepeatStartAt'))\
-            .with_current_repeat_end_at(data.get('currentRepeatEndAt'))\
-            .with_last_repeat_end_at(data.get('lastRepeatEndAt'))\
-            .with_next_repeat_start_at(data.get('nextRepeatStartAt'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "repeatCount": self.repeat_count,
-            "currentRepeatStartAt": self.current_repeat_start_at,
-            "currentRepeatEndAt": self.current_repeat_end_at,
-            "lastRepeatEndAt": self.last_repeat_end_at,
-            "nextRepeatStartAt": self.next_repeat_start_at,
-        }
-
-
 class LogSetting(core.Gs2Model):
     logging_namespace_id: str = None
 
@@ -275,21 +213,181 @@ class CurrentEventMaster(core.Gs2Model):
         }
 
 
+class RepeatSchedule(core.Gs2Model):
+    repeat_count: int = None
+    current_repeat_start_at: int = None
+    current_repeat_end_at: int = None
+    last_repeat_end_at: int = None
+    next_repeat_start_at: int = None
+
+    def with_repeat_count(self, repeat_count: int) -> RepeatSchedule:
+        self.repeat_count = repeat_count
+        return self
+
+    def with_current_repeat_start_at(self, current_repeat_start_at: int) -> RepeatSchedule:
+        self.current_repeat_start_at = current_repeat_start_at
+        return self
+
+    def with_current_repeat_end_at(self, current_repeat_end_at: int) -> RepeatSchedule:
+        self.current_repeat_end_at = current_repeat_end_at
+        return self
+
+    def with_last_repeat_end_at(self, last_repeat_end_at: int) -> RepeatSchedule:
+        self.last_repeat_end_at = last_repeat_end_at
+        return self
+
+    def with_next_repeat_start_at(self, next_repeat_start_at: int) -> RepeatSchedule:
+        self.next_repeat_start_at = next_repeat_start_at
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RepeatSchedule]:
+        if data is None:
+            return None
+        return RepeatSchedule()\
+            .with_repeat_count(data.get('repeatCount'))\
+            .with_current_repeat_start_at(data.get('currentRepeatStartAt'))\
+            .with_current_repeat_end_at(data.get('currentRepeatEndAt'))\
+            .with_last_repeat_end_at(data.get('lastRepeatEndAt'))\
+            .with_next_repeat_start_at(data.get('nextRepeatStartAt'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "repeatCount": self.repeat_count,
+            "currentRepeatStartAt": self.current_repeat_start_at,
+            "currentRepeatEndAt": self.current_repeat_end_at,
+            "lastRepeatEndAt": self.last_repeat_end_at,
+            "nextRepeatStartAt": self.next_repeat_start_at,
+        }
+
+
+class RepeatSetting(core.Gs2Model):
+    repeat_type: str = None
+    begin_day_of_month: int = None
+    end_day_of_month: int = None
+    begin_day_of_week: str = None
+    end_day_of_week: str = None
+    begin_hour: int = None
+    end_hour: int = None
+    anchor_timestamp: int = None
+    active_days: int = None
+    inactive_days: int = None
+
+    def with_repeat_type(self, repeat_type: str) -> RepeatSetting:
+        self.repeat_type = repeat_type
+        return self
+
+    def with_begin_day_of_month(self, begin_day_of_month: int) -> RepeatSetting:
+        self.begin_day_of_month = begin_day_of_month
+        return self
+
+    def with_end_day_of_month(self, end_day_of_month: int) -> RepeatSetting:
+        self.end_day_of_month = end_day_of_month
+        return self
+
+    def with_begin_day_of_week(self, begin_day_of_week: str) -> RepeatSetting:
+        self.begin_day_of_week = begin_day_of_week
+        return self
+
+    def with_end_day_of_week(self, end_day_of_week: str) -> RepeatSetting:
+        self.end_day_of_week = end_day_of_week
+        return self
+
+    def with_begin_hour(self, begin_hour: int) -> RepeatSetting:
+        self.begin_hour = begin_hour
+        return self
+
+    def with_end_hour(self, end_hour: int) -> RepeatSetting:
+        self.end_hour = end_hour
+        return self
+
+    def with_anchor_timestamp(self, anchor_timestamp: int) -> RepeatSetting:
+        self.anchor_timestamp = anchor_timestamp
+        return self
+
+    def with_active_days(self, active_days: int) -> RepeatSetting:
+        self.active_days = active_days
+        return self
+
+    def with_inactive_days(self, inactive_days: int) -> RepeatSetting:
+        self.inactive_days = inactive_days
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RepeatSetting]:
+        if data is None:
+            return None
+        return RepeatSetting()\
+            .with_repeat_type(data.get('repeatType'))\
+            .with_begin_day_of_month(data.get('beginDayOfMonth'))\
+            .with_end_day_of_month(data.get('endDayOfMonth'))\
+            .with_begin_day_of_week(data.get('beginDayOfWeek'))\
+            .with_end_day_of_week(data.get('endDayOfWeek'))\
+            .with_begin_hour(data.get('beginHour'))\
+            .with_end_hour(data.get('endHour'))\
+            .with_anchor_timestamp(data.get('anchorTimestamp'))\
+            .with_active_days(data.get('activeDays'))\
+            .with_inactive_days(data.get('inactiveDays'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "repeatType": self.repeat_type,
+            "beginDayOfMonth": self.begin_day_of_month,
+            "endDayOfMonth": self.end_day_of_month,
+            "beginDayOfWeek": self.begin_day_of_week,
+            "endDayOfWeek": self.end_day_of_week,
+            "beginHour": self.begin_hour,
+            "endHour": self.end_hour,
+            "anchorTimestamp": self.anchor_timestamp,
+            "activeDays": self.active_days,
+            "inactiveDays": self.inactive_days,
+        }
+
+
 class Event(core.Gs2Model):
     event_id: str = None
     name: str = None
     metadata: str = None
     schedule_type: str = None
-    repeat_type: str = None
     absolute_begin: int = None
     absolute_end: int = None
+    relative_trigger_name: str = None
+    repeat_setting: RepeatSetting = None
+    repeat_type: str = None
     repeat_begin_day_of_month: int = None
     repeat_end_day_of_month: int = None
     repeat_begin_day_of_week: str = None
     repeat_end_day_of_week: str = None
     repeat_begin_hour: int = None
     repeat_end_hour: int = None
-    relative_trigger_name: str = None
 
     def with_event_id(self, event_id: str) -> Event:
         self.event_id = event_id
@@ -307,10 +405,6 @@ class Event(core.Gs2Model):
         self.schedule_type = schedule_type
         return self
 
-    def with_repeat_type(self, repeat_type: str) -> Event:
-        self.repeat_type = repeat_type
-        return self
-
     def with_absolute_begin(self, absolute_begin: int) -> Event:
         self.absolute_begin = absolute_begin
         return self
@@ -319,6 +413,18 @@ class Event(core.Gs2Model):
         self.absolute_end = absolute_end
         return self
 
+    def with_relative_trigger_name(self, relative_trigger_name: str) -> Event:
+        self.relative_trigger_name = relative_trigger_name
+        return self
+
+    def with_repeat_setting(self, repeat_setting: RepeatSetting) -> Event:
+        self.repeat_setting = repeat_setting
+        return self
+
+    def with_repeat_type(self, repeat_type: str) -> Event:
+        self.repeat_type = repeat_type
+        return self
+
     def with_repeat_begin_day_of_month(self, repeat_begin_day_of_month: int) -> Event:
         self.repeat_begin_day_of_month = repeat_begin_day_of_month
         return self
@@ -343,10 +449,6 @@ class Event(core.Gs2Model):
         self.repeat_end_hour = repeat_end_hour
         return self
 
-    def with_relative_trigger_name(self, relative_trigger_name: str) -> Event:
-        self.relative_trigger_name = relative_trigger_name
-        return self
-
     @classmethod
     def create_grn(
         cls,
@@ -425,16 +527,17 @@ class Event(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_schedule_type(data.get('scheduleType'))\
-            .with_repeat_type(data.get('repeatType'))\
             .with_absolute_begin(data.get('absoluteBegin'))\
             .with_absolute_end(data.get('absoluteEnd'))\
+            .with_relative_trigger_name(data.get('relativeTriggerName'))\
+            .with_repeat_setting(RepeatSetting.from_dict(data.get('repeatSetting')))\
+            .with_repeat_type(data.get('repeatType'))\
             .with_repeat_begin_day_of_month(data.get('repeatBeginDayOfMonth'))\
             .with_repeat_end_day_of_month(data.get('repeatEndDayOfMonth'))\
             .with_repeat_begin_day_of_week(data.get('repeatBeginDayOfWeek'))\
             .with_repeat_end_day_of_week(data.get('repeatEndDayOfWeek'))\
             .with_repeat_begin_hour(data.get('repeatBeginHour'))\
-            .with_repeat_end_hour(data.get('repeatEndHour'))\
-            .with_relative_trigger_name(data.get('relativeTriggerName'))
+            .with_repeat_end_hour(data.get('repeatEndHour'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -442,16 +545,17 @@ class Event(core.Gs2Model):
             "name": self.name,
             "metadata": self.metadata,
             "scheduleType": self.schedule_type,
-            "repeatType": self.repeat_type,
             "absoluteBegin": self.absolute_begin,
             "absoluteEnd": self.absolute_end,
+            "relativeTriggerName": self.relative_trigger_name,
+            "repeatSetting": self.repeat_setting.to_dict() if self.repeat_setting else None,
+            "repeatType": self.repeat_type,
             "repeatBeginDayOfMonth": self.repeat_begin_day_of_month,
             "repeatEndDayOfMonth": self.repeat_end_day_of_month,
             "repeatBeginDayOfWeek": self.repeat_begin_day_of_week,
             "repeatEndDayOfWeek": self.repeat_end_day_of_week,
             "repeatBeginHour": self.repeat_begin_hour,
             "repeatEndHour": self.repeat_end_hour,
-            "relativeTriggerName": self.relative_trigger_name,
         }
 
 
@@ -459,8 +563,10 @@ class Trigger(core.Gs2Model):
     trigger_id: str = None
     name: str = None
     user_id: str = None
-    created_at: int = None
+    triggered_at: int = None
     expires_at: int = None
+    created_at: int = None
+    revision: int = None
 
     def with_trigger_id(self, trigger_id: str) -> Trigger:
         self.trigger_id = trigger_id
@@ -474,14 +580,22 @@ class Trigger(core.Gs2Model):
         self.user_id = user_id
         return self
 
-    def with_created_at(self, created_at: int) -> Trigger:
-        self.created_at = created_at
+    def with_triggered_at(self, triggered_at: int) -> Trigger:
+        self.triggered_at = triggered_at
         return self
 
     def with_expires_at(self, expires_at: int) -> Trigger:
         self.expires_at = expires_at
         return self
 
+    def with_created_at(self, created_at: int) -> Trigger:
+        self.created_at = created_at
+        return self
+
+    def with_revision(self, revision: int) -> Trigger:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -571,16 +685,20 @@ class Trigger(core.Gs2Model):
             .with_trigger_id(data.get('triggerId'))\
             .with_name(data.get('name'))\
             .with_user_id(data.get('userId'))\
+            .with_triggered_at(data.get('triggeredAt'))\
+            .with_expires_at(data.get('expiresAt'))\
             .with_created_at(data.get('createdAt'))\
-            .with_expires_at(data.get('expiresAt'))
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "triggerId": self.trigger_id,
             "name": self.name,
             "userId": self.user_id,
-            "createdAt": self.created_at,
+            "triggeredAt": self.triggered_at,
             "expiresAt": self.expires_at,
+            "createdAt": self.created_at,
+            "revision": self.revision,
         }
 
 
@@ -590,18 +708,20 @@ class EventMaster(core.Gs2Model):
     description: str = None
     metadata: str = None
     schedule_type: str = None
-    repeat_type: str = None
     absolute_begin: int = None
     absolute_end: int = None
+    relative_trigger_name: str = None
+    repeat_setting: RepeatSetting = None
+    created_at: int = None
+    updated_at: int = None
+    revision: int = None
+    repeat_type: str = None
     repeat_begin_day_of_month: int = None
     repeat_end_day_of_month: int = None
     repeat_begin_day_of_week: str = None
     repeat_end_day_of_week: str = None
     repeat_begin_hour: int = None
     repeat_end_hour: int = None
-    relative_trigger_name: str = None
-    created_at: int = None
-    updated_at: int = None
 
     def with_event_id(self, event_id: str) -> EventMaster:
         self.event_id = event_id
@@ -623,10 +743,6 @@ class EventMaster(core.Gs2Model):
         self.schedule_type = schedule_type
         return self
 
-    def with_repeat_type(self, repeat_type: str) -> EventMaster:
-        self.repeat_type = repeat_type
-        return self
-
     def with_absolute_begin(self, absolute_begin: int) -> EventMaster:
         self.absolute_begin = absolute_begin
         return self
@@ -635,6 +751,30 @@ class EventMaster(core.Gs2Model):
         self.absolute_end = absolute_end
         return self
 
+    def with_relative_trigger_name(self, relative_trigger_name: str) -> EventMaster:
+        self.relative_trigger_name = relative_trigger_name
+        return self
+
+    def with_repeat_setting(self, repeat_setting: RepeatSetting) -> EventMaster:
+        self.repeat_setting = repeat_setting
+        return self
+
+    def with_created_at(self, created_at: int) -> EventMaster:
+        self.created_at = created_at
+        return self
+
+    def with_updated_at(self, updated_at: int) -> EventMaster:
+        self.updated_at = updated_at
+        return self
+
+    def with_revision(self, revision: int) -> EventMaster:
+        self.revision = revision
+        return self
+
+    def with_repeat_type(self, repeat_type: str) -> EventMaster:
+        self.repeat_type = repeat_type
+        return self
+
     def with_repeat_begin_day_of_month(self, repeat_begin_day_of_month: int) -> EventMaster:
         self.repeat_begin_day_of_month = repeat_begin_day_of_month
         return self
@@ -659,18 +799,6 @@ class EventMaster(core.Gs2Model):
         self.repeat_end_hour = repeat_end_hour
         return self
 
-    def with_relative_trigger_name(self, relative_trigger_name: str) -> EventMaster:
-        self.relative_trigger_name = relative_trigger_name
-        return self
-
-    def with_created_at(self, created_at: int) -> EventMaster:
-        self.created_at = created_at
-        return self
-
-    def with_updated_at(self, updated_at: int) -> EventMaster:
-        self.updated_at = updated_at
-        return self
-
     @classmethod
     def create_grn(
         cls,
@@ -750,18 +878,20 @@ class EventMaster(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
             .with_schedule_type(data.get('scheduleType'))\
-            .with_repeat_type(data.get('repeatType'))\
             .with_absolute_begin(data.get('absoluteBegin'))\
             .with_absolute_end(data.get('absoluteEnd'))\
+            .with_relative_trigger_name(data.get('relativeTriggerName'))\
+            .with_repeat_setting(RepeatSetting.from_dict(data.get('repeatSetting')))\
+            .with_created_at(data.get('createdAt'))\
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))\
+            .with_repeat_type(data.get('repeatType'))\
             .with_repeat_begin_day_of_month(data.get('repeatBeginDayOfMonth'))\
             .with_repeat_end_day_of_month(data.get('repeatEndDayOfMonth'))\
             .with_repeat_begin_day_of_week(data.get('repeatBeginDayOfWeek'))\
             .with_repeat_end_day_of_week(data.get('repeatEndDayOfWeek'))\
             .with_repeat_begin_hour(data.get('repeatBeginHour'))\
-            .with_repeat_end_hour(data.get('repeatEndHour'))\
-            .with_relative_trigger_name(data.get('relativeTriggerName'))\
-            .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_repeat_end_hour(data.get('repeatEndHour'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -770,18 +900,20 @@ class EventMaster(core.Gs2Model):
             "description": self.description,
             "metadata": self.metadata,
             "scheduleType": self.schedule_type,
-            "repeatType": self.repeat_type,
             "absoluteBegin": self.absolute_begin,
             "absoluteEnd": self.absolute_end,
+            "relativeTriggerName": self.relative_trigger_name,
+            "repeatSetting": self.repeat_setting.to_dict() if self.repeat_setting else None,
+            "createdAt": self.created_at,
+            "updatedAt": self.updated_at,
+            "revision": self.revision,
+            "repeatType": self.repeat_type,
             "repeatBeginDayOfMonth": self.repeat_begin_day_of_month,
             "repeatEndDayOfMonth": self.repeat_end_day_of_month,
             "repeatBeginDayOfWeek": self.repeat_begin_day_of_week,
             "repeatEndDayOfWeek": self.repeat_end_day_of_week,
             "repeatBeginHour": self.repeat_begin_hour,
             "repeatEndHour": self.repeat_end_hour,
-            "relativeTriggerName": self.relative_trigger_name,
-            "createdAt": self.created_at,
-            "updatedAt": self.updated_at,
         }
 
 
@@ -792,6 +924,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -817,6 +950,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -884,7 +1021,8 @@ class Namespace(core.Gs2Model):
             .with_description(data.get('description'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -894,4 +1032,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
