@@ -65,6 +65,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     log_setting: LogSetting = None
 
     def with_name(self, name: str) -> CreateNamespaceRequest:
@@ -75,6 +76,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> CreateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_log_setting(self, log_setting: LogSetting) -> CreateNamespaceRequest:
         self.log_setting = log_setting
         return self
@@ -100,12 +105,14 @@ class CreateNamespaceRequest(core.Gs2Request):
         return CreateNamespaceRequest()\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "name": self.name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
         }
 
@@ -187,6 +194,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     description: str = None
+    transaction_setting: TransactionSetting = None
     log_setting: LogSetting = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateNamespaceRequest:
@@ -197,6 +205,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.description = description
         return self
 
+    def with_transaction_setting(self, transaction_setting: TransactionSetting) -> UpdateNamespaceRequest:
+        self.transaction_setting = transaction_setting
+        return self
+
     def with_log_setting(self, log_setting: LogSetting) -> UpdateNamespaceRequest:
         self.log_setting = log_setting
         return self
@@ -222,12 +234,14 @@ class UpdateNamespaceRequest(core.Gs2Request):
         return UpdateNamespaceRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
+            .with_transaction_setting(TransactionSetting.from_dict(data.get('transactionSetting')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "description": self.description,
+            "transactionSetting": self.transaction_setting.to_dict() if self.transaction_setting else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
         }
 
@@ -268,6 +282,35 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
 class DescribeScriptsRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -325,6 +368,7 @@ class CreateScriptRequest(core.Gs2Request):
     name: str = None
     description: str = None
     script: str = None
+    disable_string_number_to_number: bool = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateScriptRequest:
         self.namespace_name = namespace_name
@@ -342,6 +386,10 @@ class CreateScriptRequest(core.Gs2Request):
         self.script = script
         return self
 
+    def with_disable_string_number_to_number(self, disable_string_number_to_number: bool) -> CreateScriptRequest:
+        self.disable_string_number_to_number = disable_string_number_to_number
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -364,7 +412,8 @@ class CreateScriptRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
-            .with_script(data.get('script'))
+            .with_script(data.get('script'))\
+            .with_disable_string_number_to_number(data.get('disableStringNumberToNumber'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -372,6 +421,7 @@ class CreateScriptRequest(core.Gs2Request):
             "name": self.name,
             "description": self.description,
             "script": self.script,
+            "disableStringNumberToNumber": self.disable_string_number_to_number,
         }
 
 
@@ -382,6 +432,7 @@ class CreateScriptFromGitHubRequest(core.Gs2Request):
     name: str = None
     description: str = None
     checkout_setting: GitHubCheckoutSetting = None
+    disable_string_number_to_number: bool = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateScriptFromGitHubRequest:
         self.namespace_name = namespace_name
@@ -399,6 +450,10 @@ class CreateScriptFromGitHubRequest(core.Gs2Request):
         self.checkout_setting = checkout_setting
         return self
 
+    def with_disable_string_number_to_number(self, disable_string_number_to_number: bool) -> CreateScriptFromGitHubRequest:
+        self.disable_string_number_to_number = disable_string_number_to_number
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -421,7 +476,8 @@ class CreateScriptFromGitHubRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
-            .with_checkout_setting(GitHubCheckoutSetting.from_dict(data.get('checkoutSetting')))
+            .with_checkout_setting(GitHubCheckoutSetting.from_dict(data.get('checkoutSetting')))\
+            .with_disable_string_number_to_number(data.get('disableStringNumberToNumber'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -429,6 +485,7 @@ class CreateScriptFromGitHubRequest(core.Gs2Request):
             "name": self.name,
             "description": self.description,
             "checkoutSetting": self.checkout_setting.to_dict() if self.checkout_setting else None,
+            "disableStringNumberToNumber": self.disable_string_number_to_number,
         }
 
 
@@ -482,6 +539,7 @@ class UpdateScriptRequest(core.Gs2Request):
     script_name: str = None
     description: str = None
     script: str = None
+    disable_string_number_to_number: bool = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateScriptRequest:
         self.namespace_name = namespace_name
@@ -499,6 +557,10 @@ class UpdateScriptRequest(core.Gs2Request):
         self.script = script
         return self
 
+    def with_disable_string_number_to_number(self, disable_string_number_to_number: bool) -> UpdateScriptRequest:
+        self.disable_string_number_to_number = disable_string_number_to_number
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -521,7 +583,8 @@ class UpdateScriptRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_script_name(data.get('scriptName'))\
             .with_description(data.get('description'))\
-            .with_script(data.get('script'))
+            .with_script(data.get('script'))\
+            .with_disable_string_number_to_number(data.get('disableStringNumberToNumber'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -529,6 +592,7 @@ class UpdateScriptRequest(core.Gs2Request):
             "scriptName": self.script_name,
             "description": self.description,
             "script": self.script,
+            "disableStringNumberToNumber": self.disable_string_number_to_number,
         }
 
 
@@ -539,6 +603,7 @@ class UpdateScriptFromGitHubRequest(core.Gs2Request):
     script_name: str = None
     description: str = None
     checkout_setting: GitHubCheckoutSetting = None
+    disable_string_number_to_number: bool = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateScriptFromGitHubRequest:
         self.namespace_name = namespace_name
@@ -556,6 +621,10 @@ class UpdateScriptFromGitHubRequest(core.Gs2Request):
         self.checkout_setting = checkout_setting
         return self
 
+    def with_disable_string_number_to_number(self, disable_string_number_to_number: bool) -> UpdateScriptFromGitHubRequest:
+        self.disable_string_number_to_number = disable_string_number_to_number
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -578,7 +647,8 @@ class UpdateScriptFromGitHubRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_script_name(data.get('scriptName'))\
             .with_description(data.get('description'))\
-            .with_checkout_setting(GitHubCheckoutSetting.from_dict(data.get('checkoutSetting')))
+            .with_checkout_setting(GitHubCheckoutSetting.from_dict(data.get('checkoutSetting')))\
+            .with_disable_string_number_to_number(data.get('disableStringNumberToNumber'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -586,6 +656,7 @@ class UpdateScriptFromGitHubRequest(core.Gs2Request):
             "scriptName": self.script_name,
             "description": self.description,
             "checkoutSetting": self.checkout_setting.to_dict() if self.checkout_setting else None,
+            "disableStringNumberToNumber": self.disable_string_number_to_number,
         }
 
 
@@ -638,6 +709,9 @@ class InvokeScriptRequest(core.Gs2Request):
     script_id: str = None
     user_id: str = None
     args: str = None
+    random_status: RandomStatus = None
+    time_offset_token: str = None
+    duplication_avoider: str = None
 
     def with_script_id(self, script_id: str) -> InvokeScriptRequest:
         self.script_id = script_id
@@ -651,6 +725,18 @@ class InvokeScriptRequest(core.Gs2Request):
         self.args = args
         return self
 
+    def with_random_status(self, random_status: RandomStatus) -> InvokeScriptRequest:
+        self.random_status = random_status
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> InvokeScriptRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> InvokeScriptRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -672,13 +758,17 @@ class InvokeScriptRequest(core.Gs2Request):
         return InvokeScriptRequest()\
             .with_script_id(data.get('scriptId'))\
             .with_user_id(data.get('userId'))\
-            .with_args(data.get('args'))
+            .with_args(data.get('args'))\
+            .with_random_status(RandomStatus.from_dict(data.get('randomStatus')))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "scriptId": self.script_id,
             "userId": self.user_id,
             "args": self.args,
+            "randomStatus": self.random_status.to_dict() if self.random_status else None,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -687,6 +777,11 @@ class DebugInvokeRequest(core.Gs2Request):
     context_stack: str = None
     script: str = None
     args: str = None
+    user_id: str = None
+    random_status: RandomStatus = None
+    disable_string_number_to_number: bool = None
+    time_offset_token: str = None
+    duplication_avoider: str = None
 
     def with_script(self, script: str) -> DebugInvokeRequest:
         self.script = script
@@ -696,6 +791,26 @@ class DebugInvokeRequest(core.Gs2Request):
         self.args = args
         return self
 
+    def with_user_id(self, user_id: str) -> DebugInvokeRequest:
+        self.user_id = user_id
+        return self
+
+    def with_random_status(self, random_status: RandomStatus) -> DebugInvokeRequest:
+        self.random_status = random_status
+        return self
+
+    def with_disable_string_number_to_number(self, disable_string_number_to_number: bool) -> DebugInvokeRequest:
+        self.disable_string_number_to_number = disable_string_number_to_number
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> DebugInvokeRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> DebugInvokeRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -716,10 +831,61 @@ class DebugInvokeRequest(core.Gs2Request):
             return None
         return DebugInvokeRequest()\
             .with_script(data.get('script'))\
-            .with_args(data.get('args'))
+            .with_args(data.get('args'))\
+            .with_user_id(data.get('userId'))\
+            .with_random_status(RandomStatus.from_dict(data.get('randomStatus')))\
+            .with_disable_string_number_to_number(data.get('disableStringNumberToNumber'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "script": self.script,
             "args": self.args,
+            "userId": self.user_id,
+            "randomStatus": self.random_status.to_dict() if self.random_status else None,
+            "disableStringNumberToNumber": self.disable_string_number_to_number,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class InvokeByStampSheetRequest(core.Gs2Request):
+
+    context_stack: str = None
+    stamp_sheet: str = None
+    key_id: str = None
+
+    def with_stamp_sheet(self, stamp_sheet: str) -> InvokeByStampSheetRequest:
+        self.stamp_sheet = stamp_sheet
+        return self
+
+    def with_key_id(self, key_id: str) -> InvokeByStampSheetRequest:
+        self.key_id = key_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[InvokeByStampSheetRequest]:
+        if data is None:
+            return None
+        return InvokeByStampSheetRequest()\
+            .with_stamp_sheet(data.get('stampSheet'))\
+            .with_key_id(data.get('keyId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "stampSheet": self.stamp_sheet,
+            "keyId": self.key_id,
         }
\ No newline at end of file
