@@ -27,6 +27,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DescribeNamespacesResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -100,6 +101,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -113,6 +115,8 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             body["name"] = request.name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -175,6 +179,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceStatusResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -246,6 +251,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -317,6 +323,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -330,6 +337,8 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         }
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -392,6 +401,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteNamespaceResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -457,12 +467,83 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='script',
+            region=self.session.region,
+        ) + "/system/version"
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetServiceVersionResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_scripts(
         self,
         request: DescribeScriptsRequest,
         callback: Callable[[AsyncResult[DescribeScriptsResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -538,6 +619,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateScriptResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -555,6 +637,8 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             body["description"] = request.description
         if request.script is not None:
             body["script"] = request.script
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -615,6 +699,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[CreateScriptFromGitHubResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -632,6 +717,8 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             body["description"] = request.description
         if request.checkout_setting is not None:
             body["checkoutSetting"] = request.checkout_setting.to_dict()
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -692,6 +779,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[GetScriptResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -764,6 +852,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateScriptResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -780,6 +869,8 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             body["description"] = request.description
         if request.script is not None:
             body["script"] = request.script
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -840,6 +931,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[UpdateScriptFromGitHubResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -856,6 +948,8 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             body["description"] = request.description
         if request.checkout_setting is not None:
             body["checkoutSetting"] = request.checkout_setting.to_dict()
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
@@ -916,6 +1010,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DeleteScriptResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -988,6 +1083,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[InvokeScriptResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -1003,9 +1099,15 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             body["userId"] = request.user_id
         if request.args is not None:
             body["args"] = request.args
+        if request.random_status is not None:
+            body["randomStatus"] = request.random_status.to_dict()
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='POST',
@@ -1063,6 +1165,7 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
         callback: Callable[[AsyncResult[DebugInvokeResult]], None],
         is_blocking: bool,
     ):
+
         url = Gs2Constant.ENDPOINT_HOST.format(
             service='script',
             region=self.session.region,
@@ -1076,9 +1179,19 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             body["script"] = request.script
         if request.args is not None:
             body["args"] = request.args
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.random_status is not None:
+            body["randomStatus"] = request.random_status.to_dict()
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        if request.time_offset_token:
+            headers["X-GS2-TIME-OFFSET-TOKEN"] = request.time_offset_token
         _job = rest.NetworkJob(
             url=url,
             method='POST',
@@ -1121,6 +1234,80 @@ class Gs2ScriptRestClient(rest.AbstractGs2RestClient):
             is_blocking=False,
         )
 
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _invoke_by_stamp_sheet(
+        self,
+        request: InvokeByStampSheetRequest,
+        callback: Callable[[AsyncResult[InvokeByStampSheetResult]], None],
+        is_blocking: bool,
+    ):
+
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='script',
+            region=self.session.region,
+        ) + "/stamp/script/invoke"
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.stamp_sheet is not None:
+            body["stampSheet"] = request.stamp_sheet
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=InvokeByStampSheetResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def invoke_by_stamp_sheet(
+        self,
+        request: InvokeByStampSheetRequest,
+    ) -> InvokeByStampSheetResult:
+        async_result = []
+        with timeout(30):
+            self._invoke_by_stamp_sheet(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def invoke_by_stamp_sheet_async(
+        self,
+        request: InvokeByStampSheetRequest,
+    ) -> InvokeByStampSheetResult:
+        async_result = []
+        self._invoke_by_stamp_sheet(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
         import asyncio
         with timeout(30):
             while not async_result:
