@@ -14,6 +14,7 @@
 
 from __future__ import annotations
 
+from ..core.model import *
 from .model import *
 
 
@@ -48,17 +49,17 @@ class DescribeNamespacesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNamespacesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Namespace.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -234,6 +235,40 @@ class DeleteNamespaceResult(core.Gs2Result):
         }
 
 
+class GetServiceVersionResult(core.Gs2Result):
+    item: str = None
+
+    def with_item(self, item: str) -> GetServiceVersionResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionResult]:
+        if data is None:
+            return None
+        return GetServiceVersionResult()\
+            .with_item(data.get('item'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item,
+        }
+
+
 class DescribeScriptsResult(core.Gs2Result):
     items: List[Script] = None
     next_page_token: str = None
@@ -265,17 +300,17 @@ class DescribeScriptsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeScriptsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Script.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -488,6 +523,10 @@ class DeleteScriptResult(core.Gs2Result):
 class InvokeScriptResult(core.Gs2Result):
     code: int = None
     result: str = None
+    transaction: Transaction = None
+    random_status: RandomStatus = None
+    atomic_commit: bool = None
+    transaction_result: TransactionResult = None
     execute_time: int = None
     charged: int = None
     output: List[str] = None
@@ -500,6 +539,22 @@ class InvokeScriptResult(core.Gs2Result):
         self.result = result
         return self
 
+    def with_transaction(self, transaction: Transaction) -> InvokeScriptResult:
+        self.transaction = transaction
+        return self
+
+    def with_random_status(self, random_status: RandomStatus) -> InvokeScriptResult:
+        self.random_status = random_status
+        return self
+
+    def with_atomic_commit(self, atomic_commit: bool) -> InvokeScriptResult:
+        self.atomic_commit = atomic_commit
+        return self
+
+    def with_transaction_result(self, transaction_result: TransactionResult) -> InvokeScriptResult:
+        self.transaction_result = transaction_result
+        return self
+
     def with_execute_time(self, execute_time: int) -> InvokeScriptResult:
         self.execute_time = execute_time
         return self
@@ -533,22 +588,30 @@ class InvokeScriptResult(core.Gs2Result):
         return InvokeScriptResult()\
             .with_code(data.get('code'))\
             .with_result(data.get('result'))\
+            .with_transaction(Transaction.from_dict(data.get('transaction')))\
+            .with_random_status(RandomStatus.from_dict(data.get('randomStatus')))\
+            .with_atomic_commit(data.get('atomicCommit'))\
+            .with_transaction_result(TransactionResult.from_dict(data.get('transactionResult')))\
             .with_execute_time(data.get('executeTime'))\
             .with_charged(data.get('charged'))\
-            .with_output([
+            .with_output(None if data.get('output') is None else [
                 data.get('output')[i]
-                for i in range(len(data.get('output')) if data.get('output') else 0)
+                for i in range(len(data.get('output')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "code": self.code,
             "result": self.result,
+            "transaction": self.transaction.to_dict() if self.transaction else None,
+            "randomStatus": self.random_status.to_dict() if self.random_status else None,
+            "atomicCommit": self.atomic_commit,
+            "transactionResult": self.transaction_result.to_dict() if self.transaction_result else None,
             "executeTime": self.execute_time,
             "charged": self.charged,
-            "output": [
+            "output": None if self.output is None else [
                 self.output[i]
-                for i in range(len(self.output) if self.output else 0)
+                for i in range(len(self.output))
             ],
         }
 
@@ -556,6 +619,10 @@ class InvokeScriptResult(core.Gs2Result):
 class DebugInvokeResult(core.Gs2Result):
     code: int = None
     result: str = None
+    transaction: Transaction = None
+    random_status: RandomStatus = None
+    atomic_commit: bool = None
+    transaction_result: TransactionResult = None
     execute_time: int = None
     charged: int = None
     output: List[str] = None
@@ -568,6 +635,22 @@ class DebugInvokeResult(core.Gs2Result):
         self.result = result
         return self
 
+    def with_transaction(self, transaction: Transaction) -> DebugInvokeResult:
+        self.transaction = transaction
+        return self
+
+    def with_random_status(self, random_status: RandomStatus) -> DebugInvokeResult:
+        self.random_status = random_status
+        return self
+
+    def with_atomic_commit(self, atomic_commit: bool) -> DebugInvokeResult:
+        self.atomic_commit = atomic_commit
+        return self
+
+    def with_transaction_result(self, transaction_result: TransactionResult) -> DebugInvokeResult:
+        self.transaction_result = transaction_result
+        return self
+
     def with_execute_time(self, execute_time: int) -> DebugInvokeResult:
         self.execute_time = execute_time
         return self
@@ -601,21 +684,125 @@ class DebugInvokeResult(core.Gs2Result):
         return DebugInvokeResult()\
             .with_code(data.get('code'))\
             .with_result(data.get('result'))\
+            .with_transaction(Transaction.from_dict(data.get('transaction')))\
+            .with_random_status(RandomStatus.from_dict(data.get('randomStatus')))\
+            .with_atomic_commit(data.get('atomicCommit'))\
+            .with_transaction_result(TransactionResult.from_dict(data.get('transactionResult')))\
             .with_execute_time(data.get('executeTime'))\
             .with_charged(data.get('charged'))\
-            .with_output([
+            .with_output(None if data.get('output') is None else [
                 data.get('output')[i]
-                for i in range(len(data.get('output')) if data.get('output') else 0)
+                for i in range(len(data.get('output')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "code": self.code,
             "result": self.result,
+            "transaction": self.transaction.to_dict() if self.transaction else None,
+            "randomStatus": self.random_status.to_dict() if self.random_status else None,
+            "atomicCommit": self.atomic_commit,
+            "transactionResult": self.transaction_result.to_dict() if self.transaction_result else None,
             "executeTime": self.execute_time,
             "charged": self.charged,
-            "output": [
+            "output": None if self.output is None else [
                 self.output[i]
-                for i in range(len(self.output) if self.output else 0)
+                for i in range(len(self.output))
+            ],
+        }
+
+
+class InvokeByStampSheetResult(core.Gs2Result):
+    code: int = None
+    result: str = None
+    transaction: Transaction = None
+    random_status: RandomStatus = None
+    atomic_commit: bool = None
+    transaction_result: TransactionResult = None
+    execute_time: int = None
+    charged: int = None
+    output: List[str] = None
+
+    def with_code(self, code: int) -> InvokeByStampSheetResult:
+        self.code = code
+        return self
+
+    def with_result(self, result: str) -> InvokeByStampSheetResult:
+        self.result = result
+        return self
+
+    def with_transaction(self, transaction: Transaction) -> InvokeByStampSheetResult:
+        self.transaction = transaction
+        return self
+
+    def with_random_status(self, random_status: RandomStatus) -> InvokeByStampSheetResult:
+        self.random_status = random_status
+        return self
+
+    def with_atomic_commit(self, atomic_commit: bool) -> InvokeByStampSheetResult:
+        self.atomic_commit = atomic_commit
+        return self
+
+    def with_transaction_result(self, transaction_result: TransactionResult) -> InvokeByStampSheetResult:
+        self.transaction_result = transaction_result
+        return self
+
+    def with_execute_time(self, execute_time: int) -> InvokeByStampSheetResult:
+        self.execute_time = execute_time
+        return self
+
+    def with_charged(self, charged: int) -> InvokeByStampSheetResult:
+        self.charged = charged
+        return self
+
+    def with_output(self, output: List[str]) -> InvokeByStampSheetResult:
+        self.output = output
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[InvokeByStampSheetResult]:
+        if data is None:
+            return None
+        return InvokeByStampSheetResult()\
+            .with_code(data.get('code'))\
+            .with_result(data.get('result'))\
+            .with_transaction(Transaction.from_dict(data.get('transaction')))\
+            .with_random_status(RandomStatus.from_dict(data.get('randomStatus')))\
+            .with_atomic_commit(data.get('atomicCommit'))\
+            .with_transaction_result(TransactionResult.from_dict(data.get('transactionResult')))\
+            .with_execute_time(data.get('executeTime'))\
+            .with_charged(data.get('charged'))\
+            .with_output(None if data.get('output') is None else [
+                data.get('output')[i]
+                for i in range(len(data.get('output')))
+            ])
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "code": self.code,
+            "result": self.result,
+            "transaction": self.transaction.to_dict() if self.transaction else None,
+            "randomStatus": self.random_status.to_dict() if self.random_status else None,
+            "atomicCommit": self.atomic_commit,
+            "transactionResult": self.transaction_result.to_dict() if self.transaction_result else None,
+            "executeTime": self.execute_time,
+            "charged": self.charged,
+            "output": None if self.output is None else [
+                self.output[i]
+                for i in range(len(self.output))
             ],
         }
\ No newline at end of file
