@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -115,6 +116,8 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["name"] = request.name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -332,6 +335,8 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["namespaceName"] = request.namespace_name
         if request.description is not None:
             body["description"] = request.description
+        if request.transaction_setting is not None:
+            body["transactionSetting"] = request.transaction_setting.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -457,6 +462,75 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="script",
+            component='namespace',
+            function='getServiceVersion',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=GetServiceVersionResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_scripts(
         self,
         request: DescribeScriptsRequest,
@@ -557,6 +631,8 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["description"] = request.description
         if request.script is not None:
             body["script"] = request.script
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -634,6 +710,8 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["description"] = request.description
         if request.checkout_setting is not None:
             body["checkoutSetting"] = request.checkout_setting.to_dict()
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -784,6 +862,8 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["description"] = request.description
         if request.script is not None:
             body["script"] = request.script
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -861,6 +941,8 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["description"] = request.description
         if request.checkout_setting is not None:
             body["checkoutSetting"] = request.checkout_setting.to_dict()
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1009,9 +1091,15 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.args is not None:
             body["args"] = request.args
+        if request.random_status is not None:
+            body["randomStatus"] = request.random_status.to_dict()
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
@@ -1082,9 +1170,19 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["script"] = request.script
         if request.args is not None:
             body["args"] = request.args
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.random_status is not None:
+            body["randomStatus"] = request.random_status.to_dict()
+        if request.disable_string_number_to_number is not None:
+            body["disableStringNumberToNumber"] = request.disable_string_number_to_number
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
 
         self.session.send(
             web_socket.NetworkJob(
@@ -1125,6 +1223,79 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             lambda result: async_result.append(result),
         )
 
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _invoke_by_stamp_sheet(
+        self,
+        request: InvokeByStampSheetRequest,
+        callback: Callable[[AsyncResult[InvokeByStampSheetResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="script",
+            component='script',
+            function='invokeByStampSheet',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.stamp_sheet is not None:
+            body["stampSheet"] = request.stamp_sheet
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=InvokeByStampSheetResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def invoke_by_stamp_sheet(
+        self,
+        request: InvokeByStampSheetRequest,
+    ) -> InvokeByStampSheetResult:
+        async_result = []
+        with timeout(30):
+            self._invoke_by_stamp_sheet(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def invoke_by_stamp_sheet_async(
+        self,
+        request: InvokeByStampSheetRequest,
+    ) -> InvokeByStampSheetResult:
+        async_result = []
+        self._invoke_by_stamp_sheet(
+            request,
+            lambda result: async_result.append(result),
+        )
+
         import asyncio
         with timeout(30):
             while not async_result:
