@@ -14,6 +14,7 @@
 
 from __future__ import annotations
 
+from ..core.model import *
 from .model import *
 
 
@@ -48,17 +49,17 @@ class DescribeNamespacesResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeNamespacesResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 Namespace.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -234,6 +235,257 @@ class DeleteNamespaceResult(core.Gs2Result):
         }
 
 
+class GetServiceVersionResult(core.Gs2Result):
+    item: str = None
+
+    def with_item(self, item: str) -> GetServiceVersionResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionResult]:
+        if data is None:
+            return None
+        return GetServiceVersionResult()\
+            .with_item(data.get('item'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item,
+        }
+
+
+class DumpUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckDumpUserDataByUserIdResult(core.Gs2Result):
+    url: str = None
+
+    def with_url(self, url: str) -> CheckDumpUserDataByUserIdResult:
+        self.url = url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdResult()\
+            .with_url(data.get('url'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "url": self.url,
+        }
+
+
+class CleanUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckCleanUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class PrepareImportUserDataByUserIdResult(core.Gs2Result):
+    upload_token: str = None
+    upload_url: str = None
+
+    def with_upload_token(self, upload_token: str) -> PrepareImportUserDataByUserIdResult:
+        self.upload_token = upload_token
+        return self
+
+    def with_upload_url(self, upload_url: str) -> PrepareImportUserDataByUserIdResult:
+        self.upload_url = upload_url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdResult()\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_upload_url(data.get('uploadUrl'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "uploadToken": self.upload_token,
+            "uploadUrl": self.upload_url,
+        }
+
+
+class ImportUserDataByUserIdResult(core.Gs2Result):
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdResult()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class CheckImportUserDataByUserIdResult(core.Gs2Result):
+    url: str = None
+
+    def with_url(self, url: str) -> CheckImportUserDataByUserIdResult:
+        self.url = url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdResult]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdResult()\
+            .with_url(data.get('url'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "url": self.url,
+        }
+
+
 class DescribeIssueJobsResult(core.Gs2Result):
     items: List[IssueJob] = None
     next_page_token: str = None
@@ -265,17 +517,17 @@ class DescribeIssueJobsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeIssueJobsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 IssueJob.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -380,17 +632,17 @@ class DescribeSerialKeysResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeSerialKeysResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 SerialKey.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -430,6 +682,40 @@ class DownloadSerialCodesResult(core.Gs2Result):
         }
 
 
+class IssueOnceResult(core.Gs2Result):
+    item: SerialKey = None
+
+    def with_item(self, item: SerialKey) -> IssueOnceResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[IssueOnceResult]:
+        if data is None:
+            return None
+        return IssueOnceResult()\
+            .with_item(SerialKey.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
 class GetSerialKeyResult(core.Gs2Result):
     item: SerialKey = None
     campaign_model: CampaignModel = None
@@ -471,6 +757,88 @@ class GetSerialKeyResult(core.Gs2Result):
         }
 
 
+class VerifyCodeResult(core.Gs2Result):
+    item: SerialKey = None
+    campaign_model: CampaignModel = None
+
+    def with_item(self, item: SerialKey) -> VerifyCodeResult:
+        self.item = item
+        return self
+
+    def with_campaign_model(self, campaign_model: CampaignModel) -> VerifyCodeResult:
+        self.campaign_model = campaign_model
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyCodeResult]:
+        if data is None:
+            return None
+        return VerifyCodeResult()\
+            .with_item(SerialKey.from_dict(data.get('item')))\
+            .with_campaign_model(CampaignModel.from_dict(data.get('campaignModel')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+            "campaignModel": self.campaign_model.to_dict() if self.campaign_model else None,
+        }
+
+
+class VerifyCodeByUserIdResult(core.Gs2Result):
+    item: SerialKey = None
+    campaign_model: CampaignModel = None
+
+    def with_item(self, item: SerialKey) -> VerifyCodeByUserIdResult:
+        self.item = item
+        return self
+
+    def with_campaign_model(self, campaign_model: CampaignModel) -> VerifyCodeByUserIdResult:
+        self.campaign_model = campaign_model
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyCodeByUserIdResult]:
+        if data is None:
+            return None
+        return VerifyCodeByUserIdResult()\
+            .with_item(SerialKey.from_dict(data.get('item')))\
+            .with_campaign_model(CampaignModel.from_dict(data.get('campaignModel')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+            "campaignModel": self.campaign_model.to_dict() if self.campaign_model else None,
+        }
+
+
 class UseResult(core.Gs2Result):
     item: SerialKey = None
     campaign_model: CampaignModel = None
@@ -553,6 +921,47 @@ class UseByUserIdResult(core.Gs2Result):
         }
 
 
+class RevertUseByUserIdResult(core.Gs2Result):
+    item: SerialKey = None
+    campaign_model: CampaignModel = None
+
+    def with_item(self, item: SerialKey) -> RevertUseByUserIdResult:
+        self.item = item
+        return self
+
+    def with_campaign_model(self, campaign_model: CampaignModel) -> RevertUseByUserIdResult:
+        self.campaign_model = campaign_model
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RevertUseByUserIdResult]:
+        if data is None:
+            return None
+        return RevertUseByUserIdResult()\
+            .with_item(SerialKey.from_dict(data.get('item')))\
+            .with_campaign_model(CampaignModel.from_dict(data.get('campaignModel')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+            "campaignModel": self.campaign_model.to_dict() if self.campaign_model else None,
+        }
+
+
 class UseByStampTaskResult(core.Gs2Result):
     item: SerialKey = None
     campaign_model: CampaignModel = None
@@ -601,6 +1010,129 @@ class UseByStampTaskResult(core.Gs2Result):
         }
 
 
+class RevertUseByStampSheetResult(core.Gs2Result):
+    item: SerialKey = None
+    campaign_model: CampaignModel = None
+
+    def with_item(self, item: SerialKey) -> RevertUseByStampSheetResult:
+        self.item = item
+        return self
+
+    def with_campaign_model(self, campaign_model: CampaignModel) -> RevertUseByStampSheetResult:
+        self.campaign_model = campaign_model
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RevertUseByStampSheetResult]:
+        if data is None:
+            return None
+        return RevertUseByStampSheetResult()\
+            .with_item(SerialKey.from_dict(data.get('item')))\
+            .with_campaign_model(CampaignModel.from_dict(data.get('campaignModel')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+            "campaignModel": self.campaign_model.to_dict() if self.campaign_model else None,
+        }
+
+
+class VerifyByStampTaskResult(core.Gs2Result):
+    item: SerialKey = None
+    campaign_model: CampaignModel = None
+    new_context_stack: str = None
+
+    def with_item(self, item: SerialKey) -> VerifyByStampTaskResult:
+        self.item = item
+        return self
+
+    def with_campaign_model(self, campaign_model: CampaignModel) -> VerifyByStampTaskResult:
+        self.campaign_model = campaign_model
+        return self
+
+    def with_new_context_stack(self, new_context_stack: str) -> VerifyByStampTaskResult:
+        self.new_context_stack = new_context_stack
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[VerifyByStampTaskResult]:
+        if data is None:
+            return None
+        return VerifyByStampTaskResult()\
+            .with_item(SerialKey.from_dict(data.get('item')))\
+            .with_campaign_model(CampaignModel.from_dict(data.get('campaignModel')))\
+            .with_new_context_stack(data.get('newContextStack'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+            "campaignModel": self.campaign_model.to_dict() if self.campaign_model else None,
+            "newContextStack": self.new_context_stack,
+        }
+
+
+class IssueOnceByStampSheetResult(core.Gs2Result):
+    item: SerialKey = None
+
+    def with_item(self, item: SerialKey) -> IssueOnceByStampSheetResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[IssueOnceByStampSheetResult]:
+        if data is None:
+            return None
+        return IssueOnceByStampSheetResult()\
+            .with_item(SerialKey.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
 class DescribeCampaignModelsResult(core.Gs2Result):
     items: List[CampaignModel] = None
 
@@ -627,16 +1159,16 @@ class DescribeCampaignModelsResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeCampaignModelsResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 CampaignModel.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
         }
 
@@ -706,17 +1238,17 @@ class DescribeCampaignModelMastersResult(core.Gs2Result):
         if data is None:
             return None
         return DescribeCampaignModelMastersResult()\
-            .with_items([
+            .with_items(None if data.get('items') is None else [
                 CampaignModelMaster.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
+                for i in range(len(data.get('items')))
             ])\
             .with_next_page_token(data.get('nextPageToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "items": [
+            "items": None if self.items is None else [
                 self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
+                for i in range(len(self.items))
             ],
             "nextPageToken": self.next_page_token,
         }
@@ -926,6 +1458,47 @@ class GetCurrentCampaignMasterResult(core.Gs2Result):
         }
 
 
+class PreUpdateCurrentCampaignMasterResult(core.Gs2Result):
+    upload_token: str = None
+    upload_url: str = None
+
+    def with_upload_token(self, upload_token: str) -> PreUpdateCurrentCampaignMasterResult:
+        self.upload_token = upload_token
+        return self
+
+    def with_upload_url(self, upload_url: str) -> PreUpdateCurrentCampaignMasterResult:
+        self.upload_url = upload_url
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PreUpdateCurrentCampaignMasterResult]:
+        if data is None:
+            return None
+        return PreUpdateCurrentCampaignMasterResult()\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_upload_url(data.get('uploadUrl'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "uploadToken": self.upload_token,
+            "uploadUrl": self.upload_url,
+        }
+
+
 class UpdateCurrentCampaignMasterResult(core.Gs2Result):
     item: CurrentCampaignMaster = None
 
