@@ -17,6 +17,7 @@
 from gs2.core import *
 from .request import *
 from .result import *
+import time
 
 
 class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
@@ -457,6 +458,590 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+        callback: Callable[[AsyncResult[GetServiceVersionResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='getServiceVersion',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=GetServiceVersionResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def get_service_version(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        with timeout(30):
+            self._get_service_version(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_service_version_async(
+        self,
+        request: GetServiceVersionRequest,
+    ) -> GetServiceVersionResult:
+        async_result = []
+        self._get_service_version(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _dump_user_data_by_user_id(
+        self,
+        request: DumpUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[DumpUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='dumpUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=DumpUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def dump_user_data_by_user_id(
+        self,
+        request: DumpUserDataByUserIdRequest,
+    ) -> DumpUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._dump_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def dump_user_data_by_user_id_async(
+        self,
+        request: DumpUserDataByUserIdRequest,
+    ) -> DumpUserDataByUserIdResult:
+        async_result = []
+        self._dump_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_dump_user_data_by_user_id(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckDumpUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='checkDumpUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckDumpUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_dump_user_data_by_user_id(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+    ) -> CheckDumpUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_dump_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_dump_user_data_by_user_id_async(
+        self,
+        request: CheckDumpUserDataByUserIdRequest,
+    ) -> CheckDumpUserDataByUserIdResult:
+        async_result = []
+        self._check_dump_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _clean_user_data_by_user_id(
+        self,
+        request: CleanUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CleanUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='cleanUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CleanUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def clean_user_data_by_user_id(
+        self,
+        request: CleanUserDataByUserIdRequest,
+    ) -> CleanUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._clean_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def clean_user_data_by_user_id_async(
+        self,
+        request: CleanUserDataByUserIdRequest,
+    ) -> CleanUserDataByUserIdResult:
+        async_result = []
+        self._clean_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_clean_user_data_by_user_id(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckCleanUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='checkCleanUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckCleanUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_clean_user_data_by_user_id(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+    ) -> CheckCleanUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_clean_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_clean_user_data_by_user_id_async(
+        self,
+        request: CheckCleanUserDataByUserIdRequest,
+    ) -> CheckCleanUserDataByUserIdResult:
+        async_result = []
+        self._check_clean_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _prepare_import_user_data_by_user_id(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[PrepareImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='prepareImportUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=PrepareImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def prepare_import_user_data_by_user_id(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+    ) -> PrepareImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._prepare_import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def prepare_import_user_data_by_user_id_async(
+        self,
+        request: PrepareImportUserDataByUserIdRequest,
+    ) -> PrepareImportUserDataByUserIdResult:
+        async_result = []
+        self._prepare_import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _import_user_data_by_user_id(
+        self,
+        request: ImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[ImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='importUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=ImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def import_user_data_by_user_id(
+        self,
+        request: ImportUserDataByUserIdRequest,
+    ) -> ImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def import_user_data_by_user_id_async(
+        self,
+        request: ImportUserDataByUserIdRequest,
+    ) -> ImportUserDataByUserIdResult:
+        async_result = []
+        self._import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _check_import_user_data_by_user_id(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+        callback: Callable[[AsyncResult[CheckImportUserDataByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='namespace',
+            function='checkImportUserDataByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=CheckImportUserDataByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def check_import_user_data_by_user_id(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+    ) -> CheckImportUserDataByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._check_import_user_data_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def check_import_user_data_by_user_id_async(
+        self,
+        request: CheckImportUserDataByUserIdRequest,
+    ) -> CheckImportUserDataByUserIdResult:
+        async_result = []
+        self._check_import_user_data_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_issue_jobs(
         self,
         request: DescribeIssueJobsRequest,
@@ -840,6 +1425,81 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _issue_once(
+        self,
+        request: IssueOnceRequest,
+        callback: Callable[[AsyncResult[IssueOnceResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='serialKey',
+            function='issueOnce',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.campaign_model_name is not None:
+            body["campaignModelName"] = request.campaign_model_name
+        if request.metadata is not None:
+            body["metadata"] = request.metadata
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=IssueOnceResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def issue_once(
+        self,
+        request: IssueOnceRequest,
+    ) -> IssueOnceResult:
+        async_result = []
+        with timeout(30):
+            self._issue_once(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def issue_once_async(
+        self,
+        request: IssueOnceRequest,
+    ) -> IssueOnceResult:
+        async_result = []
+        self._issue_once(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _get_serial_key(
         self,
         request: GetSerialKeyRequest,
@@ -913,6 +1573,172 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _verify_code(
+        self,
+        request: VerifyCodeRequest,
+        callback: Callable[[AsyncResult[VerifyCodeResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='serialKey',
+            function='verifyCode',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.access_token is not None:
+            body["accessToken"] = request.access_token
+        if request.code is not None:
+            body["code"] = request.code
+        if request.campaign_model_name is not None:
+            body["campaignModelName"] = request.campaign_model_name
+        if request.verify_type is not None:
+            body["verifyType"] = request.verify_type
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.access_token:
+            body["xGs2AccessToken"] = request.access_token
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=VerifyCodeResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def verify_code(
+        self,
+        request: VerifyCodeRequest,
+    ) -> VerifyCodeResult:
+        async_result = []
+        with timeout(30):
+            self._verify_code(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def verify_code_async(
+        self,
+        request: VerifyCodeRequest,
+    ) -> VerifyCodeResult:
+        async_result = []
+        self._verify_code(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _verify_code_by_user_id(
+        self,
+        request: VerifyCodeByUserIdRequest,
+        callback: Callable[[AsyncResult[VerifyCodeByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='serialKey',
+            function='verifyCodeByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.code is not None:
+            body["code"] = request.code
+        if request.campaign_model_name is not None:
+            body["campaignModelName"] = request.campaign_model_name
+        if request.verify_type is not None:
+            body["verifyType"] = request.verify_type
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=VerifyCodeByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def verify_code_by_user_id(
+        self,
+        request: VerifyCodeByUserIdRequest,
+    ) -> VerifyCodeByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._verify_code_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def verify_code_by_user_id_async(
+        self,
+        request: VerifyCodeByUserIdRequest,
+    ) -> VerifyCodeByUserIdResult:
+        async_result = []
+        self._verify_code_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _use(
         self,
         request: UseRequest,
@@ -1015,6 +1841,8 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["userId"] = request.user_id
         if request.code is not None:
             body["code"] = request.code
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
@@ -1069,6 +1897,85 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _revert_use_by_user_id(
+        self,
+        request: RevertUseByUserIdRequest,
+        callback: Callable[[AsyncResult[RevertUseByUserIdResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='serialKey',
+            function='revertUseByUserId',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+        if request.user_id is not None:
+            body["userId"] = request.user_id
+        if request.code is not None:
+            body["code"] = request.code
+        if request.time_offset_token is not None:
+            body["timeOffsetToken"] = request.time_offset_token
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+        if request.duplication_avoider:
+            body["xGs2DuplicationAvoider"] = request.duplication_avoider
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=RevertUseByUserIdResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def revert_use_by_user_id(
+        self,
+        request: RevertUseByUserIdRequest,
+    ) -> RevertUseByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._revert_use_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def revert_use_by_user_id_async(
+        self,
+        request: RevertUseByUserIdRequest,
+    ) -> RevertUseByUserIdResult:
+        async_result = []
+        self._revert_use_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _use_by_stamp_task(
         self,
         request: UseByStampTaskRequest,
@@ -1142,6 +2049,225 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _revert_use_by_stamp_sheet(
+        self,
+        request: RevertUseByStampSheetRequest,
+        callback: Callable[[AsyncResult[RevertUseByStampSheetResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='serialKey',
+            function='revertUseByStampSheet',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.stamp_sheet is not None:
+            body["stampSheet"] = request.stamp_sheet
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=RevertUseByStampSheetResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def revert_use_by_stamp_sheet(
+        self,
+        request: RevertUseByStampSheetRequest,
+    ) -> RevertUseByStampSheetResult:
+        async_result = []
+        with timeout(30):
+            self._revert_use_by_stamp_sheet(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def revert_use_by_stamp_sheet_async(
+        self,
+        request: RevertUseByStampSheetRequest,
+    ) -> RevertUseByStampSheetResult:
+        async_result = []
+        self._revert_use_by_stamp_sheet(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _verify_by_stamp_task(
+        self,
+        request: VerifyByStampTaskRequest,
+        callback: Callable[[AsyncResult[VerifyByStampTaskResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='serialKey',
+            function='verifyByStampTask',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.stamp_task is not None:
+            body["stampTask"] = request.stamp_task
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=VerifyByStampTaskResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def verify_by_stamp_task(
+        self,
+        request: VerifyByStampTaskRequest,
+    ) -> VerifyByStampTaskResult:
+        async_result = []
+        with timeout(30):
+            self._verify_by_stamp_task(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def verify_by_stamp_task_async(
+        self,
+        request: VerifyByStampTaskRequest,
+    ) -> VerifyByStampTaskResult:
+        async_result = []
+        self._verify_by_stamp_task(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _issue_once_by_stamp_sheet(
+        self,
+        request: IssueOnceByStampSheetRequest,
+        callback: Callable[[AsyncResult[IssueOnceByStampSheetResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='serialKey',
+            function='issueOnceByStampSheet',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.stamp_sheet is not None:
+            body["stampSheet"] = request.stamp_sheet
+        if request.key_id is not None:
+            body["keyId"] = request.key_id
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=IssueOnceByStampSheetResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def issue_once_by_stamp_sheet(
+        self,
+        request: IssueOnceByStampSheetRequest,
+    ) -> IssueOnceByStampSheetResult:
+        async_result = []
+        with timeout(30):
+            self._issue_once_by_stamp_sheet(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def issue_once_by_stamp_sheet_async(
+        self,
+        request: IssueOnceByStampSheetRequest,
+    ) -> IssueOnceByStampSheetResult:
+        async_result = []
+        self._issue_once_by_stamp_sheet(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _describe_campaign_models(
         self,
         request: DescribeCampaignModelsRequest,
@@ -1807,6 +2933,77 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _pre_update_current_campaign_master(
+        self,
+        request: PreUpdateCurrentCampaignMasterRequest,
+        callback: Callable[[AsyncResult[PreUpdateCurrentCampaignMasterResult]], None],
+    ):
+        import uuid
+
+        request_id = str(uuid.uuid4())
+        body = self._create_metadata(
+            service="serialKey",
+            component='currentCampaignMaster',
+            function='preUpdateCurrentCampaignMaster',
+            request_id=request_id,
+        )
+
+        if request.context_stack:
+            body['contextStack'] = str(request.context_stack)
+        if request.namespace_name is not None:
+            body["namespaceName"] = request.namespace_name
+
+        if request.request_id:
+            body["xGs2RequestId"] = request.request_id
+
+        self.session.send(
+            web_socket.NetworkJob(
+                request_id=request_id,
+                result_type=PreUpdateCurrentCampaignMasterResult,
+                callback=callback,
+                body=body,
+            )
+        )
+
+    def pre_update_current_campaign_master(
+        self,
+        request: PreUpdateCurrentCampaignMasterRequest,
+    ) -> PreUpdateCurrentCampaignMasterResult:
+        async_result = []
+        with timeout(30):
+            self._pre_update_current_campaign_master(
+                request,
+                lambda result: async_result.append(result),
+            )
+
+        with timeout(30):
+            while not async_result:
+                time.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def pre_update_current_campaign_master_async(
+        self,
+        request: PreUpdateCurrentCampaignMasterRequest,
+    ) -> PreUpdateCurrentCampaignMasterResult:
+        async_result = []
+        self._pre_update_current_campaign_master(
+            request,
+            lambda result: async_result.append(result),
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _update_current_campaign_master(
         self,
         request: UpdateCurrentCampaignMasterRequest,
@@ -1826,8 +3023,12 @@ class Gs2SerialKeyWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body['contextStack'] = str(request.context_stack)
         if request.namespace_name is not None:
             body["namespaceName"] = request.namespace_name
+        if request.mode is not None:
+            body["mode"] = request.mode
         if request.settings is not None:
             body["settings"] = request.settings
+        if request.upload_token is not None:
+            body["uploadToken"] = request.upload_token
 
         if request.request_id:
             body["xGs2RequestId"] = request.request_id
