@@ -197,6 +197,7 @@ class Stamina(core.Gs2Model):
     last_recovered_at: int = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_stamina_id(self, stamina_id: str) -> Stamina:
         self.stamina_id = stamina_id
@@ -246,6 +247,10 @@ class Stamina(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Stamina:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -343,7 +348,8 @@ class Stamina(core.Gs2Model):
             .with_next_recover_at(data.get('nextRecoverAt'))\
             .with_last_recovered_at(data.get('lastRecoveredAt'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -359,20 +365,16 @@ class Stamina(core.Gs2Model):
             "lastRecoveredAt": self.last_recovered_at,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
 class RecoverValueTable(core.Gs2Model):
-    recover_value_table_id: str = None
     name: str = None
     metadata: str = None
     experience_model_id: str = None
     values: List[int] = None
 
-    def with_recover_value_table_id(self, recover_value_table_id: str) -> RecoverValueTable:
-        self.recover_value_table_id = recover_value_table_id
-        return self
-
     def with_name(self, name: str) -> RecoverValueTable:
         self.name = name
         return self
@@ -389,61 +391,6 @@ class RecoverValueTable(core.Gs2Model):
         self.values = values
         return self
 
-    @classmethod
-    def create_grn(
-        cls,
-        region,
-        owner_id,
-        namespace_name,
-        recover_value_table_name,
-    ):
-        return 'grn:gs2:{region}:{ownerId}:stamina:{namespaceName}:recoverValueTable:{recoverValueTableName}'.format(
-            region=region,
-            ownerId=owner_id,
-            namespaceName=namespace_name,
-            recoverValueTableName=recover_value_table_name,
-        )
-
-    @classmethod
-    def get_region_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverValueTable:(?P<recoverValueTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('region')
-
-    @classmethod
-    def get_owner_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverValueTable:(?P<recoverValueTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('owner_id')
-
-    @classmethod
-    def get_namespace_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverValueTable:(?P<recoverValueTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('namespace_name')
-
-    @classmethod
-    def get_recover_value_table_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverValueTable:(?P<recoverValueTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('recover_value_table_name')
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -463,39 +410,32 @@ class RecoverValueTable(core.Gs2Model):
         if data is None:
             return None
         return RecoverValueTable()\
-            .with_recover_value_table_id(data.get('recoverValueTableId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "recoverValueTableId": self.recover_value_table_id,
             "name": self.name,
             "metadata": self.metadata,
             "experienceModelId": self.experience_model_id,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
         }
 
 
 class RecoverIntervalTable(core.Gs2Model):
-    recover_interval_table_id: str = None
     name: str = None
     metadata: str = None
     experience_model_id: str = None
     values: List[int] = None
 
-    def with_recover_interval_table_id(self, recover_interval_table_id: str) -> RecoverIntervalTable:
-        self.recover_interval_table_id = recover_interval_table_id
-        return self
-
     def with_name(self, name: str) -> RecoverIntervalTable:
         self.name = name
         return self
@@ -512,61 +452,6 @@ class RecoverIntervalTable(core.Gs2Model):
         self.values = values
         return self
 
-    @classmethod
-    def create_grn(
-        cls,
-        region,
-        owner_id,
-        namespace_name,
-        recover_interval_table_name,
-    ):
-        return 'grn:gs2:{region}:{ownerId}:stamina:{namespaceName}:recoverIntervalTable:{recoverIntervalTableName}'.format(
-            region=region,
-            ownerId=owner_id,
-            namespaceName=namespace_name,
-            recoverIntervalTableName=recover_interval_table_name,
-        )
-
-    @classmethod
-    def get_region_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverIntervalTable:(?P<recoverIntervalTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('region')
-
-    @classmethod
-    def get_owner_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverIntervalTable:(?P<recoverIntervalTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('owner_id')
-
-    @classmethod
-    def get_namespace_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverIntervalTable:(?P<recoverIntervalTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('namespace_name')
-
-    @classmethod
-    def get_recover_interval_table_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):recoverIntervalTable:(?P<recoverIntervalTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('recover_interval_table_name')
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -586,39 +471,32 @@ class RecoverIntervalTable(core.Gs2Model):
         if data is None:
             return None
         return RecoverIntervalTable()\
-            .with_recover_interval_table_id(data.get('recoverIntervalTableId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "recoverIntervalTableId": self.recover_interval_table_id,
             "name": self.name,
             "metadata": self.metadata,
             "experienceModelId": self.experience_model_id,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
         }
 
 
 class MaxStaminaTable(core.Gs2Model):
-    max_stamina_table_id: str = None
     name: str = None
     metadata: str = None
     experience_model_id: str = None
     values: List[int] = None
 
-    def with_max_stamina_table_id(self, max_stamina_table_id: str) -> MaxStaminaTable:
-        self.max_stamina_table_id = max_stamina_table_id
-        return self
-
     def with_name(self, name: str) -> MaxStaminaTable:
         self.name = name
         return self
@@ -635,61 +513,6 @@ class MaxStaminaTable(core.Gs2Model):
         self.values = values
         return self
 
-    @classmethod
-    def create_grn(
-        cls,
-        region,
-        owner_id,
-        namespace_name,
-        max_stamina_table_name,
-    ):
-        return 'grn:gs2:{region}:{ownerId}:stamina:{namespaceName}:maxStaminaTable:{maxStaminaTableName}'.format(
-            region=region,
-            ownerId=owner_id,
-            namespaceName=namespace_name,
-            maxStaminaTableName=max_stamina_table_name,
-        )
-
-    @classmethod
-    def get_region_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):maxStaminaTable:(?P<maxStaminaTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('region')
-
-    @classmethod
-    def get_owner_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):maxStaminaTable:(?P<maxStaminaTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('owner_id')
-
-    @classmethod
-    def get_namespace_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):maxStaminaTable:(?P<maxStaminaTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('namespace_name')
-
-    @classmethod
-    def get_max_stamina_table_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):stamina:(?P<namespaceName>.+):maxStaminaTable:(?P<maxStaminaTableName>.+)', grn)
-        if match is None:
-            return None
-        return match.group('max_stamina_table_name')
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -709,24 +532,22 @@ class MaxStaminaTable(core.Gs2Model):
         if data is None:
             return None
         return MaxStaminaTable()\
-            .with_max_stamina_table_id(data.get('maxStaminaTableId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
-            "maxStaminaTableId": self.max_stamina_table_id,
             "name": self.name,
             "metadata": self.metadata,
             "experienceModelId": self.experience_model_id,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
         }
 
@@ -983,6 +804,7 @@ class RecoverValueTableMaster(core.Gs2Model):
     values: List[int] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_recover_value_table_id(self, recover_value_table_id: str) -> RecoverValueTableMaster:
         self.recover_value_table_id = recover_value_table_id
@@ -1016,6 +838,10 @@ class RecoverValueTableMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> RecoverValueTableMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1095,12 +921,13 @@ class RecoverValueTableMaster(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_description(data.get('description'))\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1109,12 +936,13 @@ class RecoverValueTableMaster(core.Gs2Model):
             "metadata": self.metadata,
             "description": self.description,
             "experienceModelId": self.experience_model_id,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1127,6 +955,7 @@ class RecoverIntervalTableMaster(core.Gs2Model):
     values: List[int] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_recover_interval_table_id(self, recover_interval_table_id: str) -> RecoverIntervalTableMaster:
         self.recover_interval_table_id = recover_interval_table_id
@@ -1160,6 +989,10 @@ class RecoverIntervalTableMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> RecoverIntervalTableMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1239,12 +1072,13 @@ class RecoverIntervalTableMaster(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_description(data.get('description'))\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1253,12 +1087,13 @@ class RecoverIntervalTableMaster(core.Gs2Model):
             "metadata": self.metadata,
             "description": self.description,
             "experienceModelId": self.experience_model_id,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1271,6 +1106,7 @@ class MaxStaminaTableMaster(core.Gs2Model):
     values: List[int] = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_max_stamina_table_id(self, max_stamina_table_id: str) -> MaxStaminaTableMaster:
         self.max_stamina_table_id = max_stamina_table_id
@@ -1304,6 +1140,10 @@ class MaxStaminaTableMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> MaxStaminaTableMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1383,12 +1223,13 @@ class MaxStaminaTableMaster(core.Gs2Model):
             .with_metadata(data.get('metadata'))\
             .with_description(data.get('description'))\
             .with_experience_model_id(data.get('experienceModelId'))\
-            .with_values([
+            .with_values(None if data.get('values') is None else [
                 data.get('values')[i]
-                for i in range(len(data.get('values')) if data.get('values') else 0)
+                for i in range(len(data.get('values')))
             ])\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1397,12 +1238,13 @@ class MaxStaminaTableMaster(core.Gs2Model):
             "metadata": self.metadata,
             "description": self.description,
             "experienceModelId": self.experience_model_id,
-            "values": [
+            "values": None if self.values is None else [
                 self.values[i]
-                for i in range(len(self.values) if self.values else 0)
+                for i in range(len(self.values))
             ],
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1421,6 +1263,7 @@ class StaminaModelMaster(core.Gs2Model):
     recover_value_table_name: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_stamina_model_id(self, stamina_model_id: str) -> StaminaModelMaster:
         self.stamina_model_id = stamina_model_id
@@ -1478,6 +1321,10 @@ class StaminaModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> StaminaModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1565,7 +1412,8 @@ class StaminaModelMaster(core.Gs2Model):
             .with_recover_interval_table_name(data.get('recoverIntervalTableName'))\
             .with_recover_value_table_name(data.get('recoverValueTableName'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1583,6 +1431,7 @@ class StaminaModelMaster(core.Gs2Model):
             "recoverValueTableName": self.recover_value_table_name,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -1590,10 +1439,11 @@ class Namespace(core.Gs2Model):
     namespace_id: str = None
     name: str = None
     description: str = None
-    overflow_trigger_script: ScriptSetting = None
+    overflow_trigger_script: str = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -1607,7 +1457,7 @@ class Namespace(core.Gs2Model):
         self.description = description
         return self
 
-    def with_overflow_trigger_script(self, overflow_trigger_script: ScriptSetting) -> Namespace:
+    def with_overflow_trigger_script(self, overflow_trigger_script: str) -> Namespace:
         self.overflow_trigger_script = overflow_trigger_script
         return self
 
@@ -1623,6 +1473,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1688,18 +1542,20 @@ class Namespace(core.Gs2Model):
             .with_namespace_id(data.get('namespaceId'))\
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
-            .with_overflow_trigger_script(ScriptSetting.from_dict(data.get('overflowTriggerScript')))\
+            .with_overflow_trigger_script(data.get('overflowTriggerScript'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceId": self.namespace_id,
             "name": self.name,
             "description": self.description,
-            "overflowTriggerScript": self.overflow_trigger_script.to_dict() if self.overflow_trigger_script else None,
+            "overflowTriggerScript": self.overflow_trigger_script,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
