@@ -19,6 +19,109 @@ from typing import *
 from gs2 import core
 
 
+class ScheduleVersion(core.Gs2Model):
+    current_version: Version = None
+    warning_version: Version = None
+    error_version: Version = None
+    schedule_event_id: str = None
+
+    def with_current_version(self, current_version: Version) -> ScheduleVersion:
+        self.current_version = current_version
+        return self
+
+    def with_warning_version(self, warning_version: Version) -> ScheduleVersion:
+        self.warning_version = warning_version
+        return self
+
+    def with_error_version(self, error_version: Version) -> ScheduleVersion:
+        self.error_version = error_version
+        return self
+
+    def with_schedule_event_id(self, schedule_event_id: str) -> ScheduleVersion:
+        self.schedule_event_id = schedule_event_id
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ScheduleVersion]:
+        if data is None:
+            return None
+        return ScheduleVersion()\
+            .with_current_version(Version.from_dict(data.get('currentVersion')))\
+            .with_warning_version(Version.from_dict(data.get('warningVersion')))\
+            .with_error_version(Version.from_dict(data.get('errorVersion')))\
+            .with_schedule_event_id(data.get('scheduleEventId'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "currentVersion": self.current_version.to_dict() if self.current_version else None,
+            "warningVersion": self.warning_version.to_dict() if self.warning_version else None,
+            "errorVersion": self.error_version.to_dict() if self.error_version else None,
+            "scheduleEventId": self.schedule_event_id,
+        }
+
+
+class Version(core.Gs2Model):
+    major: int = None
+    minor: int = None
+    micro: int = None
+
+    def with_major(self, major: int) -> Version:
+        self.major = major
+        return self
+
+    def with_minor(self, minor: int) -> Version:
+        self.minor = minor
+        return self
+
+    def with_micro(self, micro: int) -> Version:
+        self.micro = micro
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[Version]:
+        if data is None:
+            return None
+        return Version()\
+            .with_major(data.get('major'))\
+            .with_minor(data.get('minor'))\
+            .with_micro(data.get('micro'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "major": self.major,
+            "minor": self.minor,
+            "micro": self.micro,
+        }
+
+
 class LogSetting(core.Gs2Model):
     logging_namespace_id: str = None
 
@@ -325,18 +428,14 @@ class SignTargetVersion(core.Gs2Model):
 
 class TargetVersion(core.Gs2Model):
     version_name: str = None
-    version: Version = None
     body: str = None
     signature: str = None
+    version: Version = None
 
     def with_version_name(self, version_name: str) -> TargetVersion:
         self.version_name = version_name
         return self
 
-    def with_version(self, version: Version) -> TargetVersion:
-        self.version = version
-        return self
-
     def with_body(self, body: str) -> TargetVersion:
         self.body = body
         return self
@@ -345,6 +444,10 @@ class TargetVersion(core.Gs2Model):
         self.signature = signature
         return self
 
+    def with_version(self, version: Version) -> TargetVersion:
+        self.version = version
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -365,16 +468,16 @@ class TargetVersion(core.Gs2Model):
             return None
         return TargetVersion()\
             .with_version_name(data.get('versionName'))\
-            .with_version(Version.from_dict(data.get('version')))\
             .with_body(data.get('body'))\
-            .with_signature(data.get('signature'))
+            .with_signature(data.get('signature'))\
+            .with_version(Version.from_dict(data.get('version')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "versionName": self.version_name,
-            "version": self.version.to_dict() if self.version else None,
             "body": self.body,
             "signature": self.signature,
+            "version": self.version.to_dict() if self.version else None,
         }
 
 
@@ -424,8 +527,10 @@ class AcceptVersion(core.Gs2Model):
     version_name: str = None
     user_id: str = None
     version: Version = None
+    status: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_accept_version_id(self, accept_version_id: str) -> AcceptVersion:
         self.accept_version_id = accept_version_id
@@ -443,6 +548,10 @@ class AcceptVersion(core.Gs2Model):
         self.version = version
         return self
 
+    def with_status(self, status: str) -> AcceptVersion:
+        self.status = status
+        return self
+
     def with_created_at(self, created_at: int) -> AcceptVersion:
         self.created_at = created_at
         return self
@@ -451,6 +560,10 @@ class AcceptVersion(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> AcceptVersion:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -541,8 +654,10 @@ class AcceptVersion(core.Gs2Model):
             .with_version_name(data.get('versionName'))\
             .with_user_id(data.get('userId'))\
             .with_version(Version.from_dict(data.get('version')))\
+            .with_status(data.get('status'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -550,8 +665,10 @@ class AcceptVersion(core.Gs2Model):
             "versionName": self.version_name,
             "userId": self.user_id,
             "version": self.version.to_dict() if self.version else None,
+            "status": self.status,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -559,12 +676,15 @@ class VersionModel(core.Gs2Model):
     version_model_id: str = None
     name: str = None
     metadata: str = None
+    scope: str = None
+    type: str = None
+    current_version: Version = None
     warning_version: Version = None
     error_version: Version = None
-    scope: str = None
-    current_version: Version = None
+    schedule_versions: List[ScheduleVersion] = None
     need_signature: bool = None
     signature_key_id: str = None
+    approve_requirement: str = None
 
     def with_version_model_id(self, version_model_id: str) -> VersionModel:
         self.version_model_id = version_model_id
@@ -578,6 +698,18 @@ class VersionModel(core.Gs2Model):
         self.metadata = metadata
         return self
 
+    def with_scope(self, scope: str) -> VersionModel:
+        self.scope = scope
+        return self
+
+    def with_type(self, type: str) -> VersionModel:
+        self.type = type
+        return self
+
+    def with_current_version(self, current_version: Version) -> VersionModel:
+        self.current_version = current_version
+        return self
+
     def with_warning_version(self, warning_version: Version) -> VersionModel:
         self.warning_version = warning_version
         return self
@@ -586,12 +718,8 @@ class VersionModel(core.Gs2Model):
         self.error_version = error_version
         return self
 
-    def with_scope(self, scope: str) -> VersionModel:
-        self.scope = scope
-        return self
-
-    def with_current_version(self, current_version: Version) -> VersionModel:
-        self.current_version = current_version
+    def with_schedule_versions(self, schedule_versions: List[ScheduleVersion]) -> VersionModel:
+        self.schedule_versions = schedule_versions
         return self
 
     def with_need_signature(self, need_signature: bool) -> VersionModel:
@@ -602,6 +730,10 @@ class VersionModel(core.Gs2Model):
         self.signature_key_id = signature_key_id
         return self
 
+    def with_approve_requirement(self, approve_requirement: str) -> VersionModel:
+        self.approve_requirement = approve_requirement
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -679,72 +811,36 @@ class VersionModel(core.Gs2Model):
             .with_version_model_id(data.get('versionModelId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
+            .with_scope(data.get('scope'))\
+            .with_type(data.get('type'))\
+            .with_current_version(Version.from_dict(data.get('currentVersion')))\
             .with_warning_version(Version.from_dict(data.get('warningVersion')))\
             .with_error_version(Version.from_dict(data.get('errorVersion')))\
-            .with_scope(data.get('scope'))\
-            .with_current_version(Version.from_dict(data.get('currentVersion')))\
+            .with_schedule_versions(None if data.get('scheduleVersions') is None else [
+                ScheduleVersion.from_dict(data.get('scheduleVersions')[i])
+                for i in range(len(data.get('scheduleVersions')))
+            ])\
             .with_need_signature(data.get('needSignature'))\
-            .with_signature_key_id(data.get('signatureKeyId'))
+            .with_signature_key_id(data.get('signatureKeyId'))\
+            .with_approve_requirement(data.get('approveRequirement'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "versionModelId": self.version_model_id,
             "name": self.name,
             "metadata": self.metadata,
+            "scope": self.scope,
+            "type": self.type,
+            "currentVersion": self.current_version.to_dict() if self.current_version else None,
             "warningVersion": self.warning_version.to_dict() if self.warning_version else None,
             "errorVersion": self.error_version.to_dict() if self.error_version else None,
-            "scope": self.scope,
-            "currentVersion": self.current_version.to_dict() if self.current_version else None,
+            "scheduleVersions": None if self.schedule_versions is None else [
+                self.schedule_versions[i].to_dict() if self.schedule_versions[i] else None
+                for i in range(len(self.schedule_versions))
+            ],
             "needSignature": self.need_signature,
             "signatureKeyId": self.signature_key_id,
-        }
-
-
-class Version(core.Gs2Model):
-    major: int = None
-    minor: int = None
-    micro: int = None
-
-    def with_major(self, major: int) -> Version:
-        self.major = major
-        return self
-
-    def with_minor(self, minor: int) -> Version:
-        self.minor = minor
-        return self
-
-    def with_micro(self, micro: int) -> Version:
-        self.micro = micro
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[Version]:
-        if data is None:
-            return None
-        return Version()\
-            .with_major(data.get('major'))\
-            .with_minor(data.get('minor'))\
-            .with_micro(data.get('micro'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "major": self.major,
-            "minor": self.minor,
-            "micro": self.micro,
+            "approveRequirement": self.approve_requirement,
         }
 
 
@@ -753,14 +849,18 @@ class VersionModelMaster(core.Gs2Model):
     name: str = None
     description: str = None
     metadata: str = None
+    scope: str = None
+    type: str = None
+    current_version: Version = None
     warning_version: Version = None
     error_version: Version = None
-    scope: str = None
-    current_version: Version = None
+    schedule_versions: List[ScheduleVersion] = None
     need_signature: bool = None
     signature_key_id: str = None
+    approve_requirement: str = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_version_model_id(self, version_model_id: str) -> VersionModelMaster:
         self.version_model_id = version_model_id
@@ -778,6 +878,18 @@ class VersionModelMaster(core.Gs2Model):
         self.metadata = metadata
         return self
 
+    def with_scope(self, scope: str) -> VersionModelMaster:
+        self.scope = scope
+        return self
+
+    def with_type(self, type: str) -> VersionModelMaster:
+        self.type = type
+        return self
+
+    def with_current_version(self, current_version: Version) -> VersionModelMaster:
+        self.current_version = current_version
+        return self
+
     def with_warning_version(self, warning_version: Version) -> VersionModelMaster:
         self.warning_version = warning_version
         return self
@@ -786,12 +898,8 @@ class VersionModelMaster(core.Gs2Model):
         self.error_version = error_version
         return self
 
-    def with_scope(self, scope: str) -> VersionModelMaster:
-        self.scope = scope
-        return self
-
-    def with_current_version(self, current_version: Version) -> VersionModelMaster:
-        self.current_version = current_version
+    def with_schedule_versions(self, schedule_versions: List[ScheduleVersion]) -> VersionModelMaster:
+        self.schedule_versions = schedule_versions
         return self
 
     def with_need_signature(self, need_signature: bool) -> VersionModelMaster:
@@ -802,6 +910,10 @@ class VersionModelMaster(core.Gs2Model):
         self.signature_key_id = signature_key_id
         return self
 
+    def with_approve_requirement(self, approve_requirement: str) -> VersionModelMaster:
+        self.approve_requirement = approve_requirement
+        return self
+
     def with_created_at(self, created_at: int) -> VersionModelMaster:
         self.created_at = created_at
         return self
@@ -810,6 +922,10 @@ class VersionModelMaster(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> VersionModelMaster:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -888,14 +1004,21 @@ class VersionModelMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
+            .with_scope(data.get('scope'))\
+            .with_type(data.get('type'))\
+            .with_current_version(Version.from_dict(data.get('currentVersion')))\
             .with_warning_version(Version.from_dict(data.get('warningVersion')))\
             .with_error_version(Version.from_dict(data.get('errorVersion')))\
-            .with_scope(data.get('scope'))\
-            .with_current_version(Version.from_dict(data.get('currentVersion')))\
+            .with_schedule_versions(None if data.get('scheduleVersions') is None else [
+                ScheduleVersion.from_dict(data.get('scheduleVersions')[i])
+                for i in range(len(data.get('scheduleVersions')))
+            ])\
             .with_need_signature(data.get('needSignature'))\
             .with_signature_key_id(data.get('signatureKeyId'))\
+            .with_approve_requirement(data.get('approveRequirement'))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -903,14 +1026,21 @@ class VersionModelMaster(core.Gs2Model):
             "name": self.name,
             "description": self.description,
             "metadata": self.metadata,
+            "scope": self.scope,
+            "type": self.type,
+            "currentVersion": self.current_version.to_dict() if self.current_version else None,
             "warningVersion": self.warning_version.to_dict() if self.warning_version else None,
             "errorVersion": self.error_version.to_dict() if self.error_version else None,
-            "scope": self.scope,
-            "currentVersion": self.current_version.to_dict() if self.current_version else None,
+            "scheduleVersions": None if self.schedule_versions is None else [
+                self.schedule_versions[i].to_dict() if self.schedule_versions[i] else None
+                for i in range(len(self.schedule_versions))
+            ],
             "needSignature": self.need_signature,
             "signatureKeyId": self.signature_key_id,
+            "approveRequirement": self.approve_requirement,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
 
 
@@ -924,6 +1054,7 @@ class Namespace(core.Gs2Model):
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
+    revision: int = None
 
     def with_namespace_id(self, namespace_id: str) -> Namespace:
         self.namespace_id = namespace_id
@@ -961,6 +1092,10 @@ class Namespace(core.Gs2Model):
         self.updated_at = updated_at
         return self
 
+    def with_revision(self, revision: int) -> Namespace:
+        self.revision = revision
+        return self
+
     @classmethod
     def create_grn(
         cls,
@@ -1031,7 +1166,8 @@ class Namespace(core.Gs2Model):
             .with_check_version_trigger_script_id(data.get('checkVersionTriggerScriptId'))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
+            .with_updated_at(data.get('updatedAt'))\
+            .with_revision(data.get('revision'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -1044,4 +1180,5 @@ class Namespace(core.Gs2Model):
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
+            "revision": self.revision,
         }
\ No newline at end of file
