@@ -310,6 +310,350 @@ class DeleteNamespaceRequest(core.Gs2Request):
         }
 
 
+class GetServiceVersionRequest(core.Gs2Request):
+
+    context_stack: str = None
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetServiceVersionRequest]:
+        if data is None:
+            return None
+        return GetServiceVersionRequest()\
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+        }
+
+
+class DumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> DumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> DumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return DumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckDumpUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckDumpUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckDumpUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckDumpUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckDumpUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckCleanUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckCleanUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckCleanUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckCleanUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckCleanUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class PrepareImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> PrepareImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> PrepareImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PrepareImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return PrepareImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class ImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> ImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> ImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> ImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[ImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return ImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class CheckImportUserDataByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    user_id: str = None
+    upload_token: str = None
+    time_offset_token: str = None
+
+    def with_user_id(self, user_id: str) -> CheckImportUserDataByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_upload_token(self, upload_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.upload_token = upload_token
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> CheckImportUserDataByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CheckImportUserDataByUserIdRequest]:
+        if data is None:
+            return None
+        return CheckImportUserDataByUserIdRequest()\
+            .with_user_id(data.get('userId'))\
+            .with_upload_token(data.get('uploadToken'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "userId": self.user_id,
+            "uploadToken": self.upload_token,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
 class DescribeVersionModelMastersRequest(core.Gs2Request):
 
     context_stack: str = None
@@ -367,12 +711,15 @@ class CreateVersionModelMasterRequest(core.Gs2Request):
     name: str = None
     description: str = None
     metadata: str = None
+    scope: str = None
+    type: str = None
+    current_version: Version = None
     warning_version: Version = None
     error_version: Version = None
-    scope: str = None
-    current_version: Version = None
+    schedule_versions: List[ScheduleVersion] = None
     need_signature: bool = None
     signature_key_id: str = None
+    approve_requirement: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateVersionModelMasterRequest:
         self.namespace_name = namespace_name
@@ -390,6 +737,18 @@ class CreateVersionModelMasterRequest(core.Gs2Request):
         self.metadata = metadata
         return self
 
+    def with_scope(self, scope: str) -> CreateVersionModelMasterRequest:
+        self.scope = scope
+        return self
+
+    def with_type(self, type: str) -> CreateVersionModelMasterRequest:
+        self.type = type
+        return self
+
+    def with_current_version(self, current_version: Version) -> CreateVersionModelMasterRequest:
+        self.current_version = current_version
+        return self
+
     def with_warning_version(self, warning_version: Version) -> CreateVersionModelMasterRequest:
         self.warning_version = warning_version
         return self
@@ -398,12 +757,8 @@ class CreateVersionModelMasterRequest(core.Gs2Request):
         self.error_version = error_version
         return self
 
-    def with_scope(self, scope: str) -> CreateVersionModelMasterRequest:
-        self.scope = scope
-        return self
-
-    def with_current_version(self, current_version: Version) -> CreateVersionModelMasterRequest:
-        self.current_version = current_version
+    def with_schedule_versions(self, schedule_versions: List[ScheduleVersion]) -> CreateVersionModelMasterRequest:
+        self.schedule_versions = schedule_versions
         return self
 
     def with_need_signature(self, need_signature: bool) -> CreateVersionModelMasterRequest:
@@ -414,6 +769,10 @@ class CreateVersionModelMasterRequest(core.Gs2Request):
         self.signature_key_id = signature_key_id
         return self
 
+    def with_approve_requirement(self, approve_requirement: str) -> CreateVersionModelMasterRequest:
+        self.approve_requirement = approve_requirement
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -437,12 +796,18 @@ class CreateVersionModelMasterRequest(core.Gs2Request):
             .with_name(data.get('name'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
+            .with_scope(data.get('scope'))\
+            .with_type(data.get('type'))\
+            .with_current_version(Version.from_dict(data.get('currentVersion')))\
             .with_warning_version(Version.from_dict(data.get('warningVersion')))\
             .with_error_version(Version.from_dict(data.get('errorVersion')))\
-            .with_scope(data.get('scope'))\
-            .with_current_version(Version.from_dict(data.get('currentVersion')))\
+            .with_schedule_versions(None if data.get('scheduleVersions') is None else [
+                ScheduleVersion.from_dict(data.get('scheduleVersions')[i])
+                for i in range(len(data.get('scheduleVersions')))
+            ])\
             .with_need_signature(data.get('needSignature'))\
-            .with_signature_key_id(data.get('signatureKeyId'))
+            .with_signature_key_id(data.get('signatureKeyId'))\
+            .with_approve_requirement(data.get('approveRequirement'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -450,12 +815,18 @@ class CreateVersionModelMasterRequest(core.Gs2Request):
             "name": self.name,
             "description": self.description,
             "metadata": self.metadata,
+            "scope": self.scope,
+            "type": self.type,
+            "currentVersion": self.current_version.to_dict() if self.current_version else None,
             "warningVersion": self.warning_version.to_dict() if self.warning_version else None,
             "errorVersion": self.error_version.to_dict() if self.error_version else None,
-            "scope": self.scope,
-            "currentVersion": self.current_version.to_dict() if self.current_version else None,
+            "scheduleVersions": None if self.schedule_versions is None else [
+                self.schedule_versions[i].to_dict() if self.schedule_versions[i] else None
+                for i in range(len(self.schedule_versions))
+            ],
             "needSignature": self.need_signature,
             "signatureKeyId": self.signature_key_id,
+            "approveRequirement": self.approve_requirement,
         }
 
 
@@ -509,12 +880,15 @@ class UpdateVersionModelMasterRequest(core.Gs2Request):
     version_name: str = None
     description: str = None
     metadata: str = None
+    scope: str = None
+    type: str = None
+    current_version: Version = None
     warning_version: Version = None
     error_version: Version = None
-    scope: str = None
-    current_version: Version = None
+    schedule_versions: List[ScheduleVersion] = None
     need_signature: bool = None
     signature_key_id: str = None
+    approve_requirement: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateVersionModelMasterRequest:
         self.namespace_name = namespace_name
@@ -532,6 +906,18 @@ class UpdateVersionModelMasterRequest(core.Gs2Request):
         self.metadata = metadata
         return self
 
+    def with_scope(self, scope: str) -> UpdateVersionModelMasterRequest:
+        self.scope = scope
+        return self
+
+    def with_type(self, type: str) -> UpdateVersionModelMasterRequest:
+        self.type = type
+        return self
+
+    def with_current_version(self, current_version: Version) -> UpdateVersionModelMasterRequest:
+        self.current_version = current_version
+        return self
+
     def with_warning_version(self, warning_version: Version) -> UpdateVersionModelMasterRequest:
         self.warning_version = warning_version
         return self
@@ -540,12 +926,8 @@ class UpdateVersionModelMasterRequest(core.Gs2Request):
         self.error_version = error_version
         return self
 
-    def with_scope(self, scope: str) -> UpdateVersionModelMasterRequest:
-        self.scope = scope
-        return self
-
-    def with_current_version(self, current_version: Version) -> UpdateVersionModelMasterRequest:
-        self.current_version = current_version
+    def with_schedule_versions(self, schedule_versions: List[ScheduleVersion]) -> UpdateVersionModelMasterRequest:
+        self.schedule_versions = schedule_versions
         return self
 
     def with_need_signature(self, need_signature: bool) -> UpdateVersionModelMasterRequest:
@@ -556,6 +938,10 @@ class UpdateVersionModelMasterRequest(core.Gs2Request):
         self.signature_key_id = signature_key_id
         return self
 
+    def with_approve_requirement(self, approve_requirement: str) -> UpdateVersionModelMasterRequest:
+        self.approve_requirement = approve_requirement
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -579,12 +965,18 @@ class UpdateVersionModelMasterRequest(core.Gs2Request):
             .with_version_name(data.get('versionName'))\
             .with_description(data.get('description'))\
             .with_metadata(data.get('metadata'))\
+            .with_scope(data.get('scope'))\
+            .with_type(data.get('type'))\
+            .with_current_version(Version.from_dict(data.get('currentVersion')))\
             .with_warning_version(Version.from_dict(data.get('warningVersion')))\
             .with_error_version(Version.from_dict(data.get('errorVersion')))\
-            .with_scope(data.get('scope'))\
-            .with_current_version(Version.from_dict(data.get('currentVersion')))\
+            .with_schedule_versions(None if data.get('scheduleVersions') is None else [
+                ScheduleVersion.from_dict(data.get('scheduleVersions')[i])
+                for i in range(len(data.get('scheduleVersions')))
+            ])\
             .with_need_signature(data.get('needSignature'))\
-            .with_signature_key_id(data.get('signatureKeyId'))
+            .with_signature_key_id(data.get('signatureKeyId'))\
+            .with_approve_requirement(data.get('approveRequirement'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -592,12 +984,18 @@ class UpdateVersionModelMasterRequest(core.Gs2Request):
             "versionName": self.version_name,
             "description": self.description,
             "metadata": self.metadata,
+            "scope": self.scope,
+            "type": self.type,
+            "currentVersion": self.current_version.to_dict() if self.current_version else None,
             "warningVersion": self.warning_version.to_dict() if self.warning_version else None,
             "errorVersion": self.error_version.to_dict() if self.error_version else None,
-            "scope": self.scope,
-            "currentVersion": self.current_version.to_dict() if self.current_version else None,
+            "scheduleVersions": None if self.schedule_versions is None else [
+                self.schedule_versions[i].to_dict() if self.schedule_versions[i] else None
+                for i in range(len(self.schedule_versions))
+            ],
             "needSignature": self.need_signature,
             "signatureKeyId": self.signature_key_id,
+            "approveRequirement": self.approve_requirement,
         }
 
 
@@ -787,6 +1185,7 @@ class DescribeAcceptVersionsByUserIdRequest(core.Gs2Request):
     user_id: str = None
     page_token: str = None
     limit: int = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeAcceptVersionsByUserIdRequest:
         self.namespace_name = namespace_name
@@ -804,6 +1203,10 @@ class DescribeAcceptVersionsByUserIdRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DescribeAcceptVersionsByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -826,7 +1229,8 @@ class DescribeAcceptVersionsByUserIdRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
             .with_page_token(data.get('pageToken'))\
-            .with_limit(data.get('limit'))
+            .with_limit(data.get('limit'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -834,6 +1238,7 @@ class DescribeAcceptVersionsByUserIdRequest(core.Gs2Request):
             "userId": self.user_id,
             "pageToken": self.page_token,
             "limit": self.limit,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -843,6 +1248,7 @@ class AcceptRequest(core.Gs2Request):
     namespace_name: str = None
     version_name: str = None
     access_token: str = None
+    version: Version = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> AcceptRequest:
@@ -857,6 +1263,10 @@ class AcceptRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
+    def with_version(self, version: Version) -> AcceptRequest:
+        self.version = version
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> AcceptRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -882,13 +1292,15 @@ class AcceptRequest(core.Gs2Request):
         return AcceptRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_version_name(data.get('versionName'))\
-            .with_access_token(data.get('accessToken'))
+            .with_access_token(data.get('accessToken'))\
+            .with_version(Version.from_dict(data.get('version')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "versionName": self.version_name,
             "accessToken": self.access_token,
+            "version": self.version.to_dict() if self.version else None,
         }
 
 
@@ -898,6 +1310,8 @@ class AcceptByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     version_name: str = None
     user_id: str = None
+    version: Version = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> AcceptByUserIdRequest:
@@ -912,6 +1326,14 @@ class AcceptByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_version(self, version: Version) -> AcceptByUserIdRequest:
+        self.version = version
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> AcceptByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> AcceptByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -937,13 +1359,148 @@ class AcceptByUserIdRequest(core.Gs2Request):
         return AcceptByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_version_name(data.get('versionName'))\
-            .with_user_id(data.get('userId'))
+            .with_user_id(data.get('userId'))\
+            .with_version(Version.from_dict(data.get('version')))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "versionName": self.version_name,
             "userId": self.user_id,
+            "version": self.version.to_dict() if self.version else None,
+            "timeOffsetToken": self.time_offset_token,
+        }
+
+
+class RejectRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    version_name: str = None
+    access_token: str = None
+    version: Version = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> RejectRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_version_name(self, version_name: str) -> RejectRequest:
+        self.version_name = version_name
+        return self
+
+    def with_access_token(self, access_token: str) -> RejectRequest:
+        self.access_token = access_token
+        return self
+
+    def with_version(self, version: Version) -> RejectRequest:
+        self.version = version
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> RejectRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RejectRequest]:
+        if data is None:
+            return None
+        return RejectRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_version_name(data.get('versionName'))\
+            .with_access_token(data.get('accessToken'))\
+            .with_version(Version.from_dict(data.get('version')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "versionName": self.version_name,
+            "accessToken": self.access_token,
+            "version": self.version.to_dict() if self.version else None,
+        }
+
+
+class RejectByUserIdRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+    version_name: str = None
+    user_id: str = None
+    version: Version = None
+    time_offset_token: str = None
+    duplication_avoider: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> RejectByUserIdRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def with_version_name(self, version_name: str) -> RejectByUserIdRequest:
+        self.version_name = version_name
+        return self
+
+    def with_user_id(self, user_id: str) -> RejectByUserIdRequest:
+        self.user_id = user_id
+        return self
+
+    def with_version(self, version: Version) -> RejectByUserIdRequest:
+        self.version = version
+        return self
+
+    def with_time_offset_token(self, time_offset_token: str) -> RejectByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
+    def with_duplication_avoider(self, duplication_avoider: str) -> RejectByUserIdRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[RejectByUserIdRequest]:
+        if data is None:
+            return None
+        return RejectByUserIdRequest()\
+            .with_namespace_name(data.get('namespaceName'))\
+            .with_version_name(data.get('versionName'))\
+            .with_user_id(data.get('userId'))\
+            .with_version(Version.from_dict(data.get('version')))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+            "versionName": self.version_name,
+            "userId": self.user_id,
+            "version": self.version.to_dict() if self.version else None,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1003,6 +1560,7 @@ class GetAcceptVersionByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     version_name: str = None
+    time_offset_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetAcceptVersionByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1016,6 +1574,10 @@ class GetAcceptVersionByUserIdRequest(core.Gs2Request):
         self.version_name = version_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> GetAcceptVersionByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1037,13 +1599,15 @@ class GetAcceptVersionByUserIdRequest(core.Gs2Request):
         return GetAcceptVersionByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_version_name(data.get('versionName'))
+            .with_version_name(data.get('versionName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "versionName": self.version_name,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1108,6 +1672,7 @@ class DeleteAcceptVersionByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     version_name: str = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteAcceptVersionByUserIdRequest:
@@ -1122,6 +1687,10 @@ class DeleteAcceptVersionByUserIdRequest(core.Gs2Request):
         self.version_name = version_name
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> DeleteAcceptVersionByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> DeleteAcceptVersionByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1147,13 +1716,15 @@ class DeleteAcceptVersionByUserIdRequest(core.Gs2Request):
         return DeleteAcceptVersionByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_version_name(data.get('versionName'))
+            .with_version_name(data.get('versionName'))\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
             "versionName": self.version_name,
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1202,18 +1773,18 @@ class CheckVersionRequest(core.Gs2Request):
         return CheckVersionRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_access_token(data.get('accessToken'))\
-            .with_target_versions([
+            .with_target_versions(None if data.get('targetVersions') is None else [
                 TargetVersion.from_dict(data.get('targetVersions')[i])
-                for i in range(len(data.get('targetVersions')) if data.get('targetVersions') else 0)
+                for i in range(len(data.get('targetVersions')))
             ])
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "accessToken": self.access_token,
-            "targetVersions": [
+            "targetVersions": None if self.target_versions is None else [
                 self.target_versions[i].to_dict() if self.target_versions[i] else None
-                for i in range(len(self.target_versions) if self.target_versions else 0)
+                for i in range(len(self.target_versions))
             ],
         }
 
@@ -1224,6 +1795,7 @@ class CheckVersionByUserIdRequest(core.Gs2Request):
     namespace_name: str = None
     user_id: str = None
     target_versions: List[TargetVersion] = None
+    time_offset_token: str = None
     duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CheckVersionByUserIdRequest:
@@ -1238,6 +1810,10 @@ class CheckVersionByUserIdRequest(core.Gs2Request):
         self.target_versions = target_versions
         return self
 
+    def with_time_offset_token(self, time_offset_token: str) -> CheckVersionByUserIdRequest:
+        self.time_offset_token = time_offset_token
+        return self
+
     def with_duplication_avoider(self, duplication_avoider: str) -> CheckVersionByUserIdRequest:
         self.duplication_avoider = duplication_avoider
         return self
@@ -1263,19 +1839,21 @@ class CheckVersionByUserIdRequest(core.Gs2Request):
         return CheckVersionByUserIdRequest()\
             .with_namespace_name(data.get('namespaceName'))\
             .with_user_id(data.get('userId'))\
-            .with_target_versions([
+            .with_target_versions(None if data.get('targetVersions') is None else [
                 TargetVersion.from_dict(data.get('targetVersions')[i])
-                for i in range(len(data.get('targetVersions')) if data.get('targetVersions') else 0)
-            ])
+                for i in range(len(data.get('targetVersions')))
+            ])\
+            .with_time_offset_token(data.get('timeOffsetToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
             "userId": self.user_id,
-            "targetVersions": [
+            "targetVersions": None if self.target_versions is None else [
                 self.target_versions[i].to_dict() if self.target_versions[i] else None
-                for i in range(len(self.target_versions) if self.target_versions else 0)
+                for i in range(len(self.target_versions))
             ],
+            "timeOffsetToken": self.time_offset_token,
         }
 
 
@@ -1401,20 +1979,66 @@ class GetCurrentVersionMasterRequest(core.Gs2Request):
         }
 
 
+class PreUpdateCurrentVersionMasterRequest(core.Gs2Request):
+
+    context_stack: str = None
+    namespace_name: str = None
+
+    def with_namespace_name(self, namespace_name: str) -> PreUpdateCurrentVersionMasterRequest:
+        self.namespace_name = namespace_name
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[PreUpdateCurrentVersionMasterRequest]:
+        if data is None:
+            return None
+        return PreUpdateCurrentVersionMasterRequest()\
+            .with_namespace_name(data.get('namespaceName'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "namespaceName": self.namespace_name,
+        }
+
+
 class UpdateCurrentVersionMasterRequest(core.Gs2Request):
 
     context_stack: str = None
     namespace_name: str = None
+    mode: str = None
     settings: str = None
+    upload_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateCurrentVersionMasterRequest:
         self.namespace_name = namespace_name
         return self
 
+    def with_mode(self, mode: str) -> UpdateCurrentVersionMasterRequest:
+        self.mode = mode
+        return self
+
     def with_settings(self, settings: str) -> UpdateCurrentVersionMasterRequest:
         self.settings = settings
         return self
 
+    def with_upload_token(self, upload_token: str) -> UpdateCurrentVersionMasterRequest:
+        self.upload_token = upload_token
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1435,12 +2059,16 @@ class UpdateCurrentVersionMasterRequest(core.Gs2Request):
             return None
         return UpdateCurrentVersionMasterRequest()\
             .with_namespace_name(data.get('namespaceName'))\
-            .with_settings(data.get('settings'))
+            .with_mode(data.get('mode'))\
+            .with_settings(data.get('settings'))\
+            .with_upload_token(data.get('uploadToken'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "namespaceName": self.namespace_name,
+            "mode": self.mode,
             "settings": self.settings,
+            "uploadToken": self.upload_token,
         }
 
 
